@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,7 +18,6 @@
  */
 ///@cond DOXYGEN_HIDDEN
 
-
 #ifndef Bfs_H
 #define Bfs_H
 
@@ -29,22 +28,19 @@ namespace tlp {
 class Graph;
 class BooleanProperty;
 class TLP_SCOPE Bfs {
-public :
-
-  Bfs(Graph * G, BooleanProperty* resultatAlgoSelection);
+public:
+  Bfs(Graph *G, BooleanProperty *resultatAlgoSelection);
   ~Bfs();
 
   Graph *graph;
 
-private :
-
-  void computeBfs(Graph * G, BooleanProperty* resultatAlgoSelection, node root);
+private:
+  void computeBfs(Graph *G, BooleanProperty *resultatAlgoSelection, node root);
 
   unsigned int nbNodes;
   MutableContainer<bool> selectedNodes;
   MutableContainer<bool> selectedEdges;
-
 };
-}
+} // namespace tlp
 #endif
 ///@endcond
