@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,270 +18,343 @@
  */
 ///@cond DOXYGEN_HIDDEN
 
-
 #ifndef GRAPHSTORAGE_H
 #define GRAPHSTORAGE_H
+#include <cstring>
 #include <cassert>
 #include <vector>
 
 #include <tulip/Node.h>
 #include <tulip/Edge.h>
 #include <tulip/IdManager.h>
-#include <tulip/SimpleVector.h>
-#include <tulip/MutableContainer.h>
 
 namespace tlp {
 
+class Graph;
+
 //===========================================
 /**
-  * @class GraphStorageIdsMemento
-  * @brief that class provides a simple interface
-  * to save the state of the ids manage by the GraphStorage class
-  */
+ * @class GraphStorageIdsMemento
+ * @brief that class provides a simple interface
+ * to save the state of the ids manage by the GraphStorage class
+ */
 class GraphStorageIdsMemento {
 public:
   virtual ~GraphStorageIdsMemento() {}
 };
 //===========================================
 /**
-  * @class GraphStorage
-  * @brief That class provide a simple implementation
-  * for the storage of graph  elts (nodes edges)
-  */
+ * @class GraphStorage
+ * @brief That class provide a simple implementation
+ * for the storage of graph elts (nodes edges)
+ */
 class GraphStorage {
 public:
   //=======================================================
   void clear();
   //=======================================================
-  GraphStorage();
-  //=======================================================
-  ~GraphStorage();
-  //=======================================================
   /**
    * @brief Return true if n belongs to the graph
    */
-  bool isElement(const node n) const;
+  inline bool isElement(const node n) const {
+    return nodeIds.isElement(n);
+  }
+  //=======================================================
+  /**
+   * @brief Return the number of nodes in the graph
+   */
+  inline unsigned int numberOfNodes() const {
+    return nodeIds.size();
+  }
   //=======================================================
   /**
    * @brief Return true if e belongs to the graph
    */
-  bool isElement(const edge e) const;
+  inline bool isElement(const edge e) const {
+    return edgeIds.isElement(e);
+  }
+  //=======================================================
+  /**
+   * @brief Return the number of edges in the graph
+   */
+  inline unsigned int numberOfEdges() const {
+    return edgeIds.size();
+  }
   //=======================================================
   /**
    * @brief Enables to reserve memory for nbNodes
    * Reserving memory before to addNode enable to reduce the number of vector resizing and then
    * to speed up significantly construction of graphs.
    */
-  void reserveNodes(size_t nb);
+  void reserveNodes(const size_t nb);
   //=======================================================
   /**
    * @brief Enables to reserve memory for nbEdges
    * Reserving memory before to addEdge enable to reduce the number of vector resizing and then
    * to speed up significantly construction of graphs.
-    */
-  void reserveEdges(size_t nb);
+   */
+  void reserveEdges(const size_t nb);
   //=======================================================
   /**
    * @brief Enables to reserve memory for adjacency nodes
    * Reserving memory before to addEdge enable to reduce the number of vector resizing and then
    * to speed up significantly construction of graphs.
    */
-  void reserveAdj(node n, size_t nb);
+  void reserveAdj(const node n, const size_t nb);
   //=======================================================
   /**
    * @brief Enables to reserve memory for adjacency nodes
    * Reserving memory before to addEdge enable to reduce the number of vector resizing and then
    * to speed up significantly construction of graphs.
    */
-  void reserveAdj(size_t nb);
+  void reserveAdj(const size_t nb);
   //=======================================================
   /**
    * @brief restore adjacency edges of a given node
    */
-  void restoreAdj(node n, const std::vector<edge>& edges);
+  void restoreAdj(const node n, const std::vector<edge> &edges);
+  //=======================================================
+  /**
+   * @brief return the adjacency edges of a given node
+   */
+  inline const std::vector<edge> &adj(const node n) const {
+    assert(isElement(n));
+    return nodeData[n.id].edges;
+  }
   //=======================================================
   /**
    * @brief Return the first node of graph
    */
-  node getOneNode() const;
+  inline node getOneNode() const {
+    return numberOfNodes() ? nodeIds[0] : node();
+  }
   //=======================================================
   /**
    * @brief Return a Tulip Iterator on nodes of the graph
    * @warning: The returned iterator should be deleted by the caller to prevent memory leaks
    * @complexity: o(1)
    */
-  Iterator<node>* getNodes() const;
+  inline Iterator<node> *getNodes() const {
+    return nodeIds.getElts();
+  }
   //=======================================================
   /**
    * @brief Return the current state of the ids management
    * must be deleted by the caller
    * this can be used for push/pop
    */
-  const GraphStorageIdsMemento* getIdsMemento();
+  const GraphStorageIdsMemento *getIdsMemento() const;
   //=======================================================
   /**
    * @brief  restore a state of the ids management
    */
-  void restoreIdsMemento(const GraphStorageIdsMemento*);
+  void restoreIdsMemento(const GraphStorageIdsMemento *);
   //=======================================================
   /**
    * @brief Return a Tulip Iterator on edges of the graph
    * @warning: The returned iterator should be deleted by the caller to prevent memory leaks
    */
-  Iterator<edge>* getEdges() const;
+  inline Iterator<edge> *getEdges() const {
+    return edgeIds.getElts();
+  }
   //=======================================================
   /**
    * @brief Return a Tulip Iterator on adjacent edges of the node n
    * @warning: be careful that loops appear twice
    * @warning: The returned iterator should be deleted by the caller to prevent memory leaks
    */
-  Iterator<edge>* getInOutEdges(node n) const;
-  //=======================================================
-  /**
-   * @brief get adjacency edges of a given node
-   */
-  void getInOutEdges(node n, std::vector<edge>& edges,
-                     bool loopsOnlyOnce = false) const;
+  Iterator<edge> *getInOutEdges(const node n) const;
   //=======================================================
   /**
    * @brief Return a Tulip Iterator on out edges of the node n
    * @warning: The returned iterator must be deleted by the caller to prevent memory leaks
    */
-  Iterator<edge>* getOutEdges(node n) const;
+  Iterator<edge> *getOutEdges(const node n) const;
   //=======================================================
   /**
    * @brief Return a Tulip Iterator on in edges of the node n
    * @warning: The returned iterator must be deleted by the caller to prevent memory leaks
    */
-  Iterator<edge>* getInEdges(node n) const;
+  Iterator<edge> *getInEdges(const node n) const;
   //=======================================================
   /**
-   * @brief Returns if edges exist between two nodes
-   * @param source The source of the hypothetical edges.
-   * @param target The target of the hypothetical edges.
+   * @brief Return if edges exist between two nodes
+   * @param src The source of the hypothetical edges.
+   * @param tgt The target of the hypothetical edges.
    * @param directed When set to false edges from target to source are also considered
    * @param edges The vector of edges to fill up with the edges found
+   * @param the subgraph owning the edges
    * @param onlyFirst If true only the first edge found will be returned
    * @return true if an edge has been bound
    */
-  bool getEdges(const node source, const node target, bool directed,
-                std::vector<edge>& edges, bool onlyFirst = false) const;
+  bool getEdges(const node src, const node tgt, bool directed, std::vector<edge> &edges,
+                const Graph *sg = nullptr, bool onlyFirst = false) const;
 
   //=======================================================
   /**
    * @brief Return a Tulip Iterator on adjacent nodes of the node n
    * @warning: The returned iterator must be deleted by the caller to prevent memory leaks
    */
-  Iterator<node>* getInOutNodes(node n) const;
+  Iterator<node> *getInOutNodes(const node n) const;
   //=======================================================
   /**
    * @brief Return a Tulip Iterator on in nodes of the node n
    * @warning: The returned iterator must be deleted by the caller to prevent memory leaks
    */
-  Iterator<node>* getInNodes(node n) const;
+  Iterator<node> *getInNodes(const node n) const;
   //=======================================================
   /**
    * @brief Return a Tulip Iterator on out nodes of the node n
    * @warning: The returned iterator must be deleted by the caller to prevent memory leaks
    */
-  Iterator<node>* getOutNodes(node n) const;
+  Iterator<node> *getOutNodes(const node n) const;
   //=======================================================
   /**
    * @brief Return the degree of a node
    */
-  unsigned int deg(node n) const;
+  inline unsigned int deg(const node n) const {
+    assert(isElement(n));
+    return nodeData[n.id].edges.size();
+  }
   //=======================================================
   /**
    * @brief Return the out degree of a node
    */
-  unsigned int outdeg(node n) const;
+  inline unsigned int outdeg(const node n) const {
+    assert(isElement(n));
+    return nodeData[n.id].outDegree;
+  }
   //=======================================================
   /**
    * @brief Return the in degree of a node
    */
-  unsigned int indeg(node n) const;
+  inline unsigned int indeg(const node n) const {
+    assert(isElement(n));
+    const NodeData &ctnr = nodeData[n.id];
+    return ctnr.edges.size() - ctnr.outDegree;
+  }
   //=======================================================
   /**
-   * @brief Return the number of edges in the graph
+   * @brief Return the edges of the graph
    */
-  unsigned int numberOfEdges() const;
+  inline const std::vector<edge> &edges() const {
+    return edgeIds;
+  }
   //=======================================================
   /**
-   * @brief Return the number of nodes in the graph
+   * @brief Return the position of an edge in the edges of the graph
    */
-  unsigned int numberOfNodes() const;
+  inline unsigned int edgePos(const edge e) const {
+    return edgeIds.getPos(e);
+  }
+  //=======================================================
+  /**
+   * @brief Return the nodes of the graph
+   */
+  inline const std::vector<node> &nodes() const {
+    return nodeIds;
+  }
+  //=======================================================
+  /**
+   * @brief Return the position of a node in the nodes of the graph
+   */
+  inline unsigned int nodePos(const node n) const {
+    return nodeIds.getPos(n);
+  }
   //=======================================================
   /**
    * @brief Return the extremities of an edge (src, target)
    */
-  const std::pair<node, node>& ends(const edge e) const;
+  inline const std::pair<node, node> &ends(const edge e) const {
+    assert(isElement(e));
+    return edgeEnds[e.id];
+  }
   //=======================================================
   /**
    * @brief return the first extremity (considered as source if the graph is directed) of an edge
    */
-  node source(edge e) const;
+  inline node source(const edge e) const {
+    assert(isElement(e));
+    return edgeEnds[e.id].first;
+  }
   //=======================================================
   /**
    * @brief return the second extremity (considered as target if the graph is directed) of an edge
    */
-  node target(edge e) const;
+  inline node target(const edge e) const {
+    assert(isElement(e));
+    return edgeEnds[e.id].second;
+  }
   //=======================================================
   /**
    * @brief return the opposite node of n through edge e
    */
-  node opposite(edge e, node n) const;
+  inline node opposite(const edge e, const node n) const {
+    assert(isElement(e));
+    const std::pair<node, node> &eEnds = edgeEnds[e.id];
+    assert((eEnds.first == n) || (eEnds.second == n));
+    return (eEnds.first == n) ? eEnds.second : eEnds.first;
+  }
+
   //=======================================================
   /**
    * @brief Reconnect the edge e to have the new given ends
-   * @warning That operation modify the array of neighboors of extrmities of edges, thus
-   * it devalidates iterators on adjacency for the nodes at the extremities of the modified edges and nodes.
+   * @warning That operation modifies the array of neighboors of extrmities of edges, thus
+   * it invalidates iterators on adjacency for the nodes at the extremities of the modified edges
+   * and nodes.
    */
   void setEnds(const edge e, const node newSrc, const node newTgt);
   //=======================================================
   /**
    * @brief change the source of an edge
-   * @warning That operation modify the array of neighboors of extrmities of edges, thus
-   * it devalidates iterators on adjacency for the nodes at the extremities of the modified edges and nodes.
+   * @warning That operation modifies the array of neighboors of extrmities of edges, thus
+   * it invalidates iterators on adjacency for the nodes at the extremities of the modified edges
+   * and nodes.
    * \see setEnds
    */
-  void setSource(const edge e, const node n);
+  inline void setSource(const edge e, const node n) {
+    setEnds(e, n, node());
+  }
   //=======================================================
   /**
    * @brief change the target of an edge
-   * @warning That operation modify the array of neighboors of extrmities of edges, thus
-   * it devalidates iterators on adjacency for the nodes at the extremities of the modified edges and nodes.
+   * @warning That operation modifies the array of neighboors of extremities of edges, thus
+   * it invalidates iterators on adjacency for the nodes at the extremities of the modified edges
+   * and nodes.
    * \see setEnds
    */
-  void setTarget(const edge e, const node n);
+  inline void setTarget(const edge e, const node n) {
+    setEnds(e, node(), n);
+  }
   //=======================================================
   /**
-   * @brief Reverse an edge e, source become target and target become soure
+   * @brief Reverse an edge e, source becomes target and target becomes source
    */
   void reverse(const edge e);
   //=======================================================
   /**
    * \brief Set the ordering of edges around n according to their order in v.
    */
-  void setEdgeOrder(const node n, const std::vector<edge> &v );
+  void setEdgeOrder(const node n, const std::vector<edge> &v);
   //=======================================================
   /**
-   * \brief swap to edge in the ordered adjacency vector
+   * \brief swap two edges in the ordered adjacency vector
    * \warning the two edges must be element of star(v)
    */
   void swapEdgeOrder(const node n, const edge e1, const edge e2);
   //=======================================================
   /**
    * @brief Add the given node in the structure and return it
-   * @warning: That operation modify the array of nodes
-   * and thus devalidate all iterators on it.
+   * @warning: That operation modifies the array of nodes
+   * and thus invalidates all iterators on it.
    * @complexity: o(1)
    */
-  node addNode(node n);
+  void restoreNode(const node n);
   //=======================================================
   /**
    * @brief Add a new node in the structure and return it
-   * @warning: That operation modify the array of nodes
-   * and thus devalidate all iterators on it.
+   * @warning: That operation modifies the array of nodes
+   * and thus invalidates all iterators on it.
    * @complexity: o(1)
    */
   node addNode();
@@ -289,143 +362,128 @@ public:
   /**
    * @brief Add nb new nodes in the structure and returns them
    * in the addedNodes vector
-   * @warning: That operation modify the array of nodes
-   * and thus devalidate all iterators on it. The addedNodes vector
+   * @warning: That operation modifies the array of nodes
+   * and thus invalidates all iterators on it. The addedNodes vector
    * is cleared before adding nodes
    * @complexity: o(1)
    */
-  void addNodes(unsigned int nb, std::vector<node>* addedNodes = NULL);
-  //=======================================================
-  /**
-   * @brief Add the given nodes in the structure
-   * @warning: That operation modify the array of nodes
-   * and thus devalidate all iterators on it.
-   * @complexity: o(1)
-   */
-  void restoreNodes(const std::vector<node>& addedNodes);
+  void addNodes(unsigned int nb, std::vector<node> *addedNodes = nullptr);
   //=======================================================
   /**
    * @brief remove a node from the nodes structure only
-   * @warning That operation modify the array of nodes
-   * and thus devalidate all iterators on it.
+   * @warning That operation modifies the array of nodes
+   * and thus invalidates all iterators on it.
    * @complexity: o(1)
    */
   void removeFromNodes(const node n);
   //=======================================================
   /**
    * @brief Delete a node and all its adjacent edges in the graph
-   * @warning That operation modify the array of nodes and the array of edges
-   * and thus devalidate all iterators on it.
-   * @warning That operation modify the array of neighboors of extrmities of edges, thus
-   * it devalidates iterators on adjacency for the nodes at the extremities od the deleted edges.
+   * @warning That operation modifies the array of nodes and the array of edges
+   * and thus invalidates all iterators on it.
+   * @warning That operation modifies the array of neighboors of extrmities of edges, thus
+   * it invalidates iterators on adjacency for the nodes at the extremities od the deleted edges.
    * @warning Orders of edges in the extremities of the deleted edges are affected
    * @complexity: o(1)
    */
-  void delNode(node n);
+  void delNode(const node n);
   //=======================================================
   /**
-   * @brief Add the given edge between src and tgt and return it
+   * @brief restore the given edge between src and tgt and return it
    * the last argument indicates if the edge has to be added
    * in the adjacency edges of its two ends
-   * @warning That operation modify the array of edges and
+   * @warning That operation modifies the array of edges and
    * the adjacency edges of its ends thus any iterators existing for
-   * these structures will be devalidated.
+   * these structures will be invalidated.
    */
-  edge addEdge(const node src, const node tgt,
-               const edge e, bool updateEndsEdges);
+  void restoreEdge(const node src, const node tgt, const edge e);
   //=======================================================
   /**
    * @brief Add a new edge between src and tgt and return it
-   * @warning That operation modify the array of edges and
+   * @warning That operation modifies the array of edges and
    * the adjacency edges of its ends thus any iterators existing for
-   * these structures will be devalidated.
+   * these structures will be invalidated.
    */
-  edge addEdge(node src, node tgt);
+  edge addEdge(const node src, const node tgt);
   //=======================================================
   /**
    * @brief Add edges in the structure and returns them
    * in the addedEdges vector
-   * @warning: That operation modify the array of edges and
+   * @warning: That operation modifies the array of edges and
    * the adjacency edges of its ends thus any iterators existing for
-   * these structures will be devalidated.
+   * these structures will be invalidated.
    */
-  void addEdges(const std::vector<std::pair<node, node> >& edges,
-                std::vector<edge>* addedEdges = NULL);
+  void addEdges(const std::vector<std::pair<node, node>> &edges,
+                std::vector<edge> *addedEdges = nullptr);
   //=======================================================
-  /**
-   * @brief restore edges in the structure and returns them
-   * in the addedEdges vector
-   * @warning: That operation modify the array of edges
-   * thus any iterators existing for
-   * these structures will be devalidated.
-   */
-  void restoreEdges(const std::vector<edge>& edgesToRestore,
-                    const std::vector<std::pair<node, node> >& ends);
-//=======================================================
   /**
    * @brief Delete an edge in the graph
-   * @warning: That operation modify the array of edges
-   * and thus devalidate all iterators on it.
-   * @warning That operation modify the array of neighboors of extremities of the edge e, thus
-   * it devalidates iterators on adjacency for the nodes at the extremities od the deleted edge.
+   * @warning: That operation modifies the array of edges
+   * and thus invalidates all iterators on it.
+   * @warning That operation modifies the array of neighboors of extremities of the edge e, thus
+   * it invalidates iterators on adjacency for the nodes at the extremities od the deleted edge.
    * @warning Orders of edges in the extremities of the deleted edge are affected
    */
-  void delEdge(edge e);
+  void delEdge(const edge e);
   //=======================================================
   /**
    * @brief Delete all edges in the graph
-   * @warning: That operation modify the array of edges and all arrays of nodes
-   * and thus devalidate all iterators, only graph nodes iterators are not affected.
+   * @warning: That operation modifies the array of edges and all arrays of nodes
+   * and thus invalidates all iterators, only graph nodes iterators are not affected.
    */
   void delAllEdges();
   //=======================================================
   /**
    * @brief Delete all nodes in the graph
-   * @warning: That operation modify the array of edges and all arrays of nodes
-   * and thus devalidate all iterators.
+   * @warning: That operation modifies the array of edges and all arrays of nodes
+   * and thus invalidates all iterators.
    */
   void delAllNodes();
   //=======================================================
-private :
+  /**
+   * @brief sort the graph elements in ascending order
+   * @warning: That operation modifies the vector of nodes and the vector of edges
+   * and thus invalidates all iterators.
+   */
+  inline void sortElts() {
+    nodeIds.sort();
+    edgeIds.sort();
+  }
+  //=======================================================
+private:
   // specific types
-  typedef SimpleVector<edge> EdgeVector;
-
-  struct EdgeContainer {
-    EdgeVector edges;
+  struct NodeData {
+    std::vector<edge> edges;
     unsigned int outDegree;
 
-    EdgeContainer():outDegree(0) {}
+    NodeData() : outDegree(0) {}
   };
-  typedef std::vector<EdgeContainer> Nodes;
-  typedef std::vector<std::pair< node , node > > Edges;
 
   // data members
-  mutable Edges edges;
-  mutable Nodes nodes;
-  IdManager nodeIds;
-  IdManager edgeIds;
-  unsigned int nbNodes;
-  unsigned int nbEdges;
+  mutable std::vector<std::pair<node, node>> edgeEnds;
+  mutable std::vector<NodeData> nodeData;
+  IdContainer<node> nodeIds;
+  IdContainer<edge> edgeIds;
 
   // member functions below do not belong to the public API
   // they are just needed by the current implementation
   //=======================================================
   /**
-   * @brief remove an edge from an EdgeContainer
-   * @warning That operation modify the EdgeContainer
-   * and thus devalidate all iterators on it.
+   * @brief remove an edge from an NodeData
+   * @warning That operation modifies the NodeData
+   * and thus invalidates all iterators on it.
    */
-  static void removeFromEdgeContainer(EdgeContainer &c, const edge e);
+  static void removeFromNodeData(NodeData &c, const edge e);
   //=======================================================
   /**
    * @brief remove an edge from the edges structure
-   * and from the EdgeContainer of its ends
+   * and from the NodeData of its ends
    * except for the end node in argument if it is valid
-   * @warning That operation modify the array of edges
-   * and thus devalidate all iterators on it.
+   * @warning That operation modifies the array of edges
+   * and thus invalidates all iterators on it.
    */
   void removeFromEdges(const edge e, node end = node());
 };
-}
+} // namespace tlp
 #endif // GRAPHSTORAGE_H
 ///@endcond
