@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -27,13 +27,12 @@ namespace tlp {
  * @ingroup Plugins
  * @brief A simple implementation of tlp::PluginLoader to display load state into the console
  */
-struct TLP_SCOPE PluginLoaderTxt:public PluginLoader {
-  virtual void start(const std::string &path);
-  virtual void loading(const std::string &filename);
-  virtual void loaded(const Plugin* infos, const std::list <Dependency>&);
-  virtual void aborted(const std::string &filename,const  std::string &erreurmsg);
-  virtual void finished(bool state,const std::string &msg);
+struct TLP_SCOPE PluginLoaderTxt : public PluginLoader {
+  void start(const std::string &path) override;
+  void loading(const std::string &filename) override;
+  void loaded(const Plugin *info, const std::list<Dependency> &) override;
+  void aborted(const std::string &filename, const std::string &erreurmsg) override;
+  void finished(bool state, const std::string &msg) override;
 };
-
-}
+} // namespace tlp
 #endif
