@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -34,11 +34,12 @@ namespace tlp {
 class TLP_SCOPE TulipException : public std::exception {
 public:
   TulipException(const std::string &desc);
-  virtual ~TulipException() throw ();
-  virtual const char* what() const throw();
+  ~TulipException() throw() override;
+  const char *what() const throw() override;
+
 private:
   std::string desc;
 };
-}
+} // namespace tlp
 #endif // TULIPEXCEPTION
 ///@endcond
