@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -16,16 +16,18 @@
  * See the GNU General Public License for more details.
  *
  */
+
 ///@cond DOXYGEN_HIDDEN
 
-#ifndef __TULIPPLUGININCLUDE_H
-#define __TULIPPLUGININCLUDE_H
+#ifndef TULIP_PLUGIN_HEADERS_H
+#define TULIP_PLUGIN_HEADERS_H
 
 #include <tulip/DoubleProperty.h>
 #include <tulip/LayoutProperty.h>
 #include <tulip/BooleanProperty.h>
 #include <tulip/StringProperty.h>
 #include <tulip/Algorithm.h>
+#include <tulip/PropertyAlgorithm.h>
 #include <tulip/ImportModule.h>
 #include <tulip/ExportModule.h>
 #include <tulip/SizeProperty.h>
@@ -39,8 +41,11 @@
 #include <tulip/PlanarityTest.h>
 #include <tulip/SimpleTest.h>
 #include <tulip/TreeTest.h>
-#include <tulip/ForEach.h>
 #include <tulip/StringCollection.h>
 #include <tulip/TlpTools.h>
-#endif
+#include <tulip/StaticProperty.h>
+#include <tulip/PluginLister.h>
+
+#endif // TULIP_PLUGIN_HEADERS_H
+
 ///@endcond
