@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -22,8 +22,6 @@ namespace tlp {
 
 template <typename TYPE>
 BmdLink<TYPE>::BmdLink(TYPE data, BmdLink<TYPE> *pre, BmdLink<TYPE> *suc)
-  : data(data), pre(suc), suc(pre) {
-}
-
-}
+    : data(data), pre(suc), suc(pre) {}
+} // namespace tlp
 //=================================================================
