@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,22 +17,27 @@
  *
  */
 
+#include <iostream>
+#include <algorithm>
+
 #include <tulip/Delaunay.h>
 #include <tulip/Matrix.h>
 #include <tulip/Graph.h>
-#include <tulip/ForEach.h>
 #include <tulip/LayoutProperty.h>
 #include <tulip/BoundingBox.h>
 #include <tulip/DrawingTools.h>
 
-#include <iostream>
+#ifdef __GNUC__
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wold-style-cast"
+#endif
 
 extern "C" {
-#include <libqhull/libqhull.h>
-#include <libqhull/qset.h>
-#include <libqhull/geom.h>
-#include <libqhull/poly.h>
-#include <libqhull/io.h>
+#ifdef HAVE_REENTRANT_QHULL
+#include <qhull_ra.h>
+#else
+#include <qhull_a.h>
+#endif
 }
 
 using namespace std;
@@ -41,8 +46,9 @@ using namespace tlp;
 typedef Matrix<long double, 3> Mat3ld;
 typedef Vector<long double, 3> Vec3ld;
 
-static bool runQHull(int dim, vector<double> &points, vector<pair<unsigned int, unsigned int> >&edges,
-                     vector<vector<unsigned int> > &simplices) {
+static bool runQHull(int dim, vector<double> &points,
+                     vector<pair<unsigned int, unsigned int>> &edges,
+                     vector<vector<unsigned int>> &simplices) {
 
   // Set default options for qhull delaunay triangulation
   // - Qt : triangulated output
@@ -53,46 +59,76 @@ static bool runQHull(int dim, vector<double> &points, vector<pair<unsigned int,
   // build qhull command
   string qhullCommand = string("qhull d ") + qhullOptions;
 
-  // initialize qhull
-  int qhullKo = qh_new_qhull(dim, points.size()/dim, &points[0], false, const_cast<char *>(qhullCommand.c_str()), NULL, stderr);
+// initialize qhull
+#ifdef HAVE_REENTRANT_QHULL
+  qhT qh_qh;
+  qhT *qh = &qh_qh;
+  QHULL_LIB_CHECK
+  qh_zero(qh, stderr);
+  int qhullKo = qh_new_qhull(qh, dim, points.size() / dim, &points[0], false,
+                             const_cast<char *>(qhullCommand.c_str()), nullptr, stderr);
+#else
+  int qhullKo = qh_new_qhull(dim, points.size() / dim, &points[0], false,
+                             const_cast<char *>(qhullCommand.c_str()), nullptr, stderr);
+#endif
 
   if (!qhullKo) {
 
-    set<pair<unsigned int, unsigned int> > placedEdges;
+    set<pair<unsigned int, unsigned int>> placedEdges;
 
-    // call qhull delaunay triangulation
+// call qhull delaunay triangulation
+#ifdef HAVE_REENTRANT_QHULL
+    qh_triangulate(qh);
+#else
     qh_triangulate();
+#endif
 
-    facetT *facet;
-    vertexT *vertex, **vertexp;
+    facetT *facet = nullptr;
+    vertexT *vertex = nullptr, **vertexp;
 
-    // iterate over generated simplices (triangles or tetrahedra) and get corresponding delaunay edges
+    // iterate over generated simplices (triangles or tetrahedra) and get corresponding delaunay
+    // edges
     FORALLfacets {
 
       if (!facet->upperdelaunay) {
-        int pointId0=0, pointId1=0, pointId2=0, pointId3 = -1;
+        int pointId0 = 0, pointId1 = 0, pointId2 = 0, pointId3 = -1;
         int i = 0;
-        FOREACHvertex_ (facet->vertices) {
+        FOREACHvertex_(facet->vertices) {
+#ifdef HAVE_REENTRANT_QHULL
+
+          if (i == 0) {
+            pointId0 = qh_pointid(qh, vertex->point);
+          } else if (i == 1) {
+            pointId1 = qh_pointid(qh, vertex->point);
+          } else if (i == 2) {
+            pointId2 = qh_pointid(qh, vertex->point);
+          } else {
+            pointId3 = qh_pointid(qh, vertex->point);
+          }
+
+#else
+
           if (i == 0) {
             pointId0 = qh_pointid(vertex->point);
-          }
-          else if (i == 1) {
+          } else if (i == 1) {
             pointId1 = qh_pointid(vertex->point);
-          }
-          else if (i == 2) {
+          } else if (i == 2) {
             pointId2 = qh_pointid(vertex->point);
-          }
-          else {
+          } else {
             pointId3 = qh_pointid(vertex->point);
           }
 
+#endif
           ++i;
         }
 
         vector<unsigned int> simplex;
-        pair<unsigned int, unsigned int> edge1 = make_pair(min(pointId0, pointId1), max(pointId0, pointId1));
-        pair<unsigned int, unsigned int> edge2 = make_pair(min(pointId1, pointId2), max(pointId1, pointId2));
-        pair<unsigned int, unsigned int> edge3 = make_pair(min(pointId2, pointId0), max(pointId2, pointId0));
+        pair<unsigned int, unsigned int> edge1 =
+            make_pair(min(pointId0, pointId1), max(pointId0, pointId1));
+        pair<unsigned int, unsigned int> edge2 =
+            make_pair(min(pointId1, pointId2), max(pointId1, pointId2));
+        pair<unsigned int, unsigned int> edge3 =
+            make_pair(min(pointId2, pointId0), max(pointId2, pointId0));
 
         if (placedEdges.find(edge1) == placedEdges.end()) {
           edges.push_back(edge1);
@@ -116,9 +152,12 @@ static bool runQHull(int dim, vector<double> &points, vector<pair<unsigned int,
 
         if (pointId3 != -1) {
           simplex.push_back(pointId3);
-          pair<unsigned int, unsigned int> edge4 = make_pair(min(pointId0, pointId3), max(pointId0, pointId3));
-          pair<unsigned int, unsigned int> edge5 = make_pair(min(pointId1, pointId3), max(pointId1, pointId3));
-          pair<unsigned int, unsigned int> edge6 = make_pair(min(pointId2, pointId3), max(pointId2, pointId3));
+          pair<unsigned int, unsigned int> edge4 =
+              make_pair(min(pointId0, pointId3), max(pointId0, pointId3));
+          pair<unsigned int, unsigned int> edge5 =
+              make_pair(min(pointId1, pointId3), max(pointId1, pointId3));
+          pair<unsigned int, unsigned int> edge6 =
+              make_pair(min(pointId2, pointId3), max(pointId2, pointId3));
 
           if (placedEdges.find(edge4) == placedEdges.end()) {
             edges.push_back(edge4);
@@ -142,9 +181,14 @@ static bool runQHull(int dim, vector<double> &points, vector<pair<unsigned int,
   }
 
   // free memory allocated by qhull
-  qh_freeqhull(!qh_ALL);
   int curlong, totlong;
+#ifdef HAVE_REENTRANT_QHULL
+  qh_freeqhull(qh, !qh_ALL);
+  qh_memfreeshort(qh, &curlong, &totlong);
+#else
+  qh_freeqhull(!qh_ALL);
   qh_memfreeshort(&curlong, &totlong);
+#endif
 
   return !qhullKo;
 }
@@ -161,17 +205,16 @@ static void normalize(Vec3f &v) {
 // B -- C
 // |    |
 // A -- D
-static vector<Coord> buildGrid(const Coord &A, const Coord &B,
-                               const Coord &C, const Coord &D,
+static vector<Coord> buildGrid(const Coord &A, const Coord &B, const Coord &C, const Coord &D,
                                const float nbSubDiv = 10) {
   vector<Coord> ret;
 
-  for (float i = 1 ; i < nbSubDiv - 1 ; ++i) {
-    Coord start = A + (i/(nbSubDiv-1) * (B-A));
-    Coord end = D + (i/(nbSubDiv-1) * (C-D));
+  for (float i = 1; i < nbSubDiv - 1; ++i) {
+    Coord start(A + (i / (nbSubDiv - 1) * (B - A)));
+    Coord end(D + (i / (nbSubDiv - 1) * (C - D)));
 
-    for (float j = 0 ; j < nbSubDiv ; ++j) {
-      ret.push_back(start + (j/(nbSubDiv-1)) * (end - start));
+    for (float j = 0; j < nbSubDiv; ++j) {
+      ret.push_back(start + (j / (nbSubDiv - 1)) * (end - start));
     }
   }
 
@@ -180,48 +223,48 @@ static vector<Coord> buildGrid(const Coord &A, const Coord &B,
 
 //================================================================================================
 
-static tlp::Coord computeTriangleCircumscribedCenter(const tlp::Coord &A, const tlp::Coord &B, const tlp::Coord &C) {
+static tlp::Coord computeTriangleCircumscribedCenter(const tlp::Coord &A, const tlp::Coord &B,
+                                                     const tlp::Coord &C) {
   Vec3ld Ad, Bd, Cd;
 
-  for (size_t i = 0 ; i < 3 ; ++i) {
+  for (size_t i = 0; i < 3; ++i) {
     Ad[i] = A[i];
     Bd[i] = B[i];
     Cd[i] = C[i];
   }
 
-  Vec3ld a = Ad-Cd;
-  Vec3ld b = Bd-Cd;
-  Vec3ld axb = a^b;
+  Vec3ld a = Ad - Cd;
+  Vec3ld b = Bd - Cd;
+  Vec3ld axb = a ^ b;
   long double anorm = a.norm();
   long double bnorm = b.norm();
   long double axbnorm = axb.norm();
 
   if (axbnorm != 0) {
-    Vec3ld c = Cd + (((anorm*anorm*b) - (bnorm*bnorm*a))^axb) / (2.0*axbnorm*axbnorm);
+    Vec3ld c = Cd + (((anorm * anorm * b) - (bnorm * bnorm * a)) ^ axb) / (2.0 * axbnorm * axbnorm);
     return tlp::Coord(c[0], c[1], c[2]);
-  }
-  else {
-    return (A+B+C)/3.0f;
+  } else {
+    return (A + B + C) / 3.0f;
   }
 }
 
 //================================================================================================
 
 static tlp::Coord computeTetrahedronCircumscribedCenter(const tlp::Coord &A, const tlp::Coord &B,
-    const tlp::Coord &C, const tlp::Coord &D) {
+                                                        const tlp::Coord &C, const tlp::Coord &D) {
 
   Vec3ld Ad, Bd, Cd, Dd;
 
-  for (size_t i = 0 ; i < 3 ; ++i) {
+  for (size_t i = 0; i < 3; ++i) {
     Ad[i] = A[i];
     Bd[i] = B[i];
     Cd[i] = C[i];
     Dd[i] = D[i];
   }
 
-  Vec3ld da = Dd-Ad;
-  Vec3ld ba = Bd-Ad;
-  Vec3ld ca = Cd-Ad;
+  Vec3ld da = Dd - Ad;
+  Vec3ld ba = Bd - Ad;
+  Vec3ld ca = Cd - Ad;
 
   long double danorm = da.norm();
   long double banorm = ba.norm();
@@ -229,7 +272,7 @@ static tlp::Coord computeTetrahedronCircumscribedCenter(const tlp::Coord &A, con
 
   Mat3ld m;
 
-  for (int i = 0 ; i < 3 ; ++i) {
+  for (int i = 0; i < 3; ++i) {
     m[0][i] = ba[i];
     m[1][i] = ca[i];
     m[2][i] = da[i];
@@ -238,11 +281,12 @@ static tlp::Coord computeTetrahedronCircumscribedCenter(const tlp::Coord &A, con
   long double det = m.determinant();
 
   if (det != 0) {
-    Vec3ld c =  Ad + ((danorm*danorm*(ba^ca)) + (canorm*canorm*(da^ba)) + (banorm*banorm*(ca^da))) / (2.0*det);
+    Vec3ld c = Ad + ((danorm * danorm * (ba ^ ca)) + (canorm * canorm * (da ^ ba)) +
+                     (banorm * banorm * (ca ^ da))) /
+                        (2.0 * det);
     return tlp::Coord(c[0], c[1], c[2]);
-  }
-  else {
-    return (A+B+C+D)/4.0f;
+  } else {
+    return (A + B + C + D) / 4.0f;
   }
 }
 
@@ -258,20 +302,18 @@ struct Face {
   }
 
   bool operator==(const Face &f) const {
-    return sortedIndexes[0] == f.sortedIndexes[0] &&
-           sortedIndexes[1] == f.sortedIndexes[1] &&
+    return sortedIndexes[0] == f.sortedIndexes[0] && sortedIndexes[1] == f.sortedIndexes[1] &&
            sortedIndexes[2] == f.sortedIndexes[2];
   }
 
   bool isValid() const {
-    return sortedIndexes[0] != UINT_MAX &&
-           sortedIndexes[1] != UINT_MAX;
+    return sortedIndexes[0] != UINT_MAX && sortedIndexes[1] != UINT_MAX;
   }
 
   unsigned int size() const {
     unsigned int ret = 0;
 
-    for (unsigned int i = 0 ; i < 3 ; ++i) {
+    for (unsigned int i = 0; i < 3; ++i) {
       if (sortedIndexes[i] != UINT_MAX) {
         ++ret;
       }
@@ -283,24 +325,24 @@ struct Face {
   vector<unsigned int> sortedIndexes;
 };
 
-TLP_BEGIN_HASH_NAMESPACE {
-  template <>
-  struct hash<Face> {
-    inline std::size_t operator()(const Face &f) const {
-      size_t seed = 0;
-      hash_combine(seed, f.sortedIndexes[0]);
-      hash_combine(seed, f.sortedIndexes[1]);
-      hash_combine(seed, f.sortedIndexes[2]);
-      return seed;
-    }
-  };
-} TLP_END_HASH_NAMESPACE
+namespace std {
+template <>
+struct hash<Face> {
+  inline std::size_t operator()(const Face &f) const {
+    size_t seed = 0;
+    tlp_hash_combine(seed, f.sortedIndexes[0]);
+    tlp_hash_combine(seed, f.sortedIndexes[1]);
+    tlp_hash_combine(seed, f.sortedIndexes[2]);
+    return seed;
+  }
+};
+} // namespace std
 
 //================================================================================================
 
-bool tlp::delaunayTriangulation(vector<Coord> & points,
-                                vector<pair<unsigned int, unsigned int> > &edges,
-                                vector<vector<unsigned int> > &simplices, bool voronoiMode) {
+bool tlp::delaunayTriangulation(vector<Coord> &points,
+                                vector<pair<unsigned int, unsigned int>> &edges,
+                                vector<vector<unsigned int>> &simplices, bool voronoiMode) {
 
   vector<double> pointsQHull;
   BoundingBox bb;
@@ -316,10 +358,10 @@ bool tlp::delaunayTriangulation(vector<Coord> & points,
 
   // if the layout is not coplanar, use a 3d delaunay triangulation
   if (!coPlanarLayout) {
-    pointsQHull.reserve(points.size()*3);
+    pointsQHull.reserve(points.size() * 3);
 
     // copy coordinates in the pointsQHull vector
-    for(size_t i = 0 ; i < points.size() ; ++i) {
+    for (size_t i = 0; i < points.size(); ++i) {
       bb.expand(points[i]);
       pointsQHull.push_back(points[i].getX());
       pointsQHull.push_back(points[i].getY());
@@ -336,15 +378,15 @@ bool tlp::delaunayTriangulation(vector<Coord> & points,
       float newHeight = bb.height() * 1.2f;
       float newDepth = bb.depth() * 1.2f;
 
-      Coord p1 = Coord(bb.center()) + Coord(-newWidth/2, -newHeight/2, -newDepth/2);
-      Coord p2 = Coord(bb.center()) + Coord(-newWidth/2, newHeight/2, -newDepth/2);
-      Coord p3 = Coord(bb.center()) + Coord(newWidth/2, newHeight/2, -newDepth/2);
-      Coord p4 = Coord(bb.center()) + Coord(newWidth/2, -newHeight/2, -newDepth/2);
+      Coord p1 = Coord(bb.center()) + Coord(-newWidth / 2, -newHeight / 2, -newDepth / 2);
+      Coord p2 = Coord(bb.center()) + Coord(-newWidth / 2, newHeight / 2, -newDepth / 2);
+      Coord p3 = Coord(bb.center()) + Coord(newWidth / 2, newHeight / 2, -newDepth / 2);
+      Coord p4 = Coord(bb.center()) + Coord(newWidth / 2, -newHeight / 2, -newDepth / 2);
 
-      Coord p5 = Coord(bb.center()) + Coord(-newWidth/2, -newHeight/2, newDepth/2);
-      Coord p6 = Coord(bb.center()) + Coord(-newWidth/2, newHeight/2, newDepth/2);
-      Coord p7 = Coord(bb.center()) + Coord(newWidth/2, newHeight/2, newDepth/2);
-      Coord p8 = Coord(bb.center()) + Coord(newWidth/2, -newHeight/2, newDepth/2);
+      Coord p5 = Coord(bb.center()) + Coord(-newWidth / 2, -newHeight / 2, newDepth / 2);
+      Coord p6 = Coord(bb.center()) + Coord(-newWidth / 2, newHeight / 2, newDepth / 2);
+      Coord p7 = Coord(bb.center()) + Coord(newWidth / 2, newHeight / 2, newDepth / 2);
+      Coord p8 = Coord(bb.center()) + Coord(newWidth / 2, -newHeight / 2, newDepth / 2);
 
       vector<Coord> mesh;
 
@@ -361,7 +403,7 @@ bool tlp::delaunayTriangulation(vector<Coord> & points,
       grid = buildGrid(p4, p8, p7, p3);
       mesh.insert(mesh.end(), grid.begin(), grid.end());
 
-      for (size_t i = 0 ; i < mesh.size() ; ++i) {
+      for (size_t i = 0; i < mesh.size(); ++i) {
         points.push_back(mesh[i]);
         pointsQHull.push_back(mesh[i].getX());
         pointsQHull.push_back(mesh[i].getY());
@@ -369,13 +411,12 @@ bool tlp::delaunayTriangulation(vector<Coord> & points,
       }
     }
 
-  }
-  else {
+  } else {
     dim = 2;
-    pointsQHull.reserve(points.size()*2);
+    pointsQHull.reserve(points.size() * 2);
 
     // copy coordinates in the pointsQHull vector
-    for(size_t i = 0 ; i < points.size() ; ++i) {
+    for (size_t i = 0; i < points.size(); ++i) {
       Coord p = Coord(invTransformMatrix * points[i]);
       pointsQHull.push_back(p.getX());
       pointsQHull.push_back(p.getY());
@@ -390,7 +431,7 @@ bool tlp::delaunayTriangulation(vector<Coord> & points,
       vector<Coord> inputHullPoints;
       inputHullPoints.reserve(points.size());
 
-      for (size_t i = 0 ; i < points.size() ; ++i) {
+      for (size_t i = 0; i < points.size(); ++i) {
         Coord p = Coord(invTransformMatrix * points[i]);
         inputHullPoints.push_back(p);
       }
@@ -399,20 +440,22 @@ bool tlp::delaunayTriangulation(vector<Coord> & points,
       vector<Coord> newHullPoints;
       float nbSubdiv = 4;
 
-      for (size_t i = 0 ; i < hullPoints.size() -1 ; ++i) {
-        for (float j = 0 ; j < nbSubdiv - 1; ++j) {
-          newHullPoints.push_back(hullPoints[i] + (j/(nbSubdiv-1)) * (hullPoints[i+1]-hullPoints[i]));
+      for (size_t i = 0; i < hullPoints.size() - 1; ++i) {
+        for (float j = 0; j < nbSubdiv - 1; ++j) {
+          newHullPoints.push_back(hullPoints[i] +
+                                  (j / (nbSubdiv - 1)) * (hullPoints[i + 1] - hullPoints[i]));
         }
       }
 
-      for (float j = 0 ; j < nbSubdiv - 1; ++j) {
-        newHullPoints.push_back(hullPoints.back() + (j/(nbSubdiv-1)) * (hullPoints[0]-hullPoints.back()));
+      for (float j = 0; j < nbSubdiv - 1; ++j) {
+        newHullPoints.push_back(hullPoints.back() +
+                                (j / (nbSubdiv - 1)) * (hullPoints[0] - hullPoints.back()));
       }
 
       hullPoints = newHullPoints;
       Coord centroid = computePolygonCentroid(hullPoints);
 
-      for (size_t i = 0 ; i < hullPoints.size() ; ++i) {
+      for (size_t i = 0; i < hullPoints.size(); ++i) {
         float dist = centroid.dist(hullPoints[i]);
         Coord dir = hullPoints[i] - centroid;
         normalize(dir);
@@ -429,7 +472,8 @@ bool tlp::delaunayTriangulation(vector<Coord> & points,
 
 //================================================================================================
 
-static void addVoronoiEdge(VoronoiDiagram &voronoiDiagram, const Face &face, const VoronoiDiagram::Edge &edge) {
+static void addVoronoiEdge(VoronoiDiagram &voronoiDiagram, const Face &face,
+                           const VoronoiDiagram::Edge &edge) {
   bool addEdge = false;
 
   if (face.sortedIndexes[0] < voronoiDiagram.nbSites()) {
@@ -458,8 +502,8 @@ static void addVoronoiEdge(VoronoiDiagram &voronoiDiagram, const Face &face, con
 
 bool tlp::voronoiDiagram(vector<Coord> &sites, VoronoiDiagram &voronoiDiagram) {
 
-  vector<pair<unsigned int, unsigned int> > edges;
-  vector<vector<unsigned int> > simplices;
+  vector<pair<unsigned int, unsigned int>> edges;
+  vector<vector<unsigned int>> simplices;
   voronoiDiagram.sites = sites;
   unsigned int nbSites = sites.size();
 
@@ -470,27 +514,24 @@ bool tlp::voronoiDiagram(vector<Coord> &sites, VoronoiDiagram &voronoiDiagram) {
   // now compute the dual voronoi diagram
   if (ret) {
     // Iterate over each delaunay simplex
-    TLP_HASH_MAP<Face, unsigned int> faceToCircumCenter;
+    std::unordered_map<Face, unsigned int> faceToCircumCenter;
     map<Coord, unsigned int> circumCenterToIdx;
-    tlp::Coord A, B, C, D;
+    tlp::Coord A(0), B(0), C(0), D(0);
 
-    for (size_t i = 0 ; i < simplices.size() ; ++i) {
+    for (size_t i = 0; i < simplices.size(); ++i) {
       vector<unsigned int> sitesIdx;
 
-      for (size_t j = 0 ; j < simplices[i].size() ; ++j) {
+      for (size_t j = 0; j < simplices[i].size(); ++j) {
         if (j == 0) {
           A = sites[simplices[i][j]];
           sitesIdx.push_back(simplices[i][j]);
-        }
-        else if (j == 1) {
+        } else if (j == 1) {
           B = sites[simplices[i][j]];
           sitesIdx.push_back(simplices[i][j]);
-        }
-        else if (j == 2) {
+        } else if (j == 2) {
           C = sites[simplices[i][j]];
           sitesIdx.push_back(simplices[i][j]);
-        }
-        else {
+        } else {
           D = sites[simplices[i][j]];
           sitesIdx.push_back(simplices[i][j]);
         }
@@ -498,7 +539,7 @@ bool tlp::voronoiDiagram(vector<Coord> &sites, VoronoiDiagram &voronoiDiagram) {
 
       bool treatSimplex = false;
 
-      for (size_t j = 0 ; j < sitesIdx.size() ; ++j) {
+      for (size_t j = 0; j < sitesIdx.size(); ++j) {
         if (sitesIdx[j] < nbSites) {
           treatSimplex = true;
           break;
@@ -521,8 +562,7 @@ bool tlp::voronoiDiagram(vector<Coord> &sites, VoronoiDiagram &voronoiDiagram) {
 
       if (circumCenterToIdx.find(circumCenterPos) != circumCenterToIdx.end()) {
         circumCenterIdx = circumCenterToIdx[circumCenterPos];
-      }
-      else {
+      } else {
         // add the voronoi vertex in the voronoi diagram
         circumCenterIdx = voronoiDiagram.vertices.size();
         circumCenterToIdx[circumCenterPos] = circumCenterIdx;
@@ -549,13 +589,12 @@ bool tlp::voronoiDiagram(vector<Coord> &sites, VoronoiDiagram &voronoiDiagram) {
         face4 = Face(simplices[i][0], simplices[i][1], simplices[i][3]);
       }
 
-      TLP_HASH_MAP<Face, unsigned int>::const_iterator it = faceToCircumCenter.find(face1);
+      std::unordered_map<Face, unsigned int>::const_iterator it = faceToCircumCenter.find(face1);
 
       if (it != faceToCircumCenter.end()) {
         VoronoiDiagram::Edge edge = make_pair(circumCenterIdx, faceToCircumCenter[face1]);
         addVoronoiEdge(voronoiDiagram, face1, edge);
-      }
-      else {
+      } else {
         faceToCircumCenter[face1] = circumCenterIdx;
       }
 
@@ -564,8 +603,7 @@ bool tlp::voronoiDiagram(vector<Coord> &sites, VoronoiDiagram &voronoiDiagram) {
       if (it != faceToCircumCenter.end()) {
         VoronoiDiagram::Edge edge = make_pair(circumCenterIdx, faceToCircumCenter[face2]);
         addVoronoiEdge(voronoiDiagram, face2, edge);
-      }
-      else {
+      } else {
         faceToCircumCenter[face2] = circumCenterIdx;
       }
 
@@ -574,8 +612,7 @@ bool tlp::voronoiDiagram(vector<Coord> &sites, VoronoiDiagram &voronoiDiagram) {
       if (it != faceToCircumCenter.end()) {
         VoronoiDiagram::Edge edge = make_pair(circumCenterIdx, faceToCircumCenter[face3]);
         addVoronoiEdge(voronoiDiagram, face3, edge);
-      }
-      else {
+      } else {
         faceToCircumCenter[face3] = circumCenterIdx;
       }
 
@@ -587,8 +624,7 @@ bool tlp::voronoiDiagram(vector<Coord> &sites, VoronoiDiagram &voronoiDiagram) {
         if (it != faceToCircumCenter.end()) {
           VoronoiDiagram::Edge edge = make_pair(circumCenterIdx, faceToCircumCenter[face4]);
           addVoronoiEdge(voronoiDiagram, face4, edge);
-        }
-        else {
+        } else {
           faceToCircumCenter[face4] = circumCenterIdx;
         }
       }
@@ -597,11 +633,11 @@ bool tlp::voronoiDiagram(vector<Coord> &sites, VoronoiDiagram &voronoiDiagram) {
     // compute the voronoi cells associated to sites
     voronoiDiagram.cells.reserve(nbSites);
 
-    for (unsigned int i = 0 ; i < nbSites ; ++i) {
+    for (unsigned int i = 0; i < nbSites; ++i) {
       VoronoiDiagram::Cell cell;
       const vector<VoronoiDiagram::Edge> &voronoiEdges = voronoiDiagram.voronoiEdgesForSite(i);
 
-      for (size_t j = 0 ; j < voronoiEdges.size() ; ++j) {
+      for (size_t j = 0; j < voronoiEdges.size(); ++j) {
         cell.insert(voronoiEdges[j].first);
         cell.insert(voronoiEdges[j].second);
       }
@@ -615,3 +651,7 @@ bool tlp::voronoiDiagram(vector<Coord> &sites, VoronoiDiagram &voronoiDiagram) {
   sites.resize(nbSites);
   return ret;
 }
+
+#ifdef __GNUC__
+#pragma GCC diagnostic pop
+#endif
