@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -25,6 +25,7 @@
 #include <tulip/GraphImpl.h>
 #include <tulip/ConcatIterator.h>
 #include <tulip/GraphTools.h>
+#include <tulip/TlpTools.h>
 
 using namespace std;
 using namespace tlp;
@@ -33,21 +34,19 @@ const string metaGraphPropertyName = "viewMetaGraph";
 
 //=========================================================================
 GraphAbstract::GraphAbstract(Graph *supergraph, unsigned int sgId)
-  :supergraph(supergraph ? supergraph : this),
-   root((supergraph == this) ? this : supergraph->getRoot()),
-   subGraphToKeep(NULL), metaGraphProperty(NULL) {
+    : supergraph(supergraph ? supergraph : this),
+      root((supergraph == this) ? this : supergraph->getRoot()), subGraphToKeep(nullptr),
+      metaGraphProperty(nullptr) {
   // get id
   if (supergraph != this)
-    id = ((GraphImpl *) getRoot())->getSubGraphId(sgId);
+    id = static_cast<GraphImpl *>(getRoot())->getSubGraphId(sgId);
 
   propertyContainer = new PropertyManager(this);
 }
 //=========================================================================
 GraphAbstract::~GraphAbstract() {
-  StableIterator<Graph *> itS(getSubGraphs());
 
-  while(itS.hasNext()) {
-    Graph* sg = itS.next();
+  for (Graph *sg : subgraphs) {
 
     // avoid double free
     // in a push context, a 'deleted' graph (see delSubGraph)
@@ -64,32 +63,33 @@ GraphAbstract::~GraphAbstract() {
   delete propertyContainer;
 
   if (id != 0)
-    ((GraphImpl *) getRoot())->freeSubGraphId(id);
+    static_cast<GraphImpl *>(getRoot())->freeSubGraphId(id);
 }
 //=========================================================================
 void GraphAbstract::clear() {
-  StableIterator<Graph *> itS(getSubGraphs());
+  delAllSubGraphs();
 
-  while(itS.hasNext())
-    delAllSubGraphs(itS.next());
-
-  StableIterator<node> itN(getNodes());
-
-  while(itN.hasNext())
-    delNode(itN.next());
+  vector<node> vnodes(nodes());
+  for (auto n : vnodes) {
+    delNode(n);
+  }
 }
 //=========================================================================
-void GraphAbstract::restoreSubGraph(Graph* sg) {
+void GraphAbstract::restoreSubGraph(Graph *sg) {
   subgraphs.push_back(sg);
   sg->setSuperGraph(this);
+  if (sg == subGraphToKeep) {
+    static_cast<GraphImpl *>(getRoot())->getSubGraphId(sg->getId());
+    subGraphToKeep = nullptr;
+  }
 }
 //=========================================================================
-void GraphAbstract::setSubGraphToKeep(Graph* sg) {
+void GraphAbstract::setSubGraphToKeep(Graph *sg) {
   subGraphToKeep = sg;
 }
 //=========================================================================
 Graph *GraphAbstract::addSubGraph(unsigned int id, BooleanProperty *selection,
-                                  const std::string& name) {
+                                  const std::string &name) {
   Graph *tmp = new GraphView(this, selection, id);
 
   if (!name.empty())
@@ -101,30 +101,19 @@ Graph *GraphAbstract::addSubGraph(unsigned int id, BooleanProperty *selection,
   return tmp;
 }
 //=========================================================================
-Graph *GraphAbstract::addSubGraph(BooleanProperty *selection,
-                                  const std::string& name) {
-  return addSubGraph(0, selection, name);
-}
-//=========================================================================
 Graph *GraphAbstract::getNthSubGraph(unsigned int n) const {
 
   if (n >= subgraphs.size())
-    return NULL;
+    return nullptr;
 
   return subgraphs[n];
 }
 //=========================================================================
-unsigned int GraphAbstract::numberOfSubGraphs() const {
-  return subgraphs.size();
-}
-//=========================================================================
 unsigned int GraphAbstract::numberOfDescendantGraphs() const {
-  GRAPH_SEQ::const_iterator it = subgraphs.begin();
-  int result = numberOfSubGraphs();
+  unsigned int result = numberOfSubGraphs();
 
-  while(it != subgraphs.end()) {
-    result += (*it)->numberOfDescendantGraphs();
-    ++it;
+  for (auto sg : subgraphs) {
+    result += sg->numberOfDescendantGraphs();
   }
 
   return result;
@@ -132,62 +121,73 @@ unsigned int GraphAbstract::numberOfDescendantGraphs() const {
 //=========================================================================
 void GraphAbstract::delSubGraph(Graph *toRemove) {
   // look for the graph we want to remove in the subgraphs
-  GRAPH_SEQ::iterator it =
-    std::find(subgraphs.begin(), subgraphs.end(), toRemove);
+  auto it = std::find(subgraphs.begin(), subgraphs.end(), toRemove);
 
   assert(it != subgraphs.end());
 
   if (it != subgraphs.end()) {
-    subGraphToKeep = NULL;
+    subGraphToKeep = nullptr;
 
     // remove from subgraphs
     notifyBeforeDelSubGraph(toRemove);
     subgraphs.erase(it);
-    Iterator<Graph *> *itS = toRemove->getSubGraphs();
 
     // add toRemove subgraphs
-    while (itS->hasNext()) {
-      restoreSubGraph(itS->next());
+    for (Graph *sg : toRemove->subGraphs()) {
+      restoreSubGraph(sg);
     }
 
-    delete itS;
     notifyAfterDelSubGraph(toRemove);
 
-    // subGraphToKeep may have change on notifyDelSubGraph
+    // subGraphToKeep may have change on notifyAfterDelSubGraph
     // see GraphUpdatesRecorder::delSubGraph
     // in GraphUpdatesRecorder.cpp
     if (toRemove != subGraphToKeep) {
       // avoid deletion of toRemove subgraphs
       toRemove->clearSubGraphs();
       delete toRemove;
-    }
-    else
+    } else {
       // toRemove is not deleted,
       // and its subgraphs list is not erased;
-      // beacause it is registered into a GraphUpdatesRecorder
+      // because it is registered into a GraphUpdatesRecorder
       // in order it can be restored on undo or redo
       toRemove->notifyDestroy();
+      // free subgraph id which will be restored in case of undo
+      // see restoreSubGraph
+      static_cast<GraphImpl *>(getRoot())->freeSubGraphId(toRemove->getId());
+      subGraphToKeep = nullptr;
+    }
   }
 }
 //=========================================================================
-void GraphAbstract::removeSubGraph(Graph * toRemove) {
-  GRAPH_SEQ::iterator it =
-    std::find(subgraphs.begin(), subgraphs.end(), toRemove);
+void GraphAbstract::removeSubGraph(Graph *toRemove) {
+  auto it = std::find(subgraphs.begin(), subgraphs.end(), toRemove);
 
   if (it != subgraphs.end()) {
     subgraphs.erase(it);
   }
+  if (toRemove == subGraphToKeep) {
+    // free subgraph id which will be restored in case of undo
+    // see restoreSubGraph
+    static_cast<GraphImpl *>(getRoot())->freeSubGraphId(toRemove->getId());
+    subGraphToKeep = nullptr;
+  }
 }
 //=========================================================================
-void GraphAbstract::delAllSubGraphs(Graph * toRemove) {
-  if (this != toRemove->getSuperGraph() || this==toRemove)
+void GraphAbstract::delAllSubGraphs() {
+  while (subgraphs.size()) {
+    auto sg = subgraphs[0];
+    static_cast<GraphAbstract *>(sg)->delAllSubGraphs();
+    delSubGraph(sg);
+  }
+}
+//=========================================================================
+void GraphAbstract::delAllSubGraphs(Graph *toRemove) {
+  if (this != toRemove->getSuperGraph() || this == toRemove)
     // this==toRemove : root graph
     return;
 
-  StableIterator<Graph *> itS(toRemove->getSubGraphs());
-
-  while (itS.hasNext())
-    ((GraphAbstract*) toRemove)->delAllSubGraphs(itS.next());
+  static_cast<GraphAbstract *>(toRemove)->delAllSubGraphs();
 
   delSubGraph(toRemove);
 }
@@ -196,263 +196,143 @@ void GraphAbstract::clearSubGraphs() {
   subgraphs.clear();
 }
 //=========================================================================
-Graph* GraphAbstract::getSuperGraph()const {
-  return supergraph;
-}
-//=========================================================================
-Graph* GraphAbstract::getRoot() const {
-  return root;
-}
-//=========================================================================
 void GraphAbstract::setSuperGraph(Graph *sg) {
-  supergraph=sg;
+  supergraph = sg;
 }
 //=========================================================================
-Iterator<Graph *> * GraphAbstract::getSubGraphs() const {
-  return new StlIterator<Graph *, GRAPH_SEQ::const_iterator >(subgraphs.begin(),subgraphs.end());
+Iterator<Graph *> *GraphAbstract::getSubGraphs() const {
+  return new StlIterator<Graph *, vector<Graph *>::const_iterator>(subgraphs.cbegin(),
+                                                                   subgraphs.cend());
 }
 //=========================================================================
-bool GraphAbstract::isSubGraph(const Graph* sg) const {
+bool GraphAbstract::isSubGraph(const Graph *sg) const {
   return (std::find(subgraphs.begin(), subgraphs.end(), sg) != subgraphs.end());
 }
 //=========================================================================
-bool GraphAbstract::isDescendantGraph(const Graph* sg) const {
-  if (isSubGraph(sg))
+bool GraphAbstract::isDescendantGraph(const Graph *g) const {
+  if (isSubGraph(g))
     return true;
 
-  GRAPH_SEQ::const_iterator it = subgraphs.begin();
-
-  while(it != subgraphs.end()) {
-    if ((*it)->isDescendantGraph(sg))
+  for (auto sg : subgraphs) {
+    if (sg->isDescendantGraph(g))
       return true;
-
-    ++it;
   }
 
   return false;
 }
 //=========================================================================
-Graph* GraphAbstract::getSubGraph(unsigned int sgId) const {
-  GRAPH_SEQ::const_iterator it = subgraphs.begin();
-
-  while(it != subgraphs.end()) {
-    if ((*it)->getId() == sgId)
-      return *it;
-
-    ++it;
+Graph *GraphAbstract::getSubGraph(unsigned int sgId) const {
+  for (auto sg : subgraphs) {
+    if (sg->getId() == sgId)
+      return sg;
   }
 
-  return NULL;
+  return nullptr;
 }
 //=========================================================================
-Graph* GraphAbstract::getSubGraph(const std::string &name) const {
-  GRAPH_SEQ::const_iterator it = subgraphs.begin();
-
-  while(it != subgraphs.end()) {
-    if ((*it)->getName() == name)
-      return *it;
-
-    ++it;
+Graph *GraphAbstract::getSubGraph(const std::string &name) const {
+  for (auto sg : subgraphs) {
+    if (sg->getName() == name)
+      return sg;
   }
 
-  return NULL;
+  return nullptr;
 }
 //=========================================================================
-Graph* GraphAbstract::getDescendantGraph(unsigned int sgId) const {
-  Graph* sg = getSubGraph(sgId);
+Graph *GraphAbstract::getDescendantGraph(unsigned int sgId) const {
+  Graph *sg = getSubGraph(sgId);
 
   if (sg)
     return sg;
 
-  GRAPH_SEQ::const_iterator it = subgraphs.begin();
-
-  while(it != subgraphs.end()) {
-    if ((sg = (*it)->getDescendantGraph(sgId)))
+  for (auto sg : subgraphs) {
+    if ((sg = sg->getDescendantGraph(sgId)))
       return sg;
-
-    ++it;
   }
 
-  return NULL;
+  return nullptr;
 }
 //=========================================================================
-Graph* GraphAbstract::getDescendantGraph(const string &name) const {
-  Graph* sg = getSubGraph(name);
+Graph *GraphAbstract::getDescendantGraph(const string &name) const {
+  Graph *sg = getSubGraph(name);
 
   if (sg)
     return sg;
 
-  GRAPH_SEQ::const_iterator it = subgraphs.begin();
-
-  while(it != subgraphs.end()) {
-    if ((sg = (*it)->getDescendantGraph(name)))
+  for (auto sg : subgraphs) {
+    if ((sg = sg->getDescendantGraph(name)))
       return sg;
-
-    ++it;
   }
 
-  return NULL;
+  return nullptr;
 }
 //=========================================================================
 node GraphAbstract::getOneNode() const {
-  node result;
-  Iterator<node> *it = getNodes();
-
-  if (it->hasNext())
-    result = it->next();
-
-  delete it;
-  return result;
+  const std::vector<node> &vNodes = nodes();
+  return (vNodes.size() > 0) ? vNodes[0] : node();
 }
 //=========================================================================
 node GraphAbstract::getRandomNode() const {
-  unsigned int nodeIdx = static_cast<unsigned int>((rand() / static_cast<double>(RAND_MAX)) * numberOfNodes());
-  unsigned int i = 0;
-  node n;
-  forEach(n, getNodes()) {
-    if (i++ == nodeIdx) {
-      break;
-    }
-  }
-  return n;
+  const std::vector<node> &vNodes = nodes();
+
+  if (!vNodes.empty())
+    return vNodes[randomUnsignedInteger(vNodes.size() - 1)];
+
+  return node();
 }
 //=========================================================================
 edge GraphAbstract::getOneEdge() const {
-  edge result;
-  Iterator<edge> *it=getEdges();
-
-  if (it->hasNext())
-    result = it->next();
-
-  delete it;
-  return result;
+  const std::vector<edge> &vEdges = edges();
+  return (vEdges.size() > 0) ? vEdges[0] : edge();
 }
 //=========================================================================
 edge GraphAbstract::getRandomEdge() const {
-  unsigned int edgeIdx = static_cast<unsigned int>((rand() / static_cast<double>(RAND_MAX)) * numberOfEdges());
-  unsigned int i = 0;
-  edge e;
-  forEach(e, getEdges()) {
-    if (i++ == edgeIdx) {
-      break;
-    }
-  }
-  return e;
+  const std::vector<edge> &vEdges = edges();
+
+  if (!vEdges.empty())
+    return vEdges[randomUnsignedInteger(vEdges.size() - 1)];
+
+  return edge();
 }
 //=========================================================================
-node GraphAbstract::getInNode(const node n,unsigned int i)const {
-  assert(i<=indeg(n) && i>0);
-  Iterator<node>*itN=getInNodes(n);
+node GraphAbstract::getInNode(const node n, unsigned int i) const {
+  assert(i <= indeg(n) && i > 0);
+  Iterator<node> *itN = getInNodes(n);
   node result;
 
-  while(i--) {
-    result=itN->next();
+  while (i--) {
+    result = itN->next();
   }
 
   delete itN;
   return result;
 }
 //=========================================================================
-node GraphAbstract::getOutNode(const node n,unsigned int i)const {
-  assert(i<=outdeg(n) && i>0);
-  Iterator<node>*itN=getOutNodes(n);
+node GraphAbstract::getOutNode(const node n, unsigned int i) const {
+  assert(i <= outdeg(n) && i > 0);
+  Iterator<node> *itN = getOutNodes(n);
   node result;
 
-  while(i--) {
-    result=itN->next();
+  while (i--) {
+    result = itN->next();
   }
 
   delete itN;
   return result;
 }
 //=========================================================================
-unsigned int GraphAbstract::deg(const node n) const {
-  unsigned int deg=0;
-  Iterator<edge> *it=getInOutEdges(n);
+void GraphAbstract::delNodes(Iterator<node> *itN, bool deleteInAllGraphs) {
+  assert(itN != nullptr);
 
-  while (it->hasNext()) {
-    it->next();
-    ++deg;
-  }
-
-  delete it;
-  return deg;
-}
-//=========================================================================
-unsigned int GraphAbstract::indeg(const node n) const {
-  unsigned int deg=0;
-  Iterator<edge> *it=getInEdges(n);
-
-  while (it->hasNext()) {
-    it->next();
-    ++deg;
-  }
-
-  delete it;
-  return deg;
-}
-//=========================================================================
-unsigned int GraphAbstract::outdeg(const node n) const {
-  unsigned int deg=0;
-  Iterator<edge> *it=getOutEdges(n);
-
-  while(it->hasNext()) {
-    it->next();
-    ++deg;
-  }
-
-  delete it;
-  return deg;
-}
-//=========================================================================
-void GraphAbstract::delNodes(Iterator<node>* itN, bool deleteInAllGraphs) {
-  assert(itN != NULL);
-
-  while(itN->hasNext()) {
+  while (itN->hasNext()) {
     delNode(itN->next(), deleteInAllGraphs);
   }
 }
 //=========================================================================
-node GraphAbstract::source(const edge e) const {
-  return root->source(e);
-}
-//=========================================================================
-void GraphAbstract::setSource(const edge e, const node newSrc) {
-  assert(isElement(e));
-  root->setEnds(e, newSrc, node());
-}
-//=========================================================================
-node GraphAbstract::target(const edge e) const {
-  return root->target(e);
-}
-//=========================================================================
-void GraphAbstract::setTarget(const edge e, const node newTgt) {
-  assert(isElement(e));
-  root->setEnds(e, node(), newTgt);
-}
-//=========================================================================
-const std::pair<node, node>& GraphAbstract::ends(const edge e) const {
-  return root->ends(e);
-}
-//=========================================================================
-void GraphAbstract::setEnds(const edge e, const node newSrc, const node newTgt) {
-  assert(isElement(e));
-  root->setEnds(e, newSrc, newTgt);
-}
-//=========================================================================
-node GraphAbstract::opposite(const edge e, const node n) const {
-  return root->opposite(e, n);
-}
-//=========================================================================
-void GraphAbstract::reverse(const edge e) {
-  assert(isElement(e));
-  root->reverse(e);
-}
-//=========================================================================
-void GraphAbstract::delEdges(Iterator<edge>* itE, bool deleteInAllGraphs) {
-  assert(itE != NULL);
+void GraphAbstract::delEdges(Iterator<edge> *itE, bool deleteInAllGraphs) {
+  assert(itE != nullptr);
 
-  while(itE->hasNext()) {
+  while (itE->hasNext()) {
     delEdge(itE->next(), deleteInAllGraphs);
   }
 }
@@ -465,12 +345,13 @@ bool GraphAbstract::existLocalProperty(const std::string &name) const {
   return propertyContainer->existLocalProperty(name);
 }
 //=========================================================================
-PropertyInterface* GraphAbstract::getProperty(const string &str) const {
+PropertyInterface *GraphAbstract::getProperty(const string &str) const {
   return propertyContainer->getProperty(str);
 }
 //=========================================================================
 void GraphAbstract::delLocalProperty(const std::string &name) {
-  std::string nameCopy = name; // the name is copied to ensure that the notifyBeforeDel event will not use an invalid reference
+  std::string nameCopy = name; // the name is copied to ensure that the notifyBeforeDel event will
+                               // not use an invalid reference
   assert(existLocalProperty(nameCopy));
   notifyBeforeDelLocalProperty(nameCopy);
   propertyContainer->delLocalProperty(nameCopy);
@@ -483,103 +364,74 @@ void GraphAbstract::addLocalProperty(const std::string &name, PropertyInterface
   propertyContainer->setLocalProperty(name, prop);
 
   if (name == metaGraphPropertyName) {
-    metaGraphProperty = (GraphProperty *) prop;
+    metaGraphProperty = static_cast<GraphProperty *>(prop);
   }
 
   notifyAddLocalProperty(name);
 }
 //=========================================================================
-bool GraphAbstract::renameLocalProperty(PropertyInterface* prop, const std::string& newName) {
+bool GraphAbstract::renameLocalProperty(PropertyInterface *prop, const std::string &newName) {
   return propertyContainer->renameLocalProperty(prop, newName);
 }
 //=========================================================================
-void GraphAbstract::notifyAddInheritedProperty(const std::string& propName) {
+void GraphAbstract::notifyAddInheritedProperty(const std::string &propName) {
   if (hasOnlookers())
     sendEvent(GraphEvent(*this, GraphEvent::TLP_ADD_INHERITED_PROPERTY, propName));
 }
-void GraphAbstract::notifyBeforeAddInheritedProperty(const std::string& propName) {
+void GraphAbstract::notifyBeforeAddInheritedProperty(const std::string &propName) {
   if (hasOnlookers())
     sendEvent(GraphEvent(*this, GraphEvent::TLP_BEFORE_ADD_INHERITED_PROPERTY, propName));
 }
 //=========================================================================
-void GraphAbstract::notifyBeforeDelInheritedProperty(const std::string& propName) {
+void GraphAbstract::notifyBeforeDelInheritedProperty(const std::string &propName) {
   if (hasOnlookers())
-    sendEvent(GraphEvent(*this, GraphEvent::TLP_BEFORE_DEL_INHERITED_PROPERTY, propName,Event::TLP_INFORMATION));
+    sendEvent(GraphEvent(*this, GraphEvent::TLP_BEFORE_DEL_INHERITED_PROPERTY, propName,
+                         Event::TLP_INFORMATION));
 }
 //=========================================================================
-void GraphAbstract::notifyAfterDelInheritedProperty(const std::string& name) {
+void GraphAbstract::notifyAfterDelInheritedProperty(const std::string &name) {
   if (hasOnlookers())
     sendEvent(GraphEvent(*this, GraphEvent::TLP_AFTER_DEL_INHERITED_PROPERTY, name));
 }
 //=========================================================================
-void GraphAbstract::notifyBeforeRenameLocalProperty(PropertyInterface* prop,
-    const std::string& newName) {
+void GraphAbstract::notifyBeforeRenameLocalProperty(PropertyInterface *prop,
+                                                    const std::string &newName) {
   if (hasOnlookers())
-    sendEvent(GraphEvent(*this, GraphEvent::TLP_BEFORE_RENAME_LOCAL_PROPERTY,
-                         prop, newName));
+    sendEvent(GraphEvent(*this, GraphEvent::TLP_BEFORE_RENAME_LOCAL_PROPERTY, prop, newName));
 }
 //=========================================================================
-void GraphAbstract::notifyAfterRenameLocalProperty(PropertyInterface* prop,
-    const std::string& oldName) {
+void GraphAbstract::notifyAfterRenameLocalProperty(PropertyInterface *prop,
+                                                   const std::string &oldName) {
   if (hasOnlookers())
-    sendEvent(GraphEvent(*this, GraphEvent::TLP_AFTER_RENAME_LOCAL_PROPERTY,
-                         prop, oldName));
+    sendEvent(GraphEvent(*this, GraphEvent::TLP_AFTER_RENAME_LOCAL_PROPERTY, prop, oldName));
 }
 //=========================================================================
-Iterator<std::string>* GraphAbstract::getLocalProperties() const {
+Iterator<std::string> *GraphAbstract::getLocalProperties() const {
   return propertyContainer->getLocalProperties();
 }
 //=========================================================================
-Iterator<std::string>* GraphAbstract::getInheritedProperties() const {
+Iterator<std::string> *GraphAbstract::getInheritedProperties() const {
   return propertyContainer->getInheritedProperties();
 }
 //=========================================================================
-Iterator<std::string>* GraphAbstract::getProperties() const {
-  return new ConcatIterator<std::string> (propertyContainer->getLocalProperties(),propertyContainer->getInheritedProperties());
+Iterator<std::string> *GraphAbstract::getProperties() const {
+  return new ConcatIterator<std::string>(propertyContainer->getLocalProperties(),
+                                         propertyContainer->getInheritedProperties());
 }
 //=========================================================================
-Iterator<PropertyInterface*>* GraphAbstract::getLocalObjectProperties() const {
+Iterator<PropertyInterface *> *GraphAbstract::getLocalObjectProperties() const {
   return propertyContainer->getLocalObjectProperties();
 }
 //=========================================================================
-Iterator<PropertyInterface*>* GraphAbstract::getInheritedObjectProperties() const {
+Iterator<PropertyInterface *> *GraphAbstract::getInheritedObjectProperties() const {
   return propertyContainer->getInheritedObjectProperties();
 }
 //=========================================================================
-Iterator<PropertyInterface*>* GraphAbstract::getObjectProperties() const {
-  return new ConcatIterator<PropertyInterface*> (propertyContainer->getLocalObjectProperties(),propertyContainer->getInheritedObjectProperties());
+Iterator<PropertyInterface *> *GraphAbstract::getObjectProperties() const {
+  return new ConcatIterator<PropertyInterface *>(propertyContainer->getLocalObjectProperties(),
+                                                 propertyContainer->getInheritedObjectProperties());
 }
 //=========================================================================
-unsigned int GraphAbstract::numberOfNodes() const {
-  unsigned int result=0;
-  Iterator<node> *it=getNodes();
-
-  while(it->hasNext()) {
-    it->next();
-    ++result;
-  }
-
-  delete it;
-  return result;
-}
-//=========================================================================
-unsigned int GraphAbstract::numberOfEdges() const {
-  unsigned int result=0;
-  Iterator<edge> *it=getEdges();
-
-  while (it->hasNext()) {
-    it->next();
-    ++result;
-  }
-
-  delete it;
-  return result;
-}
-//=========================================================================
-DataSet& GraphAbstract::getNonConstAttributes() {
-  return attributes;
-}
-//----------------------------------------------------------------
 bool GraphAbstract::isMetaNode(const node n) const {
   assert(isElement(n));
   return metaGraphProperty && metaGraphProperty->hasNonDefaultValue(n);
@@ -590,17 +442,17 @@ bool GraphAbstract::isMetaEdge(const edge e) const {
   return metaGraphProperty && metaGraphProperty->hasNonDefaultValue(e);
 }
 //=========================================================================
-Graph* GraphAbstract::getNodeMetaInfo(const node n) const {
+Graph *GraphAbstract::getNodeMetaInfo(const node n) const {
   if (metaGraphProperty)
     return metaGraphProperty->getNodeValue(n);
 
-  return NULL;
+  return nullptr;
 }
 
 // only used to return a reference on an empty vector of edges
 static set<edge> noReferencedEdges;
 //=========================================================================
-const set<edge>& GraphAbstract::getReferencedEdges(const edge e) const {
+const set<edge> &GraphAbstract::getReferencedEdges(const edge e) const {
   if (metaGraphProperty)
     return metaGraphProperty->getReferencedEdges(e);
   else
@@ -609,33 +461,32 @@ const set<edge>& GraphAbstract::getReferencedEdges(const edge e) const {
 //=========================================================================
 // Iterator on a vector of edges
 // used for the edge associated value of a GraphProperty
-class EdgeSetIterator:public Iterator<edge> {
+class EdgeSetIterator : public Iterator<edge> {
   set<edge>::const_iterator it, itEnd;
+
 public:
-  EdgeSetIterator(const set<edge>& edges):
-    it(edges.begin()), itEnd(edges.end()) {}
-  ~EdgeSetIterator() {}
-  edge next() {
-    edge tmp=(*it);
+  EdgeSetIterator(const set<edge> &edges) : it(edges.begin()), itEnd(edges.end()) {}
+  ~EdgeSetIterator() override {}
+  edge next() override {
+    edge tmp = (*it);
     ++it;
     return tmp;
   }
 
-  bool hasNext() {
-    return (it!=itEnd);
+  bool hasNext() override {
+    return (it != itEnd);
   }
 };
 
-Iterator<edge>* GraphAbstract::getEdgeMetaInfo(const edge e) const {
+Iterator<edge> *GraphAbstract::getEdgeMetaInfo(const edge e) const {
   return new EdgeSetIterator(getReferencedEdges(e));
 }
 
-GraphProperty* GraphAbstract::getMetaGraphProperty() {
+GraphProperty *GraphAbstract::getMetaGraphProperty() {
   if (metaGraphProperty)
     return metaGraphProperty;
 
-  return metaGraphProperty =
-           getRoot()->getProperty<GraphProperty>(metaGraphPropertyName);
+  return metaGraphProperty = getRoot()->getProperty<GraphProperty>(metaGraphPropertyName);
 }
 
 void GraphAbstract::setName(const std::string &name) {
@@ -648,12 +499,16 @@ std::string GraphAbstract::getName() const {
   return name;
 }
 
-Iterator<node>* GraphAbstract::bfs(const node root) const {
-  vector<node> bfsResult = tlp::bfs(this, root);
-  return new StableIterator<tlp::node>(new StlIterator<node, std::vector<tlp::node>::iterator>(bfsResult.begin(), bfsResult.end()));
+Iterator<node> *GraphAbstract::bfs(const node root) const {
+  vector<node> bfsResult;
+  tlp::bfs(this, root, bfsResult);
+  return new StableIterator<tlp::node>(
+      new StlIterator<node, std::vector<tlp::node>::iterator>(bfsResult.begin(), bfsResult.end()));
 }
 
-Iterator<node>* GraphAbstract::dfs(const node root) const {
-  vector<node> dfsResult = tlp::dfs(this, root);
-  return new StableIterator<tlp::node>(new StlIterator<node, std::vector<tlp::node>::iterator>(dfsResult.begin(), dfsResult.end()));
+Iterator<node> *GraphAbstract::dfs(const node root) const {
+  vector<node> dfsResult;
+  tlp::dfs(this, root, dfsResult);
+  return new StableIterator<tlp::node>(
+      new StlIterator<node, std::vector<tlp::node>::iterator>(dfsResult.begin(), dfsResult.end()));
 }
