@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,7 +20,7 @@
 
 using namespace tlp;
 
-GraphDecorator::GraphDecorator(Graph* s):graph_component(s) {
+GraphDecorator::GraphDecorator(Graph *s) : graph_component(s) {
   assert(s);
 }
 
@@ -28,16 +28,14 @@ GraphDecorator::~GraphDecorator() {
   notifyDestroy();
 }
 
-
 //============================================================
 void GraphDecorator::clear() {
   graph_component->clear();
 }
 
 //============================================================
-Graph *GraphDecorator::addSubGraph(BooleanProperty *selection,
-                                   const std::string& name) {
-  Graph* sg = graph_component->addSubGraph(selection, name);
+Graph *GraphDecorator::addSubGraph(BooleanProperty *selection, const std::string &name) {
+  Graph *sg = graph_component->addSubGraph(selection, name);
   notifyBeforeAddSubGraph(sg);
   notifyAfterAddSubGraph(sg);
   return sg;
@@ -59,22 +57,22 @@ unsigned int GraphDecorator::numberOfDescendantGraphs() const {
 }
 //============================================================
 void GraphDecorator::restoreSubGraph(Graph *) {
-  tlp::warning() << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
+  tlp::warning() << "Warning : " << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 
 //============================================================
 void GraphDecorator::setSubGraphToKeep(Graph *) {
-  tlp::warning() << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
+  tlp::warning() << "Warning : " << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 
 //============================================================
-void GraphDecorator::removeSubGraph(Graph*) {
-  tlp::warning() << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
+void GraphDecorator::removeSubGraph(Graph *) {
+  tlp::warning() << "Warning : " << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 
 //============================================================
 void GraphDecorator::clearSubGraphs() {
-  tlp::warning() << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
+  tlp::warning() << "Warning : " << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 
 //============================================================
@@ -85,64 +83,71 @@ void GraphDecorator::delAllSubGraphs(Graph *s) {
 }
 
 //============================================================
-Graph* GraphDecorator::getSuperGraph()const {
+Graph *GraphDecorator::getSuperGraph() const {
   return graph_component->getSuperGraph();
 }
 
 //============================================================
-node GraphDecorator::createMetaNode(const std::set<node> &nodeSet, bool multiEdges, bool delAllEdge) {
-  return graph_component->createMetaNode(nodeSet, multiEdges, delAllEdge);
+node GraphDecorator::createMetaNode(const std::vector<node> &nodes, bool multiEdges,
+                                    bool delAllEdge) {
+  return graph_component->createMetaNode(nodes, multiEdges, delAllEdge);
 }
 
-void GraphDecorator::createMetaNodes(Iterator<Graph *> *itS, Graph *quotientGraph, std::vector<node>& metaNodes) {
+void GraphDecorator::createMetaNodes(Iterator<Graph *> *itS, Graph *quotientGraph,
+                                     std::vector<node> &metaNodes) {
   graph_component->createMetaNodes(itS, quotientGraph, metaNodes);
 }
 
-node GraphDecorator::createMetaNode(Graph* subGraph, bool multiEdges, bool delAllEdge) {
+node GraphDecorator::createMetaNode(Graph *subGraph, bool multiEdges, bool delAllEdge) {
   return graph_component->createMetaNode(subGraph, multiEdges, delAllEdge);
 }
 
 //============================================================
-void GraphDecorator::setSuperGraph(Graph* s) {
+void GraphDecorator::setSuperGraph(Graph *s) {
   graph_component->setSuperGraph(s);
 }
 
 //============================================================
-Graph* GraphDecorator::getRoot() const {
+Graph *GraphDecorator::getRoot() const {
   return graph_component->getRoot();
 }
 
 //============================================================
-Iterator<Graph *> * GraphDecorator::getSubGraphs() const {
+Iterator<Graph *> *GraphDecorator::getSubGraphs() const {
   return graph_component->getSubGraphs();
 }
 
+//============================================================
+const std::vector<Graph *> &GraphDecorator::subGraphs() const {
+  return graph_component->subGraphs();
+}
+
 //=========================================================================
-bool GraphDecorator::isSubGraph(const Graph* sg) const {
+bool GraphDecorator::isSubGraph(const Graph *sg) const {
   return graph_component->isSubGraph(sg);
 }
 //=========================================================================
-bool GraphDecorator::isDescendantGraph(const Graph* sg) const {
+bool GraphDecorator::isDescendantGraph(const Graph *sg) const {
   return graph_component->isDescendantGraph(sg);
 }
 //=========================================================================
-Graph* GraphDecorator::getSubGraph(unsigned int sgId) const {
+Graph *GraphDecorator::getSubGraph(unsigned int sgId) const {
   return graph_component->getSubGraph(sgId);
 }
 //=========================================================================
-Graph* GraphDecorator::getSubGraph(const std::string &name) const {
+Graph *GraphDecorator::getSubGraph(const std::string &name) const {
   return graph_component->getSubGraph(name);
 }
 //=========================================================================
-Graph* GraphDecorator::getDescendantGraph(unsigned int sgId) const {
+Graph *GraphDecorator::getDescendantGraph(unsigned int sgId) const {
   return graph_component->getDescendantGraph(sgId);
 }
 //=========================================================================
-Graph* GraphDecorator::getDescendantGraph(const std::string &name) const {
+Graph *GraphDecorator::getDescendantGraph(const std::string &name) const {
   return graph_component->getDescendantGraph(name);
 }
 //============================================================
-node GraphDecorator::source(const edge e)const {
+node GraphDecorator::source(const edge e) const {
   return graph_component->source(e);
 }
 
@@ -152,7 +157,7 @@ void GraphDecorator::setSource(const edge e, const node n) {
 }
 
 //============================================================
-node GraphDecorator::target(const edge e)const {
+node GraphDecorator::target(const edge e) const {
   return graph_component->target(e);
 }
 
@@ -162,30 +167,27 @@ void GraphDecorator::setTarget(const edge e, const node n) {
 }
 
 //============================================================
-node GraphDecorator::opposite(const edge e, const node n)const {
-  return graph_component->opposite(e,n);
+node GraphDecorator::opposite(const edge e, const node n) const {
+  return graph_component->opposite(e, n);
 }
 
 //============================================================
-bool GraphDecorator::hasEdge(const node n, const node m,
-                             bool directed) const {
+bool GraphDecorator::hasEdge(const node n, const node m, bool directed) const {
   return graph_component->hasEdge(n, m, directed);
 }
 
 //============================================================
-std::vector<edge> GraphDecorator::getEdges(const node n, const node m,
-    bool directed) const {
+std::vector<edge> GraphDecorator::getEdges(const node n, const node m, bool directed) const {
   return graph_component->getEdges(n, m, directed);
 }
 
 //============================================================
-edge GraphDecorator::existEdge(const node n, const node m,
-                               bool directed) const {
+edge GraphDecorator::existEdge(const node n, const node m, bool directed) const {
   return graph_component->existEdge(n, m, directed);
 }
 
 //============================================================
-const std::pair<node, node>& GraphDecorator::ends(const edge e) const {
+const std::pair<node, node> &GraphDecorator::ends(const edge e) const {
   return graph_component->ends(e);
 }
 
@@ -201,22 +203,22 @@ void GraphDecorator::reverse(const edge e) {
 }
 
 //============================================================
-unsigned int GraphDecorator::deg(const node n)const {
+unsigned int GraphDecorator::deg(const node n) const {
   return graph_component->deg(n);
 }
 
 //============================================================
-unsigned int GraphDecorator::indeg(const node n)const {
+unsigned int GraphDecorator::indeg(const node n) const {
   return graph_component->indeg(n);
 }
 
 //============================================================
-unsigned int GraphDecorator::outdeg(const node n)const {
+unsigned int GraphDecorator::outdeg(const node n) const {
   return graph_component->outdeg(n);
 }
 
 //============================================================
-Graph* GraphDecorator::getNodeMetaInfo(const node n)const {
+Graph *GraphDecorator::getNodeMetaInfo(const node n) const {
   return graph_component->getNodeMetaInfo(n);
 }
 
@@ -231,13 +233,13 @@ node GraphDecorator::getRandomNode() const {
 }
 
 //============================================================
-node GraphDecorator::getInNode(const node n,unsigned int i)const {
-  return graph_component->getInNode(n,i);
+node GraphDecorator::getInNode(const node n, unsigned int i) const {
+  return graph_component->getInNode(n, i);
 }
 
 //============================================================
-node GraphDecorator::getOutNode(const node n,unsigned int i) const {
-  return graph_component->getOutNode(n,i);
+node GraphDecorator::getOutNode(const node n, unsigned int i) const {
+  return graph_component->getOutNode(n, i);
 }
 
 //============================================================
@@ -251,7 +253,7 @@ edge GraphDecorator::getRandomEdge() const {
 }
 
 //============================================================
-unsigned int GraphDecorator::numberOfNodes()const {
+unsigned int GraphDecorator::numberOfNodes() const {
   return graph_component->numberOfNodes();
 }
 
@@ -261,10 +263,15 @@ void GraphDecorator::reserveNodes(unsigned int nbNodes) {
 }
 
 //============================================================
-unsigned int GraphDecorator::numberOfEdges()const {
+unsigned int GraphDecorator::numberOfEdges() const {
   return graph_component->numberOfEdges();
 }
 
+//============================================================
+bool GraphDecorator::isEmpty() const {
+  return graph_component->isEmpty();
+}
+
 //============================================================
 void GraphDecorator::reserveEdges(unsigned int nbEdges) {
   return graph_component->reserveEdges(nbEdges);
@@ -298,37 +305,39 @@ node GraphDecorator::addNode() {
 }
 
 //============================================================
-void GraphDecorator::addNodes(unsigned int nb, std::vector<node>& addedNodes) {
+void GraphDecorator::addNodes(unsigned int nb) {
+  graph_component->addNodes(nb);
+
+  if (hasOnlookers())
+    sendEvent(GraphEvent(*this, GraphEvent::TLP_ADD_NODES, nb));
+}
+
+//============================================================
+void GraphDecorator::addNodes(unsigned int nb, std::vector<node> &addedNodes) {
   graph_component->addNodes(nb, addedNodes);
 
   if (hasOnlookers())
-    sendEvent(GraphEvent(*this, GraphEvent::TLP_ADD_NODES, addedNodes));
+    sendEvent(GraphEvent(*this, GraphEvent::TLP_ADD_NODES, nb));
 }
 
 //============================================================
 void GraphDecorator::addNode(const node) {
-  tlp::warning() << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
+  tlp::warning() << "Warning : " << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 
 //============================================================
-void GraphDecorator::addNodes(Iterator<node>*) {
-  tlp::warning() << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
+void GraphDecorator::addNodes(Iterator<node> *) {
+  tlp::warning() << "Warning : " << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 
 //============================================================
-node GraphDecorator::restoreNode(node n) {
-  tlp::warning() << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
-  return n;
-}
-
-//============================================================
-void GraphDecorator::restoreNodes(const std::vector<node>&) {
-  tlp::warning() << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
+void GraphDecorator::restoreNode(node) {
+  tlp::warning() << "Warning : " << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 
 //============================================================
 void GraphDecorator::removeNode(const node) {
-  tlp::warning() << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
+  tlp::warning() << "Warning : " << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 
 //============================================================
@@ -339,38 +348,40 @@ edge GraphDecorator::addEdge(const node n, const node n2) {
 }
 
 //============================================================
-void GraphDecorator::addEdges(const std::vector<std::pair<node, node> >& edges,
-                              std::vector<edge>& addedEdges) {
+void GraphDecorator::addEdges(const std::vector<std::pair<node, node>> &edges) {
+  graph_component->addEdges(edges);
+
+  if (hasOnlookers())
+    sendEvent(GraphEvent(*this, GraphEvent::TLP_ADD_EDGES, edges.size()));
+}
+
+//============================================================
+void GraphDecorator::addEdges(const std::vector<std::pair<node, node>> &edges,
+                              std::vector<edge> &addedEdges) {
   graph_component->addEdges(edges, addedEdges);
 
   if (hasOnlookers())
-    sendEvent(GraphEvent(*this, GraphEvent::TLP_ADD_EDGES, addedEdges));
+    sendEvent(GraphEvent(*this, GraphEvent::TLP_ADD_EDGES, edges.size()));
 }
 
 //============================================================
 void GraphDecorator::addEdge(const edge) {
-  tlp::warning() << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
+  tlp::warning() << "Warning : " << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 
 //============================================================
-void GraphDecorator::addEdges(Iterator<edge>*) {
-  tlp::warning() << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
+void GraphDecorator::addEdges(Iterator<edge> *) {
+  tlp::warning() << "Warning : " << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 
 //============================================================
-edge GraphDecorator::restoreEdge(edge e, node, node) {
-  tlp::warning() << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
-  return e;
+void GraphDecorator::restoreEdge(edge, node, node) {
+  tlp::warning() << "Warning : " << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 
-//============================================================
-void GraphDecorator::restoreEdges(const std::vector<edge>&,
-                                  const std::vector<std::pair<node, node> >&) {
-  tlp::warning() << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
-}
 //============================================================
 void GraphDecorator::removeEdge(const edge) {
-  tlp::warning() << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
+  tlp::warning() << "Warning : " << __PRETTY_FUNCTION__ << " ... Impossible operation" << std::endl;
 }
 
 //============================================================
@@ -380,10 +391,10 @@ void GraphDecorator::delNode(const node n, bool deleteInAllGraphs) {
 }
 
 //============================================================
-void GraphDecorator::delNodes(Iterator<node>* itN, bool deleteInAllGraphs) {
-  assert(itN != NULL);
+void GraphDecorator::delNodes(Iterator<node> *itN, bool deleteInAllGraphs) {
+  assert(itN != nullptr);
 
-  while(itN->hasNext()) {
+  while (itN->hasNext()) {
     delNode(itN->next(), deleteInAllGraphs);
   }
 }
@@ -395,91 +406,116 @@ void GraphDecorator::delEdge(const edge e, bool deleteInAllGraphs) {
 }
 
 //=========================================================================
-void GraphDecorator::delEdges(Iterator<edge>* itE, bool deleteInAllGraphs) {
-  assert(itE != NULL);
+void GraphDecorator::delEdges(Iterator<edge> *itE, bool deleteInAllGraphs) {
+  assert(itE != nullptr);
 
-  while(itE->hasNext()) {
+  while (itE->hasNext()) {
     delEdge(itE->next(), deleteInAllGraphs);
   }
 }
 
 //============================================================
-void GraphDecorator::setEdgeOrder(const node n,const std::vector<edge> & s) {
-  graph_component->setEdgeOrder(n,s);
+void GraphDecorator::setEdgeOrder(const node n, const std::vector<edge> &s) {
+  graph_component->setEdgeOrder(n, s);
 }
 
-void GraphDecorator::swapEdgeOrder(const node n ,const edge e1, const edge e2) {
+//============================================================
+void GraphDecorator::swapEdgeOrder(const node n, const edge e1, const edge e2) {
   graph_component->swapEdgeOrder(n, e1, e2);
 }
 
 //============================================================
-Iterator<node>* GraphDecorator::getNodes() const {
+const std::vector<node> &GraphDecorator::nodes() const {
+  return graph_component->nodes();
+}
+//============================================================
+unsigned int GraphDecorator::nodePos(const node n) const {
+  return graph_component->nodePos(n);
+}
+//============================================================
+Iterator<node> *GraphDecorator::getNodes() const {
   return graph_component->getNodes();
 }
 
 //============================================================
-Iterator<node>* GraphDecorator::getInNodes(const node n) const {
+Iterator<node> *GraphDecorator::getInNodes(const node n) const {
   return graph_component->getInNodes(n);
 }
 
 //============================================================
-Iterator<node>* GraphDecorator::getOutNodes(const node n) const {
+Iterator<node> *GraphDecorator::getOutNodes(const node n) const {
   return graph_component->getOutNodes(n);
 }
 
 //============================================================
-Iterator<node>* GraphDecorator::getInOutNodes(const node n) const {
+Iterator<node> *GraphDecorator::getInOutNodes(const node n) const {
   return graph_component->getInOutNodes(n);
 }
 //============================================================
-Iterator<node>* GraphDecorator::bfs(const node root) const {
+Iterator<node> *GraphDecorator::bfs(const node root) const {
   return graph_component->bfs(root);
 }
 //============================================================
-Iterator<node>* GraphDecorator::dfs(const node root) const {
+Iterator<node> *GraphDecorator::dfs(const node root) const {
   return graph_component->dfs(root);
 }
 //============================================================
-Iterator<edge>* GraphDecorator::getEdges() const {
+const std::vector<edge> &GraphDecorator::edges() const {
+  return graph_component->edges();
+}
+//============================================================
+unsigned int GraphDecorator::edgePos(const edge e) const {
+  return graph_component->edgePos(e);
+}
+//============================================================
+Iterator<edge> *GraphDecorator::getEdges() const {
   return graph_component->getEdges();
 }
 //============================================================
-Iterator<edge>* GraphDecorator::getOutEdges(const node n) const {
+Iterator<edge> *GraphDecorator::getOutEdges(const node n) const {
   return graph_component->getOutEdges(n);
 }
 //============================================================
-Iterator<edge>* GraphDecorator::getInOutEdges(const node n) const {
+Iterator<edge> *GraphDecorator::getInOutEdges(const node n) const {
   return graph_component->getInOutEdges(n);
 }
 //============================================================
-Iterator<edge>* GraphDecorator::getInEdges(const node n) const {
+Iterator<edge> *GraphDecorator::getInEdges(const node n) const {
   return graph_component->getInEdges(n);
 }
 //============================================================
-Iterator<edge>* GraphDecorator::getEdgeMetaInfo(const edge e) const {
+const std::vector<edge> &GraphDecorator::allEdges(const node n) const {
+  return graph_component->allEdges(n);
+}
+//============================================================
+Iterator<edge> *GraphDecorator::getEdgeMetaInfo(const edge e) const {
   return graph_component->getEdgeMetaInfo(e);
 }
 //============================================================
-DataSet& GraphDecorator::getNonConstAttributes() {
+void GraphDecorator::sortElts() {
+  return graph_component->sortElts();
+}
+//============================================================
+DataSet &GraphDecorator::getNonConstAttributes() {
   return graph_component->getNonConstAttributes();
 }
 //============================================================
-PropertyInterface* GraphDecorator::getProperty(const std::string &name) const {
+PropertyInterface *GraphDecorator::getProperty(const std::string &name) const {
   return graph_component->getProperty(name);
 }
 
 //============================================================
-bool GraphDecorator::existProperty(const std::string&name) const {
+bool GraphDecorator::existProperty(const std::string &name) const {
   return graph_component->existProperty(name);
 }
 
 //============================================================
-bool GraphDecorator::existLocalProperty(const std::string&name) const {
-  return graph_component->existLocalProperty(name) ;
+bool GraphDecorator::existLocalProperty(const std::string &name) const {
+  return graph_component->existLocalProperty(name);
 }
 
 //============================================================
-void GraphDecorator::delLocalProperty(const std::string&name) {
+void GraphDecorator::delLocalProperty(const std::string &name) {
   notifyBeforeDelLocalProperty(name);
   graph_component->delLocalProperty(name);
   notifyAfterDelLocalProperty(name);
@@ -493,37 +529,36 @@ void GraphDecorator::addLocalProperty(const std::string &name, PropertyInterface
 }
 
 //============================================================
-bool GraphDecorator::renameLocalProperty(PropertyInterface* prop,
-    const std::string& newName) {
+bool GraphDecorator::renameLocalProperty(PropertyInterface *prop, const std::string &newName) {
   return graph_component->renameLocalProperty(prop, newName);
 }
 
 //============================================================
-Iterator<std::string>* GraphDecorator::getLocalProperties() const {
+Iterator<std::string> *GraphDecorator::getLocalProperties() const {
   return graph_component->getLocalProperties();
 }
 
 //============================================================
-Iterator<std::string>* GraphDecorator::getInheritedProperties() const {
+Iterator<std::string> *GraphDecorator::getInheritedProperties() const {
   return graph_component->getInheritedProperties();
 }
 
 //============================================================
-Iterator<std::string>* GraphDecorator::getProperties() const {
+Iterator<std::string> *GraphDecorator::getProperties() const {
   return graph_component->getProperties();
 }
 //============================================================
-Iterator<PropertyInterface*>* GraphDecorator::getLocalObjectProperties() const {
+Iterator<PropertyInterface *> *GraphDecorator::getLocalObjectProperties() const {
   return graph_component->getLocalObjectProperties();
 }
 
 //============================================================
-Iterator<PropertyInterface*>* GraphDecorator::getInheritedObjectProperties() const {
+Iterator<PropertyInterface *> *GraphDecorator::getInheritedObjectProperties() const {
   return graph_component->getInheritedObjectProperties();
 }
 
 //============================================================
-Iterator<PropertyInterface*>* GraphDecorator::getObjectProperties() const {
+Iterator<PropertyInterface *> *GraphDecorator::getObjectProperties() const {
   return graph_component->getObjectProperties();
 }
 //----------------------------------------------------------------
@@ -538,7 +573,7 @@ bool GraphDecorator::canPopThenUnpop() {
 }
 //----------------------------------------------------------------
 void GraphDecorator::push(bool unpopAllowed,
-                          std::vector<PropertyInterface*>* propertiesToPreserveOnPop) {
+                          std::vector<PropertyInterface *> *propertiesToPreserveOnPop) {
   return graph_component->push(unpopAllowed, propertiesToPreserveOnPop);
 }
 //----------------------------------------------------------------
@@ -546,6 +581,10 @@ void GraphDecorator::pop(bool unpopAllowed) {
   return graph_component->pop(unpopAllowed);
 }
 //----------------------------------------------------------------
+void GraphDecorator::popIfNoUpdates() {
+  return graph_component->popIfNoUpdates();
+}
+//----------------------------------------------------------------
 void GraphDecorator::unpop() {
   return graph_component->unpop();
 }
