@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,14 +17,13 @@
  *
  */
 
-#include <queue>
+#include <stack>
 
 #include <tulip/Graph.h>
 #include <tulip/GraphImpl.h>
 #include <tulip/PropertyManager.h>
 #include <tulip/GraphView.h>
-#include <tulip/GraphIterator.h>
-#include <tulip/ForEach.h>
+#include <tulip/GraphIterators.h>
 #include <tulip/GraphUpdatesRecorder.h>
 
 using namespace std;
@@ -35,71 +34,16 @@ using namespace tlp;
  * function to test if an edge e exist in the adjacency of a node
  */
 static bool existEdgeE(Graph *g, const node n1, const node, edge e) {
-  Iterator<edge> *it = g->getOutEdges(n1);
-
-  while (it->hasNext()) {
-    edge e1(it->next());
-
+  for (auto e1 : g->getOutEdges(n1)) {
     if (e == e1) {
-      delete it;
       return true;
     }
   }
-
-  delete it;
   return false;
 }
 #endif
-/*
- * function to test the integrity of the graph structure
- */
-/* no needed for the moment
-static bool integrityTest(Graph *graph) {
-  Iterator<edge> *itE = graph->getEdges();
-  set<edge> edgesTest;
-  while(itE->hasNext()) {
-    edge e = itE->next();
-    edgesTest.insert(e);
-    if (!existEdgeE(graph, graph->source(e), graph->target(e), e)) {
-      tlp::warning() << "edge do not exist in neighbood";
-      delete itE;
-      return false;
-    }
-  }
-  delete itE;
-  Iterator<node> *itN = graph->getNodes();
-  while(itN->hasNext()) {
-    node n(itN->next());
-    unsigned int degree = 0;
-    Iterator<edge> *it = graph->getInOutEdges(n);
-    while (it->hasNext()) {
-      edge e = it->next();
-      bool found = edgesTest.find(e)!=edgesTest.end();
-      if (graph->isElement(e)!=found) {
-  tlp::warning() << "isElment function not valid";
-  delete it;
-  delete itN;
-  return false;
-      }
-      if (!graph->isElement(e)) {
-  tlp::warning() << "Adjacency edges are not valid";
-  delete it;
-  delete itN;
-  return false;
-      }
-      degree++;
-    } delete it;
-    if (graph->deg(n) != degree) {
-      tlp::warning() << "degree failed";
-      return false;
-    }
-  }delete itN;
-  return true;
-}
-*/
 //----------------------------------------------------------------
-GraphImpl::GraphImpl():
-  GraphAbstract(this, 0) {
+GraphImpl::GraphImpl() : GraphAbstract(this) {
   // id 0 is for the root
   graphIds.get();
 }
@@ -110,9 +54,9 @@ GraphImpl::~GraphImpl() {
   // delete recorders
   if (!recorders.empty()) {
     recorders.front()->stopRecording(this);
-    std::list<GraphUpdatesRecorder*>::iterator it = recorders.begin();
+    std::list<GraphUpdatesRecorder *>::iterator it = recorders.begin();
 
-    while(it != recorders.end()) {
+    while (it != recorders.end()) {
       delete (*it);
       ++it;
     }
@@ -131,18 +75,9 @@ void GraphImpl::clear() {
   storage.clear();
 }
 //----------------------------------------------------------------
-bool GraphImpl::isElement(const node n) const {
-  return storage.isElement(n);
-}
-//----------------------------------------------------------------
-bool GraphImpl::isElement(const edge e) const {
-  return storage.isElement(e);
-}
-//----------------------------------------------------------------
-edge GraphImpl::existEdge(const node src, const node tgt,
-                          bool directed) const {
+edge GraphImpl::existEdge(const node src, const node tgt, bool directed) const {
   std::vector<edge> edges;
-  return storage.getEdges(src, tgt, directed, edges, true) ? edges[0] : edge();
+  return storage.getEdges(src, tgt, directed, edges, nullptr, true) ? edges[0] : edge();
 }
 //----------------------------------------------------------------
 unsigned int GraphImpl::getSubGraphId(unsigned int id) {
@@ -157,19 +92,9 @@ void GraphImpl::freeSubGraphId(unsigned int id) {
   graphIds.free(id);
 }
 //----------------------------------------------------------------
-node GraphImpl::restoreNode(node newNode) {
-  storage.addNode(newNode);
+void GraphImpl::restoreNode(node newNode) {
+  storage.restoreNode(newNode);
   notifyAddNode(newNode);
-  return newNode;
-}
-//----------------------------------------------------------------
-void GraphImpl::restoreNodes(const std::vector<node>& nodes) {
-  if (!nodes.empty()) {
-    storage.restoreNodes(nodes);
-
-    if (hasOnlookers())
-      sendEvent(GraphEvent(*this, GraphEvent::TLP_ADD_NODES, nodes));
-  }
 }
 //----------------------------------------------------------------
 node GraphImpl::addNode() {
@@ -179,78 +104,78 @@ node GraphImpl::addNode() {
 }
 //----------------------------------------------------------------
 void GraphImpl::addNodes(unsigned int nb) {
-  storage.addNodes(nb);
+  if (nb) {
+    storage.addNodes(nb);
+
+    if (hasOnlookers())
+      sendEvent(GraphEvent(*this, GraphEvent::TLP_ADD_NODES, nb));
+  }
 }
 //----------------------------------------------------------------
-void GraphImpl::addNodes(unsigned int nb, std::vector<node>& addedNodes) {
+void GraphImpl::addNodes(unsigned int nb, std::vector<node> &addedNodes) {
   if (nb) {
     storage.addNodes(nb, &addedNodes);
 
     if (hasOnlookers())
-      sendEvent(GraphEvent(*this, GraphEvent::TLP_ADD_NODES, addedNodes));
+      sendEvent(GraphEvent(*this, GraphEvent::TLP_ADD_NODES, nb));
   }
 }
 //----------------------------------------------------------------
 void GraphImpl::addNode(const node) {
-  tlp::warning() << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation on Root Graph" << std::endl;
+  tlp::warning() << "Warning : " << __PRETTY_FUNCTION__ << " ... Impossible operation on Root Graph"
+                 << std::endl;
 }
 //----------------------------------------------------------------
-void GraphImpl::addNodes(Iterator<node>*) {
-  tlp::warning() << "Warning : "  << __PRETTY_FUNCTION__ << " ... Impossible operation on Root Graph" << std::endl;
+void GraphImpl::addNodes(Iterator<node> *) {
+  tlp::warning() << "Warning : " << __PRETTY_FUNCTION__ << " ... Impossible operation on Root Graph"
+                 << std::endl;
 }
 //----------------------------------------------------------------
 void GraphImpl::reserveNodes(unsigned int nb) {
   storage.reserveNodes(nb);
 }
 //----------------------------------------------------------------
-void GraphImpl::restoreAdj(node n, vector<edge>& edges) {
-  storage.restoreAdj(n, edges);
-}
-//----------------------------------------------------------------
-edge GraphImpl::restoreEdge(edge newEdge, const node src, const node tgt) {
-  storage.addEdge(src, tgt, newEdge, false);
+void GraphImpl::restoreEdge(edge newEdge, const node src, const node tgt) {
+  storage.restoreEdge(src, tgt, newEdge);
   notifyAddEdge(newEdge);
-  return newEdge;
 }
 //----------------------------------------------------------------
 edge GraphImpl::addEdge(const node src, const node tgt) {
-  assert(src.isValid()&&tgt.isValid());
+  assert(src.isValid() && tgt.isValid());
   edge newEdge = storage.addEdge(src, tgt);
   notifyAddEdge(newEdge);
   return newEdge;
 }
 //----------------------------------------------------------------
-void GraphImpl::addEdges(const std::vector<std::pair<node, node> >& edges,
-                         std::vector<edge>& addedEdges) {
+void GraphImpl::addEdges(const std::vector<std::pair<node, node>> &edges,
+                         std::vector<edge> &addedEdges) {
   if (!edges.empty()) {
     storage.addEdges(edges, &addedEdges);
 
     if (hasOnlookers())
-      sendEvent(GraphEvent(*this, GraphEvent::TLP_ADD_EDGES, addedEdges));
+      sendEvent(GraphEvent(*this, GraphEvent::TLP_ADD_EDGES, edges.size()));
   }
 }
 //----------------------------------------------------------------
-void GraphImpl::addEdges(const std::vector<std::pair<node, node> >& edges) {
-  storage.addEdges(edges);
-}
-//----------------------------------------------------------------
-void GraphImpl::restoreEdges(const std::vector<edge>& edges,
-                             const std::vector<std::pair<node, node> >& ends) {
+void GraphImpl::addEdges(const std::vector<std::pair<node, node>> &edges) {
   if (!edges.empty()) {
-    storage.restoreEdges(edges, ends);
+    storage.addEdges(edges);
 
     if (hasOnlookers())
-      sendEvent(GraphEvent(*this, GraphEvent::TLP_ADD_EDGES, edges));
+      sendEvent(GraphEvent(*this, GraphEvent::TLP_ADD_EDGES, edges.size()));
   }
 }
 //----------------------------------------------------------------
 void GraphImpl::addEdge(const edge e) {
-  tlp::warning() << "Warning: "  << __PRETTY_FUNCTION__ << " ... Impossible operation on Root Graph" << std::endl;
-  tlp::warning() << "\t Trying to add edge " << e.id << " (" << source(e).id << "," << target(e).id << ")";
+  tlp::warning() << "Warning: " << __PRETTY_FUNCTION__ << " ... Impossible operation on Root Graph"
+                 << std::endl;
+  tlp::warning() << "\t Trying to add edge " << e.id << " (" << source(e).id << "," << target(e).id
+                 << ")";
 }
 //----------------------------------------------------------------
-void GraphImpl::addEdges(Iterator<edge>*) {
-  tlp::warning() << "Warning: "  << __PRETTY_FUNCTION__ << " ... Impossible operation on Root Graph" << std::endl;
+void GraphImpl::addEdges(Iterator<edge> *) {
+  tlp::warning() << "Warning: " << __PRETTY_FUNCTION__ << " ... Impossible operation on Root Graph"
+                 << std::endl;
 }
 //----------------------------------------------------------------
 void GraphImpl::reserveEdges(unsigned int nb) {
@@ -266,57 +191,41 @@ void GraphImpl::removeNode(const node n) {
 }
 //----------------------------------------------------------------
 void GraphImpl::delNode(const node n, bool) {
-  assert (isElement(n));
-  notifyDelNode(n);
-  // get edges vector with loops appearing only once
-  std::vector<edge> edges;
-  storage.getInOutEdges(n, edges, true);
+  assert(isElement(n));
+  std::vector<edge> edges(storage.adj(n));
 
-  // use a queue for a dfs subgraphs propagation
-  std::queue<Graph*> sgq;
-  Iterator<Graph*>* sgs = getSubGraphs();
-
-  while (sgs->hasNext()) {
-    Graph* sg = sgs->next();
+  // use a stack for a dfs subgraphs propagation
+  std::stack<Graph *> sgq;
 
+  for (Graph *sg : subGraphs()) {
     if (sg->isElement(n))
       sgq.push(sg);
   }
 
-  delete sgs;
-
   // subgraphs loop
-  while(!sgq.empty()) {
-    Graph* sg = sgq.front();
-
-    sgs = sg->getSubGraphs();
-
-    while (sgs->hasNext()) {
-      Graph* ssg = sgs->next();
+  while (!sgq.empty()) {
+    Graph *sg = sgq.top();
 
+    for (Graph *ssg : sg->subGraphs()) {
       if (ssg->isElement(n))
         sgq.push(ssg);
     }
 
-    delete sgs;
-
-    if (sg == sgq.front()) {
-      ((GraphView *) sg)->removeNode(n, edges);
+    if (sg == sgq.top()) {
+      static_cast<GraphView *>(sg)->removeNode(n, edges);
       sgq.pop();
     }
   }
 
   // loop on inout edges of n
   // for notification and removal from propertyContainer
-  std::vector<edge>::const_iterator ite = edges.begin();
-
-  while (ite != edges.end()) {
-    edge e = (*ite);
-    notifyDelEdge(e);
-    propertyContainer->erase(e);
-    ++ite;
+  for (auto e : edges) {
+    // if e is a loop it may have been previously deleted
+    if (isElement(e))
+      removeEdge(e);
   }
 
+  notifyDelNode(n);
   // delete n from storage
   storage.delNode(n);
 
@@ -325,126 +234,73 @@ void GraphImpl::delNode(const node n, bool) {
 }
 //----------------------------------------------------------------
 void GraphImpl::delEdge(const edge e, bool) {
-  assert(existEdgeE(this, source(e),target(e), e));
+  assert(existEdgeE(this, source(e), target(e), e));
 
   if (!isElement(e)) {
     return;
   }
 
   // propagate to subgraphs
-  Iterator<Graph *>*itS=getSubGraphs();
-
-  while (itS->hasNext()) {
-    Graph *subgraph = itS->next();
+  for (Graph *subgraph : subGraphs()) {
     assert(subgraph != this);
 
     if (subgraph->isElement(e))
       subgraph->delEdge(e);
   }
 
-  delete itS;
-
   removeEdge(e);
 }
 //----------------------------------------------------------------
-void GraphImpl::setEdgeOrder(const node n, const vector<edge> &v) {
-  storage.setEdgeOrder(n, v);
+Iterator<node> *GraphImpl::getNodes() const {
+  return new GraphNodeIterator(this, storage.getNodes());
 }
 //----------------------------------------------------------------
-void GraphImpl::swapEdgeOrder(const node n, const edge e1 , const edge e2) {
-  storage.swapEdgeOrder(n, e1, e2);
+Iterator<node> *GraphImpl::getInNodes(const node n) const {
+  return new GraphNodeIterator(this, storage.getInNodes(n));
 }
 //----------------------------------------------------------------
-Iterator<node>* GraphImpl::getNodes() const {
-  return new GraphImplNodeIterator(this, storage.getNodes());
+Iterator<node> *GraphImpl::getOutNodes(const node n) const {
+  return new GraphNodeIterator(this, storage.getOutNodes(n));
 }
 //----------------------------------------------------------------
-Iterator<node>* GraphImpl::getInNodes(const node n) const {
-  return new GraphImplNodeIterator(this, storage.getInNodes(n));
+Iterator<node> *GraphImpl::getInOutNodes(const node n) const {
+  return new GraphNodeIterator(this, storage.getInOutNodes(n));
 }
 //----------------------------------------------------------------
-Iterator<node>* GraphImpl::getOutNodes(const node n) const {
-  return new GraphImplNodeIterator(this, storage.getOutNodes(n));
+Iterator<edge> *GraphImpl::getEdges() const {
+  return new GraphEdgeIterator(this, storage.getEdges());
 }
 //----------------------------------------------------------------
-Iterator<node>* GraphImpl::getInOutNodes(const node n) const {
-  return new GraphImplNodeIterator(this, storage.getInOutNodes(n));
+Iterator<edge> *GraphImpl::getInEdges(const node n) const {
+  return new GraphEdgeIterator(this, storage.getInEdges(n));
 }
 //----------------------------------------------------------------
-Iterator<edge>* GraphImpl::getEdges() const {
-  return new GraphImplEdgeIterator(this, storage.getEdges());
+Iterator<edge> *GraphImpl::getOutEdges(const node n) const {
+  return new GraphEdgeIterator(this, storage.getOutEdges(n));
 }
 //----------------------------------------------------------------
-Iterator<edge>* GraphImpl::getInEdges(const node n) const {
-  return new GraphImplEdgeIterator(this, storage.getInEdges(n));
+Iterator<edge> *GraphImpl::getInOutEdges(const node n) const {
+  return new GraphEdgeIterator(this, storage.getInOutEdges(n));
 }
 //----------------------------------------------------------------
-Iterator<edge>* GraphImpl::getOutEdges(const node n) const {
-  return new GraphImplEdgeIterator(this, storage.getOutEdges(n));
-}
-//----------------------------------------------------------------
-Iterator<edge>* GraphImpl::getInOutEdges(const node n) const {
-  return new GraphImplEdgeIterator(this, storage.getInOutEdges(n));
-}
-//----------------------------------------------------------------
-void GraphImpl::getInOutEdges(const node n, std::vector<edge>& edges,
-                              bool loopsOnlyOnce) const {
-  storage.getInOutEdges(n, edges, loopsOnlyOnce);
-}
-//----------------------------------------------------------------
-std::vector<edge> GraphImpl::getEdges(const node src, const node tgt,
-                                      bool directed) const {
+std::vector<edge> GraphImpl::getEdges(const node src, const node tgt, bool directed) const {
   std::vector<edge> edges;
   storage.getEdges(src, tgt, directed, edges);
   return edges;
 }
 //----------------------------------------------------------------
-unsigned int GraphImpl::deg(const node n) const {
-  return storage.deg(n);
-}
-//----------------------------------------------------------------
-unsigned int GraphImpl::indeg(const node n) const {
-  assert(isElement(n));
-  return storage.indeg(n);
-}
-//----------------------------------------------------------------
-unsigned int GraphImpl::outdeg(const node n) const {
-  assert(isElement(n));
-  return storage.outdeg(n);
-}
-//----------------------------------------------------------------
-node GraphImpl::source(const edge e)const {
-  assert(isElement(e));
-  return storage.source(e);
-}
-//----------------------------------------------------------------
-node GraphImpl::target(const edge e) const {
-  assert(isElement(e));
-  return storage.target(e);
-}
-//----------------------------------------------------------------
-const std::pair<node, node>& GraphImpl::ends(const edge e) const {
-  return storage.ends(e);
-}
-//----------------------------------------------------------------
-node GraphImpl::opposite(const edge e, const node n) const {
-  assert(isElement(e));
-  return storage.opposite(e, n);
-}
-//----------------------------------------------------------------
 void GraphImpl::reverse(const edge e) {
   assert(isElement(e));
-  std::pair<node, node> eEnds = storage.ends(e);
-
-  storage.reverse(e);
+  auto eEnds = storage.ends(e);
 
   // notification
   notifyReverseEdge(e);
 
+  storage.reverse(e);
+
   // propagate edge reversal on subgraphs
-  Graph* sg;
-  forEach(sg, getSubGraphs()) {
-    ((GraphView*) sg)->reverseInternal(e, eEnds.first, eEnds.second);
+  for (Graph *sg : subGraphs()) {
+    static_cast<GraphView *>(sg)->reverseInternal(e, eEnds.first, eEnds.second);
   }
 }
 //----------------------------------------------------------------
@@ -476,30 +332,21 @@ void GraphImpl::setEnds(const edge e, const node newSrc, const node newTgt) {
   notifyAfterSetEnds(e);
 
   // propagate edge reversal on subgraphs
-  Graph* sg;
   eEnds = storage.ends(e);
   node nSrc = eEnds.first;
   node nTgt = eEnds.second;
 
-  forEach(sg, getSubGraphs()) {
-    ((GraphView*) sg)->setEndsInternal(e, src, tgt, nSrc, nTgt);
+  for (Graph *sg : subGraphs()) {
+    static_cast<GraphView *>(sg)->setEndsInternal(e, src, tgt, nSrc, nTgt);
   }
 }
 //----------------------------------------------------------------
-unsigned int GraphImpl::numberOfEdges() const {
-  return storage.numberOfEdges();
-}
-//----------------------------------------------------------------
-unsigned int GraphImpl::numberOfNodes()const {
-  return storage.numberOfNodes();
-}
-//----------------------------------------------------------------
 void GraphImpl::removeEdge(const edge e) {
   assert(isElement(e));
   notifyDelEdge(e);
   // remove from propertyContainer and storage
-  propertyContainer->erase(e);
   storage.delEdge(e);
+  propertyContainer->erase(e);
 }
 //----------------------------------------------------------------
 bool GraphImpl::canPop() {
@@ -515,14 +362,13 @@ bool GraphImpl::canUnpop() {
 }
 //----------------------------------------------------------------
 void GraphImpl::delPreviousRecorders() {
-  std::list<GraphUpdatesRecorder*>::reverse_iterator it =
-    previousRecorders.rbegin();
+  std::list<GraphUpdatesRecorder *>::reverse_iterator it = previousRecorders.rbegin();
 
   // we delete previous recorders in reverse order
   // because they are pushed in front of previousRecorders
   // when they are popped from recorders,
   // so the lasts created are back in previousRecorders
-  while(it != previousRecorders.rend()) {
+  while (it != previousRecorders.rend()) {
     delete (*it);
     ++it;
   }
@@ -530,7 +376,7 @@ void GraphImpl::delPreviousRecorders() {
   previousRecorders.clear();
 }
 //----------------------------------------------------------------
-void GraphImpl::treatEvents(const  std::vector<Event> &) {
+void GraphImpl::treatEvents(const std::vector<Event> &) {
   // an update occurs in the graph hierarchy
   // so delete the previous recorders
   delPreviousRecorders();
@@ -542,64 +388,77 @@ void GraphImpl::observeUpdates(Graph *g) {
   observedGraphs.push_front(g);
 
   // loop on local properties
-  PropertyInterface* prop;
-  forEach(prop, g->getLocalObjectProperties()) {
+  for (PropertyInterface *prop : g->getLocalObjectProperties()) {
     prop->addObserver(this);
     observedProps.push_front(prop);
   }
 
   // loop on subgraphs
-  Graph* sg;
-  forEach(sg, g->getSubGraphs()) {
+  for (Graph *sg : g->subGraphs()) {
     observeUpdates(sg);
   }
 }
 //----------------------------------------------------------------
 void GraphImpl::unobserveUpdates() {
   // loop on observed graphs
-  while(!observedGraphs.empty()) {
+  while (!observedGraphs.empty()) {
     observedGraphs.front()->removeObserver(this);
     observedGraphs.pop_front();
   }
 
   // loop on observed properties
-  while(!observedProps.empty()) {
+  while (!observedProps.empty()) {
     observedProps.front()->removeObserver(this);
     observedProps.pop_front();
   }
 }
 //----------------------------------------------------------------
 #define NB_MAX_RECORDERS 10
-void GraphImpl::push(bool unpopAllowed,
-                     std::vector<PropertyInterface*>* propsToPreserve) {
+void GraphImpl::push(bool unpopAllowed, std::vector<PropertyInterface *> *propsToPreserve) {
   // from now if previous recorders exist
   // they cannot be unpop
   // so delete them
   delPreviousRecorders();
+
+  bool hasRecorders = !recorders.empty();
+
+  // if we have a current recorder with no updates
+  // there is no need to push a new one, so go on with the same
+  // (except if a temporary non redoable state is explicitly requested)
+  if (unpopAllowed && hasRecorders && !recorders.front()->hasUpdates()) {
+    return;
+  }
+
   // end any previous updates observation
   unobserveUpdates();
 
-  if (!recorders.empty())
+  if (hasRecorders)
     // stop recording for current recorder
     recorders.front()->stopRecording(this);
 
-  GraphUpdatesRecorder* recorder = new GraphUpdatesRecorder(unpopAllowed);
+  const GraphStorageIdsMemento *prevIdsMemento =
+      hasRecorders ? recorders.front()->newIdsState : nullptr;
+
+  GraphUpdatesRecorder *recorder = new GraphUpdatesRecorder(unpopAllowed, prevIdsMemento);
   recorder->startRecording(this);
   recorders.push_front(recorder);
 
-  // delete first pushed recorder if needed
-  int nb = 0;
-  std::list<GraphUpdatesRecorder*>::iterator it = recorders.begin();
+  // if this is not a temporary state used for computation purpose
+  // as in BubbleTree for example
+  if (unpopAllowed) {
+    // delete first pushed recorders (those at the end of the list) if needed
+    unsigned int nb = recorders.size();
 
-  while(it != recorders.end()) {
-    if (nb == NB_MAX_RECORDERS) {
-      delete (*it);
-      recorders.erase(it);
-      break;
+    if (nb > NB_MAX_RECORDERS) {
+      std::list<GraphUpdatesRecorder *>::reverse_iterator it = recorders.rbegin();
+
+      while (nb > NB_MAX_RECORDERS) {
+        delete (*it);
+        --nb;
+        ++it;
+      }
+      recorders.resize(nb);
     }
-
-    ++nb;
-    ++it;
   }
 
   if (propsToPreserve) {
@@ -613,9 +472,9 @@ void GraphImpl::pop(bool unpopAllowed) {
   // save the front recorder
   // to allow unpop
   if (!recorders.empty()) {
-    //if (!previousRecorders.empty())
+    // if (!previousRecorders.empty())
     unobserveUpdates();
-    GraphUpdatesRecorder* prevRecorder = recorders.front();
+    GraphUpdatesRecorder *prevRecorder = recorders.front();
 
     if (unpopAllowed && prevRecorder->restartAllowed)
       prevRecorder->recordNewValues(this);
@@ -630,8 +489,7 @@ void GraphImpl::pop(bool unpopAllowed) {
       // observe any updates
       // in order to remove previous recorders if needed
       observeUpdates(this);
-    }
-    else
+    } else
       delete prevRecorder;
 
     // must be done here (see canPop, canUnpop)
@@ -643,6 +501,12 @@ void GraphImpl::pop(bool unpopAllowed) {
   }
 }
 //----------------------------------------------------------------
+void GraphImpl::popIfNoUpdates() {
+  if (!recorders.empty() && !recorders.front()->hasUpdates())
+    // no need of a "no updates" recorder
+    this->pop(false);
+}
+//----------------------------------------------------------------
 void GraphImpl::unpop() {
   int nbPrev = previousRecorders.size();
 
@@ -652,7 +516,7 @@ void GraphImpl::unpop() {
     if (!recorders.empty())
       recorders.front()->stopRecording(this);
 
-    GraphUpdatesRecorder* prevRecorder = previousRecorders.front();
+    GraphUpdatesRecorder *prevRecorder = previousRecorders.front();
     previousRecorders.pop_front();
     recorders.push_front(prevRecorder);
     // redo all recorded updates
@@ -667,8 +531,6 @@ void GraphImpl::unpop() {
   }
 }
 //----------------------------------------------------------------
-bool GraphImpl::canDeleteProperty(Graph* g, PropertyInterface *prop) {
-  return recorders.empty() ||
-         !recorders.front()->isAddedOrDeletedProperty(g, prop);
+bool GraphImpl::canDeleteProperty(Graph *g, PropertyInterface *prop) {
+  return recorders.empty() || !recorders.front()->isAddedOrDeletedProperty(g, prop);
 }
-
