@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,7 +17,8 @@
  *
  */
 
-#if defined(__GNUC__) && __GNUC__ >= 4 && ((__GNUC_MINOR__ == 2 && __GNUC_PATCHLEVEL__ >= 1) || (__GNUC_MINOR__ >= 3))
+#if defined(__GNUC__) && __GNUC__ >= 4 &&                                                          \
+    ((__GNUC_MINOR__ == 2 && __GNUC_PATCHLEVEL__ >= 1) || (__GNUC_MINOR__ >= 3))
 #pragma GCC diagnostic ignored "-Wstrict-aliasing"
 #endif
 
@@ -28,68 +29,42 @@
 using namespace std;
 using namespace tlp;
 
-/*std::ostream& operator <<(std::ostream &os , node n) {
-  os << n.id;
-  return os;
-}
-std::ostream& operator <<(std::ostream &os , edge e) {
-  os << e.id;
-  return os;
-  }*/
-
-// //=================================================================
-edge PlanarityTestImpl::edgeReversal( edge e) {
+//================================================================
+edge PlanarityTestImpl::edgeReversal(edge e) {
   return reversalEdge[e];
 }
 //=================================================================
-
-static int preCount;
-static int postCount;
-
-void dfsAux(Graph *sG, node n,
-            MutableContainer<int>& dfsPre,
-            MutableContainer<int>& dfsPos,
-            list<edge>& dfsEdges) {
-  dfsPre.set(n.id, preCount++);
-  StableIterator<edge> it(sG->getOutEdges(n));
-
-  while (it.hasNext()) {
-    edge e = it.next();
+static void dfsAux(Graph *sG, node n, MutableContainer<int> &dfsPre, MutableContainer<int> &dfsPos,
+                   list<edge> &dfsEdges, unsigned int &preCount, unsigned int &postCount) {
+  dfsPre.set(n.id, ++preCount);
+  for (auto e : sG->getOutEdges(n)) {
     node target = sG->target(e);
 
     if (dfsPre.get(target.id) == 0) {
       dfsEdges.push_back(e);
-      dfsAux(sG, target, dfsPre, dfsPos, dfsEdges);
+      dfsAux(sG, target, dfsPre, dfsPos, dfsEdges, preCount, postCount);
     }
   }
 
-  dfsPos.set(n.id, postCount++);
+  dfsPos.set(n.id, ++postCount);
 }
 //=================================================================
-list<edge> posDFS(Graph *sG,
-                  MutableContainer<int> &dfsPos) {
+list<edge> posDFS(Graph *sG, MutableContainer<int> &dfsPos) {
   list<edge> dfsEdges;
   MutableContainer<int> dfsPre;
   dfsPre.setAll(0);
-  preCount = postCount = 1;
-  StableIterator<node> it(sG->getNodes());
-
-  while (it.hasNext()) {
-    node n = it.next();
-
+  unsigned int preCount = 0;
+  unsigned int postCount = 0;
+  for (auto n : sG->nodes()) {
     if (dfsPre.get(n.id) == 0)
-      dfsAux(sG, n, dfsPre, dfsPos, dfsEdges);
+      dfsAux(sG, n, dfsPre, dfsPos, dfsEdges, preCount, postCount);
   }
-
   return dfsEdges;
 }
 //=================================================================
 void PlanarityTestImpl::makeBidirected(Graph *sG) {
-  StableIterator<edge> stIte(sG->getEdges());
-
-  while(stIte.hasNext()) {
-    edge e = stIte.next();
-    pair<node, node> eEnds = sG->ends(e);
+  for (auto e : stableIterator(sG->getEdges())) {
+    auto eEnds = sG->ends(e);
     edge newEdge = sG->addEdge(eEnds.second, eEnds.first);
     bidirectedEdges[newEdge] = e;
     reversalEdge[newEdge] = e;
@@ -102,12 +77,12 @@ void PlanarityTestImpl::makeBidirected(Graph *sG) {
  *         false otherwise.
  */
 bool PlanarityTestImpl::isT0Edge(Graph *g, edge e) {
-  pair<node, node> eEnds = g->ends(e);
+  auto eEnds = g->ends(e);
   edge e1 = T0EdgeIn.get(eEnds.second.id);
 
-  //test ą revoir je pense qu'en testant juste e == e1 ēa suffit !
-  if (e1 != NULL_EDGE) {
-    pair<node, node> e1Ends = g->ends(e1);
+  // test ą revoir je pense qu'en testant juste e == e1 ēa suffit !
+  if (e1.isValid()) {
+    auto e1Ends = g->ends(e1);
 
     if (e1Ends.first == eEnds.first && e1Ends.second == eEnds.second)
       return true;
@@ -115,11 +90,12 @@ bool PlanarityTestImpl::isT0Edge(Graph *g, edge e) {
 
   e1 = T0EdgeIn.get(eEnds.first.id);
 
-  if (e1 == NULL_EDGE)
-    return false;
+  if (e1.isValid()) {
+    auto e1Ends = g->ends(e1);
+    return (e1Ends.second == eEnds.first && e1Ends.first == eEnds.second);
+  }
 
-  pair<node, node> e1Ends = g->ends(e1);
-  return (e1Ends.second == eEnds.first && e1Ends.first == eEnds.second);
+  return false;
 }
 //=================================================================
 /*
@@ -127,9 +103,7 @@ bool PlanarityTestImpl::isT0Edge(Graph *g, edge e) {
  *         false otherwise.
  */
 bool PlanarityTestImpl::isBackEdge(Graph *g, edge e) {
-  if (e == NULL_EDGE) return false;
-
-  return (!isT0Edge(g, e));
+  return (e.isValid() && !isT0Edge(g, e));
 }
 //=================================================================
 /*
@@ -141,39 +115,34 @@ bool PlanarityTestImpl::isBackEdge(Graph *g, edge e) {
  * nodes in g
  */
 void PlanarityTestImpl::sortNodesIncreasingOrder(Graph *g, MutableContainer<int> &value,
-    vector<node> &sortedNodes) {
+                                                 vector<node> &sortedNodes) {
 
   // Counting sort;
   int numberOfNodes = g->numberOfNodes();
-  //array<int, numberOfNodes + 1> c;
+  // array<int, numberOfNodes + 1> c;
   vector<int> c(numberOfNodes + 1);
 
-  for (int i = 1 ; i <= numberOfNodes ; ++i)
+  for (int i = 1; i <= numberOfNodes; ++i)
     c[i] = 0;
 
-  //array<node, numberOfNodes + 1> a;
+  // array<node, numberOfNodes + 1> a;
   vector<node> a(numberOfNodes + 1);
   int j = 0;
-  node n;
-  // forall_nodes(n, g)
-  Iterator<node> *it = g->getNodes();
 
-  while (it->hasNext()) {
-    //a[++j] = n;
-    a[++j] = it->next();
+  // forall_nodes(n, g)
+  for (auto n : g->nodes()) {
+    a[++j] = n;
   }
 
-  delete it;
-
-  for (int i = 1 ; i <= numberOfNodes ; ++i) {
+  for (int i = 1; i <= numberOfNodes; ++i) {
     unsigned int tmp = value.get(a[i].id);
     ++c[tmp];
   }
 
-  for (int i = 2 ; i <= numberOfNodes ; ++i)
-    c[i] += c[i-1];
+  for (int i = 2; i <= numberOfNodes; ++i)
+    c[i] += c[i - 1];
 
-  for (int i = numberOfNodes ; i > 0 ; i--) {
+  for (int i = numberOfNodes; i > 0; i--) {
     sortedNodes[c[value.get(a[i].id)]] = a[i];
     c[value.get(a[i].id)]--;
   }
@@ -197,46 +166,34 @@ void PlanarityTestImpl::sortNodesIncreasingOrder(Graph *g, MutableContainer<int>
  */
 void PlanarityTestImpl::preProcessing(Graph *g) {
   int numberOfNodes = g->numberOfNodes();
-  list<edge> edgeInT0; // list of edges in T_0;
-  edgeInT0 = posDFS(g, dfsPosNum);
+  // list of edges in T_0;
+  list<edge> &&edgeInT0 = posDFS(g, dfsPosNum);
 
-  //forall(e, edgeInT0) {
-  //  tlp::warning() << "Edge in T0: " ;
-  for (list<edge>::iterator it = edgeInT0.begin(); it != edgeInT0.end(); ++it) {
+  for (auto it = edgeInT0.begin(); it != edgeInT0.end(); ++it) {
     edge e = *it;
-    //    tlp::warning() << e.id << ",";
-    node n = g->source(e);
-    node v = g->target(e);
+    auto ends = g->ends(e);
+    node n = ends.first;
+    node v = ends.second;
     parent.set(v.id, n);
     T0EdgeIn.set(v.id, e);
   }
 
-  //  tlp::warning() << endl;
-
 #ifndef NDEBUG
 
-  for (list<edge>::iterator it = edgeInT0.begin(); it != edgeInT0.end(); ++it) {
+  for (auto it = edgeInT0.begin(); it != edgeInT0.end(); ++it) {
     edge e = *it;
-    assert (!(isBackEdge(g, e) || isBackEdge(g, edgeReversal(e))));
+    assert(!(isBackEdge(g, e) || isBackEdge(g, edgeReversal(e))));
   }
 
 #endif
 
-
-  //  tlp::warning() << "DFS order :" ;
-  //node n;
-  //forall_nodes(n, g) {
-  Iterator<node> *it1 = g->getNodes();
-
-  while (it1->hasNext()) {
-    node n = it1->next();
+  for (auto n : g->nodes()) {
     int dfsPos = dfsPosNum.get(n.id);
-    //    tlp::warning() << "(" << n.id << "," << dfsPos << ")";
     nodeWithDfsPos.set(dfsPos, n);
     largestNeighbor.set(n.id, dfsPos);
     labelB.set(n.id, dfsPos);
 
-    if ((parent.get(n.id)) != NULL_NODE) // if u is not the root of T_0;
+    if (parent.get(n.id).isValid()) // if u is not the root of T_0;
       largestNeighbor.set(n.id, dfsPosNum.get((parent.get(n.id)).id));
 
     if (embed)
@@ -245,73 +202,33 @@ void PlanarityTestImpl::preProcessing(Graph *g) {
     // saves T_0 for obstruction edges if g is not planar;
   }
 
-  delete it1;
-  //  tlp::warning() << endl;
-
-  for (int i = 1 ; i <= numberOfNodes ; ++i) {
+  for (int i = 1; i <= numberOfNodes; ++i) {
     node n = nodeWithDfsPos.get(i);
-    //forall_out_edges (e, n) {
-    Iterator<edge> *it = g->getOutEdges(n);
-
-    while (it->hasNext()) {
-      edge e = it->next();
+    for (auto e : g->getOutEdges(n)) {
       node v = g->target(e);
 
       if (labelB.get(n.id) < labelB.get(v.id))
         labelB.set(n.id, labelB.get(v.id));
 
       if (largestNeighbor.get(n.id) < dfsPosNum.get(v.id))
-        largestNeighbor.set(n.id, dfsPosNum.get(v.id));//dfsPosNum[v];
+        largestNeighbor.set(n.id, dfsPosNum.get(v.id)); // dfsPosNum[v];
     }
-
-    delete it;
   }
 
-  /// DEBUG {
-  // tlp::debug() << "** Labels (dfs[u], h[u], b[u]): " << endl;
-  //   for (int i = 1 ; i <= numberOfNodes ; i++) {
-  //     node u = nodeWithDfsPos.get(i);
-  //     tlp::debug() << "(" << dfsPosNum.get(u.id) << "," << largestNeighbor.get(u.id)
-  //   << "," << labelB.get(u.id) << ") " << endl;
-  //   }
-  //// }
-
-  //array<node, numberOfNodes+1> sortedNodes;
   vector<node> sortedNodes(numberOfNodes + 1);
-  sortedNodes[0]=NULL_NODE;
+  sortedNodes[0] = node();
   sortNodesIncreasingOrder(g, labelB, sortedNodes);
 
-  /*
-    tlp::warning() << "Sorted Nodes : ";
-  for (int i=0; i<=numberOfNodes; ++i)
-    tlp::warning() << "[" << sortedNodes[i].id << ","  ;
-  tlp::warning() << endl;
-  */
-  for (int i = numberOfNodes ; i >= 1 ; i--) {
+  for (int i = numberOfNodes; i >= 1; i--) {
     node n = sortedNodes[i];
     node v = parent.get(n.id);
 
-    //tlp::warning() << "[" << n.id << "," << v.id << "]" << endl;
-    if (v != NULL_NODE)
+    if (v.isValid())
       childrenInT0[v].push_back(n);
   }
 
-  /*
-    tlp::debug() << "** List of children in T:\n";
-    Iterator<node> *it = g->getNodes();
-    while (it->hasNext()) {
-    node u = it->next();
-    //tlp::warning() << "  " << dfsPosNum.get(u.id) << ": " ;
-    node v;
-    for (list<node>::iterator i = childrenInT0[u].begin(); i != childrenInT0[u].end(); i++) {
-    node v = *i;
-    tlp::debug() << dfsPosNum.get(v.id) << "(" << labelB.get(v.id) << "), ";
-    tlp::debug() << "\n";
-    }
-    } delete it;
-  */
   if (embed) // needed to calculate obstruction edges;
-    for (int i = 1 ; i <= numberOfNodes ; ++i) {
+    for (int i = 1; i <= numberOfNodes; ++i) {
       node n = nodeWithDfsPos.get(i);
 
       if (labelB.get(n.id) == largestNeighbor.get(n.id))
@@ -330,9 +247,7 @@ void PlanarityTestImpl::swapNode(node &n1, node &n2) {
 }
 //=================================================================
 bool PlanarityTestImpl::isCNode(node n) {
-  if (n == NULL_NODE) return false;
-
-  return (dfsPosNum.get(n.id) < 0);
+  return (n.isValid() && (dfsPosNum.get(n.id) < 0));
 }
 //=================================================================
 node PlanarityTestImpl::activeCNodeOf(bool calculatingObstruction, node n) {
@@ -342,9 +257,9 @@ node PlanarityTestImpl::activeCNodeOf(bool calculatingObstruction, node n) {
     cNode = parent.get(n.id);
 
   if (!isCNode(cNode))
-    return NULL_NODE; //zero
+    return node(); // zero
 
-  //debug
+  // debug
   if (calculatingObstruction)
     while (isCNode(parent.get(cNode.id)))
       cNode = parent.get(cNode.id);
@@ -355,46 +270,38 @@ node PlanarityTestImpl::activeCNodeOf(bool calculatingObstruction, node n) {
   return cNode;
 }
 //=================================================================
-void PlanarityTestImpl::addOldCNodeRBCToNewRBC(node oldCNode,
-    node,
-    node n,
-    node n1,
-    node n2,
-    tlp::BmdList<node>& nodeList) {
+void PlanarityTestImpl::addOldCNodeRBCToNewRBC(node oldCNode, node, node n, node n1, node n2,
+                                               tlp::BmdList<node> &nodeList) {
   // compress RBC[oldCNode]:
   // removes all nodes v in RBC[oldCNode] s.t. label_b[v] < dfspos_num[n]
   // or v = parent[oldCNode].
 
-  BmdLink<node>* firstItem = RBC[oldCNode].firstItem();
-  BmdLink<node>* predItem  = RBC[oldCNode].cyclicPred(firstItem, 0);
-  BmdLink<node>* succItem  = RBC[oldCNode].cyclicSucc(firstItem, 0);
+  BmdLink<node> *firstItem = RBC[oldCNode].firstItem();
+  BmdLink<node> *predItem = RBC[oldCNode].cyclicPred(firstItem, nullptr);
+  BmdLink<node> *succItem = RBC[oldCNode].cyclicSucc(firstItem, nullptr);
 
   node predNode = predItem->getData();
   node succNode = succItem->getData();
-  node ul = NULL_NODE;
-  node ur = NULL_NODE;
+  node ul;
+  node ur;
 
   // goes to the left;
   while (labelB.get(predNode.id) == dfsPosNum.get(n.id) && predNode != n1 && predNode != n2) {
-    if (ul.id == UINT_MAX)
+    if (!ul.isValid())
       ul = predNode;
 
-    BmdLink<node>* tmp = predItem;
+    BmdLink<node> *tmp = predItem;
     predItem = RBC[oldCNode].cyclicPred(predItem, firstItem);
-    //tlp::debug() << "tulip predItem : " << predItem->getData().id << endl;
     predNode = predItem->getData();
-    //tlp::debug() << "tulip predNode : " << predNode.id << endl;
-    //tlp::debug() << "tulip tmp : " << tmp->getData().id << endl;
     RBC[oldCNode].delItem(tmp);
   }
 
-
   // goes to right;
   while (labelB.get(succNode.id) == dfsPosNum.get(n.id) && succNode != n1 && succNode != n2) {
-    if (ur.id == UINT_MAX)
+    if (!ur.isValid())
       ur = succNode;
 
-    BmdLink<node>* tmp = succItem;
+    BmdLink<node> *tmp = succItem;
     succItem = RBC[oldCNode].cyclicSucc(succItem, firstItem);
     succNode = succItem->getData();
     RBC[oldCNode].delItem(tmp);
@@ -402,11 +309,11 @@ void PlanarityTestImpl::addOldCNodeRBCToNewRBC(node oldCNode,
 
   RBC[oldCNode].delItem(RBC[oldCNode].firstItem());
 
-  // endpoint to correctly concatentates with RBC[new_cnode];
+  // endpoint to correctly concatenates with RBC[new_cnode];
   node first = n1;
 
-  if (n1.id == UINT_MAX) {
-    if (ul!= NULL_NODE)
+  if (!n1.isValid()) {
+    if (ul.isValid())
       first = predNode;
     else
       first = succNode;
@@ -417,11 +324,11 @@ void PlanarityTestImpl::addOldCNodeRBCToNewRBC(node oldCNode,
     RBC[oldCNode].reverse();
 
   // reoves n1 and n2 from RBC[oldCNode];
-  if (n1!= NULL_NODE) {
+  if (n1.isValid()) {
     RBC[oldCNode].delItem(RBC[oldCNode].firstItem());
   }
 
-  if (n2!= NULL_NODE) {
+  if (n2.isValid()) {
     RBC[oldCNode].delItem(RBC[oldCNode].lastItem());
   }
 
@@ -429,7 +336,7 @@ void PlanarityTestImpl::addOldCNodeRBCToNewRBC(node oldCNode,
 }
 //=================================================================
 void PlanarityTestImpl::updateLabelB(node n) {
-  if (n.id == UINT_MAX)
+  if (!n.isValid())
     return;
 
   labelB.set(n.id, largestNeighbor.get(n.id));
@@ -444,16 +351,18 @@ void PlanarityTestImpl::updateLabelB(node n) {
   else
     return;
 
-  while (v!= NULL_NODE) {
+  while (v.isValid()) {
     // or v is not a descendant of n in T,
     // or v is a child of n in T,
     // or v is a child of a c-node whose parent is n;
-    if ((parent.get(v.id))!= NULL_NODE && isCNode(parent.get(v.id)) && parent.get(parent.get(v.id).id) == n) {
-      v = parent.get(v.id); // active c-node;
+    node pv = parent.get(v.id);
+
+    if (pv.isValid() && isCNode(pv) && parent.get(pv.id) == n) {
+      v = pv; // active c-node;
       break;
     }
 
-    if (parent.get(v.id) == n)
+    if (pv == n)
       break;
 
     // v became sibling of n;
@@ -461,10 +370,11 @@ void PlanarityTestImpl::updateLabelB(node n) {
 
     if (!childrenInT0[n].empty())
       v = childrenInT0[n].front();
-    else v = NULL_NODE;
+    else
+      v = node();
   }
 
-  if (v!= NULL_NODE && labelB.get(n.id) < labelB.get(v.id)) {
+  if (v.isValid() && labelB.get(n.id) < labelB.get(v.id)) {
     labelB.set(n.id, labelB.get(v.id));
 
     if (embed)
@@ -472,21 +382,16 @@ void PlanarityTestImpl::updateLabelB(node n) {
   }
 }
 //=================================================================
-void PlanarityTestImpl::calcNewRBCFromTerminalNode(node newCNode,
-    node n,
-    node n1,
-    node n2,
-    tlp::BmdList<node>& nodeList) {
+void PlanarityTestImpl::calcNewRBCFromTerminalNode(node newCNode, node n, node n1, node n2,
+                                                   tlp::BmdList<node> &nodeList) {
   node t = n1;
-  node predT = NULL_NODE;
-  node parentT = NULL_NODE;
+  node predT;
+  node parentT;
 
   while (t != n2) {
     parentT = parent.get(t.id);
 
-    //    tlp::debug() << "Tulip t =  " << t.id << "  : ";
     if (isCNode(t)) {
-      //      tlp::debug() << "Is CNode" << endl;
       t = activeCNodeOf(false, t);
       addOldCNodeRBCToNewRBC(t, newCNode, n, predT, NULL_NODE, nodeList);
       parentT = parent.get(t.id);
@@ -498,15 +403,13 @@ void PlanarityTestImpl::calcNewRBCFromTerminalNode(node newCNode,
         if (embed) // needed to calculate obstruction edges;
           nodeLabelB.set(newCNode.id, nodeLabelB.get(t.id));
       }
-    }
-    else {
-      //      tlp::debug() << "Not Is CNode :" << t << endl;
+    } else {
       parent.set(t.id, newCNode);
       updateLabelB(t);
 
       if (labelB.get(t.id) > dfsPosNum.get(n.id)) {
-        BmdLink<node>* item = nodeList.append(t);
-        ptrItem.set(t.id, item) ;//nodeList.append(t));
+        BmdLink<node> *item = nodeList.append(t);
+        ptrItem.set(t.id, item); // nodeList.append(t));
       }
 
       if (labelB.get(t.id) > labelB.get(newCNode.id)) {
@@ -525,36 +428,32 @@ void PlanarityTestImpl::calcNewRBCFromTerminalNode(node newCNode,
 }
 //=================================================================
 node PlanarityTestImpl::lastPNode(node n1, node n2) {
-  //  tlp::warning() << __PRETTY_FUNCTION__ << endl;
   if (n1 == n2) {
-    if (!isCNode(n1))
-      return n1;
-    else
-      return NULL_NODE;
+    return isCNode(n1) ? node() : n1;
   }
 
   list<node> S;
   node n = n1;
 
-  while (n!= NULL_NODE && n != n2) {
+  while (n.isValid() && n != n2) {
     S.push_front(n);
     n = parent.get(n.id);
   }
 
-  if (n == NULL_NODE)
-    return NULL_NODE;
+  if (!n.isValid())
+    return n;
 
-  n = n2; //inutile
+  n = n2; // inutile
 
 #ifndef NDEBUG
   int count = 0;
 #endif
 
   while (isCNode(n)) {
-    assert(++count<=2);
+    assert(++count <= 2);
 
     if (S.empty())
-      return NULL_NODE;
+      return node();
 
     n = S.front();
     S.pop_front();
@@ -563,9 +462,7 @@ node PlanarityTestImpl::lastPNode(node n1, node n2) {
   return n;
 }
 //=================================================================
-node PlanarityTestImpl::lcaBetween(node n1,
-                                   node n2,
-                                   const MutableContainer<node> &p) {
+node PlanarityTestImpl::lcaBetween(node n1, node n2, const MutableContainer<node> &p) {
   if (isCNode(n1)) {
     node n = activeCNodeOf(false, n1);
     n1 = p.get(n.id);
@@ -586,7 +483,7 @@ node PlanarityTestImpl::lcaBetween(node n1,
     n1 = p.get(n1.id);
   }
 
-  node u = NULL_NODE;
+  node u;
 
   if (!nl.empty()) {
     u = nl.front();
@@ -604,34 +501,27 @@ node PlanarityTestImpl::lcaBetween(node n1,
   return nl.front();
 }
 //=================================================================
-node PlanarityTestImpl::lcaBetweenTermNodes(node n1,
-    node n2) {
+node PlanarityTestImpl::lcaBetweenTermNodes(node n1, node n2) {
   node lca = lastVisited.get(n1.id);
 
   if (dfsPosNum.get((lastVisited.get(n2.id)).id) < dfsPosNum.get(lca.id))
     lca = lastVisited.get(n2.id);
 
-  //==
-  assert(lca == lcaBetween(n1,n2, parent));
-  //==
+  assert(lca == lcaBetween(n1, n2, parent));
+
   return lca;
 }
 //=================================================================
-void PlanarityTestImpl::calculateNewRBC(Graph*,
-                                        node newCNode,
-                                        node n,
-                                        list<node>& terminalNodes) {
-  switch(terminalNodes.size()) {
+void PlanarityTestImpl::calculateNewRBC(Graph *, node newCNode, node n, list<node> &terminalNodes) {
+  switch (terminalNodes.size()) {
   case 1: {
     node n1 = terminalNodes.front();
     terminalNodes.pop_front();
-    ////
     calcNewRBCFromTerminalNode(newCNode, n, n1, n, RBC[newCNode]);
-  }
-  break;
+  } break;
 
   case 2: {
-    node m = NULL_NODE;
+    node m;
     node t1 = terminalNodes.front();
     terminalNodes.pop_front();
     node t2 = terminalNodes.front();
@@ -677,8 +567,7 @@ void PlanarityTestImpl::calculateNewRBC(Graph*,
 
       addOldCNodeRBCToNewRBC(m, newCNode, n, t22, t12, RBC[newCNode]);
       parent.set(m.id, newCNode);
-    }
-    else {
+    } else {
       parent.set(m.id, newCNode);
       updateLabelB(m);
 
@@ -695,18 +584,15 @@ void PlanarityTestImpl::calculateNewRBC(Graph*,
 
     auxNodeList.reverse();
     RBC[newCNode].conc(auxNodeList);
-  }
-  break;
+  } break;
 
   default:
     assert(false);
   }
 }
 //=================================================================
-node PlanarityTestImpl::findNodeWithLabelBGreaterThanDfsN(bool saveLastNodeTraversed,
-    Graph*,
-    node n,
-    node t) {
+node PlanarityTestImpl::findNodeWithLabelBGreaterThanDfsN(bool saveLastNodeTraversed, Graph *,
+                                                          node n, node t) {
   node result = NULL_NODE;
   node vPred = t;
   node v = parent.get(t.id);
@@ -717,7 +603,7 @@ node PlanarityTestImpl::findNodeWithLabelBGreaterThanDfsN(bool saveLastNodeTrave
 
   p[t] = parent.get(t.id); // saves info;
   nl.push_back(t);
-  parent.set(t.id, NULL_NODE);
+  parent.set(t.id, node());
 
   while (v != n) {
     if (isCNode(v)) {
@@ -732,10 +618,9 @@ node PlanarityTestImpl::findNodeWithLabelBGreaterThanDfsN(bool saveLastNodeTrave
           break;
         }
       }
-    }
-    else {
+    } else {
       nl2.push_back(v);
-      b[v] = labelB.get(v.id); // saves infos;
+      b[v] = labelB.get(v.id); // saves info
 
       if (embed) // needed to calculate obstruction edges;
         nb[v] = nodeLabelB.get(v.id);
@@ -756,21 +641,20 @@ node PlanarityTestImpl::findNodeWithLabelBGreaterThanDfsN(bool saveLastNodeTrave
   }
 
   // restores parent;
-  //forall(v, nl)
-  for (list<node>::iterator it1 = nl.begin(); it1 != nl.end(); ++it1)
-    parent.set((*it1).id, p[*it1]);
+  // forall(v, nl)
+  for (auto itn : nl)
+    parent.set(itn.id, p[itn]);
 
-
-  if (result!= NULL_NODE)
+  if (result.isValid())
     return result;
 
   // restores info if result is nil;
-  //forall(v, nl2) {
-  for (list<node>::iterator it2 = nl2.begin(); it2 != nl2.end(); ++it2) {
-    labelB.set((*it2).id, b[*it2]);
+  // forall(v, nl2) {
+  for (auto itn : nl2) {
+    labelB.set(itn.id, b[itn]);
 
     if (embed) // needed to calculate obstruction edges;
-      nodeLabelB.set((*it2).id, nb[*it2]);
+      nodeLabelB.set(itn.id, nb[itn]);
   }
 
   // to update label_b of n correctly in future iteration
@@ -778,15 +662,12 @@ node PlanarityTestImpl::findNodeWithLabelBGreaterThanDfsN(bool saveLastNodeTrave
   if (saveLastNodeTraversed && vPred != t)
     lastNodeInQLinha = vPred; // see sets_info_for_new_cnode;
   else
-    lastNodeInQLinha = NULL_NODE;
+    lastNodeInQLinha = node();
 
-  return NULL_NODE;
+  return node();
 }
 //=================================================================
-void PlanarityTestImpl::setPossibleK33Obstruction(node cNode,
-    node n,
-    node nl,
-    node nr) {
+void PlanarityTestImpl::setPossibleK33Obstruction(node cNode, node n, node nl, node nr) {
   // K_33: X = {w, parent[cnode], u}
   //       Y = {ul, ur, ?};
   obstructionNodes.clear();
@@ -796,14 +677,9 @@ void PlanarityTestImpl::setPossibleK33Obstruction(node cNode,
   cNodeOfPossibleK33Obstruction = cNode;
 }
 //=================================================================
-bool PlanarityTestImpl::testCNodeCounter(Graph*,
-    node cNode,
-    node n,
-    node n1,
-    node n2,
-    node& jl,
-    node& jr) {
-  assert (!(parent.get(cNode.id) != RBC[cNode].firstItem()->getData() ));
+bool PlanarityTestImpl::testCNodeCounter(Graph *, node cNode, node n, node n1, node n2, node &jl,
+                                         node &jr) {
+  assert(!(parent.get(cNode.id) != RBC[cNode].firstItem()->getData()));
 
   // no chance for cNode to be an obstruction;
   /// code ajoute
@@ -813,18 +689,18 @@ bool PlanarityTestImpl::testCNodeCounter(Graph*,
   if (RBC[cNode].size() <= 2)
     return false;
 
-  BmdLink<node>* it1 = RBC[cNode].firstItem();
-  BmdLink<node>* it1l = RBC[cNode].cyclicPred(it1, 0);
-  BmdLink<node>* it1r = RBC[cNode].cyclicSucc(it1, 0);
+  BmdLink<node> *it1 = RBC[cNode].firstItem();
+  BmdLink<node> *it1l = RBC[cNode].cyclicPred(it1, nullptr);
+  BmdLink<node> *it1r = RBC[cNode].cyclicSucc(it1, nullptr);
 
   jl = it1l->getData();
   jr = it1r->getData();
-  node ul = NULL_NODE;
-  node ur = NULL_NODE;
+  node ul;
+  node ur;
   int count = 0;
 
   // goes to the left;
-  BmdLink<node> *a=NULL, *s = it1;
+  BmdLink<node> *a = nullptr, *s = it1;
 
   while (labelB.get(jl.id) <= dfsPosNum.get(n.id)) {
     if (labelB.get(jl.id) == dfsPosNum.get(n.id)) {
@@ -839,7 +715,7 @@ bool PlanarityTestImpl::testCNodeCounter(Graph*,
   }
 
   // goes to right;
-  BmdLink<node>*  p = it1;
+  BmdLink<node> *p = it1;
 
   while (labelB.get(jr.id) <= dfsPosNum.get(n.id)) {
     if (labelB.get(jr.id) == dfsPosNum.get(n.id)) {
@@ -862,15 +738,14 @@ bool PlanarityTestImpl::testCNodeCounter(Graph*,
   if (count != counter.get(cNode.id))
     return true;
 
-  node u = NULL_NODE;
+  node u;
 
-  if (ul!= NULL_NODE && ur!= NULL_NODE)
+  if (ul.isValid() && ur.isValid())
     u = jl; // or u = jr;
-  else if (ul!= NULL_NODE && n1!= NULL_NODE && n1 != jl) {
+  else if (ul.isValid() && n1.isValid() && n1 != jl) {
     u = jl;
     ur = n1;
-  }
-  else if (ur!= NULL_NODE && n1!= NULL_NODE && n1 != jr) {
+  } else if (ur.isValid() && n1.isValid() && n1 != jr) {
     u = jr;
     ul = n1;
   }
@@ -881,11 +756,7 @@ bool PlanarityTestImpl::testCNodeCounter(Graph*,
   return false;
 }
 //=================================================================
-bool PlanarityTestImpl::testObstructionFromTerminalNode(Graph *sG,
-    node w,
-    node terminal,
-    node u) {
-  //  tlp::warning() << __PRETTY_FUNCTION__ << endl;
+bool PlanarityTestImpl::testObstructionFromTerminalNode(Graph *sG, node w, node terminal, node u) {
   node v = terminal, predV = NULL_NODE;
 
   while (v != u) {
@@ -917,18 +788,18 @@ bool PlanarityTestImpl::testObstructionFromTerminalNode(Graph *sG,
 }
 
 //=================================================================
-BmdLink<node>*  PlanarityTestImpl::searchRBC(int dir, BmdLink<node>* it, node n,
-    list<node>& traversedNodesInRBC) {
-  if (it != NULL && (it->prev() == NULL || it->succ() == NULL)) // 1st or last item in RBC;
+BmdLink<node> *PlanarityTestImpl::searchRBC(int dir, BmdLink<node> *it, node n,
+                                            list<node> &traversedNodesInRBC) {
+  if (it != nullptr && (it->prev() == nullptr || it->succ() == nullptr)) // 1st or last item in RBC;
     return it;
 
-  BmdLink<node>* prev = it;
-  BmdLink<node>* aux1 = it->prev();
-  BmdLink<node>* aux2 = it->succ();
+  BmdLink<node> *prev = it;
+  BmdLink<node> *aux1 = it->prev();
+  BmdLink<node> *aux2 = it->succ();
 
   if (dir == 1) {
-    //leda_swap(aux1, aux2);
-    BmdLink<node>*  tmp = aux1;
+    // leda_swap(aux1, aux2);
+    BmdLink<node> *tmp = aux1;
     aux1 = aux2;
     aux2 = tmp;
   }
@@ -937,7 +808,8 @@ BmdLink<node>*  PlanarityTestImpl::searchRBC(int dir, BmdLink<node>* it, node n,
   node u = it->getData();
   int b = labelB.get(u.id);
 
-  while (it != NULL && (b <= dfsPosNum.get(n.id) || dir != 1) && state.get(u.id) == NOT_VISITED) {
+  while (it != nullptr && (b <= dfsPosNum.get(n.id) || dir != 1) &&
+         state.get(u.id) == NOT_VISITED) {
     aux1 = it->prev();
 
     if (aux1 == prev)
@@ -949,18 +821,18 @@ BmdLink<node>*  PlanarityTestImpl::searchRBC(int dir, BmdLink<node>* it, node n,
     state.set(u.id, VISITED_IN_RBC);
     traversedNodesInRBC.push_back(u);
 
-    if (it != NULL) {
+    if (it != nullptr) {
       u = it->getData();
       b = labelB.get(u.id);
     }
   }
 
-  if (it == NULL)
+  if (it == nullptr)
     return prev;
-  else if (state.get(u.id) != NOT_VISITED || (it->prev() == NULL || it->succ() == NULL))
+  else if (state.get(u.id) != NOT_VISITED || (it->prev() == nullptr || it->succ() == nullptr))
     return it;
   else
-    return NULL;
+    return nullptr;
 }
 //=================================================================
 /*
@@ -975,8 +847,7 @@ BmdLink<node>*  PlanarityTestImpl::searchRBC(int dir, BmdLink<node>* it, node n,
  * - state[v] == NOT_VISITED for each node v in RBC list that was not
  *   traversed.
  */
-node PlanarityTestImpl::findActiveCNode(node u, node w, list<node>& nl) {
-  //  tlp::warning() << __PRETTY_FUNCTION__ << endl;
+node PlanarityTestImpl::findActiveCNode(node u, node w, list<node> &nl) {
   list<node> traversedNodesInRBC;
   assert(isCNode(parent.get(u.id)));
 
@@ -985,21 +856,22 @@ node PlanarityTestImpl::findActiveCNode(node u, node w, list<node>& nl) {
     return parent.get(u.id);
   }
 
-  BmdLink<node>*  it1 = ptrItem.get(u.id);//ptrItem[u];
-  assert(it1 != NULL);
+  BmdLink<node> *it1 = ptrItem.get(u.id); // ptrItem[u];
+  assert(it1 != nullptr);
 
   state.set(u.id, VISITED_IN_RBC);
   traversedNodesInRBC.push_back(u);
-  BmdLink<node>*  it = searchRBC(1, it1, w, traversedNodesInRBC);
+  BmdLink<node> *it = searchRBC(1, it1, w, traversedNodesInRBC);
 
-  if (it == NULL)  it = searchRBC(0, it1, w, traversedNodesInRBC);
+  if (it == nullptr)
+    it = searchRBC(0, it1, w, traversedNodesInRBC);
 
-  assert(it != NULL);
+  assert(it != nullptr);
 
   node v = it->getData();
   node cNode;
 
-  if (it->prev() != 0 && it->succ() != 0)
+  if (it->prev() != nullptr && it->succ() != nullptr)
     cNode = parent.get(v.id); // path compressed;
   else
     cNode = activeCNode[it];
@@ -1009,15 +881,15 @@ node PlanarityTestImpl::findActiveCNode(node u, node w, list<node>& nl) {
   node first = RBC[cNode].firstItem()->getData();
 
   // path compression;
-  //forall(v, traversedNodesInRBC)
-  for (list<node>::iterator it = traversedNodesInRBC.begin(); it != traversedNodesInRBC.end(); ++it) {
-    if (*it != first) {
-      if (*it != u)
+  // forall(v, traversedNodesInRBC)
+  for (auto itn : traversedNodesInRBC) {
+    if (itn != first) {
+      if (itn != u)
         nl.push_back(v);
 
-      parent.set((*it).id, cNode);
-    }
-    else state.set((*it).id, NOT_VISITED);
+      parent.set(itn.id, cNode);
+    } else
+      state.set(itn.id, NOT_VISITED);
   }
 
   return cNode;
