@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,23 +21,21 @@
 
 using namespace tlp;
 
-PluginProgress::PluginProgress(): _previewHandler(NULL) {
-}
+PluginProgress::PluginProgress() : _previewHandler(nullptr) {}
 
 PluginProgress::~PluginProgress() {
   delete _previewHandler;
 }
 
-void PluginProgress::setPreviewHandler(ProgressPreviewHandler* handler) {
+void PluginProgress::setPreviewHandler(ProgressPreviewHandler *handler) {
   delete _previewHandler;
   _previewHandler = handler;
 }
 ProgressState PluginProgress::progress(int step, int max_step) {
-  if (_previewHandler != NULL && isPreviewMode())
-    _previewHandler->progressStateChanged(step,max_step);
+  if (_previewHandler != nullptr && isPreviewMode())
+    _previewHandler->progressStateChanged(step, max_step);
 
   return TLP_CONTINUE;
 }
 
-ProgressPreviewHandler::~ProgressPreviewHandler() {
-}
+ProgressPreviewHandler::~ProgressPreviewHandler() {}
