@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -16,55 +16,52 @@
  * See the GNU General Public License for more details.
  *
  */
+#include <algorithm>
+
 #include <tulip/TLPBExportImport.h>
 #include <tulip/TlpTools.h>
 #include <tulip/PropertyTypes.h>
 #include <tulip/GraphProperty.h>
 
-
 PLUGIN(TLPBExport)
 
 using namespace tlp;
 using namespace std;
 
 //================================================================================
-void TLPBExport::getSubGraphs(Graph* g, vector<Graph*>& vsg) {
+void TLPBExport::getSubGraphs(Graph *g, vector<Graph *> &vsg) {
   // get subgraphs in a vector
-  Graph *sg;
-  forEach(sg, g->getSubGraphs()) {
+  for (Graph *sg : g->subGraphs()) {
     vsg.push_back(sg);
     getSubGraphs(sg, vsg);
   }
 }
 //================================================================================
 void TLPBExport::writeAttributes(ostream &os, Graph *g) {
-  const DataSet& attributes = g->getAttributes();
+  const DataSet &attributes = g->getAttributes();
 
   if (!attributes.empty()) {
     // If nodes and edges are stored as graph attributes
     // we need to update their ids before serializing them
     // as nodes and edges have been reindexed
-    pair<string, DataType*> attribute;
-    forEach(attribute, attributes.getValues()) {
-      if (attribute.second->getTypeName() == string(typeid(node).name())) {
-        node *n = reinterpret_cast<node*>(attribute.second->value);
-        n->id = getNode(*n).id;
-      }
-      else if (attribute.second->getTypeName() == string(typeid(edge).name())) {
-        edge *e = reinterpret_cast<edge*>(attribute.second->value);
-        e->id = getEdge(*e).id;
-      }
-      else if (attribute.second->getTypeName() == string(typeid(vector<node>).name())) {
-        vector<node> *vn = reinterpret_cast<vector<node>*>(attribute.second->value);
 
-        for (size_t i = 0 ; i < vn->size() ; ++i) {
+    for (const pair<string, DataType *> &attribute : attributes.getValues()) {
+      if (attribute.second->getTypeName() == string(typeid(node).name())) {
+        node *n = static_cast<node *>(attribute.second->value);
+        n->id = getNode(*n).id;
+      } else if (attribute.second->getTypeName() == string(typeid(edge).name())) {
+        edge *e = static_cast<edge *>(attribute.second->value);
+        e->id = getEdge(*e).id;
+      } else if (attribute.second->getTypeName() == string(typeid(vector<node>).name())) {
+        vector<node> *vn = static_cast<vector<node> *>(attribute.second->value);
+
+        for (size_t i = 0; i < vn->size(); ++i) {
           (*vn)[i].id = getNode((*vn)[i]).id;
         }
-      }
-      else if (attribute.second->getTypeName() == string(typeid(vector<edge>).name())) {
-        vector<edge> *ve = reinterpret_cast<vector<edge>*>(attribute.second->value);
+      } else if (attribute.second->getTypeName() == string(typeid(vector<edge>).name())) {
+        vector<edge> *ve = static_cast<vector<edge> *>(attribute.second->value);
 
-        for (size_t i = 0 ; i < ve->size() ; ++i) {
+        for (size_t i = 0; i < ve->size(); ++i) {
           (*ve)[i].id = getEdge((*ve)[i]).id;
         }
       }
@@ -73,16 +70,11 @@ void TLPBExport::writeAttributes(ostream &os, Graph *g) {
 
   unsigned int id = g->getSuperGraph() == g ? 0 : g->getId();
   // write graph id
-  os.write((char *) &id, sizeof(id));
+  os.write(reinterpret_cast<const char *>(&id), sizeof(id));
   // write graph attributes
   DataSet::write(os, attributes);
   // do not forget to write the end marker
   os.put(')');
-
-  // write subgraph attributes
-  Graph* sg;
-  forEach(sg, g->getSubGraphs())
-  writeAttributes(os, sg);
 }
 //================================================================================
 bool TLPBExport::exportGraph(std::ostream &os) {
@@ -95,44 +87,27 @@ bool TLPBExport::exportGraph(std::ostream &os) {
   // header
   TLPBHeader header(graph->numberOfNodes(), graph->numberOfEdges());
   // write header
-  os.write((char *) &header, sizeof(header));
-  // reindex nodes/edges
-  {
-    unsigned int i = 0;
-    node n;
-    forEach(n, graph->getNodes()) {
-      nodeIndex.set(n.id, node(i));
-      ++i;
-    }
-    i = 0;
-    edge e;
-    forEach(e, graph->getEdges()) {
-      edgeIndex.set(e.id, edge(i));
-      ++i;
-    }
-  }
+  os.write(reinterpret_cast<const char *>(&header), sizeof(header));
   // loop to write edges
   {
     pluginProgress->setComment("writing edges...");
     // use a vector as buffer
-    std::vector< std::pair<node, node> > vEdges(MAX_EDGES_TO_WRITE);
-    edge e;
+    std::vector<std::pair<node, node>> vEdges(MAX_EDGES_TO_WRITE);
     unsigned int edgesToWrite = 0, nbWrittenEdges = 0;
-    forEach(e, graph->getEdges()) {
+    for (auto e : graph->edges()) {
       std::pair<node, node> ends = graph->ends(e);
       ends.first = getNode(ends.first);
       ends.second = getNode(ends.second);
-      vEdges[edgesToWrite] = ends;
+      vEdges[edgesToWrite] = std::move(ends);
 
       if (++edgesToWrite == MAX_EDGES_TO_WRITE) {
         // write already buffered edges
-        os.write((char *) vEdges.data(),
+        os.write(reinterpret_cast<const char *>(vEdges.data()),
                  MAX_EDGES_TO_WRITE * sizeof(vEdges[0]));
         nbWrittenEdges += edgesToWrite;
 
-        if (pluginProgress->progress(nbWrittenEdges, header.numNodes)
-            != TLP_CONTINUE)
-          return pluginProgress->state()!=TLP_CANCEL;
+        if (pluginProgress->progress(nbWrittenEdges, header.numNodes) != TLP_CONTINUE)
+          return pluginProgress->state() != TLP_CANCEL;
 
         edgesToWrite = 0;
       }
@@ -140,41 +115,55 @@ bool TLPBExport::exportGraph(std::ostream &os) {
 
     if (edgesToWrite) {
       // write last buffered edges
-      os.write((char *) vEdges.data(),
+      os.write(reinterpret_cast<const char *>(vEdges.data()),
                edgesToWrite * sizeof(std::pair<node, node>));
     }
   }
   // write subgraphs
-  std::vector<Graph*> vSubGraphs;
+  std::vector<Graph *> vSubGraphs;
   // get subgraphs in a vector
   getSubGraphs(graph, vSubGraphs);
   unsigned int numSubGraphs = vSubGraphs.size();
   {
     pluginProgress->setComment("writing subgraphs...");
     // write nb subgraphs
-    os.write((char *) &numSubGraphs, sizeof(numSubGraphs));
+    os.write(reinterpret_cast<const char *>(&numSubGraphs), sizeof(numSubGraphs));
 
-    for(unsigned int i = 0; i < numSubGraphs; ++i) {
-      Graph* sg = vSubGraphs[i];
-      std::pair<unsigned int, unsigned int> ids(sg->getId(),
-          sg->getSuperGraph()->getSuperGraph() == sg->getSuperGraph() ? 0 : sg->getSuperGraph()->getId());
+    for (unsigned int i = 0; i < numSubGraphs; ++i) {
+      Graph *sg = vSubGraphs[i];
+      unsigned int parentId = sg->getSuperGraph()->getId();
+
+      if (parentId == graph->getId())
+        parentId = 0;
+
+      std::pair<unsigned int, unsigned int> ids(sg->getId(), parentId);
       // write ids
-      os.write((char *) &ids, sizeof(ids));
+      os.write(reinterpret_cast<const char *>(&ids), sizeof(ids));
       // loop to write sg nodes ranges
       {
-        // use a vector as buffer
+        // first sort sg nodes
+        const std::vector<node> &nodes = sg->nodes();
+        unsigned int nbNodes = nodes.size();
+        std::vector<node> sgNodes(nbNodes);
 
-        std::vector<std::vector<std::pair<node, node> > > vRangesVec;
-        vRangesVec.push_back(std::vector<std::pair<node, node> >(MAX_RANGES_TO_WRITE));
-        std::vector<std::pair<node, node> > &vRanges = vRangesVec.back();
+        for (unsigned int j = 0; j < nbNodes; ++j)
+          sgNodes[j] = getNode(nodes[j]);
+
+        std::sort(sgNodes.begin(), sgNodes.end());
+
+        // use a vector as buffer
+        std::vector<std::vector<std::pair<node, node>>> vRangesVec;
+        vRangesVec.emplace_back(MAX_RANGES_TO_WRITE);
+        auto &vRanges = vRangesVec.back();
 
         unsigned int rangesToWrite = 0;
         unsigned int numRanges = 0;
 
         bool pendingWrite = false;
-        node beginNode, lastNode, current;
-        forEach(current, sg->getNodes()) {
-          current = getNode(current);
+        node beginNode, lastNode;
+
+        for (unsigned int j = 0; j < nbNodes; ++j) {
+          node current = sgNodes[j];
           pendingWrite = true;
 
           if (!beginNode.isValid())
@@ -188,7 +177,7 @@ bool TLPBExport::exportGraph(std::ostream &os) {
               beginNode = lastNode = current;
 
               if (rangesToWrite == MAX_RANGES_TO_WRITE) {
-                vRangesVec.push_back(std::vector<std::pair<node, node> >(MAX_RANGES_TO_WRITE));
+                vRangesVec.emplace_back(MAX_RANGES_TO_WRITE);
                 vRanges = vRangesVec.back();
                 rangesToWrite = 0;
                 pendingWrite = false;
@@ -204,34 +193,44 @@ bool TLPBExport::exportGraph(std::ostream &os) {
         }
 
         // mark nb ranges
-        os.write((char *) &numRanges, sizeof(numRanges));
+        os.write(reinterpret_cast<const char *>(&numRanges), sizeof(numRanges));
         // write already buffered ranges
         int numRangesV = numRanges / MAX_RANGES_TO_WRITE;
 
-        for (int j = 0 ; j < numRangesV ; ++j) {
-          os.write((char *) vRangesVec[j].data(),
+        for (int j = 0; j < numRangesV; ++j) {
+          os.write(reinterpret_cast<const char *>(vRangesVec[j].data()),
                    MAX_RANGES_TO_WRITE * sizeof(vRangesVec[j][0]));
         }
 
         // write last buffered ranges
-        os.write((char *) vRanges.data(),
+        os.write(reinterpret_cast<const char *>(vRanges.data()),
                  rangesToWrite * sizeof(vRanges[0]));
-
       }
       // loop to write sg edges ranges
       {
+        // first sort sg edges
+        const std::vector<edge> &edges = sg->edges();
+        unsigned int nbEdges = edges.size();
+        std::vector<edge> sgEdges(nbEdges);
+
+        for (unsigned int j = 0; j < nbEdges; ++j)
+          sgEdges[j] = getEdge(edges[j]);
+
+        std::sort(sgEdges.begin(), sgEdges.end());
+
         // use a vector as buffer
-        std::vector<std::vector<std::pair<edge, edge> > > vRangesVec;
-        vRangesVec.push_back(std::vector<std::pair<edge, edge> >(MAX_RANGES_TO_WRITE));
-        std::vector<std::pair<edge, edge> > &vRanges = vRangesVec.back();
+        std::vector<std::vector<std::pair<edge, edge>>> vRangesVec;
+        vRangesVec.emplace_back(MAX_RANGES_TO_WRITE);
+        auto &vRanges = vRangesVec.back();
 
         unsigned int rangesToWrite = 0;
         unsigned int numRanges = 0;
 
         bool pendingWrite = false;
-        edge beginEdge, lastEdge, current;
-        forEach(current, sg->getEdges()) {
-          current = getEdge(current);
+        edge beginEdge, lastEdge;
+
+        for (unsigned int j = 0; j < nbEdges; ++j) {
+          edge current = sgEdges[j];
           pendingWrite = true;
 
           if (!beginEdge.isValid())
@@ -245,7 +244,7 @@ bool TLPBExport::exportGraph(std::ostream &os) {
               beginEdge = lastEdge = current;
 
               if (rangesToWrite == MAX_RANGES_TO_WRITE) {
-                vRangesVec.push_back(std::vector<std::pair<edge, edge> >(MAX_RANGES_TO_WRITE));
+                vRangesVec.emplace_back(MAX_RANGES_TO_WRITE);
                 vRanges = vRangesVec.back();
                 rangesToWrite = 0;
                 pendingWrite = false;
@@ -261,70 +260,71 @@ bool TLPBExport::exportGraph(std::ostream &os) {
         }
 
         // mark nb ranges
-        os.write((char *) &numRanges, sizeof(numRanges));
+        os.write(reinterpret_cast<const char *>(&numRanges), sizeof(numRanges));
         // write already buffered ranges
         int numRangesV = numRanges / MAX_RANGES_TO_WRITE;
 
-        for (int j = 0 ; j < numRangesV ; ++j) {
-          os.write((char *) vRangesVec[j].data(),
+        for (int j = 0; j < numRangesV; ++j) {
+          os.write(reinterpret_cast<const char *>(vRangesVec[j].data()),
                    MAX_RANGES_TO_WRITE * sizeof(vRangesVec[j][0]));
         }
 
         // write last buffered ranges
-        os.write((char *) vRanges.data(),
+        os.write(reinterpret_cast<const char *>(vRanges.data()),
                  rangesToWrite * sizeof(vRanges[0]));
       }
 
-      if (pluginProgress->progress(i, numSubGraphs)
-          != TLP_CONTINUE)
-        return pluginProgress->state()!=TLP_CANCEL;
+      if (pluginProgress->progress(i, numSubGraphs) != TLP_CONTINUE)
+        return pluginProgress->state() != TLP_CANCEL;
     }
   }
   // write properties
   {
     pluginProgress->setComment("writing properties...");
+    unsigned int numGraphProperties = 0;
     unsigned int numProperties = 0;
-    std::vector<PropertyInterface*> props;
-    std::set<PropertyInterface*> rootProps;
-    PropertyInterface* prop;
+    std::vector<PropertyInterface *> props;
     // get local properties in a vector
-    forEach(prop, graph->getObjectProperties()) {
+    for (PropertyInterface *prop : graph->getObjectProperties()) {
       props.push_back(prop);
-      rootProps.insert(prop);
       ++numProperties;
+      ++numGraphProperties;
     }
 
     // get subgraphs local properties too
     for (unsigned int i = 0; i < numSubGraphs; ++i) {
-      Graph* sg = vSubGraphs[i];
-      forEach(prop, sg->getLocalObjectProperties()) {
+      Graph *sg = vSubGraphs[i];
+      for (PropertyInterface *prop : sg->getLocalObjectProperties()) {
         props.push_back(prop);
         ++numProperties;
       }
     }
 
     // write nb properties
-    os.write((char *) &numProperties, sizeof(numProperties));
+    os.write(reinterpret_cast<const char *>(&numProperties), sizeof(numProperties));
 
     // loop on properties
     for (unsigned int i = 0; i < numProperties; ++i) {
-      prop = props[i];
+      PropertyInterface *prop = props[i];
       std::string nameOrType = prop->getName();
       unsigned int size = nameOrType.size();
       // write property name
-      os.write((char *) &size, sizeof(size));
-      os.write((char *) nameOrType.data(), size);
+      os.write(reinterpret_cast<const char *>(&size), sizeof(size));
+      os.write(reinterpret_cast<const char *>(nameOrType.data()), size);
       // write graph id
-      size = rootProps.find(prop) != rootProps.end() ? 0 : prop->getGraph()->getId();
-      os.write((char *) &size, sizeof(size));
+      unsigned int propGraphId = prop->getGraph()->getId();
+
+      if (i < numGraphProperties || propGraphId == graph->getId())
+        propGraphId = 0;
+
+      os.write(reinterpret_cast<const char *>(&propGraphId), sizeof(propGraphId));
       // special treament for pathnames view properties
-      bool pnViewProp = (nameOrType == string("viewFont") ||
-                         nameOrType == string("viewTexture"));
+      bool pnViewProp = (nameOrType == string("viewFont") || nameOrType == string("viewTexture"));
       // write type
       nameOrType = prop->getTypename();
       size = nameOrType.size();
-      os.write((char *) &size, sizeof(size));
-      os.write((char *) nameOrType.data(), size);
+      os.write(reinterpret_cast<const char *>(&size), sizeof(size));
+      os.write(reinterpret_cast<const char *>(nameOrType.data()), size);
 
       if (pnViewProp && !TulipBitmapDir.empty()) {
         string defVal = prop->getNodeDefaultStringValue();
@@ -342,8 +342,7 @@ bool TLPBExport::exportGraph(std::ostream &os) {
           defVal.replace(pos, TulipBitmapDir.size(), "TulipBitmapDir/");
 
         StringType::writeb(os, defVal);
-      }
-      else {
+      } else {
         // write node default value
         prop->writeNodeDefaultValue(os);
         // write edge default value
@@ -353,37 +352,45 @@ bool TLPBExport::exportGraph(std::ostream &os) {
       // write nodes values
       {
         // write nb of non default values
-        size = prop->numberOfNonDefaultValuatedNodes(rootProps.find(prop) != rootProps.end() ? graph : NULL);
-        os.write((char *) &size, sizeof(size));
-        // prepare ouput stream
+        size = prop->numberOfNonDefaultValuatedNodes(propGraphId ? nullptr : graph);
+        os.write(reinterpret_cast<const char *>(&size), sizeof(size));
+        // prepare output stream
         stringstream vs;
 
-        // seems there is a bug in emscripten that prevents to use the stringstream buffer optimization,
-        // so fallback  writing directly to the output stream in that case
-        bool emscripten = false;
-#ifdef __EMSCRIPTEN__
-        emscripten = true;
+        // std::basic_streambuf::pubsetbuf is a no-op in libcxx (LLVM implementation of STL)
+        // see https://github.com/llvm-mirror/libcxx/blob/master/include/streambuf#L150
+        // and https://github.com/llvm-mirror/libcxx/blob/master/include/streambuf#L360
+        // and also in STL implementation of Microsoft Visual C++
+        // so fallback writing directly to the output stream in these cases
+#if defined(_LIBCPP_VERSION) || defined(_MSC_VER)
+        bool canUsePubSetBuf = false;
         std::ostream &s = os;
 #else
+        bool canUsePubSetBuf = true;
         std::ostream &s = vs;
 #endif
-        char* vBuf = NULL;
+        char *vBuf = nullptr;
         unsigned int valueSize = prop->nodeValueSize();
 
-        if (valueSize && !emscripten) {
+        if (valueSize && canUsePubSetBuf) {
           // allocate a special buffer for values
           // this will ease the write of a bunch of values
-          vBuf = (char *) malloc(MAX_VALUES_TO_WRITE * (sizeof(unsigned int) + valueSize));
-          vs.rdbuf()->pubsetbuf((char *) vBuf,
-                                MAX_VALUES_TO_WRITE * (sizeof(unsigned int) + valueSize));
+          vBuf =
+              static_cast<char *>(malloc(MAX_VALUES_TO_WRITE * (sizeof(unsigned int) + valueSize)));
+          vs.rdbuf()->pubsetbuf(vBuf, MAX_VALUES_TO_WRITE * (sizeof(unsigned int) + valueSize));
         }
 
         // loop on nodes
-        node n;
         unsigned int nbValues = 0;
-        forEach(n, prop->getNonDefaultValuatedNodes(rootProps.find(prop) != rootProps.end() ? graph : NULL)) {
+        // when exporting the GraphProperty, if the exported graph
+        // is not the root graph we will have to check if the node pointed
+        // subgraph is a descendant graph of this graph
+        bool checkForDescendantGraph =
+            propGraphId && (prop->getTypename() == GraphProperty::propertyTypename);
+        for (auto n : prop->getNonDefaultValuatedNodes(propGraphId ? nullptr : graph)) {
+          // write current node reindexed id
           size = getNode(n).id;
-          s.write((char *) &size, sizeof(size));
+          s.write(reinterpret_cast<const char *>(&size), sizeof(size));
 
           if (pnViewProp && !TulipBitmapDir.empty()) { // viewFont || viewTexture
             string sVal = prop->getNodeStringValue(n);
@@ -392,20 +399,26 @@ bool TLPBExport::exportGraph(std::ostream &os) {
             if (pos != string::npos)
               sVal.replace(pos, TulipBitmapDir.size(), "TulipBitmapDir/");
 
-            StringType::write(s, sVal);
-          }
-          else
+            StringType::writeb(s, sVal);
+          } else if (checkForDescendantGraph) {
+            string tmp = prop->getNodeStringValue(n);
+            unsigned int id = strtoul(tmp.c_str(), nullptr, 10);
+
+            // record a null value if the node pointed subgraph
+            // is not a descendant of the currently exported graph
+            UnsignedIntegerType::writeb(s, graph->getDescendantGraph(id) ? id : 0);
+          } else
             prop->writeNodeValue(s, n);
 
           ++nbValues;
 
-          if (nbValues == MAX_VALUES_TO_WRITE && !emscripten) {
+          if (nbValues == MAX_VALUES_TO_WRITE && canUsePubSetBuf) {
             // write already buffered values
             if (vBuf)
               os.write(vBuf, MAX_VALUES_TO_WRITE * (sizeof(unsigned int) + valueSize));
             else {
               std::string sbuf = vs.str();
-              size = (unsigned int) vs.tellp();
+              size = uint(vs.tellp());
               // write buffer
               os.write(sbuf.c_str(), size);
             }
@@ -416,94 +429,98 @@ bool TLPBExport::exportGraph(std::ostream &os) {
           }
         }
 
-        if (nbValues && !emscripten) {
+        if (nbValues && canUsePubSetBuf) {
           // write last buffered values
           if (vBuf) {
             os.write(vBuf, nbValues * (sizeof(unsigned int) + valueSize));
-            free(vBuf);
-          }
-          else {
+          } else {
             std::string sbuf = vs.str();
-            size = (unsigned int) vs.tellp();
+            size = uint(vs.tellp());
             // write buffer
             os.write(sbuf.c_str(), size);
           }
         }
+
+        if (vBuf) {
+          free(vBuf);
+        }
       }
       // write edges values
       {
         // write nb of non default values
-        size = prop->numberOfNonDefaultValuatedEdges(rootProps.find(prop) != rootProps.end() ? graph : NULL);
-        os.write((char *) &size, sizeof(size));
-        // prepare ouput stream
+        size = prop->numberOfNonDefaultValuatedEdges(propGraphId ? nullptr : graph);
+        os.write(reinterpret_cast<const char *>(&size), sizeof(size));
+        // prepare output stream
         stringstream vs;
 
-        // seems there is a bug in emscripten that prevents to use the stringstream buffer optimization,
-        // so fallback  writing directly to the output stream in that case
-        bool emscripten = false;
-#ifdef __EMSCRIPTEN__
-        emscripten = true;
+        // std::basic_streambuf::pubsetbuf is a no-op in libcxx (LLVM implementation of STL)
+        // see https://github.com/llvm-mirror/libcxx/blob/master/include/streambuf#L150
+        // and https://github.com/llvm-mirror/libcxx/blob/master/include/streambuf#L360
+        // and also in STL implementation of Microsoft Visual C++
+        // so fallback writing directly to the output stream in these cases
+#if defined(_LIBCPP_VERSION) || defined(_MSC_VER)
+        bool canUsePubSetBuf = false;
         ostream &s = os;
 #else
+        bool canUsePubSetBuf = true;
         ostream &s = vs;
 #endif
-        char* vBuf = NULL;
+        char *vBuf = nullptr;
         unsigned int valueSize = prop->edgeValueSize();
         bool isGraphProperty = false;
 
-        if (valueSize && !emscripten) {
+        if (valueSize && canUsePubSetBuf) {
           // allocate a special buffer for values
           // this will ease the write of a bunch of values
-          vBuf = (char *) malloc(MAX_VALUES_TO_WRITE * (sizeof(unsigned int) + valueSize));
-          vs.rdbuf()->pubsetbuf((char *) vBuf,
-                                MAX_VALUES_TO_WRITE * (sizeof(unsigned int) + valueSize));
-        }
-        else {
+          vBuf =
+              static_cast<char *>(malloc(MAX_VALUES_TO_WRITE * (sizeof(unsigned int) + valueSize)));
+          vs.rdbuf()->pubsetbuf(vBuf, MAX_VALUES_TO_WRITE * (sizeof(unsigned int) + valueSize));
+        } else {
           if (prop->getTypename() == GraphProperty::propertyTypename)
             isGraphProperty = true;
         }
 
         // loop on edges
-        edge e;
         unsigned int nbValues = 0;
-        forEach(e, prop->getNonDefaultValuatedEdges(rootProps.find(prop) != rootProps.end() ? graph : NULL)) {
+        for (auto e : prop->getNonDefaultValuatedEdges(propGraphId ? nullptr : graph)) {
           size = getEdge(e).id;
-          s.write((char *) &size, sizeof(size));
+          s.write(reinterpret_cast<const char *>(&size), sizeof(size));
 
           if (isGraphProperty) {
-            // re-index embedded edges
-            const set<edge>& edges = ((GraphProperty*)prop)->getEdgeValue(e);
+            // reindex embedded edges
+            const set<edge> &eEdges = static_cast<GraphProperty *>(prop)->getEdgeValue(e);
             set<edge> rEdges;
-            set<edge>::const_iterator its;
 
-            for (its = edges.begin(); its != edges.end(); ++its) {
-              rEdges.insert(getEdge(*its));
+            for (auto eEdge : eEdges) {
+              // reindex only embedded edges belonging to the exported graph
+              if (!graph->isElement(eEdge))
+                continue;
+              edge rEdge = getEdge(eEdge);
+              rEdges.insert(rEdge);
             }
 
             // finally save set
             EdgeSetType::writeb(s, rEdges);
-          }
-          else if (pnViewProp && !TulipBitmapDir.empty()) {   // viewFont || viewTexture
+          } else if (pnViewProp && !TulipBitmapDir.empty()) { // viewFont || viewTexture
             string sVal = prop->getEdgeStringValue(e);
             size_t pos = sVal.find(TulipBitmapDir);
 
             if (pos != string::npos)
               sVal.replace(pos, TulipBitmapDir.size(), "TulipBitmapDir/");
 
-            StringType::write(s, sVal);
-          }
-          else
+            StringType::writeb(s, sVal);
+          } else
             prop->writeEdgeValue(s, e);
 
           ++nbValues;
 
-          if (nbValues == MAX_VALUES_TO_WRITE && !emscripten) {
+          if (nbValues == MAX_VALUES_TO_WRITE && canUsePubSetBuf) {
             // write already buffered values
             if (vBuf)
               os.write(vBuf, MAX_VALUES_TO_WRITE * (sizeof(unsigned int) + valueSize));
             else {
               std::string sbuf = vs.str();
-              size = (unsigned int) vs.tellp();
+              size = uint(vs.tellp());
               // write buffer
               os.write(sbuf.c_str(), size);
             }
@@ -514,29 +531,33 @@ bool TLPBExport::exportGraph(std::ostream &os) {
           }
         }
 
-        if (nbValues && !emscripten) {
+        if (nbValues && canUsePubSetBuf) {
           // write last buffered values
           if (vBuf) {
             os.write(vBuf, nbValues * (sizeof(unsigned int) + valueSize));
-            free(vBuf);
-          }
-          else {
+          } else {
             std::string sbuf = vs.str();
-            size = (unsigned int) vs.tellp();
+            size = uint(vs.tellp());
             // write buffer
             os.write(sbuf.c_str(), size);
           }
         }
+
+        if (vBuf) {
+          free(vBuf);
+        }
       }
 
-      if (pluginProgress->progress(i, numProperties)
-          != TLP_CONTINUE)
-        return pluginProgress->state()!=TLP_CANCEL;
+      if (pluginProgress->progress(i, numProperties) != TLP_CONTINUE)
+        return pluginProgress->state() != TLP_CANCEL;
     }
   }
-  // write graph attributes
+  // write graph and sub graphs attributes
   writeAttributes(os, graph);
 
+  for (unsigned int i = 0; i < numSubGraphs; ++i)
+    writeAttributes(os, vSubGraphs[i]);
+
   graph->setSuperGraph(superGraph);
   return true;
 }
