@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,10 +21,8 @@
 
 using namespace tlp;
 
-TulipException::TulipException(const std::string &desc):desc(desc) {
-}
-TulipException::~TulipException() throw () {
-}
-const char* TulipException::what() const throw() {
+TulipException::TulipException(const std::string &desc) : desc(desc) {}
+TulipException::~TulipException() throw() {}
+const char *TulipException::what() const throw() {
   return desc.c_str();
 }
