@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,7 +18,6 @@
  */
 ///@cond DOXYGEN_HIDDEN
 
-
 #ifndef CLEARABLELINEEDIT_H
 #define CLEARABLELINEEDIT_H
 
@@ -26,23 +25,21 @@
 
 #include <tulip/tulipconf.h>
 
-
 class TLP_QT_SCOPE ClearableLineEdit : public QLineEdit {
-  static QPixmap* CLEAR_PIXMAP;
+  static QPixmap *CLEAR_PIXMAP;
 
   bool _clearButtonHovered;
   static void initPixmap();
   QRect pixmapRect();
+
 public:
-  explicit ClearableLineEdit(QWidget *parent = NULL);
+  explicit ClearableLineEdit(QWidget *parent = nullptr);
 
 protected:
-  void paintEvent(QPaintEvent *);
-  void mouseMoveEvent(QMouseEvent *);
-  void mousePressEvent(QMouseEvent *);
-
+  void paintEvent(QPaintEvent *) override;
+  void mouseMoveEvent(QMouseEvent *) override;
+  void mousePressEvent(QMouseEvent *) override;
 };
 
-
 #endif // CLEARABLELINEEDIT_H
 ///@endcond
