@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -23,30 +23,30 @@
 
 #include <QPushButton>
 
-
 #include <tulip/ColorScale.h>
 
 namespace tlp {
 
 class ColorScaleConfigDialog;
 
-class TLP_QT_SCOPE ColorScaleButton: public QPushButton {
+class TLP_QT_SCOPE ColorScaleButton : public QPushButton {
   Q_OBJECT
   ColorScale _colorScale;
+  ColorScaleConfigDialog *dlg;
+
 public:
-  static void paintScale(QPainter*,const QRect&, const ColorScale&);
+  static void paintScale(QPainter *, const QRect &, const ColorScale &);
 
-  ColorScaleButton(ColorScale colorScale=ColorScale(), QWidget* parent=NULL);
+  ColorScaleButton(ColorScale colorScale = ColorScale(), QWidget *parent = nullptr);
 
-  const ColorScale& colorScale() const;
-  void setColorScale(const ColorScale&) const;
-  void paintEvent(QPaintEvent *event);
-  void editColorScale(const ColorScale& colorScale);
+  const ColorScale &colorScale() const;
+  void setColorScale(const ColorScale &) const;
+  void paintEvent(QPaintEvent *event) override;
+  void editColorScale(const ColorScale &colorScale);
 
 public slots:
   void editColorScale();
 };
-
-}
+} // namespace tlp
 #endif // COLORSCALEBUTTON_H
 ///@endcond
