@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,7 +18,6 @@
  */
 ///@cond DOXYGEN_HIDDEN
 
-
 #ifndef _DRAGHANDLE_H
 #define _DRAGHANDLE_H
 
@@ -31,19 +30,18 @@ class WorkspacePanel;
 class DragHandle : public QLabel {
   Q_OBJECT
 public:
-  explicit DragHandle(QWidget* parent = NULL, Qt::WindowFlags f = 0);
-  virtual void mousePressEvent(QMouseEvent* ev);
-  virtual void mouseReleaseEvent(QMouseEvent* ev);
-  virtual void mouseMoveEvent(QMouseEvent* ev);
+  explicit DragHandle(QWidget *parent = nullptr, Qt::WindowFlags f = nullptr);
+  void mousePressEvent(QMouseEvent *ev) override;
+  void mouseReleaseEvent(QMouseEvent *ev) override;
+  void mouseMoveEvent(QMouseEvent *ev) override;
 
-  void setPanel(tlp::WorkspacePanel* panel);
+  void setPanel(tlp::WorkspacePanel *panel);
 
 private:
-  tlp::WorkspacePanel* _panel;
+  tlp::WorkspacePanel *_panel;
   bool _pressed;
   QPoint _clickPosition;
 };
-
-}
+} // namespace tlp
 #endif //_DRAGHANDLE_H
 ///@endcond
