@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -29,15 +29,16 @@ class QStyleOptionViewItem;
 namespace tlp {
 
 /**
-* @brief QItemDelegate to display and edit data from a GraphTableModel in the Qt model/view architecture.
-**/
-class TLP_QT_SCOPE GraphTableItemDelegate: public TulipItemDelegate {
+ * @brief QItemDelegate to display and edit data from a GraphTableModel in the Qt model/view
+ *architecture.
+ **/
+class TLP_QT_SCOPE GraphTableItemDelegate : public TulipItemDelegate {
   Q_OBJECT
 public:
-  GraphTableItemDelegate(QObject* parent=NULL) ;
-  void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;
-
+  GraphTableItemDelegate(QObject *parent = nullptr);
+  void paint(QPainter *painter, const QStyleOptionViewItem &option,
+             const QModelIndex &index) const override;
 };
-}
+} // namespace tlp
 #endif /* TULIPTABLEWIDGETITEMDELEGATE_H_ */
 ///@endcond
