@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -34,12 +34,13 @@ class TLP_QT_SCOPE MouseBoxZoomer : public GLInteractorComponent {
 private:
   Qt::MouseButton mButton;
   Qt::KeyboardModifier kModifier;
+
 public:
   MouseBoxZoomer(Qt::MouseButton button = Qt::LeftButton,
                  Qt::KeyboardModifier modifier = Qt::NoModifier);
-  ~MouseBoxZoomer();
-  bool draw(GlMainWidget *);
-  bool eventFilter(QObject *, QEvent *);
+  ~MouseBoxZoomer() override;
+  bool draw(GlMainWidget *) override;
+  bool eventFilter(QObject *, QEvent *) override;
 
 private:
   unsigned int x, y;
@@ -47,8 +48,6 @@ private:
   bool started;
   Graph *graph;
 };
-
-
-}
-#endif //MOUSEZOOMBOX_H
+} // namespace tlp
+#endif // MOUSEZOOMBOX_H
 ///@endcond
