@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -26,32 +26,26 @@
 namespace tlp {
 
 class Graph;
-class TLP_QT_SCOPE MouseSelector:public GLInteractorComponent {
+class TLP_QT_SCOPE MouseSelector : public GLInteractorComponent {
 public:
-  enum SelectionMode {
-    EdgesAndNodes = 0,
-    EdgesOnly,
-    NodesOnly
-  };
+  enum SelectionMode { EdgesAndNodes = 0, EdgesOnly, NodesOnly };
 
   MouseSelector(Qt::MouseButton button = Qt::LeftButton,
-                Qt::KeyboardModifier modifier = Qt::NoModifier,
-                SelectionMode mode = EdgesAndNodes);
-  ~MouseSelector() {}
-  bool draw(GlMainWidget *);
-  bool eventFilter(QObject *, QEvent *);
+                Qt::KeyboardModifier modifier = Qt::NoModifier, SelectionMode mode = EdgesAndNodes);
+  ~MouseSelector() override {}
+  bool draw(GlMainWidget *) override;
+  bool eventFilter(QObject *, QEvent *) override;
+
 protected:
   Qt::MouseButton mButton;
   Qt::KeyboardModifier kModifier;
   Qt::KeyboardModifiers mousePressModifier;
-  unsigned int x,y;
-  int w,h;
+  unsigned int x, y;
+  int w, h;
   bool started;
   Graph *graph;
   SelectionMode _mode;
 };
-
-
-}
+} // namespace tlp
 #endif
 ///@endcond
