@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -25,29 +25,25 @@ class QLabel;
 
 namespace tlp {
 
-/** \brief Tulip interactor abstract class for NodeLinkDiagramComponent
+/** @brief Tulip interactor abstract class for NodeLinkDiagramComponent
  *
  */
-class TLP_QT_SCOPE NodeLinkDiagramComponentInteractor
-    : public GLInteractorComposite {
-  QLabel* _label;
+class TLP_QT_SCOPE NodeLinkDiagramComponentInteractor : public GLInteractorComposite {
+  QLabel *_label;
   unsigned int _priority;
 
-public :
+public:
+  NodeLinkDiagramComponentInteractor(const QString &iconPath, const QString &text,
+                                     unsigned int priority = 0);
 
-  NodeLinkDiagramComponentInteractor(const QString &iconPath, const QString &text, unsigned int priority=0);
+  ~NodeLinkDiagramComponentInteractor() override;
 
-  virtual ~NodeLinkDiagramComponentInteractor();
+  void setConfigurationWidgetText(const QString &text);
 
-  void setConfigurationWidgetText(const QString& text);
-
-  virtual QWidget* configurationWidget() const;
-
-  virtual unsigned int priority() const;
-
-  void setPriority(const unsigned int p);
+  QLabel *configurationDocWidget() const override;
 
+  unsigned int priority() const override;
 };
-}
+} // namespace tlp
 
 #endif // NODELINKDIAGRAMCOMPONENTINTERACTOR_H
