@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -39,7 +39,7 @@ private:
   static QStringList _installedVersions;
   static bool _installedVersionsChecked;
 };
-}
+} // namespace tlp
 
 #endif // PYTHONVERSIONCHECKER_H
 ///@endcond
