@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,7 +18,6 @@
  */
 ///@cond DOXYGEN_HIDDEN
 
-
 #ifndef SCENECONFIGWIDGET_H
 #define SCENECONFIGWIDGET_H
 
@@ -36,31 +35,28 @@ class GlMainWidget;
 class TLP_QT_SCOPE SceneConfigWidget : public QWidget {
   Q_OBJECT
 
-  Ui::SceneConfigWidget* _ui;
-  tlp::GlMainWidget* _glMainWidget;
+  Ui::SceneConfigWidget *_ui;
+  tlp::GlMainWidget *_glMainWidget;
 
   bool _resetting;
 
 public:
-  explicit SceneConfigWidget(QWidget *parent = NULL);
-  ~SceneConfigWidget();
+  explicit SceneConfigWidget(QWidget *parent = nullptr);
+  ~SceneConfigWidget() override;
 
 signals:
   void settingsApplied();
 
 public slots:
-  void setGlMainWidget(tlp::GlMainWidget*);
+  void setGlMainWidget(tlp::GlMainWidget *);
   void resetChanges();
   void applySettings();
   void dynamicFontRBToggled(bool);
-  void updateSliderRangeLabels();
-
 
 protected:
-  bool eventFilter(QObject *, QEvent *);
-
+  bool eventFilter(QObject *, QEvent *) override;
 };
-}
+} // namespace tlp
 
 #endif // SCENECONFIGWIDGET_H
 ///@endcond
