@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,7 +18,6 @@
  */
 ///@cond DOXYGEN_HIDDEN
 
-
 #ifndef SCENELAYERSCONFIGWIDGET_H
 #define SCENELAYERSCONFIGWIDGET_H
 
@@ -37,13 +36,14 @@ class GlMainWidget;
 class TLP_QT_SCOPE SceneLayersConfigWidget : public QWidget {
   Q_OBJECT
 
-  Ui::SceneLayersConfigWidget* _ui;
-  tlp::GlMainWidget* _glMainWidget;
-public:
-  explicit SceneLayersConfigWidget(QWidget *parent = NULL);
-  virtual ~SceneLayersConfigWidget();
+  Ui::SceneLayersConfigWidget *_ui;
+  tlp::GlMainWidget *_glMainWidget;
 
-  void setGlMainWidget(tlp::GlMainWidget* glMainWidget);
+public:
+  explicit SceneLayersConfigWidget(QWidget *parent = nullptr);
+  ~SceneLayersConfigWidget() override;
+
+  void setGlMainWidget(tlp::GlMainWidget *glMainWidget);
 
 public slots:
 
@@ -51,10 +51,8 @@ public slots:
 
 signals:
   void drawNeeded();
-
-
 };
-}
+} // namespace tlp
 
 #endif // SCENELAYERSCONFIGWIDGET_H
 ///@endcond
