@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,7 +18,6 @@
  */
 ///@cond DOXYGEN_HIDDEN
 
-
 #ifndef STRINGEDITOR_H
 #define STRINGEDITOR_H
 
@@ -30,26 +29,26 @@
 
 namespace tlp {
 /**
-* @brief Simple String edition widget.
-**/
+ * @brief Simple String edition widget.
+ **/
 class TLP_QT_SCOPE StringEditor : public QDialog {
   QString currentString;
-  QTextEdit* edit;
+  QTextEdit *edit;
 
 public:
-  explicit StringEditor(QWidget *parent = NULL);
+  explicit StringEditor(QWidget *parent = nullptr);
 
   QString getString() const;
-  void setString(const QString& qstr);
+  void setString(const QString &qstr);
 
   // redefinition to ensure it is shown in the center of its parent
-  void showEvent(QShowEvent* ev);
+  void showEvent(QShowEvent *ev) override;
 
 public slots:
   // redefinition to ensure to catch the end of input
-  void done(int r);
+  void done(int r) override;
 };
-}
+} // namespace tlp
 
 #endif // STRINGEDITOR_H
 ///@endcond
