@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,7 +18,6 @@
  */
 ///@cond DOXYGEN_HIDDEN
 
-
 #ifndef TREEVIEWCOMBOBOX_H
 #define TREEVIEWCOMBOBOX_H
 
@@ -30,33 +29,29 @@
 class TLP_QT_SCOPE TreeViewComboBox : public QComboBox {
 
   Q_OBJECT
-  QTreeView* _treeView;
-  bool _skipNextHide;
+  QTreeView *_treeView;
   bool _popupVisible;
   QModelIndex _lastIndex;
 
 public:
-  explicit TreeViewComboBox(QWidget *parent = NULL);
+  explicit TreeViewComboBox(QWidget *parent = nullptr);
 
-  void setModel(QAbstractItemModel * model);
+  void setModel(QAbstractItemModel *model);
 
-  virtual void showPopup();
-  virtual void hidePopup();
+  void showPopup() override;
+  void hidePopup() override;
 
   QModelIndex selectedIndex() const;
 
-  bool eventFilter(QObject*, QEvent*);
-
 public slots:
 
-  void selectIndex(const QModelIndex&);
-  void rowsRemoved(const QModelIndex&, int, int);
+  void selectIndex(const QModelIndex &);
+  void rowsRemoved(const QModelIndex &, int, int);
   void currentIndexChanged();
 
 signals:
 
   void currentItemChanged();
-
 };
 
 #endif // TREEVIEWCOMBOBOX_H
