@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -27,30 +27,29 @@
 
 namespace tlp {
 
-class TLP_QT_SCOPE TulipModel: public QAbstractItemModel {
+class TLP_QT_SCOPE TulipModel : public QAbstractItemModel {
   Q_OBJECT
   Q_ENUMS(TulipRole)
 
 public:
   enum TulipRole {
-    GraphRole = Qt::UserRole+1,
-    PropertyRole = Qt::UserRole+2,
-    IsNodeRole = Qt::UserRole+3,
-    StringRole = Qt::UserRole+4,
-    MandatoryRole = Qt::UserRole+5,
-    ElementIdRole = Qt::UserRole+6
+    GraphRole = Qt::UserRole + 1,
+    PropertyRole = Qt::UserRole + 2,
+    IsNodeRole = Qt::UserRole + 3,
+    StringRole = Qt::UserRole + 4,
+    MandatoryRole = Qt::UserRole + 5,
+    ElementIdRole = Qt::UserRole + 6
   };
 
-  explicit TulipModel(QObject *parent=NULL);
-  virtual ~TulipModel();
+  explicit TulipModel(QObject *parent = nullptr);
+  ~TulipModel() override;
 
-  QVariant headerData(int section, Qt::Orientation orientation, int role) const;
+  QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
 
 signals:
-  void checkStateChanged(QModelIndex,Qt::CheckState);
+  void checkStateChanged(QModelIndex, Qt::CheckState);
 };
-
-}
+} // namespace tlp
 
 #endif // TULIPMODEL_H
 ///@endcond
