@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,7 +18,6 @@
  */
 ///@cond DOXYGEN_HIDDEN
 
-
 #ifndef VECTOREDITOR_H
 #define VECTOREDITOR_H
 
@@ -31,25 +30,25 @@ namespace Ui {
 class VectorEditor;
 }
 
-class TLP_QT_SCOPE VectorEditor:public QDialog {
+class TLP_QT_SCOPE VectorEditor : public QDialog {
   Q_OBJECT
-  Ui::VectorEditor* _ui;
+  Ui::VectorEditor *_ui;
 
   int _userType;
   QVector<QVariant> currentVector;
 
 public:
-  explicit VectorEditor(QWidget* parent=0);
-  ~VectorEditor();
-  void setVector(const QVector<QVariant>& d, int userType);
-  const QVector<QVariant>& vector() const {
+  explicit VectorEditor(QWidget *parent = nullptr);
+  ~VectorEditor() override;
+  void setVector(const QVector<QVariant> &d, int userType);
+  const QVector<QVariant> &vector() const {
     return currentVector;
   }
 
 public slots:
   void add();
   void remove();
-  void done(int r);
+  void done(int r) override;
 };
 
 #endif // VECTOREDITIONWIDGET_H
