@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,7 +21,6 @@
 #include <QHeaderView>
 #include <QLinearGradient>
 #include <QPainter>
-#include <QSettings>
 #include <QMessageBox>
 #include <QInputDialog>
 
@@ -30,7 +29,9 @@
 
 #include <tulip/TlpQtTools.h>
 #include <tulip/ColorScaleConfigDialog.h>
+#include <tulip/ColorScalesManager.h>
 #include <tulip/TlpTools.h>
+#include <tulip/TulipSettings.h>
 
 #include "ui_ColorScaleConfigDialog.h"
 
@@ -38,10 +39,10 @@ using namespace std;
 
 namespace tlp {
 
-map<QString, vector<Color> > ColorScaleConfigDialog::tulipImageColorScales;
+map<QString, vector<Color>> ColorScaleConfigDialog::tulipImageColorScales;
 
-ColorScaleConfigDialog::ColorScaleConfigDialog(const ColorScale& colorScale,
-    QWidget *parent) : QDialog(parent), _ui(new Ui::ColorScaleDialog), colorScale(colorScale) {
+ColorScaleConfigDialog::ColorScaleConfigDialog(const ColorScale &colorScale, QWidget *parent)
+    : QDialog(parent), _ui(new Ui::ColorScaleDialog), colorScale(colorScale) {
   _ui->setupUi(this);
   _ui->colorsTable->setColumnWidth(0, _ui->colorsTable->width());
   _ui->colorsTable->horizontalHeader()->setHidden(true);
@@ -51,17 +52,27 @@ ColorScaleConfigDialog::ColorScaleConfigDialog(const ColorScale& colorScale,
   _ui->userGradientPreview->setPalette(palette);
   _ui->savedGradientPreview->setAutoFillBackground(true);
   _ui->userGradientPreview->setAutoFillBackground(true);
-  connect(_ui->savedColorScalesList, SIGNAL(currentItemChanged(QListWidgetItem *, QListWidgetItem *)), this, SLOT(displaySavedGradientPreview()));
-  connect(_ui->savedColorScalesList, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT(reeditSaveColorScale(QListWidgetItem *)));
+  connect(_ui->savedColorScalesList,
+          SIGNAL(currentItemChanged(QListWidgetItem *, QListWidgetItem *)), this,
+          SLOT(displaySavedGradientPreview()));
+  connect(_ui->savedColorScalesList, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this,
+          SLOT(reeditSaveColorScale(QListWidgetItem *)));
   connect(_ui->nbColors, SIGNAL(valueChanged(int)), this, SLOT(nbColorsValueChanged(int)));
-  connect(_ui->colorsTable, SIGNAL(itemDoubleClicked (QTableWidgetItem *)), this, SLOT(colorTableItemDoubleClicked(QTableWidgetItem *)));
+  connect(_ui->colorsTable, SIGNAL(itemDoubleClicked(QTableWidgetItem *)), this,
+          SLOT(colorTableItemDoubleClicked(QTableWidgetItem *)));
   connect(_ui->tabWidget, SIGNAL(currentChanged(int)), this, SLOT(displaySavedGradientPreview()));
   connect(_ui->tabWidget, SIGNAL(currentChanged(int)), this, SLOT(displayUserGradientPreview()));
   connect(_ui->gradientCB, SIGNAL(clicked()), this, SLOT(displayUserGradientPreview()));
   connect(_ui->saveColorScaleButton, SIGNAL(clicked()), this, SLOT(saveCurrentColorScale()));
   connect(_ui->deleteColorScaleButton, SIGNAL(clicked()), this, SLOT(deleteSavedColorScale()));
   connect(_ui->importFromImgButton, SIGNAL(clicked()), this, SLOT(importColorScaleFromImageFile()));
+  connect(_ui->importFromPredefinedCSButton, SIGNAL(clicked()), this,
+          SLOT(importColorScaleFromColorScaleFile()));
   connect(_ui->invertColorScaleButton, SIGNAL(clicked()), this, SLOT(invertEditedColorScale()));
+  connect(_ui->globalAlphaCB, SIGNAL(toggled(bool)), _ui->globalAlphaSB, SLOT(setEnabled(bool)));
+  connect(_ui->globalAlphaCB, SIGNAL(toggled(bool)), this, SLOT(applyGlobalAlphaToColorScale()));
+  connect(_ui->globalAlphaSB, SIGNAL(valueChanged(int)), this,
+          SLOT(applyGlobalAlphaToColorScale()));
 
   if (tulipImageColorScales.empty()) {
     loadTulipImageColorScales();
@@ -80,34 +91,34 @@ void ColorScaleConfigDialog::accept() {
   bool gradient = true;
 
   if (_ui->tabWidget->currentIndex() == 1) {
-    if (_ui->savedColorScalesList->count() > 0) {
+    if (_ui->savedColorScalesList->count() > 0 && _ui->savedColorScalesList->currentItem()) {
       QString savedColorScaleId = _ui->savedColorScalesList->currentItem()->text();
 
       if (tulipImageColorScales.find(savedColorScaleId) != tulipImageColorScales.end()) {
         colors = tulipImageColorScales[savedColorScaleId];
-      }
-      else {
-        QSettings settings("TulipSoftware","Tulip");
-        settings.beginGroup("ColorScales");
-        QList<QVariant> colorsVector = settings.value(savedColorScaleId).toList();
+      } else {
+        TulipSettings::instance().beginGroup("ColorScales");
+        QList<QVariant> colorsVector = TulipSettings::instance().value(savedColorScaleId).toList();
         QString gradientScaleId = savedColorScaleId + "_gradient?";
-        gradient = settings.value(gradientScaleId).toBool();
-        settings.endGroup();
+        gradient = TulipSettings::instance().value(gradientScaleId).toBool();
+        TulipSettings::instance().endGroup();
 
-        for (int i = 0 ; i < colorsVector.size() ; ++i) {
-          colors.push_back(Color(colorsVector.at(i).value<QColor>().red(), colorsVector.at(i).value<QColor>().green(),
-                                 colorsVector.at(i).value<QColor>().blue(), colorsVector.at(i).value<QColor>().alpha()));
+        colors.reserve(colorsVector.size());
+        for (int i = 0; i < colorsVector.size(); ++i) {
+          colors.emplace_back(colorsVector.at(i).value<QColor>().red(),
+                              colorsVector.at(i).value<QColor>().green(),
+                              colorsVector.at(i).value<QColor>().blue(),
+                              colorsVector.at(i).value<QColor>().alpha());
         }
 
         std::reverse(colors.begin(), colors.end());
       }
     }
-  }
-  else {
+  } else {
+    colors.reserve(_ui->colorsTable->rowCount());
     for (int i = 0; i < _ui->colorsTable->rowCount(); ++i) {
-      QColor itemColor = _ui->colorsTable->item(i, 0)->backgroundColor();
-      colors.push_back(Color(itemColor.red(), itemColor.green(),
-                             itemColor.blue(), itemColor.alpha()));
+      QColor itemColor = _ui->colorsTable->item(i, 0)->background().color();
+      colors.emplace_back(itemColor.red(), itemColor.green(), itemColor.blue(), itemColor.alpha());
     }
 
     std::reverse(colors.begin(), colors.end());
@@ -118,6 +129,8 @@ void ColorScaleConfigDialog::accept() {
     colorScale.setColorScale(colors, gradient);
   }
 
+  ColorScalesManager::setLatestColorScale(colorScale);
+
   QDialog::accept();
 }
 
@@ -131,51 +144,61 @@ vector<Color> ColorScaleConfigDialog::getColorScaleFromImageFile(const QString &
     step = 10;
 
   vector<Color> colors;
-
+  colors.reserve(imageHeight % step ? imageHeight / step : imageHeight / step + 1);
   for (unsigned int i = 0; i < imageHeight; i += step) {
     QRgb pixelValue = gradientImage.pixel(0, i);
-    colors.push_back(Color(qRed(pixelValue), qGreen(pixelValue), qBlue(
-                             pixelValue), qAlpha(pixelValue)));
+    colors.emplace_back(qRed(pixelValue), qGreen(pixelValue), qBlue(pixelValue),
+                        qAlpha(pixelValue));
   }
 
   if (imageHeight % step != 0) {
     QRgb pixelValue = gradientImage.pixel(0, imageHeight - 1);
-    colors.push_back(Color(qRed(pixelValue), qGreen(pixelValue), qBlue(
-                             pixelValue), qAlpha(pixelValue)));
+    colors.emplace_back(qRed(pixelValue), qGreen(pixelValue), qBlue(pixelValue),
+                        qAlpha(pixelValue));
   }
 
   std::reverse(colors.begin(), colors.end());
   return colors;
 }
 
-ColorScale ColorScaleConfigDialog::getColorScaleFromImageFile(const std::string &imageFilePath, bool gradient) {
-  return ColorScale(getColorScaleFromImageFile(QString::fromUtf8(imageFilePath.c_str())), gradient);
+ColorScale ColorScaleConfigDialog::getColorScaleFromImageFile(const std::string &imageFilePath,
+                                                              bool gradient) {
+  return ColorScale(getColorScaleFromImageFile(tlpStringToQString(imageFilePath)), gradient);
 }
 
-void ColorScaleConfigDialog::loadTulipImageColorScales() {
-  QFileInfo colorscaleDirectory(tlpStringToQString(TulipBitmapDir)+QString("colorscales"));
+void ColorScaleConfigDialog::loadImageColorScalesFromDir(const QString &colorScalesDir) {
+  QFileInfo colorscaleDirectory(colorScalesDir);
 
-  if(colorscaleDirectory.exists() && colorscaleDirectory.isDir()) {
+  if (colorscaleDirectory.exists() && colorscaleDirectory.isDir()) {
     QDir dir(colorscaleDirectory.absoluteFilePath());
-    dir.setFilter(QDir::Files | QDir::NoDot | QDir::NoDotDot);
+    dir.setFilter(QDir::Dirs | QDir::Files | QDir::NoDotAndDotDot);
     QFileInfoList list = dir.entryInfoList();
 
     for (int i = 0; i < list.size(); ++i) {
       QFileInfo fileInfo = list.at(i);
-      tulipImageColorScales[fileInfo.fileName()] = getColorScaleFromImageFile(fileInfo.absoluteFilePath());
+
+      if (fileInfo.isDir()) {
+        loadImageColorScalesFromDir(fileInfo.absoluteFilePath());
+      } else if (fileInfo.suffix() == "png") {
+        tulipImageColorScales[fileInfo.fileName()] =
+            getColorScaleFromImageFile(fileInfo.absoluteFilePath());
+      }
     }
   }
 }
 
-void ColorScaleConfigDialog::importColorScaleFromImageFile() {
-  QString parentDirectory="./";
-  QString imageFilePath = QFileDialog::getOpenFileName(this, tr("Open Image File"),
-                          parentDirectory, tr("Image Files (*.png *.jpg *.bmp)"));
+void ColorScaleConfigDialog::loadTulipImageColorScales() {
+  loadImageColorScalesFromDir(tlpStringToQString(TulipBitmapDir) + "colorscales");
+}
+
+void ColorScaleConfigDialog::importColorScaleFromFile(const QString &currentDir) {
+  QString imageFilePath = QFileDialog::getOpenFileName(this, tr("Open Image File"), currentDir,
+                                                       tr("Image Files (*.png *.jpg *.bmp)"));
 
   if (imageFilePath.isEmpty())
     return;
 
-  vector<Color> colorsList = getColorScaleFromImageFile(imageFilePath);
+  vector<Color> &&colorsList = getColorScaleFromImageFile(imageFilePath);
 
   if (!colorsList.empty()) {
     ColorScale scaleTmp(colorsList, true);
@@ -184,6 +207,14 @@ void ColorScaleConfigDialog::importColorScaleFromImageFile() {
   }
 }
 
+void ColorScaleConfigDialog::importColorScaleFromColorScaleFile() {
+  importColorScaleFromFile(QString((tlp::TulipBitmapDir + '/' + "colorscales").c_str()));
+}
+
+void ColorScaleConfigDialog::importColorScaleFromImageFile() {
+  importColorScaleFromFile(QString("./"));
+}
+
 void ColorScaleConfigDialog::pressButtonBrowse() {
 
   displaySavedGradientPreview();
@@ -199,19 +230,17 @@ void ColorScaleConfigDialog::displaySavedGradientPreview() {
       vector<Color> colors = tulipImageColorScales[savedColorScaleId];
       std::reverse(colors.begin(), colors.end());
 
-      for (size_t i = 0 ; i < colors.size() ; ++i) {
+      for (size_t i = 0; i < colors.size(); ++i) {
         colorsList.push_back(QColor(colors[i][0], colors[i][1], colors[i][2], colors[i][3]));
       }
-    }
-    else {
-      QSettings settings("TulipSoftware","Tulip");
-      settings.beginGroup("ColorScales");
-      QList<QVariant> colorsListv = settings.value(savedColorScaleId).toList();
+    } else {
+      TulipSettings::instance().beginGroup("ColorScales");
+      QList<QVariant> colorsListv = TulipSettings::instance().value(savedColorScaleId).toList();
       QString gradientScaleId = savedColorScaleId + "_gradient?";
-      gradient = settings.value(gradientScaleId).toBool();
-      settings.endGroup();
+      gradient = TulipSettings::instance().value(gradientScaleId).toBool();
+      TulipSettings::instance().endGroup();
 
-      for (int i = 0 ; i < colorsListv.size() ; ++i) {
+      for (int i = 0; i < colorsListv.size(); ++i) {
         colorsList.push_back(colorsListv.at(i).value<QColor>());
       }
     }
@@ -220,19 +249,17 @@ void ColorScaleConfigDialog::displaySavedGradientPreview() {
   }
 }
 
-
 void ColorScaleConfigDialog::displayUserGradientPreview() {
 
   QList<QColor> colorsVector;
 
   for (int i = 0; i < _ui->colorsTable->rowCount(); ++i) {
-    colorsVector.push_back(_ui->colorsTable->item(i, 0)->backgroundColor());
+    colorsVector.push_back(_ui->colorsTable->item(i, 0)->background().color());
   }
 
   displayGradientPreview(colorsVector, _ui->gradientCB->isChecked(), _ui->userGradientPreview);
 }
 
-
 void ColorScaleConfigDialog::invertEditedColorScale() {
   QList<QTableWidgetItem *> itemsList;
   int nbItems = _ui->colorsTable->rowCount();
@@ -241,7 +268,7 @@ void ColorScaleConfigDialog::invertEditedColorScale() {
     itemsList.push_front(_ui->colorsTable->takeItem(i, 0));
   }
 
-  for (int i = 0 ; i < nbItems ; ++i) {
+  for (int i = 0; i < nbItems; ++i) {
     _ui->colorsTable->setItem(i, 0, itemsList.at(i));
   }
 
@@ -252,31 +279,31 @@ static qreal clamp(qreal f, qreal minVal, qreal maxVal) {
   return min(max(f, minVal), maxVal);
 }
 
-void ColorScaleConfigDialog::displayGradientPreview(const QList<QColor> &colorsVector, bool gradient, QLabel *displayLabel) {
+void ColorScaleConfigDialog::displayGradientPreview(const QList<QColor> &colorsVector,
+                                                    bool gradient, QLabel *displayLabel) {
   QPixmap pixmap(displayLabel->width(), displayLabel->height());
   pixmap.fill(Qt::transparent);
   QPainter painter;
   painter.begin(&pixmap);
 
   if (gradient) {
-    QLinearGradient qLinearGradient(displayLabel->width() / 2, 0,
-                                    displayLabel->width() / 2, displayLabel->height() - 1);
+    QLinearGradient qLinearGradient(displayLabel->width() / 2, 0, displayLabel->width() / 2,
+                                    displayLabel->height() - 1);
     qreal increment = 1.0 / (colorsVector.size() - 1);
     qreal relPos = 0;
 
-    for (int i = 0 ; i < colorsVector.size() ; ++i) {
+    for (int i = 0; i < colorsVector.size(); ++i) {
       qLinearGradient.setColorAt(clamp(relPos, 0.0, 1.0), colorsVector.at(i));
       relPos += increment;
     }
 
     painter.fillRect(0, 0, displayLabel->width(), displayLabel->height(), qLinearGradient);
-  }
-  else {
+  } else {
     float rectHeight = displayLabel->height() / colorsVector.size();
 
     for (int i = 0; i < colorsVector.size(); ++i) {
-      painter.fillRect(0, i * rectHeight, displayLabel->width(), (i + 1)
-                       * rectHeight, QBrush(colorsVector.at(i)));
+      painter.fillRect(0, i * rectHeight, displayLabel->width(), (i + 1) * rectHeight,
+                       QBrush(colorsVector.at(i)));
     }
   }
 
@@ -289,11 +316,17 @@ void ColorScaleConfigDialog::nbColorsValueChanged(int value) {
   _ui->colorsTable->setRowCount(value);
 
   if (lastCount < value) {
-    for(int j = 0; j <= value - lastCount; ++j) {
+    for (int j = 0; j < value - lastCount; ++j) {
       QTableWidgetItem *item = new QTableWidgetItem();
-      item->setBackgroundColor(QColor(255, 255, 255, 255));
+      QColor color(255, 255, 255, 255);
+
+      if (_ui->globalAlphaCB->isChecked()) {
+        color.setAlpha(_ui->globalAlphaSB->value());
+      }
+
+      item->setBackground(QBrush(color));
       item->setFlags(Qt::ItemIsEnabled);
-      _ui->colorsTable->setItem(0, lastCount + j - 1, item);
+      _ui->colorsTable->setItem(0, lastCount + j, item);
     }
   }
 
@@ -301,29 +334,35 @@ void ColorScaleConfigDialog::nbColorsValueChanged(int value) {
 }
 
 void ColorScaleConfigDialog::colorTableItemDoubleClicked(QTableWidgetItem *item) {
-  QColor itemBgColor = item->backgroundColor();
+  QColor itemBgColor = item->background().color();
   QColor newColor;
 
-  if(getColorDialog(itemBgColor, this, "Select Color",newColor)) {
-    item->setBackgroundColor(newColor);
+  if (getColorDialog(itemBgColor, this, "Select Color", newColor)) {
+    if (_ui->globalAlphaCB->isChecked()) {
+      newColor.setAlpha(_ui->globalAlphaSB->value());
+    }
+
+    item->setBackground(QBrush(newColor));
     displayUserGradientPreview();
   }
 }
 
 void ColorScaleConfigDialog::saveCurrentColorScale() {
-  QSettings settings("TulipSoftware","Tulip");
-  settings.beginGroup("ColorScales");
-  QStringList savedColorScalesList = settings.childKeys();
+  TulipSettings::instance().beginGroup("ColorScales");
+  QStringList savedColorScalesList = TulipSettings::instance().childKeys();
   bool ok;
   QString text = QInputDialog::getText(this, tr("Color scale saving"),
-                                       tr("Enter a name for this color scale : "), QLineEdit::Normal,
-                                       "unnamed", &ok);
+                                       tr("Enter a name for this color scale : "),
+                                       QLineEdit::Normal, "unnamed", &ok);
 
   if (ok && !text.isEmpty()) {
     if (savedColorScalesList.contains(text)) {
-      QString question = "There is already a color scale saved under the name " + text + ". Do you want to owerwrite it ?";
+      QString question = "There is already a color scale saved under the name " + text +
+                         ". Do you want to owerwrite it ?";
 
-      if (QMessageBox::question (this, "Color scale saving", question, QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes) != QMessageBox::Yes) {
+      if (QMessageBox::question(this, "Color scale saving", question,
+                                QMessageBox::Yes | QMessageBox::No,
+                                QMessageBox::Yes) != QMessageBox::Yes) {
         return;
       }
     }
@@ -331,15 +370,15 @@ void ColorScaleConfigDialog::saveCurrentColorScale() {
     QList<QVariant> colorsVector;
 
     for (int i = 0; i < _ui->colorsTable->rowCount(); ++i) {
-      colorsVector.push_back(QVariant(_ui->colorsTable->item(i, 0)->backgroundColor()));
+      colorsVector.push_back(QVariant(_ui->colorsTable->item(i, 0)->background().color()));
     }
 
-    settings.setValue(text, colorsVector);
+    TulipSettings::instance().setValue(text, colorsVector);
     QString gradientId = text + "_gradient?";
-    settings.setValue(gradientId, _ui->gradientCB->isChecked());
+    TulipSettings::instance().setValue(gradientId, _ui->gradientCB->isChecked());
   }
 
-  settings.endGroup();
+  TulipSettings::instance().endGroup();
   loadUserSavedColorScales();
 }
 
@@ -347,15 +386,16 @@ void ColorScaleConfigDialog::deleteSavedColorScale() {
   if (_ui->savedColorScalesList->count() > 0 && _ui->savedColorScalesList->currentItem()) {
     QString savedColorScaleId = _ui->savedColorScalesList->currentItem()->text();
 
-    if (QMessageBox::question (this, "Color scale deleting", "Delete saved color scale " + savedColorScaleId + " ?", QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes) != QMessageBox::Yes) {
+    if (QMessageBox::question(
+            this, "Color scale deleting", "Delete saved color scale " + savedColorScaleId + " ?",
+            QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes) != QMessageBox::Yes) {
       return;
     }
 
-    QSettings settings("TulipSoftware","Tulip");
-    settings.beginGroup("ColorScales");
-    settings.remove(savedColorScaleId);
-    settings.remove(savedColorScaleId+"_gradient?");
-    settings.endGroup();
+    TulipSettings::instance().beginGroup("ColorScales");
+    TulipSettings::instance().remove(savedColorScaleId);
+    TulipSettings::instance().remove(savedColorScaleId + "_gradient?");
+    TulipSettings::instance().endGroup();
     loadUserSavedColorScales();
   }
 }
@@ -363,23 +403,21 @@ void ColorScaleConfigDialog::deleteSavedColorScale() {
 void ColorScaleConfigDialog::loadUserSavedColorScales() {
   _ui->savedColorScalesList->clear();
 
-  map<QString, vector<Color> >::const_iterator it = tulipImageColorScales.begin();
+  map<QString, vector<Color>>::const_iterator it = tulipImageColorScales.begin();
 
-  for ( ; it != tulipImageColorScales.end(); ++it) {
+  for (; it != tulipImageColorScales.end(); ++it) {
     _ui->savedColorScalesList->addItem(it->first);
   }
 
-  QSettings settings("TulipSoftware","Tulip");
-  settings.beginGroup("ColorScales");
-  QStringList savedColorScalesIdList = settings.childKeys();
+  TulipSettings::instance().beginGroup("ColorScales");
+  QStringList savedColorScalesIdList = TulipSettings::instance().childKeys();
 
-  for (int i = 0 ; i < savedColorScalesIdList.size() ; ++i) {
+  for (int i = 0; i < savedColorScalesIdList.size(); ++i) {
     if (!savedColorScalesIdList.at(i).contains("_gradient?"))
       _ui->savedColorScalesList->addItem(savedColorScalesIdList.at(i));
   }
 
-  settings.endGroup();
-
+  TulipSettings::instance().endGroup();
 }
 
 void ColorScaleConfigDialog::resizeEvent(QResizeEvent *) {
@@ -401,18 +439,17 @@ void ColorScaleConfigDialog::reeditSaveColorScale(QListWidgetItem *savedColorSca
 
   if (tulipImageColorScales.find(savedColorScaleId) != tulipImageColorScales.end()) {
     colorsList = tulipImageColorScales[savedColorScaleId];
-  }
-  else {
-    QSettings settings("TulipSoftware","Tulip");
-    settings.beginGroup("ColorScales");
-    QList<QVariant> colorsListv = settings.value(savedColorScaleId).toList();
+  } else {
+    TulipSettings::instance().beginGroup("ColorScales");
+    QList<QVariant> colorsListv = TulipSettings::instance().value(savedColorScaleId).toList();
     QString gradientScaleId = savedColorScaleId + "_gradient?";
-    gradient = settings.value(gradientScaleId).toBool();
-    settings.endGroup();
+    gradient = TulipSettings::instance().value(gradientScaleId).toBool();
+    TulipSettings::instance().endGroup();
 
-    for (int i = 0 ; i < colorsListv.size() ; ++i) {
+    colorsList.reserve(colorsListv.size());
+    for (int i = 0; i < colorsListv.size(); ++i) {
       QColor color = colorsListv.at(i).value<QColor>();
-      colorsList.push_back(Color(color.red(), color.green(), color.blue(), color.alpha()));
+      colorsList.emplace_back(color.red(), color.green(), color.blue(), color.alpha());
     }
 
     reverse(colorsList.begin(), colorsList.end());
@@ -420,17 +457,28 @@ void ColorScaleConfigDialog::reeditSaveColorScale(QListWidgetItem *savedColorSca
 
   ColorScale scaleTmp(colorsList, gradient);
   setColorScale(scaleTmp);
-  _ui->tabWidget->setCurrentIndex(0);
 }
 
 void ColorScaleConfigDialog::setColorScale(const ColorScale &colorScale) {
-  disconnect(_ui->nbColors, SIGNAL(valueChanged(int)), this, SLOT(nbColorsValueChanged(int)));
-
-  _ui->colorsTable->clear();
-
   if (colorScale.colorScaleInitialized()) {
-    //init dialog with colors in the color Scale
-    std::map<float, tlp::Color> colorMap = colorScale.getColorMap();
+    for (int row = 0; row < _ui->savedColorScalesList->count(); ++row) {
+      QListWidgetItem *item = _ui->savedColorScalesList->item(row);
+
+      if (tulipImageColorScales.find(item->text()) != tulipImageColorScales.end() &&
+          colorScale == tulipImageColorScales[item->text()]) {
+        // colorScale is a predefined one
+        // so select it in the list view
+        _ui->savedColorScalesList->setCurrentItem(item);
+      }
+    }
+
+    disconnect(_ui->nbColors, SIGNAL(valueChanged(int)), this, SLOT(nbColorsValueChanged(int)));
+
+    _ui->colorsTable->clear();
+    _ui->colorsTable->setRowCount(0);
+
+    // init dialog with colors in the color Scale
+    const auto &colorMap = colorScale.getColorMap();
     unsigned int row = 0;
 
     if (colorScale.isGradient()) {
@@ -438,67 +486,50 @@ void ColorScaleConfigDialog::setColorScale(const ColorScale &colorScale) {
       _ui->nbColors->setValue(colorMap.size());
       _ui->gradientCB->setChecked(true);
       row = colorMap.size() - 1;
-    }
-    else {
+    } else {
       _ui->colorsTable->setRowCount(colorMap.size() / 2);
       _ui->nbColors->setValue(colorMap.size() / 2);
       _ui->gradientCB->setChecked(false);
       row = (colorMap.size() / 2) - 1;
     }
 
-    for (std::map<float, tlp::Color>::iterator it = colorMap.begin(); it
-         != colorMap.end();) {
+    for (auto it = colorMap.begin(); it != colorMap.end();) {
       QTableWidgetItem *item = new QTableWidgetItem();
       item->setFlags(Qt::ItemIsEnabled);
-      item->setBackgroundColor(QColor(it->second.getR(), it->second.getG(),
-                                      it->second.getB(), it->second.getA()));
+      item->setBackground(QBrush(
+          QColor(it->second.getR(), it->second.getG(), it->second.getB(), it->second.getA())));
       _ui->colorsTable->setItem(row, 0, item);
       --row;
 
       if (colorScale.isGradient()) {
         ++it;
-      }
-      else {
+      } else {
         ++it;
         ++it;
       }
     }
 
-  }
-  else {
-    //init dialog with default colors
-    _ui->colorsTable->setRowCount(5);
-    QTableWidgetItem *item1 = new QTableWidgetItem();
-    item1->setBackgroundColor(QColor(229, 40, 0, 200));
-    item1->setFlags(Qt::ItemIsEnabled);
-    QTableWidgetItem *item2 = new QTableWidgetItem();
-    item2->setBackgroundColor(QColor(255, 170, 0, 200));
-    item2->setFlags(Qt::ItemIsEnabled);
-    QTableWidgetItem *item3 = new QTableWidgetItem();
-    item3->setBackgroundColor(QColor(255, 255, 127, 200));
-    item3->setFlags(Qt::ItemIsEnabled);
-    QTableWidgetItem *item4 = new QTableWidgetItem();
-    item4->setBackgroundColor(QColor(156, 161, 255, 200));
-    item4->setFlags(Qt::ItemIsEnabled);
-    QTableWidgetItem *item5 = new QTableWidgetItem();
-    item5->setBackgroundColor(QColor(75, 75, 255, 200));
-    item5->setFlags(Qt::ItemIsEnabled);
-    _ui->colorsTable->setItem(0, 0, item1);
-    _ui->colorsTable->setItem(1, 0, item2);
-    _ui->colorsTable->setItem(2, 0, item3);
-    _ui->colorsTable->setItem(3, 0, item4);
-    _ui->colorsTable->setItem(4, 0, item5);
-    _ui->nbColors->setValue(5);
-    _ui->gradientCB->setChecked(true);
-
-    accept();
-  }
-
-  connect(_ui->nbColors, SIGNAL(valueChanged(int)), this, SLOT(nbColorsValueChanged(int)));
+    connect(_ui->nbColors, SIGNAL(valueChanged(int)), this, SLOT(nbColorsValueChanged(int)));
+    _ui->tabWidget->setCurrentIndex(0);
+    applyGlobalAlphaToColorScale();
+  } else
+    // use latest ColorScale
+    setColorScale(ColorScalesManager::getLatestColorScale());
 }
 
-const ColorScale& ColorScaleConfigDialog::getColorScale() const {
+const ColorScale &ColorScaleConfigDialog::getColorScale() const {
   return colorScale;
 }
 
+void ColorScaleConfigDialog::applyGlobalAlphaToColorScale() {
+  if (_ui->globalAlphaCB->isChecked()) {
+    for (int i = 0; i < _ui->colorsTable->rowCount(); ++i) {
+      QColor itemColor = _ui->colorsTable->item(i, 0)->background().color();
+      itemColor.setAlpha(_ui->globalAlphaSB->value());
+      _ui->colorsTable->item(i, 0)->setBackground(QBrush(itemColor));
+    }
+
+    displayUserGradientPreview();
+  }
 }
+} // namespace tlp
