@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,23 +21,22 @@
 using namespace tlp;
 
 GLInteractorComposite::GLInteractorComposite(const QIcon &icon, const QString &text)
-  : InteractorComposite(icon,text) {
-}
+    : InteractorComposite(icon, text) {}
 
 void GLInteractorComposite::draw(tlp::GlMainWidget *w) {
-  foreach(tlp::InteractorComponent* i,_components) {
-    GLInteractorComponent* cmp = dynamic_cast<GLInteractorComponent*>(i);
+  for (auto i : _components) {
+    GLInteractorComponent *cmp = dynamic_cast<GLInteractorComponent *>(i);
 
-    if (cmp != NULL)
+    if (cmp != nullptr)
       cmp->draw(w);
   }
 }
 
 void GLInteractorComposite::compute(tlp::GlMainWidget *w) {
-  foreach(tlp::InteractorComponent* i,_components) {
-    GLInteractorComponent* cmp = dynamic_cast<GLInteractorComponent*>(i);
+  for (auto i : _components) {
+    GLInteractorComponent *cmp = dynamic_cast<GLInteractorComponent *>(i);
 
-    if (cmp != NULL)
+    if (cmp != nullptr)
       cmp->compute(w);
   }
 }
