@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -23,33 +23,33 @@
 #include <QWidget>
 #include <QDebug>
 
-PlaceHolderWidget::PlaceHolderWidget(QWidget *parent): QWidget(parent), _widget(NULL) {
+PlaceHolderWidget::PlaceHolderWidget(QWidget *parent) : QWidget(parent), _widget(nullptr) {
   setLayout(new QVBoxLayout);
   layout()->setMargin(0);
   layout()->setSpacing(0);
 }
 
 void PlaceHolderWidget::setWidget(QWidget *widget) {
-  if (_widget != NULL) {
+  if (_widget != nullptr) {
     _widget->hide();
     layout()->removeWidget(_widget);
-    _widget->setParent(NULL);
-    _widget = NULL;
+    _widget->setParent(nullptr);
+    _widget = nullptr;
   }
 
   _widget = widget;
 
-  if (_widget != NULL) {
+  if (_widget != nullptr) {
     _widget->installEventFilter(this);
     layout()->addWidget(_widget);
     _widget->show();
   }
 }
 
-QWidget* PlaceHolderWidget::widget() const {
+QWidget *PlaceHolderWidget::widget() const {
   return _widget;
 }
 
 void PlaceHolderWidget::resetWidget() {
-  _widget = NULL;
+  _widget = nullptr;
 }
