@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,30 +20,26 @@
 #include "tulip/TulipMimes.h"
 
 #include <tulip/TulipMetaTypes.h>
-#include <tulip/ForEach.h>
 #include <tulip/Perspective.h>
 #include <tulip/TlpQtTools.h>
 
 using namespace tlp;
 
+AlgorithmMimeType::AlgorithmMimeType(QString algorithmName, const DataSet &data)
+    : _algorithm(algorithmName), _params(data) {}
 
-
-
-AlgorithmMimeType::AlgorithmMimeType(QString algorithmName, const DataSet &data): _algorithm(algorithmName), _params(data) {
-}
-
-void AlgorithmMimeType::run(Graph* g) const {
+void AlgorithmMimeType::run(Graph *g) const {
   emit mimeRun(g);
 }
 
-QStringList GraphMimeType::formats()const {
-  return QMimeData::formats()<<GRAPH_MIME_TYPE;
+QStringList GraphMimeType::formats() const {
+  return QMimeData::formats() << GRAPH_MIME_TYPE;
 }
 
-QStringList AlgorithmMimeType::formats()const {
-  return QMimeData::formats()<<ALGORITHM_NAME_MIME_TYPE<<DATASET_MIME_TYPE;
+QStringList AlgorithmMimeType::formats() const {
+  return QMimeData::formats() << ALGORITHM_NAME_MIME_TYPE << DATASET_MIME_TYPE;
 }
 
-QStringList PanelMimeType::formats()const {
-  return QMimeData::formats()<<WORKSPACE_PANEL_MIME_TYPE;
+QStringList PanelMimeType::formats() const {
+  return QMimeData::formats() << WORKSPACE_PANEL_MIME_TYPE;
 }
