@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -22,11 +22,9 @@
 
 using namespace tlp;
 
-TulipModel::TulipModel(QObject *parent): QAbstractItemModel(parent) {
-}
+TulipModel::TulipModel(QObject *parent) : QAbstractItemModel(parent) {}
 
-TulipModel::~TulipModel() {
-}
+TulipModel::~TulipModel() {}
 
 QVariant TulipModel::headerData(int, Qt::Orientation orientation, int role) const {
   if (orientation == Qt::Horizontal && role == Qt::FontRole) {
