@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -34,17 +34,14 @@ class GlLayout;
 class TLP_GL_SCOPE GlEntity {
 
 public:
-
   virtual ~GlEntity() {}
 
   /**
    * Accpet visitor function
    */
-  virtual void acceptVisitor(GlSceneVisitor *visitor)=0;
-
+  virtual void acceptVisitor(GlSceneVisitor *visitor) = 0;
 };
-
-}
+} // namespace tlp
 
 #endif // Tulip_GLENTITY_H
 ///@endcond
