@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -33,27 +33,24 @@ class GlLayer;
 class TLP_GL_SCOPE GlSceneVisitor {
 
 public:
-
-  GlSceneVisitor():threadSafe(false) {}
+  GlSceneVisitor() : threadSafe(false) {}
   virtual ~GlSceneVisitor() {}
 
   virtual void visit(GlSimpleEntity *) {}
   virtual void visit(GlNode *) {}
   virtual void visit(GlEdge *) {}
   virtual void visit(GlLayer *) {}
-  virtual void reserveMemoryForNodes(unsigned int) {}
-  virtual void reserveMemoryForEdges(unsigned int) {}
+  virtual void endOfVisit() {}
+  virtual void reserveMemoryForGraphElts(unsigned int /*nbNodes*/, unsigned int /*nbEdges*/) {}
+
   bool isThreadSafe() {
     return threadSafe;
   }
 
-protected :
-
+protected:
   bool threadSafe;
-
 };
-
-}
+} // namespace tlp
 
 #endif // Tulip_GLSCENEVISITOR_H
 ///@endcond
