@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -31,6 +31,8 @@ using namespace std;
 
 namespace tlp {
 
+// clang-format off
+
 static string fisheyeDistortionVertexShaderSrc =
   "#version 120\n"
 
@@ -466,42 +468,51 @@ static string curveFragmentShaderSrc =
   "}"
   ;
 
-map<unsigned int, GLfloat *> AbstractGlCurve::curveVertexBuffersData;
-map<unsigned int, vector<GLushort *> > AbstractGlCurve::curveVertexBuffersIndices;
-map<unsigned int, GLuint* > AbstractGlCurve::curveVertexBuffersObject;
-map<string, GlShaderProgram *> AbstractGlCurve::curvesShadersMap;
-map<string, GlShaderProgram *> AbstractGlCurve::curvesBillboardShadersMap;
-GlShader *AbstractGlCurve::fisheyeDistortionVertexShader(NULL);
-GlShader *AbstractGlCurve::curveVertexShaderNormalMain(NULL);
-GlShader *AbstractGlCurve::curveVertexShaderBillboardMain(NULL);
-GlShader *AbstractGlCurve::curveFragmentShader(NULL);
-bool AbstractGlCurve::canUseGeometryShader = false;
-std::map<std::string, std::pair<GlShaderProgram *, GlShaderProgram *> > AbstractGlCurve::curvesGeometryShadersMap;
-GlShader *AbstractGlCurve::curveVertexGeometryShaderNormalMain(NULL);
-std::map<std::string, std::pair<GlShaderProgram *, GlShaderProgram *> > AbstractGlCurve::curvesBillboardGeometryShadersMap;
+// clang-format on
 
-AbstractGlCurve::AbstractGlCurve(const string &shaderProgramName, const string &curveSpecificShaderCode) :
-  curveShaderProgramNormal(NULL), curveShaderProgramBillboard(NULL), curveShaderProgram(NULL),
-  outlined(false), outlineColor(Color(0,0,0)), texture(""), texCoordFactor(1), billboardCurve(false),
-  lookDir(Coord(0,0,1)), lineCurve(false), curveLineWidth(1.0f), curveQuadBordersWidth(1.0f),
-  outlineColorInterpolation(false) {
+unordered_map<unsigned int, GLfloat *> AbstractGlCurve::curveVertexBuffersData;
+unordered_map<unsigned int, vector<GLushort *>> AbstractGlCurve::curveVertexBuffersIndices;
+unordered_map<unsigned int, GLuint *> AbstractGlCurve::curveVertexBuffersObject;
+unordered_map<string, GlShaderProgram *> AbstractGlCurve::curvesShadersMap;
+unordered_map<string, GlShaderProgram *> AbstractGlCurve::curvesBillboardShadersMap;
+GlShader *AbstractGlCurve::fisheyeDistortionVertexShader(nullptr);
+GlShader *AbstractGlCurve::curveVertexShaderNormalMain(nullptr);
+GlShader *AbstractGlCurve::curveVertexShaderBillboardMain(nullptr);
+GlShader *AbstractGlCurve::curveFragmentShader(nullptr);
+bool AbstractGlCurve::canUseGeometryShader = false;
+std::unordered_map<std::string, std::pair<GlShaderProgram *, GlShaderProgram *>>
+    AbstractGlCurve::curvesGeometryShadersMap;
+GlShader *AbstractGlCurve::curveVertexGeometryShaderNormalMain(nullptr);
+std::unordered_map<std::string, std::pair<GlShaderProgram *, GlShaderProgram *>>
+    AbstractGlCurve::curvesBillboardGeometryShadersMap;
+
+AbstractGlCurve::AbstractGlCurve(const string &shaderProgramName,
+                                 const string &curveSpecificShaderCode)
+    : curveShaderProgramNormal(nullptr), curveShaderProgramBillboard(nullptr),
+      curveShaderProgram(nullptr), outlined(false), outlineColor(Color(0, 0, 0)), texture(""),
+      texCoordFactor(1), billboardCurve(false), lookDir(Coord(0, 0, 1)), lineCurve(false),
+      curveLineWidth(1.0f), curveQuadBordersWidth(1.0f), outlineColorInterpolation(false) {
   canUseGeometryShader = GlShaderProgram::geometryShaderSupported();
   initShader(shaderProgramName, curveSpecificShaderCode);
 }
 
-AbstractGlCurve::AbstractGlCurve(const string &shaderProgramName, const string &curveSpecificShaderCode, const vector<Coord> &controlPoints,
-                                 const Color &startColor, const Color &endColor, const float startSize, const float endSize, const unsigned int nbCurvePoints) :
-  shaderProgramName(shaderProgramName), curveShaderProgramNormal(NULL), curveShaderProgramBillboard(NULL), curveShaderProgram(NULL),
-  controlPoints(controlPoints), startColor(startColor), endColor(endColor), startSize(startSize), endSize(endSize), nbCurvePoints(nbCurvePoints),
-  outlined(false), outlineColor(Color(0,0,0)), texture(""), texCoordFactor(1), billboardCurve(false), lookDir(Coord(0,0,1)),
-  lineCurve(false), curveLineWidth(1.0f), curveQuadBordersWidth(1.0f), outlineColorInterpolation(false) {
+AbstractGlCurve::AbstractGlCurve(const string &shaderProgramName,
+                                 const string &curveSpecificShaderCode,
+                                 const vector<Coord> &controlPoints, const Color &startColor,
+                                 const Color &endColor, const float startSize, const float endSize,
+                                 const unsigned int nbCurvePoints)
+    : shaderProgramName(shaderProgramName), curveShaderProgramNormal(nullptr),
+      curveShaderProgramBillboard(nullptr), curveShaderProgram(nullptr),
+      controlPoints(controlPoints), startColor(startColor), endColor(endColor),
+      startSize(startSize), endSize(endSize), nbCurvePoints(nbCurvePoints), outlined(false),
+      outlineColor(Color(0, 0, 0)), texture(""), texCoordFactor(1), billboardCurve(false),
+      lookDir(Coord(0, 0, 1)), lineCurve(false), curveLineWidth(1.0f), curveQuadBordersWidth(1.0f),
+      outlineColorInterpolation(false) {
 
   canUseGeometryShader = GlShaderProgram::geometryShaderSupported();
   initShader(shaderProgramName, curveSpecificShaderCode);
 
-  for (size_t i = 0 ; i < controlPoints.size() ; ++i) {
-    boundingBox.expand(controlPoints[i]);
-  }
+  boundingBox.expand(controlPoints);
 }
 
 AbstractGlCurve::~AbstractGlCurve() {}
@@ -515,34 +526,39 @@ void AbstractGlCurve::buildCurveVertexBuffers(const unsigned int nbCurvePoints,
   curveVertexBuffersIndices[nbCurvePoints][2] = new GLushort[nbCurvePoints];
   curveVertexBuffersIndices[nbCurvePoints][3] = new GLushort[nbCurvePoints];
 
-  for (unsigned int i = 0 ; i < nbCurvePoints ; ++i) {
-    float t =  i / static_cast<float>(nbCurvePoints - 1);
-    curveVertexBuffersData[nbCurvePoints][6*i] = t;
-    curveVertexBuffersData[nbCurvePoints][6*i+1] = 1.0f;
-    curveVertexBuffersData[nbCurvePoints][6*i+2] = t;
-    curveVertexBuffersData[nbCurvePoints][6*i+3] = 0.0f;
-    curveVertexBuffersData[nbCurvePoints][6*i+4] = t;
-    curveVertexBuffersData[nbCurvePoints][6*i+5] = -1.0f;
+  for (unsigned int i = 0; i < nbCurvePoints; ++i) {
+    float t = i / float(nbCurvePoints - 1);
+    curveVertexBuffersData[nbCurvePoints][6 * i] = t;
+    curveVertexBuffersData[nbCurvePoints][6 * i + 1] = 1.0f;
+    curveVertexBuffersData[nbCurvePoints][6 * i + 2] = t;
+    curveVertexBuffersData[nbCurvePoints][6 * i + 3] = 0.0f;
+    curveVertexBuffersData[nbCurvePoints][6 * i + 4] = t;
+    curveVertexBuffersData[nbCurvePoints][6 * i + 5] = -1.0f;
 
-    curveVertexBuffersIndices[nbCurvePoints][0][2*i] = 3*i;
-    curveVertexBuffersIndices[nbCurvePoints][0][2*i+1] = 3*i+2;
-    curveVertexBuffersIndices[nbCurvePoints][1][i] = 3*i+1;
-    curveVertexBuffersIndices[nbCurvePoints][2][i] = 3*i;
-    curveVertexBuffersIndices[nbCurvePoints][3][i] = 3*i+2;
+    curveVertexBuffersIndices[nbCurvePoints][0][2 * i] = 3 * i;
+    curveVertexBuffersIndices[nbCurvePoints][0][2 * i + 1] = 3 * i + 2;
+    curveVertexBuffersIndices[nbCurvePoints][1][i] = 3 * i + 1;
+    curveVertexBuffersIndices[nbCurvePoints][2][i] = 3 * i;
+    curveVertexBuffersIndices[nbCurvePoints][3][i] = 3 * i + 2;
   }
 
   if (vboOk) {
     glGenBuffers(5, curveVertexBuffersObject[nbCurvePoints]);
     glBindBuffer(GL_ARRAY_BUFFER, curveVertexBuffersObject[nbCurvePoints][0]);
-    glBufferData(GL_ARRAY_BUFFER, 6 * nbCurvePoints * sizeof(GLfloat), curveVertexBuffersData[nbCurvePoints], GL_STATIC_DRAW);
+    glBufferData(GL_ARRAY_BUFFER, 6 * nbCurvePoints * sizeof(GLfloat),
+                 curveVertexBuffersData[nbCurvePoints], GL_STATIC_DRAW);
     glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, curveVertexBuffersObject[nbCurvePoints][1]);
-    glBufferData(GL_ELEMENT_ARRAY_BUFFER, 2 * nbCurvePoints * sizeof(GLushort), curveVertexBuffersIndices[nbCurvePoints][0], GL_STATIC_DRAW);
+    glBufferData(GL_ELEMENT_ARRAY_BUFFER, 2 * nbCurvePoints * sizeof(GLushort),
+                 curveVertexBuffersIndices[nbCurvePoints][0], GL_STATIC_DRAW);
     glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, curveVertexBuffersObject[nbCurvePoints][2]);
-    glBufferData(GL_ELEMENT_ARRAY_BUFFER, nbCurvePoints * sizeof(GLushort), curveVertexBuffersIndices[nbCurvePoints][1], GL_STATIC_DRAW);
+    glBufferData(GL_ELEMENT_ARRAY_BUFFER, nbCurvePoints * sizeof(GLushort),
+                 curveVertexBuffersIndices[nbCurvePoints][1], GL_STATIC_DRAW);
     glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, curveVertexBuffersObject[nbCurvePoints][3]);
-    glBufferData(GL_ELEMENT_ARRAY_BUFFER, nbCurvePoints * sizeof(GLushort), curveVertexBuffersIndices[nbCurvePoints][2], GL_STATIC_DRAW);
+    glBufferData(GL_ELEMENT_ARRAY_BUFFER, nbCurvePoints * sizeof(GLushort),
+                 curveVertexBuffersIndices[nbCurvePoints][2], GL_STATIC_DRAW);
     glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, curveVertexBuffersObject[nbCurvePoints][4]);
-    glBufferData(GL_ELEMENT_ARRAY_BUFFER, nbCurvePoints * sizeof(GLushort), curveVertexBuffersIndices[nbCurvePoints][3], GL_STATIC_DRAW);
+    glBufferData(GL_ELEMENT_ARRAY_BUFFER, nbCurvePoints * sizeof(GLushort),
+                 curveVertexBuffersIndices[nbCurvePoints][3], GL_STATIC_DRAW);
     glBindBuffer(GL_ARRAY_BUFFER, 0);
     glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, 0);
   }
@@ -552,44 +568,47 @@ void AbstractGlCurve::draw(float, Camera *) {
   drawCurve(controlPoints, startColor, endColor, startSize, endSize, nbCurvePoints);
 }
 
-void AbstractGlCurve::initShader(const std::string &shaderProgramName, const std::string &curveSpecificShaderCode) {
-  // restrict shaders compilation on compatible hardware, crashs can happen
+void AbstractGlCurve::initShader(const std::string &shaderProgramName,
+                                 const std::string &curveSpecificShaderCode) {
+  // restrict shaders compilation on compatible hardware, crashes can happen
   // when using a software implementation of OpenGL
-  static string glVendor = OpenGlConfigManager::getInst().getOpenGLVendor();
-  static bool glVendorOk = (glVendor.find("NVIDIA")!=string::npos) ||
-                           (glVendor.find("ATI")!=string::npos) ||
-                           (glVendor.find("Intel")!=string::npos);
+  static string glVendor = OpenGlConfigManager::getOpenGLVendor();
+  static bool glVendorOk = (glVendor.find("NVIDIA") != string::npos) ||
+                           (glVendor.find("ATI") != string::npos) ||
+                           (glVendor.find("Intel") != string::npos);
 
   if (glVendorOk && GlShaderProgram::shaderProgramsSupported()) {
 
-    if (curveVertexShaderNormalMain == NULL) {
+    if (curveVertexShaderNormalMain == nullptr) {
       curveVertexShaderNormalMain = new GlShader(Vertex);
       curveVertexShaderNormalMain->compileFromSourceCode(curveVertexShaderNormalMainSrc);
     }
 
-    if (curveVertexShaderBillboardMain == NULL) {
+    if (curveVertexShaderBillboardMain == nullptr) {
       curveVertexShaderBillboardMain = new GlShader(Vertex);
       curveVertexShaderBillboardMain->compileFromSourceCode(curveVertexShaderBillboardMainSrc);
     }
 
-    if (fisheyeDistortionVertexShader == NULL) {
+    if (fisheyeDistortionVertexShader == nullptr) {
       fisheyeDistortionVertexShader = new GlShader(Vertex);
       fisheyeDistortionVertexShader->compileFromSourceCode(fisheyeDistortionVertexShaderSrc);
     }
 
-    if (curveVertexGeometryShaderNormalMain == NULL) {
+    if (curveVertexGeometryShaderNormalMain == nullptr) {
       curveVertexGeometryShaderNormalMain = new GlShader(Vertex);
-      curveVertexGeometryShaderNormalMain->compileFromSourceCode(curveVertexShaderGeometryNormalMainSrc);
+      curveVertexGeometryShaderNormalMain->compileFromSourceCode(
+          curveVertexShaderGeometryNormalMainSrc);
     }
 
-    if (curveFragmentShader == NULL) {
+    if (curveFragmentShader == nullptr) {
       curveFragmentShader = new GlShader(Fragment);
       curveFragmentShader->compileFromSourceCode(curveFragmentShaderSrc);
     }
 
     if (curvesShadersMap.find(shaderProgramName) == curvesShadersMap.end()) {
       curvesShadersMap[shaderProgramName] = new GlShaderProgram(shaderProgramName);
-      curvesShadersMap[shaderProgramName]->addShaderFromSourceCode(Vertex, genCommonUniformVariables() + curveSpecificShaderCode);
+      curvesShadersMap[shaderProgramName]->addShaderFromSourceCode(
+          Vertex, genCommonUniformVariables() + curveSpecificShaderCode);
       curvesShadersMap[shaderProgramName]->addShader(curveVertexShaderNormalMain);
       curvesShadersMap[shaderProgramName]->addShader(fisheyeDistortionVertexShader);
       curvesShadersMap[shaderProgramName]->addShader(curveFragmentShader);
@@ -597,11 +616,14 @@ void AbstractGlCurve::initShader(const std::string &shaderProgramName, const std
       curvesShadersMap[shaderProgramName]->printInfoLog();
     }
 
-    if (canUseGeometryShader && curvesGeometryShadersMap.find(shaderProgramName) == curvesGeometryShadersMap.end()) {
+    if (canUseGeometryShader &&
+        curvesGeometryShadersMap.find(shaderProgramName) == curvesGeometryShadersMap.end()) {
       GlShaderProgram *polygonShader = new GlShaderProgram(shaderProgramName);
-      polygonShader->addShaderFromSourceCode(Vertex, genCommonUniformVariables() + curveSpecificShaderCode);
+      polygonShader->addShaderFromSourceCode(Vertex,
+                                             genCommonUniformVariables() + curveSpecificShaderCode);
       polygonShader->addShader(curveVertexGeometryShaderNormalMain);
-      polygonShader->addGeometryShaderFromSourceCode(curveExtrusionGeometryShaderSrc, GL_LINES_ADJACENCY_EXT, GL_TRIANGLE_STRIP);
+      polygonShader->addGeometryShaderFromSourceCode(curveExtrusionGeometryShaderSrc,
+                                                     GL_LINES_ADJACENCY_EXT, GL_TRIANGLE_STRIP);
       polygonShader->setMaxGeometryShaderOutputVertices(6);
       polygonShader->addShader(curveFragmentShader);
       polygonShader->link();
@@ -609,13 +631,15 @@ void AbstractGlCurve::initShader(const std::string &shaderProgramName, const std
 
       if (!polygonShader->isLinked()) {
         delete polygonShader;
-        polygonShader = NULL;
+        polygonShader = nullptr;
       }
 
       GlShaderProgram *lineShader = new GlShaderProgram(shaderProgramName);
-      lineShader->addShaderFromSourceCode(Vertex, genCommonUniformVariables() + curveSpecificShaderCode);
+      lineShader->addShaderFromSourceCode(Vertex,
+                                          genCommonUniformVariables() + curveSpecificShaderCode);
       lineShader->addShader(curveVertexGeometryShaderNormalMain);
-      lineShader->addGeometryShaderFromSourceCode(curveExtrusionGeometryShaderSrc, GL_LINES_ADJACENCY_EXT, GL_LINE_STRIP);
+      lineShader->addGeometryShaderFromSourceCode(curveExtrusionGeometryShaderSrc,
+                                                  GL_LINES_ADJACENCY_EXT, GL_LINE_STRIP);
       lineShader->setMaxGeometryShaderOutputVertices(6);
       lineShader->addShader(curveFragmentShader);
       lineShader->link();
@@ -623,7 +647,7 @@ void AbstractGlCurve::initShader(const std::string &shaderProgramName, const std
 
       if (!lineShader->isLinked()) {
         delete lineShader;
-        lineShader = NULL;
+        lineShader = nullptr;
       }
 
       curvesGeometryShadersMap[shaderProgramName] = make_pair(polygonShader, lineShader);
@@ -631,7 +655,8 @@ void AbstractGlCurve::initShader(const std::string &shaderProgramName, const std
 
     if (curvesBillboardShadersMap.find(shaderProgramName) == curvesBillboardShadersMap.end()) {
       curvesBillboardShadersMap[shaderProgramName] = new GlShaderProgram(shaderProgramName);
-      curvesBillboardShadersMap[shaderProgramName]->addShaderFromSourceCode(Vertex, genCommonUniformVariables() + curveSpecificShaderCode);
+      curvesBillboardShadersMap[shaderProgramName]->addShaderFromSourceCode(
+          Vertex, genCommonUniformVariables() + curveSpecificShaderCode);
 
       curvesBillboardShadersMap[shaderProgramName]->addShader(curveVertexShaderBillboardMain);
       curvesBillboardShadersMap[shaderProgramName]->addShader(fisheyeDistortionVertexShader);
@@ -640,11 +665,14 @@ void AbstractGlCurve::initShader(const std::string &shaderProgramName, const std
       curvesBillboardShadersMap[shaderProgramName]->printInfoLog();
     }
 
-    if (canUseGeometryShader && curvesBillboardGeometryShadersMap.find(shaderProgramName) == curvesBillboardGeometryShadersMap.end()) {
+    if (canUseGeometryShader && curvesBillboardGeometryShadersMap.find(shaderProgramName) ==
+                                    curvesBillboardGeometryShadersMap.end()) {
       GlShaderProgram *polygonShader = new GlShaderProgram(shaderProgramName);
-      polygonShader->addShaderFromSourceCode(Vertex, genCommonUniformVariables() + curveSpecificShaderCode);
+      polygonShader->addShaderFromSourceCode(Vertex,
+                                             genCommonUniformVariables() + curveSpecificShaderCode);
       polygonShader->addShader(curveVertexGeometryShaderNormalMain);
-      polygonShader->addGeometryShaderFromSourceCode(curveExtrusionBillboardGeometryShaderSrc, GL_LINES_ADJACENCY_EXT, GL_TRIANGLE_STRIP);
+      polygonShader->addGeometryShaderFromSourceCode(curveExtrusionBillboardGeometryShaderSrc,
+                                                     GL_LINES_ADJACENCY_EXT, GL_TRIANGLE_STRIP);
       polygonShader->setMaxGeometryShaderOutputVertices(6);
       polygonShader->addShader(curveFragmentShader);
       polygonShader->link();
@@ -652,13 +680,15 @@ void AbstractGlCurve::initShader(const std::string &shaderProgramName, const std
 
       if (!polygonShader->isLinked()) {
         delete polygonShader;
-        polygonShader = NULL;
+        polygonShader = nullptr;
       }
 
       GlShaderProgram *lineShader = new GlShaderProgram(shaderProgramName);
-      lineShader->addShaderFromSourceCode(Vertex, genCommonUniformVariables() + curveSpecificShaderCode);
+      lineShader->addShaderFromSourceCode(Vertex,
+                                          genCommonUniformVariables() + curveSpecificShaderCode);
       lineShader->addShader(curveVertexGeometryShaderNormalMain);
-      lineShader->addGeometryShaderFromSourceCode(curveExtrusionBillboardGeometryShaderSrc, GL_LINES_ADJACENCY_EXT, GL_LINE_STRIP);
+      lineShader->addGeometryShaderFromSourceCode(curveExtrusionBillboardGeometryShaderSrc,
+                                                  GL_LINES_ADJACENCY_EXT, GL_LINE_STRIP);
       lineShader->setMaxGeometryShaderOutputVertices(6);
       lineShader->addShader(curveFragmentShader);
       lineShader->link();
@@ -666,7 +696,7 @@ void AbstractGlCurve::initShader(const std::string &shaderProgramName, const std
 
       if (!lineShader->isLinked()) {
         delete lineShader;
-        lineShader = NULL;
+        lineShader = nullptr;
       }
 
       curvesBillboardGeometryShadersMap[shaderProgramName] = make_pair(polygonShader, lineShader);
@@ -682,7 +712,9 @@ void AbstractGlCurve::initShader(const std::string &shaderProgramName, const std
   }
 }
 
-void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &startColor, const Color &endColor, const float startSize, const float endSize, const unsigned int nbCurvePoints) {
+void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &startColor,
+                                const Color &endColor, const float startSize, const float endSize,
+                                const unsigned int nbCurvePoints) {
 
   GLint renderMode;
   glGetIntegerv(GL_RENDER_MODE, &renderMode);
@@ -693,31 +725,34 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
   glDisable(GL_LIGHTING);
   glDisable(GL_CULL_FACE);
 
-  if (texture != "") {
+  if (!texture.empty()) {
     unsigned int i = nbCurvePoints / 2;
-    Coord firstCurvePoint(computeCurvePointOnCPU(controlPoints, i / static_cast<float>(nbCurvePoints - 1)));
-    Coord nexCurvePoint(computeCurvePointOnCPU(controlPoints, (i+1) / static_cast<float>(nbCurvePoints - 1)));
+    Coord firstCurvePoint(computeCurvePointOnCPU(controlPoints, i / float(nbCurvePoints - 1)));
+    Coord nexCurvePoint(computeCurvePointOnCPU(controlPoints, (i + 1) / float(nbCurvePoints - 1)));
     float dist = firstCurvePoint.dist(nexCurvePoint);
     texCoordFactor = dist / (startSize * 2.0f);
   }
 
   if (billboardCurve) {
     curveShaderProgram = curveShaderProgramBillboard;
-  }
-  else {
+  } else {
     curveShaderProgram = curveShaderProgramNormal;
   }
 
-  static bool canUseFloatTextures = OpenGlConfigManager::getInst().isExtensionSupported("GL_ARB_texture_float");
+  static bool canUseFloatTextures =
+      OpenGlConfigManager::isExtensionSupported("GL_ARB_texture_float");
 
-  if (curveShaderProgram != NULL && canUseFloatTextures && renderMode != GL_SELECT) {
+  if (curveShaderProgram != nullptr && canUseFloatTextures && renderMode != GL_SELECT) {
 
-    static bool vboOk = OpenGlConfigManager::getInst().hasVertexBufferObject();
+    static bool vboOk = OpenGlConfigManager::hasVertexBufferObject();
 
-    pair<GlShaderProgram *, GlShaderProgram *> geometryShaders = std::make_pair((GlShaderProgram*)NULL,(GlShaderProgram*)NULL);
-    pair<GlShaderProgram *, GlShaderProgram *> geometryBillboardShaders = std::make_pair((GlShaderProgram*)NULL,(GlShaderProgram*)NULL);
+    pair<GlShaderProgram *, GlShaderProgram *> geometryShaders = std::make_pair(
+        static_cast<GlShaderProgram *>(nullptr), static_cast<GlShaderProgram *>(nullptr));
+    pair<GlShaderProgram *, GlShaderProgram *> geometryBillboardShaders = std::make_pair(
+        static_cast<GlShaderProgram *>(nullptr), static_cast<GlShaderProgram *>(nullptr));
 
-    if (canUseGeometryShader && curvesGeometryShadersMap.find(curveShaderProgram->getName()) != curvesGeometryShadersMap.end()) {
+    if (canUseGeometryShader && curvesGeometryShadersMap.find(curveShaderProgram->getName()) !=
+                                    curvesGeometryShadersMap.end()) {
       geometryShaders = curvesGeometryShadersMap[curveShaderProgram->getName()];
       geometryBillboardShaders = curvesBillboardGeometryShadersMap[curveShaderProgram->getName()];
     }
@@ -728,18 +763,19 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
 
     GLuint *vbo = curveVertexBuffersObject[nbCurvePoints];
     GlShaderProgram *currentActiveShader = GlShaderProgram::getCurrentActiveShader();
-    bool fisheyeActivated = currentActiveShader != NULL && currentActiveShader->getName() == "fisheye";
+    bool fisheyeActivated =
+        currentActiveShader != nullptr && currentActiveShader->getName() == "fisheye";
     GLfloat fisheyeCenter[4];
     GLfloat fisheyeRadius;
     GLfloat fisheyeHeight;
-    GLint   fisheyeType;
+    GLint fisheyeType;
 
     if (fisheyeActivated) {
       currentActiveShader->getUniformFloatVariableValue("center", fisheyeCenter);
       currentActiveShader->getUniformFloatVariableValue("radius", &fisheyeRadius);
       currentActiveShader->getUniformFloatVariableValue("height", &fisheyeHeight);
-      currentActiveShader->getUniformIntVariableValue("fisheyeType", (int*)(&fisheyeType));
-      currentActiveShader->desactivate();
+      currentActiveShader->getUniformIntVariableValue("fisheyeType", &fisheyeType);
+      currentActiveShader->deactivate();
     }
 
     static GLuint controlPointsTexId = 0;
@@ -748,15 +784,13 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
       glGenTextures(1, &controlPointsTexId);
     }
 
-    vector<float> controlPointsData(1024*4, 0);
-
-
     glEnable(GL_TEXTURE_1D);
     glBindTexture(GL_TEXTURE_1D, controlPointsTexId);
     glTexParameteri(GL_TEXTURE_1D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE);
     glTexParameteri(GL_TEXTURE_1D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
     glTexParameteri(GL_TEXTURE_1D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
-    glTexImage1D(GL_TEXTURE_1D, 0, GL_RGB32F_ARB, controlPoints.size(), 0, GL_RGB, GL_FLOAT, &controlPoints[0][0]);
+    glTexImage1D(GL_TEXTURE_1D, 0, GL_RGB32F_ARB, controlPoints.size(), 0, GL_RGB, GL_FLOAT,
+                 &controlPoints[0][0]);
     glBindTexture(GL_TEXTURE_1D, 0);
     glDisable(GL_TEXTURE_1D);
 
@@ -765,8 +799,7 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
     if (canUseGeometryShader && nbCurvePoints > 3 && !lineCurve && geometryShaders.first) {
       if (!billboardCurve) {
         curveShaderProgram = geometryShaders.first;
-      }
-      else {
+      } else {
         curveShaderProgram = geometryBillboardShaders.first;
       }
 
@@ -783,14 +816,12 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
     curveShaderProgram->setUniformColor("endColor", endColor);
     curveShaderProgram->setUniformTextureSampler("texture", 0);
     curveShaderProgram->setUniformTextureSampler("texture3d", 1);
-    curveShaderProgram->setUniformBool("useTexture", texture != "" && !lineCurve);
+    curveShaderProgram->setUniformBool("useTexture", !texture.empty() && !lineCurve);
     curveShaderProgram->setUniformBool("billboard", billboardCurve && !lineCurve);
 
-
     if (!geometryShaderActivated) {
-      curveShaderProgram->setUniformFloat("step", 1.0f / (static_cast<float>(nbCurvePoints) - 1.0f));
-    }
-    else {
+      curveShaderProgram->setUniformFloat("step", 1.0f / (float(nbCurvePoints) - 1.0f));
+    } else {
       curveShaderProgram->setUniformBool("topOutline", true);
       curveShaderProgram->setUniformBool("bottomOutline", true);
     }
@@ -804,7 +835,8 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
     curveShaderProgram->setUniformBool("fisheye", fisheyeActivated);
 
     if (fisheyeActivated) {
-      curveShaderProgram->setUniformVec4Float("center", fisheyeCenter[0], fisheyeCenter[1], fisheyeCenter[2], fisheyeCenter[3]);
+      curveShaderProgram->setUniformVec4Float("center", fisheyeCenter[0], fisheyeCenter[1],
+                                              fisheyeCenter[2], fisheyeCenter[3]);
       curveShaderProgram->setUniformFloat("radius", fisheyeRadius);
       curveShaderProgram->setUniformFloat("height", fisheyeHeight);
       curveShaderProgram->setUniformInt("fisheyeType", fisheyeType);
@@ -816,9 +848,8 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
 
     if (vboOk) {
       glBindBuffer(GL_ARRAY_BUFFER, vbo[0]);
-      glVertexPointer(2, GL_FLOAT, 2 * sizeof(GLfloat), 0);
-    }
-    else {
+      glVertexPointer(2, GL_FLOAT, 2 * sizeof(GLfloat), nullptr);
+    } else {
       glVertexPointer(2, GL_FLOAT, 2 * sizeof(GLfloat), curveVertexBuffersData[nbCurvePoints]);
     }
 
@@ -830,64 +861,61 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
 
       if (vboOk) {
         glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, vbo[2]);
-        glDrawElements(GL_LINE_STRIP, nbCurvePoints, GL_UNSIGNED_SHORT, 0);
-      }
-      else {
-        glDrawElements(GL_LINE_STRIP, nbCurvePoints, GL_UNSIGNED_SHORT, curveVertexBuffersIndices[nbCurvePoints][1]);
+        glDrawElements(GL_LINE_STRIP, nbCurvePoints, GL_UNSIGNED_SHORT, nullptr);
+      } else {
+        glDrawElements(GL_LINE_STRIP, nbCurvePoints, GL_UNSIGNED_SHORT,
+                       curveVertexBuffersIndices[nbCurvePoints][1]);
       }
 
-    }
-    else {
-      if (texture != "") {
+    } else {
+      if (!texture.empty()) {
         glActiveTexture(GL_TEXTURE0);
-        GlTextureManager::getInst().activateTexture(texture);
+        GlTextureManager::activateTexture(texture);
         glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_REPEAT);
       }
 
       if (billboardCurve) {
         glActiveTexture(GL_TEXTURE1);
         glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_REPEAT);
-        GlTextureManager::getInst().activateTexture(TulipBitmapDir+"cylinderTexture.png");
+        GlTextureManager::activateTexture(TulipBitmapDir + "cylinderTexture.png");
       }
 
       if (vboOk) {
         if (geometryShaderActivated) {
           glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, vbo[3]);
-          glDrawElements(GL_LINE_STRIP_ADJACENCY_EXT, nbCurvePoints, GL_UNSIGNED_SHORT, 0);
-        }
-        else {
+          glDrawElements(GL_LINE_STRIP_ADJACENCY_EXT, nbCurvePoints, GL_UNSIGNED_SHORT, nullptr);
+        } else {
           glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, vbo[1]);
-          glDrawElements(GL_TRIANGLE_STRIP, nbCurvePoints * 2, GL_UNSIGNED_SHORT, 0);
+          glDrawElements(GL_TRIANGLE_STRIP, nbCurvePoints * 2, GL_UNSIGNED_SHORT, nullptr);
         }
-      }
-      else {
+      } else {
         if (geometryShaderActivated) {
-          glDrawElements(GL_LINE_STRIP_ADJACENCY_EXT, nbCurvePoints, GL_UNSIGNED_SHORT, curveVertexBuffersIndices[nbCurvePoints][1]);
-        }
-        else {
-          glDrawElements(GL_TRIANGLE_STRIP, nbCurvePoints * 2, GL_UNSIGNED_SHORT, curveVertexBuffersIndices[nbCurvePoints][0]);
+          glDrawElements(GL_LINE_STRIP_ADJACENCY_EXT, nbCurvePoints, GL_UNSIGNED_SHORT,
+                         curveVertexBuffersIndices[nbCurvePoints][1]);
+        } else {
+          glDrawElements(GL_TRIANGLE_STRIP, nbCurvePoints * 2, GL_UNSIGNED_SHORT,
+                         curveVertexBuffersIndices[nbCurvePoints][0]);
         }
       }
 
       if (billboardCurve) {
         glActiveTexture(GL_TEXTURE1);
-        GlTextureManager::getInst().desactivateTexture();
+        GlTextureManager::deactivateTexture();
       }
 
-      if (texture != "") {
+      if (!texture.empty()) {
         glActiveTexture(GL_TEXTURE0);
-        GlTextureManager::getInst().desactivateTexture();
+        GlTextureManager::deactivateTexture();
       }
 
       if (outlined) {
 
         if (canUseGeometryShader && nbCurvePoints > 3 && geometryShaders.second) {
-          curveShaderProgram->desactivate();
+          curveShaderProgram->deactivate();
 
           if (billboardCurve) {
             curveShaderProgram = geometryBillboardShaders.second;
-          }
-          else {
+          } else {
             curveShaderProgram = geometryShaders.second;
           }
 
@@ -908,7 +936,8 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
           curveShaderProgram->setUniformBool("fisheye", fisheyeActivated);
 
           if (fisheyeActivated) {
-            curveShaderProgram->setUniformVec4Float("center", fisheyeCenter[0], fisheyeCenter[1], fisheyeCenter[2], fisheyeCenter[3]);
+            curveShaderProgram->setUniformVec4Float("center", fisheyeCenter[0], fisheyeCenter[1],
+                                                    fisheyeCenter[2], fisheyeCenter[3]);
             curveShaderProgram->setUniformFloat("radius", fisheyeRadius);
             curveShaderProgram->setUniformFloat("height", fisheyeHeight);
             curveShaderProgram->setUniformInt("fisheyeType", fisheyeType);
@@ -920,8 +949,7 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
         if (outlineColorInterpolation) {
           curveShaderProgram->setUniformColor("startColor", startColor);
           curveShaderProgram->setUniformColor("endColor", endColor);
-        }
-        else {
+        } else {
           curveShaderProgram->setUniformColor("startColor", outlineColor);
           curveShaderProgram->setUniformColor("endColor", outlineColor);
         }
@@ -932,18 +960,17 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
           glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, vbo[3]);
 
           if (geometryShaderActivated) {
-            glDrawElements(GL_LINE_STRIP_ADJACENCY_EXT, nbCurvePoints, GL_UNSIGNED_SHORT, 0);
+            glDrawElements(GL_LINE_STRIP_ADJACENCY_EXT, nbCurvePoints, GL_UNSIGNED_SHORT, nullptr);
+          } else {
+            glDrawElements(GL_LINE_STRIP, nbCurvePoints, GL_UNSIGNED_SHORT, nullptr);
           }
-          else {
-            glDrawElements(GL_LINE_STRIP, nbCurvePoints, GL_UNSIGNED_SHORT, 0);
-          }
-        }
-        else {
+        } else {
           if (geometryShaderActivated) {
-            glDrawElements(GL_LINE_STRIP_ADJACENCY_EXT, nbCurvePoints, GL_UNSIGNED_SHORT, curveVertexBuffersIndices[nbCurvePoints][2]);
-          }
-          else {
-            glDrawElements(GL_LINE_STRIP, nbCurvePoints, GL_UNSIGNED_SHORT, curveVertexBuffersIndices[nbCurvePoints][2]);
+            glDrawElements(GL_LINE_STRIP_ADJACENCY_EXT, nbCurvePoints, GL_UNSIGNED_SHORT,
+                           curveVertexBuffersIndices[nbCurvePoints][2]);
+          } else {
+            glDrawElements(GL_LINE_STRIP, nbCurvePoints, GL_UNSIGNED_SHORT,
+                           curveVertexBuffersIndices[nbCurvePoints][2]);
           }
         }
 
@@ -956,24 +983,22 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
           glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, vbo[4]);
 
           if (geometryShaderActivated) {
-            glDrawElements(GL_LINE_STRIP_ADJACENCY_EXT, nbCurvePoints, GL_UNSIGNED_SHORT, 0);
+            glDrawElements(GL_LINE_STRIP_ADJACENCY_EXT, nbCurvePoints, GL_UNSIGNED_SHORT, nullptr);
+          } else {
+            glDrawElements(GL_LINE_STRIP, nbCurvePoints, GL_UNSIGNED_SHORT, nullptr);
           }
-          else {
-            glDrawElements(GL_LINE_STRIP, nbCurvePoints, GL_UNSIGNED_SHORT, 0);
-          }
-        }
-        else {
+        } else {
           if (geometryShaderActivated) {
-            glDrawElements(GL_LINE_STRIP_ADJACENCY_EXT, nbCurvePoints, GL_UNSIGNED_SHORT, curveVertexBuffersIndices[nbCurvePoints][3]);
-          }
-          else {
-            glDrawElements(GL_LINE_STRIP, nbCurvePoints, GL_UNSIGNED_SHORT, curveVertexBuffersIndices[nbCurvePoints][3]);
+            glDrawElements(GL_LINE_STRIP_ADJACENCY_EXT, nbCurvePoints, GL_UNSIGNED_SHORT,
+                           curveVertexBuffersIndices[nbCurvePoints][3]);
+          } else {
+            glDrawElements(GL_LINE_STRIP, nbCurvePoints, GL_UNSIGNED_SHORT,
+                           curveVertexBuffersIndices[nbCurvePoints][3]);
           }
         }
       }
     }
 
-
     if (vboOk) {
       glBindBuffer(GL_ARRAY_BUFFER, 0);
       glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, 0);
@@ -981,7 +1006,7 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
 
     glDisableClientState(GL_VERTEX_ARRAY);
 
-    curveShaderProgram->desactivate();
+    curveShaderProgram->deactivate();
 
     glActiveTexture(GL_TEXTURE3);
     glBindTexture(GL_TEXTURE_1D, 0);
@@ -994,21 +1019,25 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
       currentActiveShader->activate();
     }
 
-  }
-  else {
+  } else {
     vector<Coord> curvePoints;
     computeCurvePointsOnCPU(controlPoints, curvePoints, nbCurvePoints);
 
     if (lineCurve) {
       glLineWidth(curveLineWidth);
       polyLine(curvePoints, startColor, endColor);
-    }
-    else if (!billboardCurve) {
-      polyQuad(curvePoints, startColor, endColor, startSize, endSize, Coord(2.f*curvePoints[0] - curvePoints[1]), Coord(2.f*curvePoints[curvePoints.size() - 1] - curvePoints[curvePoints.size() - 2]),outlineColorInterpolation,outlineColor,texture,curveQuadBordersWidth);
-    }
-    else {
-      simpleQuad(curvePoints, startColor, endColor, startSize, endSize, Coord(2.f*curvePoints[0] - curvePoints[1]),
-                 Coord(2.f*curvePoints[curvePoints.size() - 1] - curvePoints[curvePoints.size() - 2]), lookDir, !outlined,outlineColor,texture);
+    } else if (!billboardCurve) {
+      polyQuad(
+          curvePoints, startColor, endColor, startSize, endSize,
+          Coord(2.f * curvePoints[0] - curvePoints[1]),
+          Coord(2.f * curvePoints[curvePoints.size() - 1] - curvePoints[curvePoints.size() - 2]),
+          outlineColorInterpolation, outlineColor, texture, curveQuadBordersWidth);
+    } else {
+      simpleQuad(
+          curvePoints, startColor, endColor, startSize, endSize,
+          Coord(2.f * curvePoints[0] - curvePoints[1]),
+          Coord(2.f * curvePoints[curvePoints.size() - 1] - curvePoints[curvePoints.size() - 2]),
+          lookDir, !outlined, outlineColor, texture);
     }
   }
 
@@ -1016,11 +1045,10 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
 
   glEnable(GL_LIGHTING);
   glEnable(GL_CULL_FACE);
-
 }
 
 void AbstractGlCurve::translate(const Coord &move) {
-  for (size_t i = 0 ; i < controlPoints.size() ; ++i) {
+  for (size_t i = 0; i < controlPoints.size(); ++i) {
     controlPoints[i] += move;
   }
 
@@ -1029,6 +1057,5 @@ void AbstractGlCurve::translate(const Coord &move) {
 
 void AbstractGlCurve::getXML(string &) {}
 
-void AbstractGlCurve::setWithXML(const string &,unsigned int &) {}
-
-}
+void AbstractGlCurve::setWithXML(const string &, unsigned int &) {}
+} // namespace tlp
