@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -22,17 +22,11 @@ using namespace std;
 
 namespace tlp {
 
-GlHexagon::GlHexagon(const Coord &position,
-                     const Size &size,
-                     const Color &fillColor,
-                     const Color &outlineColor,
-                     bool filled,
-                     bool outlined,
-                     const string &textureName,
-                     float outlineSize):
-  GlRegularPolygon(position,size,6,fillColor,outlineColor,filled,outlined,textureName,outlineSize) {
-}
+GlHexagon::GlHexagon(const Coord &position, const Size &size, const Color &fillColor,
+                     const Color &outlineColor, bool filled, bool outlined,
+                     const string &textureName, float outlineSize)
+    : GlRegularPolygon(position, size, 6, fillColor, outlineColor, filled, outlined, textureName,
+                       outlineSize) {}
 //=====================================================
-GlHexagon::~GlHexagon() {
-}
-}
+GlHexagon::~GlHexagon() {}
+} // namespace tlp
