@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -24,8 +24,8 @@ using namespace std;
 
 namespace tlp {
 GlSimpleEntity::~GlSimpleEntity() {
-  for(std::vector<GlComposite*>::iterator it=parents.begin(); it!=parents.end(); ++it) {
-    (*it)->deleteGlEntity(this,false);
+  for (auto parent : parents) {
+    parent->deleteGlEntity(this, false);
   }
 }
 
@@ -34,21 +34,21 @@ void GlSimpleEntity::addParent(GlComposite *composite) {
 }
 
 void GlSimpleEntity::setVisible(bool visible) {
-  if(this->visible==visible)
+  if (this->visible == visible)
     return;
 
-  this->visible=visible;
+  this->visible = visible;
 
-  for(vector<GlComposite*>::iterator it=parents.begin(); it!=parents.end(); ++it) {
-    (*it)->notifyModified(this);
+  for (auto parent : parents) {
+    parent->notifyModified(this);
   }
 }
 void GlSimpleEntity::removeParent(GlComposite *composite) {
-  for(std::vector<GlComposite*>::iterator it=parents.begin(); it!=parents.end(); ++it) {
-    if((*it)==composite) {
+  for (auto it = parents.begin(); it != parents.end(); ++it) {
+    if ((*it) == composite) {
       parents.erase(it);
       return;
     }
   }
 }
-}
+} // namespace tlp
