@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,6 +19,8 @@
 
 #include <cstdio>
 #include <cstring>
+
+#ifdef TULIP_BUILD_GL_TEX_LOADER
 #if defined(_MSC_VER)
 // need to include that header with Visual Studio to fix a typedef conflict
 // with latest version of jpeg lib (9a)
@@ -26,27 +28,32 @@
 #endif
 #include <jpeglib.h>
 #include <png.h>
+#endif
+
 #include <GL/glew.h>
 
 #include <tulip/GlTextureManager.h>
 #include <tulip/OpenGlConfigManager.h>
 
 //====================================================
-tlp::GlTextureManager* tlp::GlTextureManager::inst=NULL;
-tlp::GlTextureLoader* tlp::GlTextureManager::loader=NULL;
+tlp::GlTextureLoader *tlp::GlTextureManager::loader = nullptr;
+tlp::GlTextureManager::TextureMap tlp::GlTextureManager::texturesMap;
+std::set<std::string> tlp::GlTextureManager::texturesWithError;
+unsigned int tlp::GlTextureManager::animationFrame = 0;
 
 using namespace std;
 
 namespace tlp {
 
+#ifdef TULIP_BUILD_GL_TEX_LOADER
 struct TextureInfo {
   bool hasAlpha;
-  unsigned int  width;
-  unsigned int  height;
+  unsigned int width;
+  unsigned int height;
   unsigned char *data;
 };
 
-typedef bool (TextureLoader_t)(const string &, TextureInfo *);
+typedef bool(TextureLoader_t)(const string &, TextureInfo *);
 
 //====================================================================
 /* simple loader for 24bit bitmaps (data is in rgb-format) */
@@ -58,19 +65,19 @@ static bool loadBMP(const string &filename, TextureInfo *texture) {
   short int biBitCount;
   long int biSizeImage;
   int i;
-  /* make sure the file is there and open it read-only (binary) */
+/* make sure the file is there and open it read-only (binary) */
 #ifndef _MSC_VER
   file = fopen(filename.c_str(), "rb");
 #else
   fopen_s(&file, filename.c_str(), "rb");
 #endif
 
-  if (file == NULL) {
+  if (file == nullptr) {
     tlp::error() << "File not found:" << filename << std::endl;
     return false;
   }
 
-  if(!fread(&bfType, sizeof(short int), 1, file)) {
+  if (!fread(&bfType, sizeof(short int), 1, file)) {
     tlp::error() << "Error reading file: " << filename << endl;
     fclose(file);
     return false;
@@ -143,8 +150,8 @@ static bool loadBMP(const string &filename, TextureInfo *texture) {
 
   if (!fread(texture->data, biSizeImage, 1, file)) {
     tlp::error() << "Error reading file: " << filename << std::endl;
-    delete [] texture->data;
-    texture->data=NULL;
+    delete[] texture->data;
+    texture->data = nullptr;
     fclose(file);
     return false;
   }
@@ -161,6 +168,10 @@ static bool loadBMP(const string &filename, TextureInfo *texture) {
   return true;
 }
 //====================================================================
+#ifdef __GNUC__
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wold-style-cast"
+#endif
 static bool loadJPEG(const string &filename, TextureInfo *texture) {
   FILE *file;
 #ifndef _MSC_VER
@@ -169,7 +180,7 @@ static bool loadJPEG(const string &filename, TextureInfo *texture) {
   fopen_s(&file, filename.c_str(), "rb");
 #endif
 
-  if (file == NULL) {
+  if (file == nullptr) {
     tlp::error() << "File not found:" << filename << std::endl;
     return false;
   }
@@ -198,9 +209,9 @@ static bool loadJPEG(const string &filename, TextureInfo *texture) {
 
   texture->hasAlpha = false;
 
-  texture->width    = cinfo.output_width;
+  texture->width = cinfo.output_width;
 
-  texture->height   = cinfo.output_height;
+  texture->height = cinfo.output_height;
 
   texture->data = new unsigned char[texture->width * texture->height * 3];
 
@@ -208,15 +219,19 @@ static bool loadJPEG(const string &filename, TextureInfo *texture) {
 
   while (cinfo.output_scanline < cinfo.output_height) {
     jpeg_read_scanlines(&cinfo, &row_pointer, 1);
-    memcpy((void *) &(texture->data[(cinfo.output_height - cinfo.output_scanline) * 3 * cinfo.output_width]), row_pointer, (texture->width) * 3);
+    memcpy(&(texture->data[(cinfo.output_height - cinfo.output_scanline) * 3 * cinfo.output_width]),
+           row_pointer, (texture->width) * 3);
   }
 
-  delete [] row_pointer;
+  delete[] row_pointer;
   jpeg_finish_decompress(&cinfo);
   jpeg_destroy_decompress(&cinfo);
   fclose(file);
   return true;
 }
+#ifdef __GNUC__
+#pragma GCC diagnostic pop
+#endif
 //====================================================================
 static bool loadPNG(const string &filename, TextureInfo *texture) {
   FILE *file;
@@ -226,12 +241,12 @@ static bool loadPNG(const string &filename, TextureInfo *texture) {
   fopen_s(&file, filename.c_str(), "rb");
 #endif
 
-  if (file == NULL) {
+  if (file == nullptr) {
     tlp::error() << "File not found:" << filename << std::endl;
     return false;
   }
 
-  png_structp png_ptr = png_create_read_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
+  png_structp png_ptr = png_create_read_struct(PNG_LIBPNG_VER_STRING, nullptr, nullptr, nullptr);
 
   if (!png_ptr) {
     tlp::error() << "Error reading file: " << filename << std::endl;
@@ -243,7 +258,8 @@ static bool loadPNG(const string &filename, TextureInfo *texture) {
 
   if (!info_ptr) {
     tlp::error() << "Error reading file: " << filename << std::endl;
-    png_destroy_read_struct(&png_ptr, (png_infopp)NULL, (png_infopp)NULL);
+    png_destroy_read_struct(&png_ptr, static_cast<png_infopp>(nullptr),
+                            static_cast<png_infopp>(nullptr));
     fclose(file);
     return false;
   }
@@ -252,7 +268,7 @@ static bool loadPNG(const string &filename, TextureInfo *texture) {
 
   if (!end_info) {
     tlp::error() << "Error reading file: " << filename << std::endl;
-    png_destroy_read_struct(&png_ptr, &info_ptr,  (png_infopp)NULL);
+    png_destroy_read_struct(&png_ptr, &info_ptr, static_cast<png_infopp>(nullptr));
     fclose(file);
     return false;
   }
@@ -264,7 +280,7 @@ static bool loadPNG(const string &filename, TextureInfo *texture) {
   {
     png_destroy_read_struct(&png_ptr, &info_ptr, &end_info);
     fclose(file);
-    return file != NULL;
+    return true;
   }
 
   png_init_io(png_ptr, file);
@@ -276,19 +292,20 @@ static bool loadPNG(const string &filename, TextureInfo *texture) {
          &color_type, &interlace_method, &compression_method, &filter_method);
    */
 
-  int ctype = png_get_color_type( png_ptr, info_ptr );
-  texture->hasAlpha = ( ctype == PNG_COLOR_TYPE_GRAY_ALPHA ) || ( ctype == PNG_COLOR_TYPE_RGB_ALPHA );
-  texture->width    = png_get_image_width( png_ptr, info_ptr );
-  texture->height   = png_get_image_height( png_ptr, info_ptr );
+  int ctype = png_get_color_type(png_ptr, info_ptr);
+  texture->hasAlpha = (ctype == PNG_COLOR_TYPE_GRAY_ALPHA) || (ctype == PNG_COLOR_TYPE_RGB_ALPHA);
+  texture->width = png_get_image_width(png_ptr, info_ptr);
+  texture->height = png_get_image_height(png_ptr, info_ptr);
   int linestride = texture->width * (texture->hasAlpha ? 4 : 3);
   texture->data = new unsigned char[linestride * texture->height];
-  png_bytep* row_pointers = new png_bytep[texture->height];
+  png_bytep *row_pointers = new png_bytep[texture->height];
 
-  for (unsigned int i=0; i < texture->height; ++i)
-    row_pointers[i] = (png_bytep) &(texture->data[linestride*(texture->height-1-i)]);
+  for (unsigned int i = 0; i < texture->height; ++i)
+    row_pointers[i] =
+        static_cast<png_bytep>(&(texture->data[linestride * (texture->height - 1 - i)]));
 
-  png_set_strip_16(png_ptr);  //force 8 bits/channel
-  png_set_gray_to_rgb(png_ptr); //force RGB
+  png_set_strip_16(png_ptr);    // force 8 bits/channel
+  png_set_gray_to_rgb(png_ptr); // force RGB
   png_read_image(png_ptr, row_pointers);
   png_read_end(png_ptr, end_info);
   png_destroy_read_struct(&png_ptr, &info_ptr, &end_info);
@@ -296,120 +313,133 @@ static bool loadPNG(const string &filename, TextureInfo *texture) {
   return true;
 }
 
-static bool generateTexture(const std::string &filename,
-                            const TextureInfo &texti,
+static bool generateTexture(const std::string &filename, const TextureInfo &texti,
                             GlTexture &glTexture) {
   int GLFmt = texti.hasAlpha ? GL_RGBA : GL_RGB;
 
-  bool spriteOnWidth=false;
-  unsigned int spriteNumber=1;
-  unsigned int width=texti.width;
-  unsigned int height=texti.height;
+  bool spriteOnWidth = false;
+  unsigned int spriteNumber = 1;
+  unsigned int width = texti.width;
+  unsigned int height = texti.height;
 
-  if((texti.height-(texti.height/texti.width)*texti.width)!=0 && (texti.width-(texti.width/texti.height)*texti.height)!=0) {
-    tlp::error() << "Texture loader error: invalid size\ntexture size should be of the form:\n - width=height or\n - height=N*width (for animated textures)\nfor file: " << filename << std::endl;
+  if ((texti.height - (texti.height / texti.width) * texti.width) != 0 &&
+      (texti.width - (texti.width / texti.height) * texti.height) != 0) {
+    tlp::error() << "Texture loader error: invalid size\ntexture size should be of the form:\n - "
+                    "width=height or\n - height=N*width (for animated textures)\nfor file: "
+                 << filename << std::endl;
     return false;
-  }
-  else {
-    if(texti.width!=texti.height) {
-      if(texti.height>texti.width) {
-        //spriteOnHeight=true;
-        spriteNumber=texti.height/texti.width;
-        height=width;
-      }
-      else {
-        spriteOnWidth=true;
-        spriteNumber=texti.width/texti.height;
-        width=height;
+  } else {
+    if (texti.width != texti.height) {
+      if (texti.height > texti.width) {
+        // spriteOnHeight=true;
+        spriteNumber = texti.height / texti.width;
+        height = width;
+      } else {
+        spriteOnWidth = true;
+        spriteNumber = texti.width / texti.height;
+        width = height;
       }
     }
 
-    bool canUseNpotTextures = OpenGlConfigManager::getInst().isExtensionSupported("GL_ARB_texture_non_power_of_two");
+    bool canUseNpotTextures =
+        OpenGlConfigManager::isExtensionSupported("GL_ARB_texture_non_power_of_two");
 
     if (!canUseNpotTextures) {
-      bool formatOk=false;
+      bool formatOk = false;
 
-      for(unsigned int i=1; i<=width; i*=2) {
-        if(i==width)
-          formatOk=true;
+      for (unsigned int i = 1; i <= width; i *= 2) {
+        if (i == width)
+          formatOk = true;
       }
 
-      if(!formatOk) {
-        tlp::error() << "Texture loader error: invalid size\ntexture width should be a power of 2\nfor file: " << filename << std::endl;
+      if (!formatOk) {
+        tlp::error() << "Texture loader error: invalid size\ntexture width should be a power of "
+                        "2\nfor file: "
+                     << filename << std::endl;
         return false;
       }
 
-      formatOk=false;
+      formatOk = false;
 
-      for(unsigned int i=1; i<=height; i*=2) {
-        if(i==height)
-          formatOk=true;
+      for (unsigned int i = 1; i <= height; i *= 2) {
+        if (i == height)
+          formatOk = true;
       }
 
-      if(!formatOk) {
-        tlp::error() << "Texture loader error: invalid size\ntexture height should be a power of 2\nfor file: " << filename << std::endl;
+      if (!formatOk) {
+        tlp::error() << "Texture loader error: invalid size\ntexture height should be a power of "
+                        "2\nfor file: "
+                     << filename << std::endl;
         return false;
       }
     }
   }
 
-  bool canUseMipmaps = OpenGlConfigManager::getInst().isExtensionSupported("GL_ARB_framebuffer_object") ||
-                       OpenGlConfigManager::getInst().isExtensionSupported("GL_EXT_framebuffer_object");
+  bool canUseMipmaps = OpenGlConfigManager::isExtensionSupported("GL_ARB_framebuffer_object") ||
+                       OpenGlConfigManager::isExtensionSupported("GL_EXT_framebuffer_object");
 
-  GLuint* textureNum = new GLuint[spriteNumber];
+  GLuint *textureNum = new GLuint[spriteNumber];
 
-  glTexture.width=width;
-  glTexture.height=height;
-  glTexture.spriteNumber=spriteNumber;
-  glTexture.id=new GLuint[spriteNumber];
+  glTexture.width = width;
+  glTexture.height = height;
+  glTexture.spriteNumber = spriteNumber;
+  glTexture.id = new GLuint[spriteNumber];
 
   unsigned char **dataForWidthSpriteTexture;
-  dataForWidthSpriteTexture=new unsigned char*[spriteNumber];
+  dataForWidthSpriteTexture = new unsigned char *[spriteNumber];
 
-  if(spriteOnWidth) {
-    for(unsigned int i=0; i<spriteNumber; i++) {
-      if(texti.hasAlpha)
-        dataForWidthSpriteTexture[i]=new unsigned char[4*width*height];
+  if (spriteOnWidth) {
+    for (unsigned int i = 0; i < spriteNumber; i++) {
+      if (texti.hasAlpha)
+        dataForWidthSpriteTexture[i] = new unsigned char[4 * width * height];
       else
-        dataForWidthSpriteTexture[i]=new unsigned char[3*width*height];
+        dataForWidthSpriteTexture[i] = new unsigned char[3 * width * height];
     }
 
-    for(unsigned int i=0; i<texti.height; i++) {
-      for(unsigned int j=0; j<texti.width; ++j) {
-        if(texti.hasAlpha) {
-          dataForWidthSpriteTexture[j/width][i*width*4+(j-(j/width)*width)*4]=texti.data[i*texti.width*4+j*4];
-          dataForWidthSpriteTexture[j/width][i*width*4+(j-(j/width)*width)*4+1]=texti.data[i*texti.width*4+j*4+1];
-          dataForWidthSpriteTexture[j/width][i*width*4+(j-(j/width)*width)*4+2]=texti.data[i*texti.width*4+j*4+2];
-          dataForWidthSpriteTexture[j/width][i*width*4+(j-(j/width)*width)*4+3]=texti.data[i*texti.width*4+j*4+3];
-        }
-        else {
-          dataForWidthSpriteTexture[j/width][i*width*3+(j-(j/width)*width)*3]=texti.data[i*texti.width*3+j*3];
-          dataForWidthSpriteTexture[j/width][i*width*3+(j-(j/width)*width)*3+1]=texti.data[i*texti.width*3+j*3+1];
-          dataForWidthSpriteTexture[j/width][i*width*3+(j-(j/width)*width)*3+2]=texti.data[i*texti.width*3+j*3+2];
+    for (unsigned int i = 0; i < texti.height; i++) {
+      for (unsigned int j = 0; j < texti.width; ++j) {
+        if (texti.hasAlpha) {
+          dataForWidthSpriteTexture[j / width][i * width * 4 + (j - (j / width) * width) * 4] =
+              texti.data[i * texti.width * 4 + j * 4];
+          dataForWidthSpriteTexture[j / width][i * width * 4 + (j - (j / width) * width) * 4 + 1] =
+              texti.data[i * texti.width * 4 + j * 4 + 1];
+          dataForWidthSpriteTexture[j / width][i * width * 4 + (j - (j / width) * width) * 4 + 2] =
+              texti.data[i * texti.width * 4 + j * 4 + 2];
+          dataForWidthSpriteTexture[j / width][i * width * 4 + (j - (j / width) * width) * 4 + 3] =
+              texti.data[i * texti.width * 4 + j * 4 + 3];
+        } else {
+          dataForWidthSpriteTexture[j / width][i * width * 3 + (j - (j / width) * width) * 3] =
+              texti.data[i * texti.width * 3 + j * 3];
+          dataForWidthSpriteTexture[j / width][i * width * 3 + (j - (j / width) * width) * 3 + 1] =
+              texti.data[i * texti.width * 3 + j * 3 + 1];
+          dataForWidthSpriteTexture[j / width][i * width * 3 + (j - (j / width) * width) * 3 + 2] =
+              texti.data[i * texti.width * 3 + j * 3 + 2];
         }
       }
     }
   }
 
-  glGenTextures(spriteNumber, textureNum);  //FIXME: handle case where no memory is available to load texture
+  glGenTextures(spriteNumber, textureNum);
 
   glEnable(GL_TEXTURE_2D);
 
-  for(unsigned int i=0; i<spriteNumber; ++i) {
+  for (unsigned int i = 0; i < spriteNumber; ++i) {
     glBindTexture(GL_TEXTURE_2D, textureNum[i]);
 
-    glTexture.id[i]=textureNum[i];
+    glTexture.id[i] = textureNum[i];
 
-    if(!spriteOnWidth) {
-      if(texti.hasAlpha)
-        glTexImage2D(GL_TEXTURE_2D, 0, GLFmt, width, height, 0, GLFmt, GL_UNSIGNED_BYTE, texti.data + (width*height*4*i));
+    if (!spriteOnWidth) {
+      if (texti.hasAlpha)
+        glTexImage2D(GL_TEXTURE_2D, 0, GLFmt, width, height, 0, GLFmt, GL_UNSIGNED_BYTE,
+                     texti.data + (width * height * 4 * i));
       else
-        glTexImage2D(GL_TEXTURE_2D, 0, GLFmt, width, height, 0, GLFmt, GL_UNSIGNED_BYTE, texti.data + (width*height*3*i));
-    }
-    else {
-      glTexImage2D(GL_TEXTURE_2D, 0, GLFmt, width, height, 0, GLFmt, GL_UNSIGNED_BYTE, dataForWidthSpriteTexture[i]);
+        glTexImage2D(GL_TEXTURE_2D, 0, GLFmt, width, height, 0, GLFmt, GL_UNSIGNED_BYTE,
+                     texti.data + (width * height * 3 * i));
+    } else {
+      glTexImage2D(GL_TEXTURE_2D, 0, GLFmt, width, height, 0, GLFmt, GL_UNSIGNED_BYTE,
+                   dataForWidthSpriteTexture[i]);
 
-      delete [] dataForWidthSpriteTexture[i];
+      delete[] dataForWidthSpriteTexture[i];
     }
 
     glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
@@ -417,76 +447,68 @@ static bool generateTexture(const std::string &filename,
     if (canUseMipmaps) {
       glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR_MIPMAP_LINEAR);
       glGenerateMipmap(GL_TEXTURE_2D);
-    }
-    else {
+    } else {
       glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
     }
-
   }
 
   glDisable(GL_TEXTURE_2D);
 
-  delete [] textureNum;
-  delete [] dataForWidthSpriteTexture;
+  delete[] textureNum;
+  delete[] dataForWidthSpriteTexture;
 
   return true;
 }
 //====================================================================
-bool GlTextureLoader::loadTexture(const string& filename,
-                                  GlTexture &texture) {
+bool GlTextureLoader::loadTexture(const string &filename, GlTexture &texture) {
   string extension = filename.substr(filename.find_last_of('.') + 1);
 
-  for (int i=0; i < (int)extension.length(); ++i)
-    extension[i] = (char) toupper(extension[i]);
+  for (unsigned int i = 0; i < extension.length(); ++i)
+    extension[i] = static_cast<char>(toupper(extension[i]));
 
-  TextureLoader_t *loader = NULL;
+  TextureLoader_t *loader = nullptr;
 
-  if (extension == "BMP") loader = &loadBMP;
-  else if ((extension == "JPG") || (extension == "JPEG")) loader = &loadJPEG;
-  else if (extension == "PNG") loader = &loadPNG;
+  if (extension == "BMP")
+    loader = &loadBMP;
+  else if ((extension == "JPG") || (extension == "JPEG"))
+    loader = &loadJPEG;
+  else if (extension == "PNG")
+    loader = &loadPNG;
   else {
-    tlp::error() << "GlTextureLoader Error: no texture loader found for file extension \"" << extension << "\"" << std::endl;
+    tlp::error() << "GlTextureLoader Error: no texture loader found for file extension \""
+                 << extension << "\"" << std::endl;
   }
 
   TextureInfo texti;
 
-  if ((loader == NULL) || !(*loader)(filename, &texti)) {
+  if ((loader == nullptr) || !(*loader)(filename, &texti)) {
     return false;
   }
 
   bool result = generateTexture(filename, texti, texture);
 
-  delete [] texti.data;
+  delete[] texti.data;
 
   return result;
 }
+#endif
+
 //====================================================================
-GlTextureManager::GlTextureManager():animationFrame(0) {
-}
-//====================================================================
-void GlTextureManager::changeContext(uintptr_t context) {
-  currentContext=context;
-}
-//====================================================================
-void GlTextureManager::removeContext(uintptr_t context) {
-  texturesMap.erase(context);
-}
-//====================================================================
-GlTexture GlTextureManager::getTextureInfo(const string& filename) {
-  if(texturesMap[currentContext].find(filename) != texturesMap[currentContext].end())
-    return (texturesMap[currentContext])[filename];
+GlTexture GlTextureManager::getTextureInfo(const string &filename) {
+  if (texturesMap.find(filename) != texturesMap.end())
+    return (texturesMap)[filename];
   else
     return GlTexture();
 }
 //====================================================================
-bool GlTextureManager::existsTexture(const string& filename) {
-  return (texturesMap[currentContext].find(filename) != texturesMap[currentContext].end());
+bool GlTextureManager::existsTexture(const string &filename) {
+  return (texturesMap.find(filename) != texturesMap.end());
 }
 //====================================================================
-bool GlTextureManager::loadTexture(const string& filename) {
+bool GlTextureManager::loadTexture(const string &filename) {
   glEnable(GL_TEXTURE_2D);
 
-  if (texturesMap[currentContext].find(filename) != texturesMap[currentContext].end())
+  if (texturesMap.find(filename) != texturesMap.end())
     return true;
 
   GlTexture texture;
@@ -494,34 +516,36 @@ bool GlTextureManager::loadTexture(const string& filename) {
   if (!getTextureLoader()->loadTexture(filename, texture))
     return false;
 
-  (texturesMap[currentContext])[filename] = texture;
+  (texturesMap)[filename] = texture;
   return true;
 }
 
-void GlTextureManager::registerExternalTexture(const std::string &textureName, const GLuint textureId) {
+void GlTextureManager::registerExternalTexture(const std::string &textureName,
+                                               const GLuint textureId) {
   GlTexture texture;
-  texture.spriteNumber=1;
-  texture.id=new GLuint[1];
+  texture.spriteNumber = 1;
+  texture.id = new GLuint[1];
   texture.id[0] = textureId;
-  (texturesMap[currentContext])[textureName] = texture;
+  (texturesMap)[textureName] = texture;
 }
 
 //====================================================================
-void GlTextureManager::deleteTexture(const string& name) {
-  for(ContextAndTextureMap::iterator it=texturesMap.begin(); it!=texturesMap.end(); ++it) {
-    TextureUnit::iterator it2=it->second.find(name);
+static void deleteGlTexture(GlTexture &texture) {
+  for (unsigned int i = 0; i < texture.spriteNumber; ++i) {
+    glDeleteTextures(1, &(texture.id[i]));
+  }
+  delete[] texture.id;
+}
 
-    if(it2!=it->second.end()) {
-      for(unsigned int i=0; i<it2->second.spriteNumber; ++i)
-        glDeleteTextures(1,&(it2->second.id[i]));
-
-      delete [] it2->second.id;
-      it->second.erase(name);
-    }
+void GlTextureManager::deleteTexture(const string &name) {
+  TextureMap::iterator it = texturesMap.find(name);
+  if (it != texturesMap.end()) {
+    deleteGlTexture(it->second);
+    texturesMap.erase(it);
   }
 }
 //====================================================================
-void GlTextureManager::beginNewTexture(const string&) {
+void GlTextureManager::beginNewTexture(const string &) {
   GLuint textureNum;
   glGenTextures(1, &textureNum);
   glBindTexture(GL_TEXTURE_2D, textureNum);
@@ -531,36 +555,41 @@ void GlTextureManager::beginNewTexture(const string&) {
   glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP);
 }
 //====================================================================
-bool GlTextureManager::activateTexture(const string& filename) {
-  return activateTexture(filename,animationFrame);
+bool GlTextureManager::activateTexture(const string &filename) {
+  return activateTexture(filename, animationFrame);
 }
 //====================================================================
-bool GlTextureManager::activateTexture(const string& filename,unsigned int frame) {
-  if(texturesWithError.count(filename)!=0)
+bool GlTextureManager::activateTexture(const string &filename, unsigned int frame) {
+  if (texturesWithError.count(filename) != 0)
     return false;
 
-  bool loadOk=true;
+  bool loadOk = true;
 
-  if (texturesMap[currentContext].find(filename) == texturesMap[currentContext].end())
-    loadOk=loadTexture(filename);
+  if (texturesMap.find(filename) == texturesMap.end())
+    loadOk = loadTexture(filename);
   else
     glEnable(GL_TEXTURE_2D);
 
-  if(!loadOk) {
+  if (!loadOk) {
     texturesWithError.insert(filename);
     glDisable(GL_TEXTURE_2D);
     return false;
   }
 
-  unsigned int spriteNumber=((texturesMap[currentContext])[filename]).spriteNumber;
-  frame=frame-(frame/spriteNumber)*spriteNumber;
-  glBindTexture(GL_TEXTURE_2D, (texturesMap[currentContext])[filename].id[frame]);
+  unsigned int spriteNumber = texturesMap[filename].spriteNumber;
+  frame = frame - (frame / spriteNumber) * spriteNumber;
+  glBindTexture(GL_TEXTURE_2D, texturesMap[filename].id[frame]);
   return true;
 }
 //====================================================================
-void GlTextureManager::desactivateTexture() {
+void GlTextureManager::deactivateTexture() {
   glDisable(GL_TEXTURE_2D);
 }
-
-
+//====================================================================
+void GlTextureManager::deleteAllTextures() {
+  for (auto &it : texturesMap) {
+    deleteGlTexture(it.second);
+  }
 }
+
+} // namespace tlp
