@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,23 +18,15 @@
  */
 #include <tulip/GlTriangle.h>
 
-
-
 using namespace std;
 
 namespace tlp {
 
-GlTriangle::GlTriangle(const Coord &position,
-                       const Size &size,
-                       const Color &fillColor,
-                       const Color &outlineColor,
-                       bool filled,
-                       bool outlined,
-                       const string &textureName,
-                       float outlineSize):
-  GlRegularPolygon(position,size,3,fillColor,outlineColor,filled,outlined,textureName,outlineSize) {
-}
+GlTriangle::GlTriangle(const Coord &position, const Size &size, const Color &fillColor,
+                       const Color &outlineColor, bool filled, bool outlined,
+                       const string &textureName, float outlineSize)
+    : GlRegularPolygon(position, size, 3, fillColor, outlineColor, filled, outlined, textureName,
+                       outlineSize) {}
 //=====================================================
-GlTriangle::~GlTriangle() {
-}
-}
+GlTriangle::~GlTriangle() {}
+} // namespace tlp
