@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -32,21 +32,18 @@ struct ParenInfo {
   bool operator<(const ParenInfo &info) const {
     return position < info.position;
   }
-
 };
 
 class ParenInfoTextBlockData : public QTextBlockUserData {
 
-  QVector<ParenInfo> _parenInfos;
+  QVector<ParenInfo> _parenInfo;
 
 public:
-
   ParenInfoTextBlockData();
 
   QVector<ParenInfo> parens();
   void insert(const ParenInfo &parenInfo);
-  void sortParenInfos();
-
+  void sortParenInfo();
 };
 
 class ParenMatcherHighlighter : public QSyntaxHighlighter {
@@ -55,13 +52,10 @@ class ParenMatcherHighlighter : public QSyntaxHighlighter {
   QVector<char> _rightParensToMatch;
 
 public:
-
-  explicit ParenMatcherHighlighter(QTextDocument *parent = 0);
+  explicit ParenMatcherHighlighter(QTextDocument *parent = nullptr);
 
 protected:
-
-  void highlightBlock(const QString &text);
-
+  void highlightBlock(const QString &text) override;
 };
 
 #endif /* PARENMATCHERHIGHLIGHTER_H_ */
