@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -38,19 +38,22 @@ class TLP_PYTHON_SCOPE PythonShellWidget : public PythonCodeEditor {
   QVector<QString> _history;
   int _currentHistoryPos;
 
-public :
+public:
+  explicit PythonShellWidget(QWidget *parent = nullptr, bool showBanner = false);
 
-  explicit PythonShellWidget(QWidget *parent = 0);
+signals:
+
+  void beginCurrentLinesExecution();
+  void endCurrentLinesExecution();
 
 protected:
-
-  void keyPressEvent(QKeyEvent * e);
+  void keyPressEvent(QKeyEvent *e) override;
 
   bool isCursorOnLastLine();
 
   void executeCurrentLines();
 
-  void showEvent(QShowEvent * event);
+  void showEvent(QShowEvent *event) override;
 
 public slots:
 
@@ -58,10 +61,8 @@ public slots:
 
 protected slots:
 
-  void updateAutoCompletionList(bool dotContext=false);
-
+  void updateAutoCompletionList(bool dotContext = false) override;
 };
-
-}
+} // namespace tlp
 
 #endif /* PYTHONSHELLWIDGET_H_ */
