@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -26,9 +26,8 @@
 
 class TLP_PYTHON_SCOPE PythonTabWidget : public QTabWidget {
 
-public :
-
-  explicit PythonTabWidget(QWidget *parent = 0);
+public:
+  explicit PythonTabWidget(QWidget *parent = nullptr);
 
   void setDrawTabBarBgGradient(const bool drawGradient) {
     _drawGradient = drawGradient;
@@ -39,12 +38,10 @@ public :
   }
 
 protected:
-
-  void paintEvent(QPaintEvent * event);
+  void paintEvent(QPaintEvent *event) override;
 
   bool _drawGradient;
   QColor _textColor;
-
 };
 
 #endif // PYTHONTABWIDGET_H
