@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -34,13 +34,14 @@ class DoubleStringsListRelationDialog : public QDialog {
 
   Q_OBJECT
 
-  Ui::DoubleStringsListRelationDialogData* _ui;
+  Ui::DoubleStringsListRelationDialogData *_ui;
 
-public :
-
-  DoubleStringsListRelationDialog(const std::vector<std::string> &firstValues,const std::vector<Color> &secondValues,QWidget *parent = 0);
-  ~DoubleStringsListRelationDialog();
-  void getResult(std::vector<std::pair<std::string,Color> > &result);
+public:
+  DoubleStringsListRelationDialog(const std::vector<std::string> &firstValues,
+                                  const std::vector<Color> &secondValues,
+                                  QWidget *parent = nullptr);
+  ~DoubleStringsListRelationDialog() override;
+  void getResult(std::vector<std::pair<std::string, Color>> &result);
 
 private slots:
   void upButtonClicked();
@@ -48,8 +49,11 @@ private slots:
   void upButtonColorClicked();
   void downButtonColorClicked();
   void scrollBarValueChanged(int value);
-};
+  void interpolateCheckBoxChange(int state);
 
-}
+private:
+  std::vector<Color> lastNonInterpolateValues;
+};
+} // namespace tlp
 
 #endif /* DOUBLESTRINGSLISTRELATIONDIALOG_H_ */
