@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -26,13 +26,16 @@
 
 class BendsTools {
 public:
-  static  std::vector<tlp::node> bendsSimplification( std::vector<tlp::node> &bends, tlp::LayoutProperty * layout);
+  static std::vector<tlp::node> bendsSimplification(std::vector<tlp::node> &bends,
+                                                    tlp::LayoutProperty *layout);
 
 private:
   BendsTools();
 
-  static bool straightLine(tlp::LayoutProperty *  layout, const tlp::node a, const tlp::node b, const tlp::node c);
-  static double cosAlpha(tlp::LayoutProperty *  layout, const tlp::node a, const tlp::node b, const tlp::node c);
+  static bool straightLine(tlp::LayoutProperty *layout, const tlp::node a, const tlp::node b,
+                           const tlp::node c);
+  static double cosAlpha(tlp::LayoutProperty *layout, const tlp::node a, const tlp::node b,
+                         const tlp::node c);
 };
 
 #endif // BENDSTOOLS_H
