@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,14 +21,14 @@
 
 using namespace tlp;
 
-class EmptyGraphImport: public ImportModule {
+class EmptyGraphImport : public ImportModule {
 public:
-  PLUGININFORMATION("Empty graph","Tulip team", "05/09/2012","A no-op plugin to import empty graphs","1.0","")
+  PLUGININFORMATION("Empty graph", "Tulip team", "05/09/2012",
+                    "A no-op plugin to import empty graphs", "1.0", "")
 
-  EmptyGraphImport(const tlp::PluginContext* context): ImportModule(context) {
-  }
+  EmptyGraphImport(const tlp::PluginContext *context) : ImportModule(context) {}
 
-  virtual bool importGraph() {
+  bool importGraph() override {
     return true;
   }
 };
