@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,6 +17,7 @@
  *
  */
 
+#include <algorithm>
 #include <iostream>
 #include <fstream>
 #include <cctype>
@@ -24,64 +25,48 @@
 #include <cstring>
 #include <tulip/TulipPluginHeaders.h>
 
-
 /** \file
  *  \brief - Import UCINET DL format graph file.
  *  This plugin imports a graph from a file in UCINET DL input format,</br>
- *  as it is described in the UCINET reference manual (http://www.analytictech.com/ucinet/documentation/reference.rtf).
+ *  as it is described in the UCINET reference manual
+ * (http://www.analytictech.com/ucinet/documentation/reference.rtf).
  *  <b>HISTORY</b>
  *
  *  - 12/09/2011 Version 1.0: Initial release
  *
- *  \author Patrick Mary of Tulip Team http://tulip-software.org/
+ *  \author Patrick Mary of Tulip Team http://tulip.labri.fr/
  *
  *
-*/
+ */
 using namespace std;
 using namespace tlp;
 
 namespace {
-const char * paramHelp[] = {
-  // filename
-  HTML_HELP_OPEN()            \
-  HTML_HELP_DEF( "type", "pathname" )       \
-  HTML_HELP_BODY()                  \
-  "This parameter indicates the pathname of the file in dl format to import."       \
-  HTML_HELP_CLOSE(),
-  HTML_HELP_OPEN()            \
-  HTML_HELP_DEF( "type", "string" )       \
-  HTML_HELP_BODY()                  \
-  "This parameter indicates the name of the default metric."        \
-  HTML_HELP_CLOSE(),
-};
-}
-
-namespace {
-bool getUnsignedInt(unsigned int& i, const string& str) {
-  const char* ptr = str.c_str();
-  char* endPtr;
+bool getUnsignedInt(unsigned int &i, const string &str) {
+  const char *ptr = str.c_str();
+  char *endPtr;
   long int value = strtol(ptr, &endPtr, 10);
-  i = (unsigned int) value;
+  i = uint(value);
   return (value >= 0) && (*endPtr == 0);
 }
 
-bool getDouble(double& d, const string& str) {
-  const char* ptr = str.c_str();
-  char* endPtr;
+bool getDouble(double &d, const string &str) {
+  const char *ptr = str.c_str();
+  char *endPtr;
   d = strtod(ptr, &endPtr);
   return (*endPtr == 0);
 }
 
-bool nocasecmp(const string& str1, const char* str2) {
+bool nocasecmp(const string &str1, const char *str2) {
   return strcasecmp(str1.c_str(), str2) == 0;
 }
 
-bool skipEqualSign(const string& str, string::size_type& pos) {
+bool skipEqualSign(const string &str, string::size_type &pos) {
   bool equalFound = false;
   string::size_type size = str.size();
 
   for (; pos < size; ++pos) {
-    switch(str[pos]) {
+    switch (str[pos]) {
     case '=':
       equalFound = true;
 
@@ -98,8 +83,7 @@ bool skipEqualSign(const string& str, string::size_type& pos) {
   return false;
 }
 
-bool nextUnsignedInt(const string& str, unsigned int& value,
-                     string::size_type& pos) {
+bool nextUnsignedInt(const string &str, unsigned int &value, string::size_type &pos) {
   string::size_type lastPos = str.find_first_not_of(" \r\t ,=", pos);
   // Find next separator
   pos = str.find_first_of(" \r\t ,", lastPos);
@@ -110,8 +94,7 @@ bool nextUnsignedInt(const string& str, unsigned int& value,
   return false;
 }
 
-bool nextString(const string& str, string& token,
-                string::size_type& pos) {
+bool nextString(const string &str, string &token, string::size_type &pos) {
   token.clear();
   // Skip separators at the beginning.
   string::size_type lastPos = str.find_first_not_of(" \r\t", pos);
@@ -129,8 +112,7 @@ bool nextString(const string& str, string& token,
       if (bslashFound) {
         token.push_back(c);
         bslashFound = false;
-      }
-      else {
+      } else {
         if (c == '\\')
           bslashFound = true;
         else {
@@ -148,8 +130,7 @@ bool nextString(const string& str, string& token,
   return false;
 }
 
-bool nextToken(const string& str, const string& separators, string& token,
-               string::size_type& pos) {
+bool nextToken(const string &str, const string &separators, string &token, string::size_type &pos) {
   token.clear();
   // Skip separators at the beginning.
   string::size_type lastPos = str.find_first_not_of(separators, pos);
@@ -170,8 +151,7 @@ bool nextToken(const string& str, const string& separators, string& token,
         if (bslashFound) {
           token.push_back(c);
           bslashFound = false;
-        }
-        else {
+        } else {
           if (c == '\\')
             bslashFound = true;
           else {
@@ -187,16 +167,14 @@ bool nextToken(const string& str, const string& separators, string& token,
         return false;
 
       ++pos;
-    }
-    else
+    } else
       token.insert(0, str, lastPos, pos - lastPos);
   }
 
   return true;
 }
 
-bool tokenize(const string& str, vector<string>& tokens,
-              const string& separators) {
+bool tokenize(const string &str, vector<string> &tokens, const string &separators) {
   if (str.empty())
     return true;
 
@@ -205,47 +183,50 @@ bool tokenize(const string& str, vector<string>& tokens,
   string::size_type pos = 0;
   bool result;
 
-  while ((result = nextToken(str, separators, token, pos))
-         && !token.empty())
+  while ((result = nextToken(str, separators, token, pos)) && !token.empty())
     tokens.push_back(token);
 
   return result;
 }
-}
+} // namespace
+
+static const char *paramHelp[] = {
+    // filename
+    "This parameter indicates the pathname of the file in UCINET DL format to import.",
+
+    // Default metric
+    "This parameter indicates the name of the default metric."};
 
 class ImportUCINET : public ImportModule {
 
-public :
-  PLUGININFORMATION("UCINET","Patrick Mary","12/09/2011",
-                    "Imports a new graph from a text file (.txt) in UCINET DL input format<br/>as it is described in the UCINET reference manual (<b>http://www.analytictech.com/ucinet/documentation/reference.rtf</b>)",
-                    "1.0","File")
-  std::list<std::string> fileExtensions() const {
+public:
+  PLUGININFORMATION("UCINET", "Patrick Mary", "12/09/2011",
+                    "<p>Supported extensions: txt</p><p>Imports a new graph from a text file in "
+                    "UCINET DL input format<br/>as it is described in the UCINET reference manual "
+                    "(<b>http://www.analytictech.com/ucinet/documentation/reference.rtf</b></p>)",
+                    "1.0", "File")
+  std::list<std::string> fileExtensions() const override {
     std::list<std::string> l;
     l.push_back("txt");
     return l;
   }
-  ImportUCINET(const tlp::PluginContext* context):ImportModule(context),
-    nbNodes(0), defaultMetric("weight"),
-    n(0), nr(0), nc(0), nm(0), current(0),
-    dl_found(false), diagonal(true),
-    diagonal_found(false),
-    labels_known(false), title_found(false),
-    expectedLine(DL_HEADER),
-    embedding(DL_NONE), dataFormat(DL_FM) {
-    addInParameter<string>("file::filename", paramHelp[0],"");
+  ImportUCINET(const tlp::PluginContext *context)
+      : ImportModule(context), nbNodes(0), defaultMetric("weight"), n(0), nr(0), nc(0), nm(0),
+        current(0), dl_found(false), diagonal(true), diagonal_found(false), labels_known(false),
+        title_found(false), expectedLine(DL_HEADER), embedding(DL_NONE), dataFormat(DL_FM) {
+    addInParameter<string>("file::filename", paramHelp[0], "");
     addInParameter<string>("Default metric", paramHelp[1], "weight");
   }
 
-  ~ImportUCINET() {}
+  ~ImportUCINET() override {}
 
-  std::string icon() const {
+  std::string icon() const override {
     return ":/tulip/graphperspective/icons/32/import_ucinet.png";
   }
 
-  vector<node> nodes;
   unsigned int nbNodes;
   string defaultMetric;
-  vector<DoubleProperty*> metrics;
+  vector<DoubleProperty *> metrics;
   // n indicates the number of nodes if the graph is not bipartite
   // if it is, nr indicates the number of nodes in the part 1
   // of the graph, nc the number of nodes in the part 2 of the graph
@@ -259,28 +240,30 @@ public :
   // diagonal_found indicates that the 'diagonal' token has been found
   // labels_known indicates the labels of nodes are known before reading data
   bool dl_found, diagonal, diagonal_found, labels_known, title_found;
-  enum TypeOfLine {DL_HEADER = 0, DL_ROW_LABELS, DL_COL_LABELS,
-                   DL_LABELS, DL_MATRIX_LABELS, DL_DATA
-                  };
+  enum TypeOfLine {
+    DL_HEADER = 0,
+    DL_ROW_LABELS,
+    DL_COL_LABELS,
+    DL_LABELS,
+    DL_MATRIX_LABELS,
+    DL_DATA
+  };
   // indicates what kind of line is expected
   TypeOfLine expectedLine;
-  enum TypeOfLabelEmbedding {DL_NONE = 0, DL_ROWS = 1, DL_COLS = 2, DL_ALL = 4};
+  enum TypeOfLabelEmbedding { DL_NONE = 0, DL_ROWS = 1, DL_COLS = 2, DL_ALL = 4 };
   // indicates what labels are embedded in the data to be read
   unsigned int embedding;
-  enum TypeOfData {DL_FM, DL_UH, DL_LH, DL_NL1, DL_NL2, DL_NL1B, DL_EL1, DL_EL2,
-                   DL_BM
-                  };
+  enum TypeOfData { DL_FM, DL_UH, DL_LH, DL_NL1, DL_NL2, DL_NL1B, DL_EL1, DL_EL2, DL_BM };
   // indicates the current format for the data to be read
   TypeOfData dataFormat;
-  TLP_HASH_MAP<std::string, node> labelToNode, colLabelToNode, rowLabelToNode;
+  std::unordered_map<std::string, node> labelToNode, colLabelToNode, rowLabelToNode;
 
-  bool readHeader(string& str, stringstream& error) {
+  bool readHeader(string &str, stringstream &error) {
     string token;
     string::size_type pos = 0;
     bool result;
 
-    while((result = nextToken(str, " \r\t,=", token, pos))
-          && !token.empty()) {
+    while ((result = nextToken(str, " \r\t,=", token, pos)) && !token.empty()) {
       // check for dl
       if (dl_found == false) {
         if (nocasecmp(token, "dl")) {
@@ -299,9 +282,7 @@ public :
           return false;
         }
 
-        if (!skipEqualSign(str, pos) ||
-            !nextString(str, token, pos) ||
-            token.empty()) {
+        if (!skipEqualSign(str, pos) || !nextString(str, token, pos) || token.empty()) {
           error << "invalid specification for parameter TITLE";
           return false;
         }
@@ -325,7 +306,7 @@ public :
         }
 
         // add nodes
-        graph->addNodes(nbNodes = n, nodes);
+        graph->addNodes(nbNodes = n);
         continue;
       }
 
@@ -344,7 +325,7 @@ public :
 
         if (nc)
           // add nodes
-          graph->addNodes(nbNodes = nc + nr, nodes);
+          graph->addNodes(nbNodes = nc + nr);
 
         continue;
       }
@@ -364,7 +345,7 @@ public :
 
         if (nr)
           // add nodes
-          graph->addNodes(nbNodes = nc + nr, nodes);
+          graph->addNodes(nbNodes = nc + nr);
 
         continue;
       }
@@ -387,34 +368,28 @@ public :
 
       if (nocasecmp(token, "format")) {
         // format found
-        if (!skipEqualSign(str, pos) ||
-            !nextToken(str, " \r\t,", token, pos)
-            || token.empty()) {
+        if (!skipEqualSign(str, pos) || !nextToken(str, " \r\t,", token, pos) || token.empty()) {
           error << "invalid specification for parameter FORMAT";
           return false;
         }
 
         // check dataFormat
-        if (nocasecmp(token, "fullmatrix") ||
-            nocasecmp(token, "fm")) {
+        if (nocasecmp(token, "fullmatrix") || nocasecmp(token, "fm")) {
           dataFormat = DL_FM;
           continue;
         }
 
-        if (nocasecmp(token, "upperhalf") ||
-            nocasecmp(token, "uh")) {
+        if (nocasecmp(token, "upperhalf") || nocasecmp(token, "uh")) {
           dataFormat = DL_UH;
           continue;
         }
 
-        if (nocasecmp(token, "lowerhalf") ||
-            nocasecmp(token, "lh")) {
+        if (nocasecmp(token, "lowerhalf") || nocasecmp(token, "lh")) {
           dataFormat = DL_LH;
           continue;
         }
 
-        if (nocasecmp(token, "nodelist1") ||
-            nocasecmp(token, "nl1")) {
+        if (nocasecmp(token, "nodelist1") || nocasecmp(token, "nl1")) {
           if (nr || nc) {
             error << "specification of parameter FORMAT applies only to 1-mode matrix";
             return false;
@@ -424,14 +399,12 @@ public :
           continue;
         }
 
-        if (nocasecmp(token, "nodelist2") ||
-            nocasecmp(token, "nl2")) {
+        if (nocasecmp(token, "nodelist2") || nocasecmp(token, "nl2")) {
           dataFormat = DL_NL2;
           continue;
         }
 
-        if (nocasecmp(token, "nodelist1b") ||
-            nocasecmp(token, "nl1b")) {
+        if (nocasecmp(token, "nodelist1b") || nocasecmp(token, "nl1b")) {
           if (nr || nc) {
             error << "specification of parameter FORMAT applies only to 1-mode matrix";
             return false;
@@ -441,20 +414,17 @@ public :
           continue;
         }
 
-        if (nocasecmp(token, "edgelist1") ||
-            nocasecmp(token, "el1")) {
+        if (nocasecmp(token, "edgelist1") || nocasecmp(token, "el1")) {
           dataFormat = DL_EL1;
           continue;
         }
 
-        if (nocasecmp(token, "edgelist2") ||
-            nocasecmp(token, "el2")) {
+        if (nocasecmp(token, "edgelist2") || nocasecmp(token, "el2")) {
           dataFormat = DL_EL2;
           continue;
         }
 
-        if (nocasecmp(token, "blockmatrix") ||
-            nocasecmp(token, "bm")) {
+        if (nocasecmp(token, "blockmatrix") || nocasecmp(token, "bm")) {
           dataFormat = DL_BM;
           continue;
         }
@@ -472,16 +442,14 @@ public :
 
         diagonal_found = true;
 
-        if (!nextToken(str, " \r\t,", token, pos)
-            || token.empty()) {
+        if (!nextToken(str, " \r\t,", token, pos) || token.empty()) {
           error << "invalid specification for parameter DIAGONAL";
           return false;
         }
 
         // specification says that DIAGONAL = PRESENT|ABSENT
         // but = may not exist
-        if ((token == "=") && (!nextToken(str, " \r\t,", token, pos)
-                               || token.empty())) {
+        if ((token == "=") && (!nextToken(str, " \r\t,", token, pos) || token.empty())) {
           error << "invalid specification for parameter DIAGONAL";
           return false;
         }
@@ -502,13 +470,12 @@ public :
 
       if (nocasecmp(token, "row")) {
         // 'row' found
-        if (embedding & (unsigned int) DL_ROWS) {
+        if (embedding & uint(DL_ROWS)) {
           error << "invalid specification for parameter ROWS";
           return false;
         }
 
-        if (!nextToken(str, " \r\t,", token, pos)
-            || token.empty())  {
+        if (!nextToken(str, " \r\t,", token, pos) || token.empty()) {
           error << "invalid specification for parameter ROWS";
           return false;
         }
@@ -516,14 +483,13 @@ public :
         // next token must be 'labels'
         if (nocasecmp(token, "labels")) {
           // next token must be 'embedded'
-          if (!nextToken(str, " \r\t,", token, pos)
-              || token.empty()
-              || !nocasecmp(token, "embedded")) {
+          if (!nextToken(str, " \r\t,", token, pos) || token.empty() ||
+              !nocasecmp(token, "embedded")) {
             error << "invalid specification for parameter ROWS";
             return false;
           }
 
-          embedding += (unsigned int) DL_ROWS;
+          embedding += uint(DL_ROWS);
           continue;
         }
 
@@ -543,14 +509,12 @@ public :
         return false;
       }
 
-      if (nocasecmp(token, "col") ||
-          nocasecmp(token, "column")) {
+      if (nocasecmp(token, "col") || nocasecmp(token, "column")) {
         // 'col' or 'column' found
-        if (embedding & (unsigned int) DL_COLS)
+        if (embedding & uint(DL_COLS))
           return false;
 
-        if (!nextToken(str, " \r\t,", token, pos)
-            || token.empty()) {
+        if (!nextToken(str, " \r\t,", token, pos) || token.empty()) {
           error << "invalid specification for parameter COLUMNS";
           return false;
         }
@@ -558,9 +522,8 @@ public :
         // next token must be 'labels'
         if (nocasecmp(token, "labels")) {
           // next token must be 'embedded'
-          if (!nextToken(str, " \r\t,", token, pos)
-              || token.empty()
-              || !nocasecmp(token, "embedded")) {
+          if (!nextToken(str, " \r\t,", token, pos) || token.empty() ||
+              !nocasecmp(token, "embedded")) {
             error << "invalid specification for parameter COLUMNS";
             return false;
           }
@@ -587,8 +550,7 @@ public :
 
       if (nocasecmp(token, "matrix")) {
         // matrix found
-        if (!nextToken(str, " \r\t,", token, pos)
-            || token.empty()) {
+        if (!nextToken(str, " \r\t,", token, pos) || token.empty()) {
           error << "invalid specification for parameter MATRIX";
           return false;
         }
@@ -617,9 +579,8 @@ public :
         }
 
         // next token must be 'embedded'
-        if (!nextToken(str, " \r\t,", token, pos)
-            || token.empty()
-            || !nocasecmp(token, "embedded")) {
+        if (!nextToken(str, " \r\t,", token, pos) || token.empty() ||
+            !nocasecmp(token, "embedded")) {
           error << "invalid specification for parameter LABELS";
           return false;
         }
@@ -651,15 +612,13 @@ public :
         // set default metric
         if (nm == 0) {
           metrics.push_back(graph->getProperty<DoubleProperty>(defaultMetric));
-        }
-        else {
+        } else {
           if (metrics.empty()) {
             // create metrics with default name
             for (unsigned int i = 0; i < nm; ++i) {
               stringstream sstr;
               sstr << defaultMetric << (i + 1);
-              DoubleProperty* metric =
-                graph->getProperty<DoubleProperty>(sstr.str());
+              DoubleProperty *metric = graph->getProperty<DoubleProperty>(sstr.str());
               metrics.push_back(metric);
             }
           }
@@ -677,11 +636,11 @@ public :
     return result;
   }
 
-  bool readLabels(const string& str, stringstream& error,
-                  TLP_HASH_MAP<std::string, node>& labelsHMap,
-                  unsigned int nbLabels, unsigned int offset) {
+  bool readLabels(const string &str, stringstream &error,
+                  std::unordered_map<std::string, node> &labelsHMap, unsigned int nbLabels,
+                  unsigned int offset, const vector<node> &nodes) {
     vector<std::string> labels;
-    StringProperty* label = graph->getProperty<StringProperty>("viewLabel");
+    StringProperty *label = graph->getProperty<StringProperty>("viewLabel");
 
     if (!tokenize(str, labels, " \r\t,"))
       return false;
@@ -696,8 +655,8 @@ public :
       // assign label to each corresponding node
       label->setNodeValue(nodes[offset + current], labels[i]);
       // and memorize the corresponding uppercase label for each node
-      std::transform(labels[i].begin(), labels[i].end(),
-                     labels[i].begin(), (int (*) (int)) std::toupper);
+      std::transform(labels[i].begin(), labels[i].end(), labels[i].begin(),
+                     static_cast<int (*)(int)>(std::toupper));
       labelsHMap[labels[i]] = nodes[offset + current];
     }
 
@@ -708,10 +667,10 @@ public :
     return true;
   }
 
-  void checkColumnLabels(vector<std::string>& tokens, unsigned int &ir,
-                         unsigned int &ic, unsigned int &i) {
-    if (ir == 0 && embedding & (unsigned int) DL_COLS) {
-      StringProperty* label = graph->getProperty<StringProperty>("viewLabel");
+  void checkColumnLabels(vector<std::string> &tokens, unsigned int &ir, unsigned int &ic,
+                         unsigned int &i, const vector<node> &nodes) {
+    if (ir == 0 && embedding & uint(DL_COLS)) {
+      StringProperty *label = graph->getProperty<StringProperty>("viewLabel");
 
       // first nc tokens are for labels of the part 1 of the graph
       for (; ic < nc && i < tokens.size(); ++i, ++ic) {
@@ -720,13 +679,13 @@ public :
 
       if (ic == nc) {
         // all columns labels have been read
-        embedding -= (unsigned int) DL_COLS;
+        embedding -= uint(DL_COLS);
         ic = 0;
       }
     }
   }
 
-  node getNodeFromInfo(string& token, unsigned int& i, bool findCol) {
+  node getNodeFromInfo(string &token, unsigned int &i, bool findCol, const vector<node> &nodes) {
     if (embedding == DL_NONE ||
         (embedding != DL_ALL && !(embedding & (findCol ? DL_COLS : DL_ROWS)))) {
       // token is row index (first is 1)
@@ -739,12 +698,11 @@ public :
     }
 
     string upcasetoken(token);
-    transform(token.begin(), token.end(),
-              upcasetoken.begin(), (int (*) (int)) std::toupper);
+    transform(token.begin(), token.end(), upcasetoken.begin(),
+              static_cast<int (*)(int)>(std::toupper));
 
-    if (n/*embedding == DL_ALL*/) { // 1-mode
-      TLP_HASH_MAP<std::string, node>::iterator it =
-        labelToNode.find(upcasetoken);
+    if (n /*embedding == DL_ALL*/) { // 1-mode
+      std::unordered_map<std::string, node>::iterator it = labelToNode.find(upcasetoken);
 
       if (it != labelToNode.end())
         return (*it).second;
@@ -754,13 +712,12 @@ public :
         return node();
 
       ++i;
-      graph->getProperty<StringProperty>("viewLabel")->setNodeValue(nodes[i -1], token);
+      graph->getProperty<StringProperty>("viewLabel")->setNodeValue(nodes[i - 1], token);
       return labelToNode[upcasetoken] = nodes[i - 1];
     }
 
     if (findCol) {
-      TLP_HASH_MAP<std::string, node>::iterator it =
-        colLabelToNode.find(upcasetoken);
+      std::unordered_map<std::string, node>::iterator it = colLabelToNode.find(upcasetoken);
 
       if (it != colLabelToNode.end())
         return (*it).second;
@@ -770,12 +727,10 @@ public :
         return node();
 
       ++i;
-      graph->getProperty<StringProperty>("viewLabel")->setNodeValue(nodes[i -1], token);
+      graph->getProperty<StringProperty>("viewLabel")->setNodeValue(nodes[i - 1], token);
       return colLabelToNode[upcasetoken] = nodes[i - 1];
-    }
-    else {
-      TLP_HASH_MAP<std::string, node>::iterator it =
-        rowLabelToNode.find(upcasetoken);
+    } else {
+      std::unordered_map<std::string, node>::iterator it = rowLabelToNode.find(upcasetoken);
 
       if (it != rowLabelToNode.end())
         return (*it).second;
@@ -785,24 +740,22 @@ public :
         return node();
 
       ++i;
-      graph->getProperty<StringProperty>("viewLabel")->setNodeValue(nodes[nc + i -1], token);
+      graph->getProperty<StringProperty>("viewLabel")->setNodeValue(nodes[nc + i - 1], token);
       return rowLabelToNode[upcasetoken] = nodes[nc + i - 1];
     }
   }
 
-  bool readData(vector<std::string>& tokens,
-                stringstream& error,
-                unsigned int &ir, unsigned int &ic,
-                DoubleProperty* metric) {
+  bool readData(vector<std::string> &tokens, stringstream &error, unsigned int &ir,
+                unsigned int &ic, DoubleProperty *metric, const vector<node> &nodes) {
     // index of current token
     unsigned int i = 0;
 
-    switch(dataFormat) {
+    switch (dataFormat) {
     case DL_FM:
     case DL_LH:
     case DL_UH: {
       // check if column labels are in first line
-      checkColumnLabels(tokens, ir, ic, i);
+      checkColumnLabels(tokens, ir, ic, i, nodes);
 
       // read row data
       for (; i < tokens.size(); ++i) {
@@ -835,8 +788,7 @@ public :
           if (dataFormat == DL_LH) {
             ir = 1;
             src = nodes[nc + 1];
-          }
-          else {
+          } else {
             if (ir == 0 && nc == 1) {
               // nothing to read in this row
               ++ir, current = 0;
@@ -856,7 +808,7 @@ public :
             metric->setEdgeValue(e, value);
 
             if (dataFormat != DL_FM) {
-              // matrix is symetric
+              // matrix is symmetric
               e = graph->addEdge(nodes[ic], src);
               metric->setEdgeValue(e, value);
             }
@@ -882,8 +834,7 @@ public :
     case DL_NL1:
     case DL_NL2: {
       // first token indicates the source
-      node src = getNodeFromInfo(tokens[0],
-                                 dataFormat == DL_NL1 ? ic : ir, false);
+      node src = getNodeFromInfo(tokens[0], dataFormat == DL_NL1 ? ic : ir, false, nodes);
 
       if (!src.isValid()) {
         error << "invalid row";
@@ -892,7 +843,7 @@ public :
 
       // read row data
       for (i = 1; i < tokens.size(); ++i) {
-        node tgt = getNodeFromInfo(tokens[i], ic, true);
+        node tgt = getNodeFromInfo(tokens[i], ic, true, nodes);
 
         if (!tgt.isValid()) {
           error << "invalid column";
@@ -947,15 +898,14 @@ public :
       }
 
       // first two token indicates the source and target of the edge
-      node src = getNodeFromInfo(tokens[0],
-                                 (dataFormat == DL_EL1) ? ic : ir, false);
+      node src = getNodeFromInfo(tokens[0], (dataFormat == DL_EL1) ? ic : ir, false, nodes);
 
       if (!src.isValid()) {
         error << "invalid row";
         return false;
       }
 
-      node tgt = getNodeFromInfo(tokens[1], ic, true);
+      node tgt = getNodeFromInfo(tokens[1], ic, true, nodes);
       edge e = graph->addEdge(src, tgt);
       double value = 1.0;
 
@@ -975,7 +925,7 @@ public :
     return false;
   }
 
-  bool importGraph() {
+  bool importGraph() override {
     string filename;
 
     dataSet->get<string>("file::filename", filename);
@@ -995,12 +945,13 @@ public :
       pluginProgress->showPreview(false);
 
     // the current metric
-    DoubleProperty* metric = NULL;
+    DoubleProperty *metric = nullptr;
 
     // index of row, column and metric when reading data
     unsigned int ic, ir, im;
     ic = ir = im = 0;
 
+    const std::vector<node> &nodes = graph->nodes();
     std::string line;
 
     while (!in->eof() && std::getline(*in, line)) {
@@ -1008,23 +959,22 @@ public :
 
       ++lineNumber;
 
-      switch(expectedLine) {
+      switch (expectedLine) {
       case DL_HEADER:
         result = readHeader(line, errors);
         break;
 
       case DL_ROW_LABELS:
-        result = readLabels(line, errors, rowLabelToNode,
-                            nr ? nr : n, nc);
+        result = readLabels(line, errors, rowLabelToNode, nr ? nr : n, nc, nodes);
         break;
 
       case DL_COL_LABELS:
-        result = readLabels(line, errors, colLabelToNode, nc ? nc : n, 0);
+        result = readLabels(line, errors, colLabelToNode, nc ? nc : n, 0, nodes);
         break;
 
       case DL_LABELS:
         labels_known = true;
-        result = readLabels(line, errors, labelToNode, nbNodes, 0);
+        result = readLabels(line, errors, labelToNode, nbNodes, 0, nodes);
         break;
 
       case DL_MATRIX_LABELS: {
@@ -1057,8 +1007,7 @@ public :
               return false;
 
             metric = metrics[im];
-          }
-          else
+          } else
             // default
             metric = metrics[0];
         }
@@ -1075,13 +1024,13 @@ public :
         // check for line separation between matrices
         // if dataFormat == DL_EL1 | DL_EL2
         // ! indicates a new matrix
-        if ((tokens.size() == 1) && (tokens[0] == "!") && (nm > 1) &&
-            (im < nm) && ((dataFormat == DL_EL1) || (dataFormat == DL_EL2))) {
+        if ((tokens.size() == 1) && (tokens[0] == "!") && (nm > 1) && (im < nm) &&
+            ((dataFormat == DL_EL1) || (dataFormat == DL_EL2))) {
           ++im;
           break;
         }
 
-        result = readData(tokens, errors, ir, ic, metric);
+        result = readData(tokens, errors, ir, ic, metric, nodes);
 
         // check for new matrix
         if (result && (nm > 1) && (ir == (nr ? nr : nbNodes))) {
