@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,6 +21,7 @@
 #include <qtimer.h>
 #include <tulip/TulipPluginHeaders.h>
 #include <tulip/DownloadManager.h>
+#include <tulip/TlpQtTools.h>
 #include "WebImport.h"
 
 using namespace std;
@@ -28,7 +29,7 @@ using namespace tlp;
 
 class UrlElement {
 public:
-  bool is_http;
+  std::string http_prefix;
   std::string data;
   std::string server;
   std::string url;
@@ -36,19 +37,22 @@ public:
 
   UrlElement();
   UrlElement(const UrlElement &c);
+  UrlElement &operator=(const UrlElement &) = default;
   bool load();
   void clear();
   bool isHtmlPage();
+  bool is_http() const {
+    return !http_prefix.empty();
+  }
   UrlElement parseUrl(const std::string &href);
-  void setUrl(const std::string&);
+  void setUrl(const std::string &);
   std::string getUrl() const {
     return clean_url.size() ? clean_url : url;
   }
 
 private:
   void fill(std::string &result);
-  bool siteconnect(const std::string &server, const std::string &url,
-                   bool headonly);
+  bool siteconnect(const std::string &server, const std::string &url, bool headonly);
 
 private:
   HttpContext *context;
@@ -74,43 +78,35 @@ namespace std {
 template <>
 struct less<UrlElement> {
   bool operator()(const UrlElement &lhs, const UrlElement &rhs) const {
-    if (lhs.server.compare(rhs.server) < 0 ) return true;
+    if (lhs.server.compare(rhs.server) < 0)
+      return true;
 
-    if (lhs.server.compare(rhs.server) > 0 ) return false;
+    if (lhs.server.compare(rhs.server) > 0)
+      return false;
 
     return lhs.getUrl().compare(rhs.getUrl()) < 0;
   }
 };
-}
+} // namespace std
 
-HttpContext::HttpContext():
-  status(false), code(-1), reply(NULL),
-  processed(false), redirected(false), isHtml(false) {
-}
+HttpContext::HttpContext()
+    : status(false), code(-1), reply(nullptr), processed(false), redirected(false), isHtml(false) {}
 
 HttpContext::~HttpContext() {
-  if (reply)  {
+  if (reply) {
     reply->close();
     reply->deleteLater();
-    reply = NULL;
   }
 }
 
-void HttpContext::request(const std::string& url, bool head) {
-  if (reply)  {
-    reply->close();
-    reply->deleteLater();
-    reply = NULL;
-  }
-
+void HttpContext::request(const std::string &url, bool head) {
   processed = isHtml = redirected = false;
   QNetworkRequest request(QUrl(url.c_str()));
 
   if (head) {
     reply = DownloadManager::getInstance()->head(request);
     connect(reply, SIGNAL(finished()), this, SLOT(headerReceived()));
-  }
-  else {
+  } else {
     reply = DownloadManager::getInstance()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(finished()));
   }
@@ -118,7 +114,7 @@ void HttpContext::request(const std::string& url, bool head) {
 
 void HttpContext::finished() {
   // check to see if it is the request we made
-  if (reply != qobject_cast<QNetworkReply*>(sender()))
+  if (reply != qobject_cast<QNetworkReply *>(sender()))
     return;
 
   // OK
@@ -127,11 +123,15 @@ void HttpContext::finished() {
   // set status of the request
   if ((status = (reply->error() == QNetworkReply::NoError)))
     data = reply->readAll().data();
+
+  reply->close();
+  reply->deleteLater();
+  reply = nullptr;
 }
 
 void HttpContext::headerReceived() {
   // check to see if it is the request we made
-  if (reply != qobject_cast<QNetworkReply*>(sender()))
+  if (reply != qobject_cast<QNetworkReply *>(sender()))
     return;
 
   processed = true;
@@ -144,16 +144,19 @@ void HttpContext::headerReceived() {
 
       if (code > 399) /* error codes */
         isHtml = false;
-      else if ((code > 299) &&
-               (code < 305 || code == 307)) {
+      else if ((code > 299) && (code < 305 || code == 307)) {
         /* redirection codes */
         redirected = true;
         QVariant redirectionTarget = reply->attribute(QNetworkRequest::RedirectionTargetAttribute);
 
         if (!redirectionTarget.isNull())
-          data = redirectionTarget.toUrl().toString().toStdString();
+          data = QStringToTlpString(redirectionTarget.toUrl().toString());
         else
           data = "";
+
+        reply->close();
+        reply->deleteLater();
+        reply = nullptr;
       }
 
       return;
@@ -161,9 +164,11 @@ void HttpContext::headerReceived() {
 
     /* normal codes */
     value = reply->header(QNetworkRequest::ContentTypeHeader);
-    status = isHtml = (value.canConvert<QString>() &&
-                       value.toString().contains(QString("text/html")));
+    status = isHtml =
+        (value.canConvert<QString>() && value.toString().contains(QString("text/html")));
     reply->close();
+    reply->deleteLater();
+    reply = nullptr;
   }
 }
 
@@ -180,14 +185,12 @@ void HttpContext::setTimer(QTimer *timer) {
   connect(timer, SIGNAL(timeout()), SLOT(timeout()));
 }
 
-UrlElement::UrlElement():is_http(true),data(""),context(0)  {
-}
-UrlElement::UrlElement(const UrlElement &c):
-  is_http(c.is_http),
-  data(""),server(c.server),url(c.url),clean_url(c.clean_url),context(NULL) {
-}
+UrlElement::UrlElement() : http_prefix("http://"), data(""), context(nullptr) {}
+UrlElement::UrlElement(const UrlElement &c)
+    : http_prefix(c.http_prefix), data(""), server(c.server), url(c.url), clean_url(c.clean_url),
+      context(nullptr) {}
 
-void UrlElement::setUrl(const std::string& theUrl) {
+void UrlElement::setUrl(const std::string &theUrl) {
   url = theUrl;
   size_t len = theUrl.find_first_of("?", 0);
 
@@ -204,25 +207,23 @@ void UrlElement::fill(std::string &result) {
 void UrlElement::clear() {
   if (context) {
     delete context;
-    context = NULL;
+    context = nullptr;
   }
 
   data = "";
 }
 
-
 bool UrlElement::load() {
-  if (!siteconnect(server,url,false))
+  if (!siteconnect(server, url, false))
     return false;
 
   fill(data);
   return true;
 }
 
-static const char* not_html_extensions[] = {
-  ".bmp", ".css", ".doc", ".ico", ".exe", ".gif", ".gz", ".js", ".jpeg", ".jpg",
-  ".pdf", ".png", ".ps", ".rss", ".tar", ".tgz", ".wav", ".zip", ".z",
-  0 /* must be the last */
+static const char *not_html_extensions[] = {
+    ".bmp", ".css", ".doc", ".ico", ".exe", ".gif", ".gz",  ".js", ".jpeg", ".jpg", ".pdf",
+    ".png", ".ps",  ".rss", ".tar", ".tgz", ".wav", ".zip", ".z",  nullptr /* must be the last */
 };
 
 bool UrlElement::isHtmlPage() {
@@ -236,16 +237,16 @@ bool UrlElement::isHtmlPage() {
     if (lowercase.rfind(not_html_extensions[i], len) != string::npos)
       return false;
 
-  if(!siteconnect(server,url,true))
+  if (!siteconnect(server, url, true))
     return false;
 
   return context->isHtml;
 }
 
-bool UrlElement::siteconnect(const std::string &server, const std::string &path,
-                             bool headonly) {
+bool UrlElement::siteconnect(const std::string &server, const std::string &path, bool headonly) {
   // check that we actually got data..
-  if (server.empty()) return false;
+  if (server.empty())
+    return false;
 
   if (!context)
     context = new HttpContext();
@@ -271,7 +272,7 @@ bool UrlElement::siteconnect(const std::string &server, const std::string &path,
   context->setTimer(&timer);
   timer.start(20000);
 
-  while(!context->processed) {
+  while (!context->processed) {
     QCoreApplication::processEvents();
   }
 
@@ -279,12 +280,11 @@ bool UrlElement::siteconnect(const std::string &server, const std::string &path,
   return context->status && context->code < 400;
 } /* end, siteconnect */
 
-static const char * rejected_protocols[] = {
-  "https:", "ftp:", "gopher:", "sftp:", "javascript:", "mms:", "mailto:",
-  0 /* must be the last */
+static const char *rejected_protocols[] = {
+    "ftp:", "gopher:", "sftp:", "javascript:", "mms:", "mailto:", nullptr /* must be the last */
 };
 
-UrlElement UrlElement::parseUrl (const std::string &href) {
+UrlElement UrlElement::parseUrl(const std::string &href) {
   UrlElement newUrl;
   string lowercase(href);
   size_t i, len = lowercase.length();
@@ -292,13 +292,13 @@ UrlElement UrlElement::parseUrl (const std::string &href) {
   for (i = 0; i < len; ++i)
     lowercase[i] = tolower(lowercase[i]);
 
-  for (i = 0; rejected_protocols[i] != 0; i++) {
+  for (i = 0; rejected_protocols[i] != nullptr; i++) {
     if (lowercase.find(rejected_protocols[i]) != string::npos)
       break;
   }
 
   if (rejected_protocols[i]) {
-    newUrl.is_http = false;
+    newUrl.http_prefix.clear();
 
     if (i != 3 /* no javascript */)
       newUrl.server = href;
@@ -306,48 +306,50 @@ UrlElement UrlElement::parseUrl (const std::string &href) {
     return newUrl;
   }
 
-  size_t pos=0;
+  size_t pos = 0;
   bool host = false;
-  pos = lowercase.rfind("http://", len);
+  pos = lowercase.rfind("://", len);
 
   if (pos == string::npos)
-    pos=0;
+    pos = 0;
   else {
-    host=true;
-    pos+=7;
+    host = true;
+
+    if (lowercase[pos - 1] == 's')
+      newUrl.http_prefix = "https://";
+
+    pos += 3;
   }
 
   if (host) {
-    size_t endhost = lowercase.find_first_of("/ ",pos);
+    size_t endhost = lowercase.find_first_of("/ ", pos);
 
     if (endhost == string::npos)
-      endhost=len;
+      endhost = len;
 
-    string hostname = href.substr(pos,endhost-pos);
+    string hostname = href.substr(pos, endhost - pos);
     newUrl.server = hostname;
     newUrl.setUrl(href.substr(endhost));
-  }
-  else {
-    size_t querystart = lowercase.find_first_of("#",pos); /* previously ?#  instead of # */
+  } else {
+    size_t querystart = lowercase.find_first_of("#", pos); /* previously ?#  instead of # */
 
     if (querystart != string::npos)
       len = querystart;
 
-    string theUrl = href.substr(pos,len-pos);
+    string theUrl = href.substr(pos, len - pos);
 
     if (theUrl.empty())
       return newUrl;
 
-    //Manage relative urls
-    if (theUrl[0]!='/') {
+    // Manage relative urls
+    if (theUrl[0] != '/') {
       string urlreference(this->url);
       size_t findUp = urlreference.rfind("/", urlreference.length());
 
-      if (findUp==string::npos) {
+      if (findUp == string::npos) {
         urlreference.clear();
         urlreference.append(1, '/');
-      }
-      else
+      } else
         urlreference = urlreference.substr(0, findUp + 1);
 
       size_t pos;
@@ -373,14 +375,13 @@ UrlElement UrlElement::parseUrl (const std::string &href) {
           theUrl = theUrl.substr(3);
           findUp = urlreference.rfind('/', findUp - 1);
 
-          if (findUp==string::npos) {
+          if (findUp == string::npos) {
             tlp::warning() << "bad url reference, to much ../" << endl;
             return newUrl;
           }
 
           urlreference = urlreference.substr(0, findUp + 1);
-        }
-        else {
+        } else {
           tlp::warning() << "bad url reference, to much ../" << endl;
           return newUrl;
         }
@@ -398,77 +399,40 @@ UrlElement UrlElement::parseUrl (const std::string &href) {
   return newUrl;
 }
 
+static const char *paramHelp[] = {
+    // server
+    "This parameter defines the web server that you want to inspect. No need for http:// at the "
+    "beginning; http protocol is always assumed. No need for / at the end.",
 
-namespace {
-const char * paramHelp[] = {
-  // server
-  HTML_HELP_OPEN() \
-  HTML_HELP_DEF( "type", "string" ) \
-  HTML_HELP_DEF( "default", "www.labri.fr" ) \
-  HTML_HELP_BODY() \
-  "This parameter defines the web server that you want to inspect. No need for http:// at the beginning; http protocol is always assumed. No need for / at the end." \
-  HTML_HELP_CLOSE(),
-  // initial page
-  HTML_HELP_OPEN() \
-  HTML_HELP_DEF( "type", "string" ) \
-  HTML_HELP_DEF( "default", "" ) \
-  HTML_HELP_BODY() \
-  "This parameter defines the first web page to visit. No need for / at the beginning."\
-  HTML_HELP_CLOSE(),
-  // max number of links
-  HTML_HELP_OPEN() \
-  HTML_HELP_DEF( "type", "unsigned int" ) \
-  HTML_HELP_DEF( "default", "1000" ) \
-  HTML_HELP_BODY() \
-  "This parameter defines the maximum number of nodes (different pages) allowed in the extracted graph." \
-  HTML_HELP_CLOSE(),
-  // non http links
-  HTML_HELP_OPEN() \
-  HTML_HELP_DEF( "type", "boolean" ) \
-  HTML_HELP_DEF( "default", "true" ) \
-  HTML_HELP_BODY() \
-  "This parameter indicates if non http links (https, ftp, mailto...) have to be extracted." \
-  HTML_HELP_CLOSE(),
-  // other server
-  HTML_HELP_OPEN() \
-  HTML_HELP_DEF( "type", "boolean" ) \
-  HTML_HELP_DEF( "default", "false" ) \
-  HTML_HELP_BODY() \
-  "This parameter indicates if links or redirection to other server pages have to be followed." \
-  HTML_HELP_CLOSE(),
-  // compute layout
-  HTML_HELP_OPEN() \
-  HTML_HELP_DEF( "type", "boolean" ) \
-  HTML_HELP_DEF( "default", "true" ) \
-  HTML_HELP_BODY() \
-  "This parameter indicates if a layout of the extracted graph has to be computed." \
-  HTML_HELP_CLOSE(),
-  // page color
-  HTML_HELP_OPEN() \
-  HTML_HELP_DEF( "type", "color" ) \
-  HTML_HELP_DEF( "default", "red" ) \
-  HTML_HELP_BODY() \
-  "This parameter indicated the color used to display nodes." \
-  HTML_HELP_CLOSE(),
-  // link color
-  HTML_HELP_OPEN() \
-  HTML_HELP_DEF( "type", "color" ) \
-  HTML_HELP_DEF( "default", "blue" ) \
-  HTML_HELP_BODY() \
-  "This parameter indicated the color used to display links." \
-  HTML_HELP_CLOSE(),
-  // link color
-  HTML_HELP_OPEN() \
-  HTML_HELP_DEF( "type", "color" ) \
-  HTML_HELP_DEF( "default", "yellow" ) \
-  HTML_HELP_BODY() \
-  "This parameter indicated the color used to display redirections." \
-  HTML_HELP_CLOSE()
-};
-}
+    // initial page
+    "This parameter defines the first web page to visit. No need for / at the beginning.",
 
-struct WebImport:public ImportModule {
-  PLUGININFORMATION("Web Site","Auber","15/11/2004","Imports a new graph from Web site structure (one node per page).","1.0","Misc")
+    // max number of links
+    "This parameter defines the maximum number of nodes (different pages) allowed in the extracted "
+    "graph.",
+
+    // non http links
+    "This parameter indicates if non http links (https, ftp, mailto...) have to be extracted.",
+
+    // other server
+    "This parameter indicates if links or redirection to other server pages have to be followed.",
+
+    // compute layout
+    "This parameter indicates if a layout of the extracted graph has to be computed.",
+
+    // page color
+    "This parameter indicates the color used to display nodes.",
+
+    // link color
+    "This parameter indicates the color used to display links.",
+
+    // link color
+    "This parameter indicates the color used to display redirections."};
+
+struct WebImport : public ImportModule {
+  PLUGININFORMATION("Web Site", "Auber", "15/11/2004",
+                    "Imports a new graph from Web site structure (one node per page).", "1.1",
+                    "Misc")
 
   std::deque<UrlElement> toVisit;
   std::set<UrlElement> visited;
@@ -477,24 +441,26 @@ struct WebImport:public ImportModule {
   tlp::StringProperty *urls;
   tlp::ColorProperty *colors;
   tlp::Color *redirectionColor;
-  unsigned int maxSize, nbNodes;
+  unsigned int maxSize;
   bool visitOther;
   bool extractNonHttp;
 
-  WebImport(tlp::PluginContext* context):ImportModule(context),labels(NULL), urls(NULL), colors(NULL), redirectionColor(NULL), maxSize(1000), nbNodes(0), visitOther(false), extractNonHttp(true) {
-    addInParameter<string>("server",paramHelp[0],"www.labri.fr");
-    addInParameter<string>("web page",paramHelp[1], "");
-    addInParameter<int>("max size",paramHelp[2], "1000");
-    addInParameter<bool>("non http links",paramHelp[3], "false");
-    addInParameter<bool>("other server",paramHelp[4], "false");
-    addInParameter<bool>("compute layout",paramHelp[5], "true");
-    addInParameter<Color>("page color",paramHelp[6],"(240, 0, 120, 128)");
-    addInParameter<Color>("link color",paramHelp[7],"(96,96,191,128)");
-    addInParameter<Color>("redirection color",paramHelp[8],"(191,175,96,128)");
+  WebImport(tlp::PluginContext *context)
+      : ImportModule(context), labels(nullptr), urls(nullptr), colors(nullptr),
+        redirectionColor(nullptr), maxSize(1000), visitOther(false), extractNonHttp(true) {
+    addInParameter<string>("server", paramHelp[0], "www.labri.fr");
+    addInParameter<string>("web page", paramHelp[1], "");
+    addInParameter<int>("max size", paramHelp[2], "1000");
+    addInParameter<bool>("non http links", paramHelp[3], "false");
+    addInParameter<bool>("other server", paramHelp[4], "false");
+    addInParameter<bool>("compute layout", paramHelp[5], "true");
+    addInParameter<Color>("page color", paramHelp[6], "(240, 0, 120, 128)");
+    addInParameter<Color>("link color", paramHelp[7], "(96,96,191,128)");
+    addInParameter<Color>("redirection color", paramHelp[8], "(191,175,96,128)");
     addDependency("FM^3 (OGDF)", "1.2");
   }
 
-  string urlDecode(const string& url) {
+  string urlDecode(const string &url) {
     string buffer = "";
     int len = url.length();
 
@@ -521,13 +487,11 @@ struct WebImport:public ImportModule {
             chnum += ch - 'A';
           else
             chnum += ch - 'a';
-        }
-        else
+        } else
           chnum += ch - '0';
 
         buffer += chnum;
-      }
-      else {
+      } else {
         buffer += ch;
       }
     }
@@ -536,16 +500,15 @@ struct WebImport:public ImportModule {
   }
 
   //========================================================
-  bool addNode(const UrlElement &url, node& n) {
-    if (nodes.find(url)==nodes.end()) {
+  bool addNode(const UrlElement &url, node &n) {
+    if (nodes.find(url) == nodes.end()) {
       // no more added node after maxSize
-      if (nbNodes == maxSize) {
+      if (graph->numberOfNodes() == maxSize) {
         n = node();
         return false;
       }
 
-      n=graph->addNode();
-      ++nbNodes;
+      n = graph->addNode();
       stringstream str;
       str << url.server;
 
@@ -556,12 +519,12 @@ struct WebImport:public ImportModule {
       labels->setNodeValue(n, urlDecode(str.str()));
       ostringstream oss;
 
-      if(url.is_http) {
-        oss<<"http://";
+      if (url.is_http()) {
+        oss << url.http_prefix.c_str();
       }
 
       oss << str.str();
-      urls->setNodeValue(n,oss.str());
+      urls->setNodeValue(n, oss.str());
       nodes[url] = n;
       return true;
     }
@@ -571,13 +534,13 @@ struct WebImport:public ImportModule {
   }
 
   //========================================================
-  bool addEdge(const UrlElement &source, const UrlElement &target,
-               const char* type, const Color *color) {
-    node sNode,tNode;
+  bool addEdge(const UrlElement &source, const UrlElement &target, const char *type,
+               const Color *color) {
+    node sNode, tNode;
     bool sAdded = addNode(source, sNode);
     bool tAdded = addNode(target, tNode);
 
-    // if new nodes can node be added (nbNodes > maxSize)
+    // if new nodes can not be added (numberOfNodes() == maxSize)
     // stop adding edge
     if (!sNode.isValid() || !tNode.isValid())
       return false;
@@ -595,13 +558,13 @@ struct WebImport:public ImportModule {
     return true;
   }
   //========================================================
-  bool nextUrl(UrlElement & url) {
-    //tlp::warning() << __PRETTY_FUNCTION__ << endl;
-    while(!toVisit.empty()) {
+  bool nextUrl(UrlElement &url) {
+    // tlp::warning() << __PRETTY_FUNCTION__ << endl;
+    while (!toVisit.empty()) {
       url = toVisit.front();
       toVisit.pop_front();
 
-      if (visited.find(url)==visited.end()) {
+      if (visited.find(url) == visited.end()) {
         visited.insert(url);
         return true;
       }
@@ -610,15 +573,14 @@ struct WebImport:public ImportModule {
     return false;
   }
   //========================================================
-  void findAndTreatUrls(const string&lowercase,
-                        const string&balise, UrlElement &url) {
+  void findAndTreatUrls(const string &lowercase, const string &balise, UrlElement &url) {
     size_t llen = lowercase.length();
     size_t len = llen;
 
-    while ( len != string::npos ) {
+    while (len != string::npos) {
       len = lowercase.rfind(balise, len);
 
-      if( len != string::npos ) {
+      if (len != string::npos) {
         bool urlFound = true;
         // find the next '=' then the first '"'
         size_t start = len + balise.length();
@@ -626,15 +588,16 @@ struct WebImport:public ImportModule {
         char c = '=';
 
         for (; start < llen; start++) {
-          if (lowercase[start] == c) {
+          if (lowercase[start] == c || ((c == '"') && lowercase[start] == '\'')) {
             // found =
             if (c == '=') {
               // now looking for "
               c = '"';
               continue;
-            }
-            else
+            } else {
+              c = lowercase[start];
               break;
+            }
           }
 
           // only space chars allowed between balise and '='
@@ -651,7 +614,7 @@ struct WebImport:public ImportModule {
 
           // find the end of the string
           for (; end < llen; end++) {
-            if (lowercase[end] == '"')
+            if (lowercase[end] == c)
               break;
           }
 
@@ -665,32 +628,33 @@ struct WebImport:public ImportModule {
   }
   //========================================================
   // parsehtml - parse the given html and add to queue
-  void parseHtml (UrlElement &url) {
-    //tlp::warning() << __PRETTY_FUNCTION__ << endl << flush;
-    if (url.data.empty()) return;
+  void parseHtml(UrlElement &url) {
+    // tlp::warning() << __PRETTY_FUNCTION__ << endl << flush;
+    if (url.data.empty())
+      return;
 
     string lowercase(url.data);
 
-    for (size_t i = 0; i< lowercase.length(); ++i)
+    for (size_t i = 0; i < lowercase.length(); ++i)
       lowercase[i] = tolower(lowercase[i]);
 
-    findAndTreatUrls(lowercase," href",url);
-    findAndTreatUrls(lowercase," src",url);
+    findAndTreatUrls(lowercase, " href", url);
+    findAndTreatUrls(lowercase, " src", url);
   }
   //========================================================
-  void addUrl (const UrlElement &url, bool _toVisit) {
-    if (visited.find(url)!=visited.end())
+  void addUrl(const UrlElement &url, bool _toVisit) {
+    if (visited.find(url) != visited.end())
       return;
 
-    if (_toVisit && url.is_http)
+    if (_toVisit && url.is_http())
       toVisit.push_back(url);
   }
   //========================================================
-  void parseUrl (const string &href, UrlElement &starturl) {
+  void parseUrl(const string &href, UrlElement &starturl) {
     UrlElement newUrl = starturl.parseUrl(href);
 
-    if (newUrl.isValid() && (extractNonHttp || newUrl.is_http) &&
-        addEdge(starturl, newUrl, 0, 0))
+    if (newUrl.isValid() && (extractNonHttp || newUrl.is_http()) &&
+        addEdge(starturl, newUrl, nullptr, nullptr))
       addUrl(newUrl, visitOther || (newUrl.server == starturl.server));
   }
   //========================================================
@@ -700,16 +664,17 @@ struct WebImport:public ImportModule {
 
     while (nextUrl(url)) {
       if (url.isHtmlPage()) {
-        if (pluginProgress && ((nbNodes % step) == 0)) {
-          pluginProgress->setComment(string("Visiting ") +
-                                     urlDecode(url.server + url.url));
+        unsigned int nbNodes = graph->numberOfNodes();
 
-          if (pluginProgress->progress(nbNodes, maxSize) !=TLP_CONTINUE)
-            return pluginProgress->state()!= TLP_CANCEL;
+        if (pluginProgress && ((nbNodes % step) == 0)) {
+          pluginProgress->setComment(string("Visiting ") + urlDecode(url.server + url.url));
+
+          if (pluginProgress->progress(nbNodes, maxSize) != TLP_CONTINUE)
+            return pluginProgress->state() != TLP_CANCEL;
         }
 
 #ifndef NDEBUG
-        tlp::warning() << "Visiting: " << url.server << url.url << " ..."  << std::endl << flush;
+        tlp::warning() << "Visiting: " << url.server << url.url << " ..." << std::endl << flush;
 #endif
 
         if (url.isRedirected()) {
@@ -717,17 +682,15 @@ struct WebImport:public ImportModule {
 
           if (redirection.isValid()) {
 #ifndef NDEBUG
-            tlp::warning() << endl << "redirected to " << redirection.server << redirection.url << endl;
+            tlp::warning() << endl
+                           << "redirected to " << redirection.server << redirection.url << endl;
 #endif
 
-            if (addEdge(url, redirection,  "redirection", redirectionColor))
-              addUrl(redirection,
-                     visitOther || redirection.server == url.server);
-          }
-          else
+            if (addEdge(url, redirection, "redirection", redirectionColor))
+              addUrl(redirection, visitOther || redirection.server == url.server);
+          } else
             tlp::warning() << endl << "invalid redirection" << endl;
-        }
-        else {
+        } else {
           url.load();
           parseHtml(url);
           url.clear();
@@ -739,7 +702,7 @@ struct WebImport:public ImportModule {
 
 #ifndef NDEBUG
       else
-        tlp::warning() << "Omitting : " << url.server << url.url << " ==> [not html]"<< endl;
+        tlp::warning() << "Omitting : " << url.server << url.url << " ==> [not html]" << endl;
 
 #endif
     }
@@ -747,20 +710,18 @@ struct WebImport:public ImportModule {
     return true;
   }
 
-
-  bool importGraph() {
+  bool importGraph() override {
     string server = "www.labri.fr";
     string url;
     bool computelayout = true;
-    Color pColor(255,0,0);
-    Color lColor(0,0,255,128);
-    Color rColor(255,255,0,128);
+    Color pColor(255, 0, 0);
+    Color lColor(0, 0, 255, 128);
+    Color rColor(255, 255, 0, 128);
     maxSize = 1000;
-    nbNodes = 0;
     visitOther = false;
     extractNonHttp = true;
 
-    if (dataSet != NULL) {
+    if (dataSet != nullptr) {
       dataSet->get("server", server);
       dataSet->get("web page", url);
       dataSet->get("max size", maxSize);
@@ -805,12 +766,13 @@ struct WebImport:public ImportModule {
     redirectionColor = &rColor;
 
     graph->getProperty<IntegerProperty>("viewShape")
-    ->setAllNodeValue(14); // GlyphManager::getInst().glyphId("2D - Circle")
+        ->setAllNodeValue(14); // GlyphManager::glyphId("2D - Circle")
 
     if (!mySite.load()) {
       if (pluginProgress) {
         stringstream sstr;
-        sstr << "Unable to access http://" << mySite.server << mySite.url << " (ERROR " << mySite.getCode() << ')';
+        sstr << "Unable to access http://" << mySite.server << mySite.url << " (ERROR "
+             << mySite.getCode() << ')';
         pluginProgress->setError(sstr.str());
       }
 
@@ -833,14 +795,12 @@ struct WebImport:public ImportModule {
       pluginProgress->setComment("Layouting extracted graph using FM³...");
       string errMsg;
       // apply FM³
-      DataSet tmp;
       LayoutProperty *layout = graph->getProperty<LayoutProperty>("viewLayout");
-      return graph->applyPropertyAlgorithm("FM^3 (OGDF)", layout, errMsg, pluginProgress, &tmp);
+      return graph->applyPropertyAlgorithm("FM^3 (OGDF)", layout, errMsg, nullptr, pluginProgress);
     }
 
     return true;
   }
 };
 
-
 PLUGIN(WebImport)
