@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -23,21 +23,21 @@
 
 #include <string>
 
-class HttpContext :public QObject {
+class HttpContext : public QObject {
   Q_OBJECT
 public:
   bool status;
   int code;
-  QNetworkReply* reply;
+  QNetworkReply *reply;
   bool processed;
   bool redirected;
   bool isHtml;
   std::string data;
 
   HttpContext();
-  ~HttpContext();
+  ~HttpContext() override;
   void setTimer(QTimer *timer);
-  void request(const std::string& url, bool header = false);
+  void request(const std::string &url, bool header = false);
 
 public slots:
   void finished();
