@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -30,12 +30,11 @@ namespace tlp {
 
 class FishEyeConfigWidget : public QWidget {
 
-  Ui::FishEyeConfigWidget* _ui;
+  Ui::FishEyeConfigWidget *_ui;
 
-public :
-
-  FishEyeConfigWidget(QWidget *parent = NULL);
-  ~FishEyeConfigWidget();
+public:
+  FishEyeConfigWidget(QWidget *parent = nullptr);
+  ~FishEyeConfigWidget() override;
 
   int getFishEyeType() const;
 
@@ -47,7 +46,6 @@ public :
 
   float getFishEyeRadiusIncrementStep() const;
   float getFishEyeHeightIncrementStep() const;
-
 };
-}
+} // namespace tlp
 #endif /* FISHEYECONFIGWIDGET_H_ */
