@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -28,7 +28,6 @@
 #include <tulip/MouseInteractors.h>
 #include <tulip/GlMainWidget.h>
 #include <tulip/GlMainView.h>
-#include <tulip/ForEach.h>
 #include <tulip/GlCircle.h>
 #include <tulip/OcclusionTest.h>
 #include <tulip/GlBoundingBoxSceneVisitor.h>
@@ -43,7 +42,7 @@
 #include <tulip/GlLayer.h>
 
 #include "NeighborhoodHighlighterInteractor.h"
-#include "../../utils/ViewNames.h"
+#include "../../utils/PluginNames.h"
 
 #include <algorithm>
 
@@ -51,95 +50,47 @@ using namespace std;
 
 namespace tlp {
 
-class GraphCompositeDrawVisitor : public GlSceneVisitor {
-
-public :
-
-  GraphCompositeDrawVisitor(GlGraphInputData *inputData, Camera *camera) : inputData(inputData), camera(camera), drawLabelMode(false) {}
-
-  void visit(GlNode *glNode) {
-    if (!drawLabelMode) {
-      glNode->draw(30, inputData, camera);
-    }
-    else {
-      glPushAttrib(GL_ALL_ATTRIB_BITS);
-      glDisable(GL_LIGHTING);
-      glDepthFunc(GL_ALWAYS );
-      glDisable(GL_CULL_FACE);
-      glDisable(GL_COLOR_MATERIAL);
-      glNode->drawLabel(&occlusionTest, inputData);
-      glPopAttrib();
-    }
-  }
-
-  void visit(GlEdge *glEdge) {
-    if (!drawLabelMode) {
-      glEdge->draw(30, inputData, camera);
-    }
-    else {
-      glPushAttrib(GL_ALL_ATTRIB_BITS);
-      glDisable(GL_LIGHTING);
-      glDepthFunc(GL_ALWAYS );
-      glDisable(GL_CULL_FACE);
-      glDisable(GL_COLOR_MATERIAL);
-      glEdge->drawLabel(&occlusionTest, inputData);
-      glPopAttrib();
-    }
-  }
-
-  void setDrawLabelMode(const bool drawLabel) {
-    drawLabelMode = drawLabel;
-  }
-
-private :
-
-  GlGraphInputData *inputData;
-  Camera *camera;
-  OcclusionTest occlusionTest;
-  bool drawLabelMode;
-
-};
-
 class GraphLayoutMorphing : public AdditionalGlSceneAnimation {
 
-public :
-  virtual ~GraphLayoutMorphing() {}
-  GraphLayoutMorphing(Graph *graph, LayoutProperty *srcLayout, LayoutProperty *destLayout, LayoutProperty *viewLayout) :
-    graph(graph), srcLayout(srcLayout), destLayout(destLayout), viewLayout(viewLayout) {}
+public:
+  ~GraphLayoutMorphing() override {}
+  GraphLayoutMorphing(Graph *graph, LayoutProperty *srcLayout, LayoutProperty *destLayout,
+                      LayoutProperty *viewLayout)
+      : graph(graph), srcLayout(srcLayout), destLayout(destLayout), viewLayout(viewLayout) {}
 
-  void animationStep(int animationStep) {
-    node n;
-    forEach(n, graph->getNodes()) {
+  void animationStep(int animationStep) override {
+    for (auto n : graph->nodes()) {
       const Coord &startPos = srcLayout->getNodeValue(n);
       const Coord &endPos = destLayout->getNodeValue(n);
-      viewLayout->setNodeValue(n, startPos + (animationStep / (float) nbAnimationSteps) * (endPos - startPos));
+      viewLayout->setNodeValue(
+          n, startPos + (animationStep / float(nbAnimationSteps) * (endPos - startPos)));
     }
 
-    edge e;
-    forEach(e, graph->getEdges()) {
+    for (auto e : graph->edges()) {
       const vector<Coord> &srcBends = srcLayout->getEdgeValue(e);
       const vector<Coord> &destBends = destLayout->getEdgeValue(e);
       vector<Coord> newBends;
+      newBends.reserve(destBends.size());
 
-      for (size_t i = 0 ; i < destBends.size() ; ++i) {
-        newBends.push_back(srcBends[i] + (animationStep / (float) nbAnimationSteps) * (destBends[i] - srcBends[i]));
+      for (size_t i = 0; i < destBends.size(); ++i) {
+        newBends.push_back(
+            srcBends[i] + (animationStep / float(nbAnimationSteps) * (destBends[i] - srcBends[i])));
       }
 
       viewLayout->setEdgeValue(e, newBends);
     }
   }
 
-private :
-
+private:
   Graph *graph;
   LayoutProperty *srcLayout, *destLayout, *viewLayout;
 };
 
 class NeighborNodesEdgeLengthOrdering : public binary_function<node, node, bool> {
 
-public :
-
-  NeighborNodesEdgeLengthOrdering(node centralNode, LayoutProperty *layout) : centralNode(centralNode), layout(layout) {}
+public:
+  NeighborNodesEdgeLengthOrdering(node centralNode, LayoutProperty *layout)
+      : centralNode(centralNode), layout(layout) {}
 
   bool operator()(tlp::node n1, tlp::node n2) const {
     Coord centralNodeCoord = layout->getNodeValue(centralNode);
@@ -150,71 +101,70 @@ public :
     return centralToN1Dist < centralToN2Dist;
   }
 
-private :
-
+private:
   node centralNode;
   LayoutProperty *layout;
 };
 
 class MouseEventDiscardFilter : public QObject {
 
-public :
-
-  bool eventFilter(QObject*, QEvent *event) {
-    if (event->type() == QEvent::MouseMove ||
-        event->type() == QEvent::MouseButtonDblClick ||
-        event->type() == QEvent::MouseButtonPress ||
-        event->type() == QEvent::MouseButtonRelease) {
+public:
+  bool eventFilter(QObject *, QEvent *event) override {
+    if (event->type() == QEvent::MouseMove || event->type() == QEvent::MouseButtonDblClick ||
+        event->type() == QEvent::MouseButtonPress || event->type() == QEvent::MouseButtonRelease) {
       return true;
     }
 
     return false;
   }
-
 };
 
 const unsigned char maxCircleAlphaValue = 200;
 
 PLUGIN(NeighborhoodHighlighterInteractor)
 
-NeighborhoodHighlighterInteractor::NeighborhoodHighlighterInteractor(const PluginContext *) : GLInteractorComposite(QIcon(":/i_neighborhood_highlighter.png"), "Highlight node neighborhood"), configWidget(NULL) {}
+NeighborhoodHighlighterInteractor::NeighborhoodHighlighterInteractor(const PluginContext *)
+    : GLInteractorComposite(QIcon(":/i_neighborhood_highlighter.png"),
+                            "Highlight node neighborhood"),
+      configWidget(nullptr) {}
 
 NeighborhoodHighlighterInteractor::~NeighborhoodHighlighterInteractor() {
   delete configWidget;
 }
 
 bool NeighborhoodHighlighterInteractor::isCompatible(const std::string &viewName) const {
-  return ((viewName==NodeLinkDiagramComponent::viewName)
-          ||(viewName==ViewName::HistogramViewName)
-          //Interactor does not work
+  return ((viewName == NodeLinkDiagramComponent::viewName) ||
+          (viewName == ViewName::HistogramViewName)
+          // Interactor does not work
           //||(viewName==ViewName::MatrixViewName)
-          ||(viewName==ViewName::ScatterPlot2DViewName)
-         );
+          || (viewName == ViewName::ScatterPlot2DViewName));
 }
 
 void NeighborhoodHighlighterInteractor::construct() {
   configWidget = new NeighborhoodHighlighterConfigWidget();
 
-  push_back(new MousePanNZoomNavigator());
+  push_back(new MouseNKeysNavigator(false));
   NeighborhoodHighlighter *neighborhoodHighlighter = new NeighborhoodHighlighter();
   neighborhoodHighlighter->setConfigWidget(configWidget);
   push_back(neighborhoodHighlighter);
 }
 
-NeighborhoodHighlighter::NeighborhoodHighlighter() :
-  originalGraph(NULL), originalGlGraphComposite(NULL),
-  neighborhoodGraph(NULL), glNeighborhoodGraph(NULL), glNeighborhoodCamera(NULL),
-  neighborhoodGraphLayout(NULL), neighborhoodGraphCircleLayout(NULL),
-  neighborhoodGraphOriginalLayout(NULL),neighborhoodGraphColors(NULL),
-  neighborhoodGraphBackupColors(NULL), centralNodeLocked(false),
-  circleLayoutSet(false), glWidget(NULL), neighborhoodDist(1),
-  configWidget(NULL), circleAlphaValue(maxCircleAlphaValue),
-  startAlpha(0), endAlpha(255), nbAnimSteps(0) {
-}
+NeighborhoodHighlighter::NeighborhoodHighlighter()
+    : originalGraph(nullptr), originalGlGraphComposite(nullptr), neighborhoodGraph(nullptr),
+      glNeighborhoodGraph(nullptr), neighborhoodGraphLayout(nullptr),
+      neighborhoodGraphCircleLayout(nullptr), neighborhoodGraphOriginalLayout(nullptr),
+      neighborhoodGraphColors(nullptr), neighborhoodGraphBackupColors(nullptr),
+      centralNodeLocked(false), circleLayoutSet(false), glWidget(nullptr), neighborhoodDist(1),
+      configWidget(nullptr), circleAlphaValue(maxCircleAlphaValue), startAlpha(0), endAlpha(255),
+      nbAnimSteps(0) {}
 
-NeighborhoodHighlighter::NeighborhoodHighlighter(const NeighborhoodHighlighter &neighborhoodHighlighter) : neighborhoodGraph(NULL), glNeighborhoodGraph(NULL), glNeighborhoodCamera(NULL), neighborhoodGraphLayout(NULL), neighborhoodGraphCircleLayout(NULL),
-  neighborhoodGraphOriginalLayout(NULL), neighborhoodGraphColors(NULL), neighborhoodGraphBackupColors(NULL),
-  centralNodeLocked(false), circleLayoutSet(false), neighborhoodDist(1), circleAlphaValue(maxCircleAlphaValue) {
+NeighborhoodHighlighter::NeighborhoodHighlighter(
+    const NeighborhoodHighlighter &neighborhoodHighlighter)
+    : neighborhoodGraph(nullptr), glNeighborhoodGraph(nullptr), neighborhoodGraphLayout(nullptr),
+      neighborhoodGraphCircleLayout(nullptr), neighborhoodGraphOriginalLayout(nullptr),
+      neighborhoodGraphColors(nullptr), neighborhoodGraphBackupColors(nullptr),
+      centralNodeLocked(false), circleLayoutSet(false), neighborhoodDist(1),
+      circleAlphaValue(maxCircleAlphaValue) {
   configWidget = neighborhoodHighlighter.configWidget;
   connect(configWidget, SIGNAL(updateNeighborhoodGraph()), this, SLOT(updateNeighborhoodGraph()));
 }
@@ -224,57 +174,45 @@ NeighborhoodHighlighter::~NeighborhoodHighlighter() {
 }
 
 void NeighborhoodHighlighter::viewChanged(View *view) {
-  originalGraph = NULL;
+  originalGraph = nullptr;
 
-  if (view == NULL) {
-    glWidget = NULL;
+  if (view == nullptr) {
+    glWidget = nullptr;
     return;
   }
 
-  GlMainView *glView = (GlMainView *) view;
+  GlMainView *glView = static_cast<GlMainView *>(view);
   glWidget = glView->getGlMainWidget();
 }
 
-bool NeighborhoodHighlighter::eventFilter(QObject*, QEvent *e) {
-  if(originalGraph==NULL) {
+bool NeighborhoodHighlighter::eventFilter(QObject *, QEvent *e) {
+
+  checkIfGraphHasChanged();
+
+  if (originalGraph == nullptr) {
     originalGraph = glWidget->getScene()->getGlGraphComposite()->getGraph();
     originalGlGraphComposite = glWidget->getScene()->getGlGraphComposite();
 
-    if(!glWidget->hasMouseTracking()) {
+    if (!glWidget->hasMouseTracking()) {
       glWidget->setMouseTracking(true);
     }
 
-    Iterator<string>* it = originalGraph->getProperties();
-
-    while(it->hasNext()) {
-      string propertyName = it->next();
-      PropertyInterface* property = originalGraph->getProperty(propertyName);
-
-      if(property->getTypename() == "double") {
-        configWidget->setPropertyToUse(propertyName);
+    for (PropertyInterface *prop : originalGraph->getObjectProperties()) {
+      if (prop->getTypename() == "double") {
+        configWidget->setPropertyToUse(prop->getName());
       }
     }
-
-    delete it;
-  }
-
-  if(glWidget->getScene()->getGlGraphComposite()->getGraph() != originalGraph) {
-    centralNodeLocked = false;
-    circleLayoutSet = false;
-    cleanupNeighborhoodGraph();
-    originalGraph = glWidget->getScene()->getGlGraphComposite()->getGraph();
-    originalGlGraphComposite = glWidget->getScene()->getGlGraphComposite();
   }
 
   SelectedEntity selectedEntity;
 
   if (e->type() == QEvent::Wheel && centralNodeLocked && !circleLayoutSet) {
-    QWheelEvent *we = (QWheelEvent *)e;
+    QWheelEvent *we = static_cast<QWheelEvent *>(e);
 
-    if (selectInAugmentedDisplayGraph(we->x(), we->y(), selectedEntity) && selectedEntity.getEntityType() == SelectedEntity::NODE_SELECTED) {
+    if (selectInAugmentedDisplayGraph(we->x(), we->y(), selectedEntity) &&
+        selectedEntity.getEntityType() == SelectedEntity::NODE_SELECTED) {
       if (selectedEntity.getComplexEntityId() == neighborhoodGraphCentralNode.id) {
-        int numDegrees = we->delta() / 8;
-        int numSteps = numDegrees / 15;
+        int numSteps = we->delta() / 120;
         neighborhoodDist += numSteps;
 
         if (neighborhoodDist < 1) {
@@ -291,9 +229,8 @@ bool NeighborhoodHighlighter::eventFilter(QObject*, QEvent *e) {
       }
     }
 
-  }
-  else if (e->type() == QEvent::MouseMove) {
-    QMouseEvent *qMouseEv = (QMouseEvent *) e;
+  } else if (e->type() == QEvent::MouseMove) {
+    QMouseEvent *qMouseEv = static_cast<QMouseEvent *>(e);
 
     if (!centralNodeLocked) {
       node tmpNode = selectNodeInOriginalGraph(glWidget, qMouseEv->x(), qMouseEv->y());
@@ -302,59 +239,68 @@ bool NeighborhoodHighlighter::eventFilter(QObject*, QEvent *e) {
         buildNeighborhoodGraph(tmpNode, originalGraph);
         selectedNode = tmpNode;
       }
-    }
-    else {
+      if (tmpNode.isValid())
+        glWidget->setCursor(Qt::PointingHandCursor);
+      else
+        glWidget->setCursor(QCursor());
+    } else {
       *neighborhoodGraphColors = *neighborhoodGraphBackupColors;
 
-      if (selectInAugmentedDisplayGraph(qMouseEv->x(), qMouseEv->y(), selectedEntity) && selectedEntity.getEntityType() == SelectedEntity::NODE_SELECTED) {
+      if (selectInAugmentedDisplayGraph(qMouseEv->x(), qMouseEv->y(), selectedEntity) &&
+          selectedEntity.getEntityType() == SelectedEntity::NODE_SELECTED) {
         if (selectedEntity.getComplexEntityId() != neighborhoodGraphCentralNode.id) {
-          neighborhoodGraphColors->setNodeValue(node(selectedEntity.getComplexEntityId()), Color(0,255,0));
-        }
-        else {
-          neighborhoodGraphColors->setNodeValue(node(selectedEntity.getComplexEntityId()), Color(0,0,255));
+          neighborhoodGraphColors->setNodeValue(node(selectedEntity.getComplexEntityId()),
+                                                Color(0, 255, 0));
+        } else {
+          neighborhoodGraphColors->setNodeValue(node(selectedEntity.getComplexEntityId()),
+                                                Color(0, 0, 255));
         }
       }
 
-      if(selectedEntity.getEntityType()==SelectedEntity::NODE_SELECTED)
+      if (selectedEntity.getEntityType() == SelectedEntity::NODE_SELECTED) {
         selectedNeighborNode = node(selectedEntity.getComplexEntityId());
-      else
+        glWidget->setCursor(Qt::PointingHandCursor);
+      } else {
         selectedNeighborNode = node();
+        glWidget->setCursor(QCursor());
+      }
     }
 
     glWidget->redraw();
     return true;
-  }
-  else if (e->type() == QEvent::MouseButtonPress && ((QMouseEvent *) e)->buttons()==Qt::LeftButton) {
+  } else if (e->type() == QEvent::MouseButtonPress &&
+             static_cast<QMouseEvent *>(e)->buttons() == Qt::LeftButton) {
     if (neighborhoodGraphCentralNode.isValid() && !centralNodeLocked) {
       centralNodeLocked = true;
-    }
-    else if (neighborhoodGraphCentralNode.isValid() && centralNodeLocked &&
-             !circleLayoutSet && selectedNeighborNode.isValid() &&
-             selectedNeighborNode == neighborhoodGraphCentralNode && neighborhoodDist == 1) {
+    } else if (neighborhoodGraphCentralNode.isValid() && centralNodeLocked && !circleLayoutSet &&
+               selectedNeighborNode.isValid() &&
+               selectedNeighborNode == neighborhoodGraphCentralNode && neighborhoodDist == 1) {
       computeNeighborhoodGraphCircleLayout();
       computeNeighborhoodGraphBoundingBoxes();
-      GraphLayoutMorphing *layoutMorphing = new GraphLayoutMorphing(neighborhoodGraph, neighborhoodGraphOriginalLayout, neighborhoodGraphCircleLayout, neighborhoodGraphLayout);
+      GraphLayoutMorphing *layoutMorphing =
+          new GraphLayoutMorphing(neighborhoodGraph, neighborhoodGraphOriginalLayout,
+                                  neighborhoodGraphCircleLayout, neighborhoodGraphLayout);
       performZoomAndPan(neighborhoodGraphCircleLayoutBB, layoutMorphing);
       delete layoutMorphing;
       circleLayoutSet = true;
-    }
-    else if (neighborhoodGraphCentralNode.isValid() && circleLayoutSet && !selectedNeighborNode.isValid()) {
+    } else if (neighborhoodGraphCentralNode.isValid() && circleLayoutSet &&
+               !selectedNeighborNode.isValid()) {
       circleLayoutSet = false;
       centralNodeLocked = false;
       neighborhoodGraphCentralNode = node();
       neighborhoodDist = 1;
       configWidget->setCurrentMaxDistanceForReachableNodes(neighborhoodDist);
       glWidget->redraw();
-    }
-    else if (selectedNeighborNode.isValid()) {
+    } else if (selectedNeighborNode.isValid()) {
       if (circleLayoutSet) {
         if (selectedNeighborNode == neighborhoodGraphCentralNode) {
-          GraphLayoutMorphing *layoutMorphing = new GraphLayoutMorphing(neighborhoodGraph, neighborhoodGraphCircleLayout, neighborhoodGraphOriginalLayout, neighborhoodGraphLayout);
+          GraphLayoutMorphing *layoutMorphing =
+              new GraphLayoutMorphing(neighborhoodGraph, neighborhoodGraphCircleLayout,
+                                      neighborhoodGraphOriginalLayout, neighborhoodGraphLayout);
           performZoomAndPan(neighborhoodGraphOriginalLayoutBB, layoutMorphing);
           delete layoutMorphing;
           circleLayoutSet = false;
-        }
-        else {
+        } else {
           node currentCentralNode = neighborhoodGraphCentralNode;
           buildNeighborhoodGraph(selectedNeighborNode, originalGraph);
           computeNeighborhoodGraphCircleLayout();
@@ -363,8 +309,7 @@ bool NeighborhoodHighlighter::eventFilter(QObject*, QEvent *e) {
 
           if (configWidget->bringAndGoAnimation1()) {
             destBB = neighborhoodGraphOriginalLayoutBB;
-          }
-          else {
+          } else {
             destBB = neighborhoodGraphCircleLayoutBB;
           }
 
@@ -372,7 +317,9 @@ bool NeighborhoodHighlighter::eventFilter(QObject*, QEvent *e) {
           computeNeighborhoodGraphCircleLayout();
           computeNeighborhoodGraphBoundingBoxes();
           *neighborhoodGraphLayout = *neighborhoodGraphCircleLayout;
-          GraphLayoutMorphing *layoutMorphing = new GraphLayoutMorphing(neighborhoodGraph, neighborhoodGraphCircleLayout, neighborhoodGraphOriginalLayout, neighborhoodGraphLayout);
+          GraphLayoutMorphing *layoutMorphing =
+              new GraphLayoutMorphing(neighborhoodGraph, neighborhoodGraphCircleLayout,
+                                      neighborhoodGraphOriginalLayout, neighborhoodGraphLayout);
           performZoomAndPan(destBB, layoutMorphing);
           delete layoutMorphing;
 
@@ -388,24 +335,25 @@ bool NeighborhoodHighlighter::eventFilter(QObject*, QEvent *e) {
             morphCircleAlpha(0, maxCircleAlphaValue);
           }
 
-          layoutMorphing = new GraphLayoutMorphing(neighborhoodGraph, neighborhoodGraphOriginalLayout, neighborhoodGraphCircleLayout, neighborhoodGraphLayout);
+          layoutMorphing =
+              new GraphLayoutMorphing(neighborhoodGraph, neighborhoodGraphOriginalLayout,
+                                      neighborhoodGraphCircleLayout, neighborhoodGraphLayout);
           performZoomAndPan(neighborhoodGraphCircleLayoutBB, layoutMorphing);
           delete layoutMorphing;
         }
-      }
-      else if (selectedNeighborNode != neighborhoodGraphCentralNode) {
+      } else if (selectedNeighborNode != neighborhoodGraphCentralNode) {
         neighborhoodDist = 1;
         configWidget->setCurrentMaxDistanceForReachableNodes(neighborhoodDist);
         buildNeighborhoodGraph(selectedNeighborNode, originalGraph);
         glWidget->redraw();
       }
-    }
-    else {
+    } else {
       centralNodeLocked = false;
       circleLayoutSet = false;
       neighborhoodDist = 1;
       configWidget->setCurrentMaxDistanceForReachableNodes(neighborhoodDist);
       neighborhoodGraphCentralNode = node();
+      glWidget->setCursor(QCursor());
       glWidget->redraw();
     }
 
@@ -418,18 +366,22 @@ node NeighborhoodHighlighter::selectNodeInOriginalGraph(GlMainWidget *glWidget,
   node n;
   glWidget->makeCurrent();
   vector<SelectedEntity> selectedElements;
-  glWidget->getScene()->selectEntities((RenderingEntitiesFlag)(RenderingNodes | RenderingWithoutRemove), glWidget->screenToViewport(x-1), glWidget->screenToViewport(y-1), glWidget->screenToViewport(3), glWidget->screenToViewport(3), NULL, selectedElements);
+  glWidget->getScene()->selectEntities(
+      static_cast<RenderingEntitiesFlag>(RenderingNodes | RenderingWithoutRemove),
+      glWidget->screenToViewport(x - 1), glWidget->screenToViewport(y - 1),
+      glWidget->screenToViewport(3), glWidget->screenToViewport(3), nullptr, selectedElements);
 
-  if(!selectedElements.empty()) {
-    n=node(selectedElements[0].getComplexEntityId());
+  if (!selectedElements.empty()) {
+    n = node(selectedElements[0].getComplexEntityId());
   }
 
   return n;
 }
 
-bool NeighborhoodHighlighter::selectInAugmentedDisplayGraph(const int x, const int y, SelectedEntity &selectedEntity) {
+bool NeighborhoodHighlighter::selectInAugmentedDisplayGraph(const int x, const int y,
+                                                            SelectedEntity &selectedEntity) {
   GlLayer *l = glWidget->getScene()->getLayer("Main");
-  GlGraphComposite *graphComposite = (GlGraphComposite *) l->findGlEntity("graph");
+  GlGraphComposite *graphComposite = static_cast<GlGraphComposite *>(l->findGlEntity("graph"));
   l->deleteGlEntity("graph");
   l->addGlEntity(glNeighborhoodGraph, "graph");
   bool ret = glWidget->pickNodesEdges(x, y, selectedEntity);
@@ -438,12 +390,13 @@ bool NeighborhoodHighlighter::selectInAugmentedDisplayGraph(const int x, const i
   return ret;
 }
 
-void NeighborhoodHighlighter::performZoomAndPan(const BoundingBox &destBB, AdditionalGlSceneAnimation *additionalAnimation) {
+void NeighborhoodHighlighter::performZoomAndPan(const BoundingBox &destBB,
+                                                AdditionalGlSceneAnimation *additionalAnimation) {
   MouseEventDiscardFilter medf;
   glWidget->installEventFilter(&medf);
   QtGlSceneZoomAndPanAnimator sceneZoomAndPan(glWidget, destBB);
 
-  if (additionalAnimation != NULL) {
+  if (additionalAnimation != nullptr) {
     sceneZoomAndPan.setAdditionalGlSceneAnimation(additionalAnimation);
   }
 
@@ -453,21 +406,19 @@ void NeighborhoodHighlighter::performZoomAndPan(const BoundingBox &destBB, Addit
 
 void NeighborhoodHighlighter::cleanupNeighborhoodGraph() {
   delete glNeighborhoodGraph;
-  glNeighborhoodGraph = NULL;
+  glNeighborhoodGraph = nullptr;
   delete neighborhoodGraph;
-  neighborhoodGraph = NULL;
+  neighborhoodGraph = nullptr;
   delete neighborhoodGraphLayout;
-  neighborhoodGraphLayout = NULL;
+  neighborhoodGraphLayout = nullptr;
   delete neighborhoodGraphCircleLayout;
-  neighborhoodGraphCircleLayout = NULL;
+  neighborhoodGraphCircleLayout = nullptr;
   delete neighborhoodGraphOriginalLayout;
-  neighborhoodGraphOriginalLayout = NULL;
+  neighborhoodGraphOriginalLayout = nullptr;
   delete neighborhoodGraphColors;
-  neighborhoodGraphColors = NULL;
+  neighborhoodGraphColors = nullptr;
   delete neighborhoodGraphBackupColors;
-  neighborhoodGraphBackupColors = NULL;
-  delete glNeighborhoodCamera;
-  glNeighborhoodCamera = NULL;
+  neighborhoodGraphBackupColors = nullptr;
 }
 
 void NeighborhoodHighlighter::buildNeighborhoodGraph(node n, Graph *g) {
@@ -480,7 +431,10 @@ void NeighborhoodHighlighter::buildNeighborhoodGraph(node n, Graph *g) {
 
     neighborhoodGraphCentralNode = n;
 
-    neighborhoodGraph = new NodeNeighborhoodView(g, n, configWidget->getNeighborsType(), neighborhoodDist, configWidget->computeReachableSubGraph(), configWidget->propertyToUse(), configWidget->numberOfNodesToBring());
+    neighborhoodGraph = new NodeNeighborhoodView(
+        g, n, configWidget->getNeighborsType(), neighborhoodDist,
+        configWidget->computeReachableSubGraph(), configWidget->propertyToUse(),
+        configWidget->numberOfNodesToBring());
 
     neighborhoodGraphLayout = new LayoutProperty(neighborhoodGraph);
     neighborhoodGraphCircleLayout = new LayoutProperty(neighborhoodGraph);
@@ -496,19 +450,17 @@ void NeighborhoodHighlighter::buildNeighborhoodGraph(node n, Graph *g) {
 }
 
 void NeighborhoodHighlighter::updateNeighborhoodGraphLayoutAndColors() {
-  if(originalGlGraphComposite != NULL) {
+  if (originalGlGraphComposite != nullptr) {
     GlGraphInputData *originalInputData = originalGlGraphComposite->getInputData();
     LayoutProperty *origGraphLayout = originalInputData->getElementLayout();
     ColorProperty *origGraphColors = originalInputData->getElementColor();
 
-    node n2;
-    forEach(n2, neighborhoodGraph->getNodes()) {
+    for (auto n2 : neighborhoodGraph->nodes()) {
       neighborhoodGraphOriginalLayout->setNodeValue(n2, origGraphLayout->getNodeValue(n2));
       neighborhoodGraphBackupColors->setNodeValue(n2, origGraphColors->getNodeValue(n2));
     }
 
-    edge e;
-    forEach(e, neighborhoodGraph->getEdges()) {
+    for (auto e : neighborhoodGraph->edges()) {
       neighborhoodGraphOriginalLayout->setEdgeValue(e, origGraphLayout->getEdgeValue(e));
       neighborhoodGraphBackupColors->setEdgeValue(e, origGraphColors->getEdgeValue(e));
     }
@@ -527,8 +479,10 @@ void NeighborhoodHighlighter::updateGlNeighborhoodGraph() {
   glNeighborhoodGraphInputData->setElementColor(neighborhoodGraphColors);
   glNeighborhoodGraphInputData->setElementLabel(originalInputData->getElementLabel());
   glNeighborhoodGraphInputData->setElementLabelColor(originalInputData->getElementLabelColor());
-  glNeighborhoodGraphInputData->setElementLabelBorderColor(originalInputData->getElementLabelBorderColor());
-  glNeighborhoodGraphInputData->setElementLabelPosition(originalInputData->getElementLabelPosition());
+  glNeighborhoodGraphInputData->setElementLabelBorderColor(
+      originalInputData->getElementLabelBorderColor());
+  glNeighborhoodGraphInputData->setElementLabelPosition(
+      originalInputData->getElementLabelPosition());
   glNeighborhoodGraphInputData->setElementLayout(neighborhoodGraphLayout);
   glNeighborhoodGraphInputData->setElementRotation(originalInputData->getElementRotation());
   glNeighborhoodGraphInputData->setElementSelected(originalInputData->getElementSelected());
@@ -537,10 +491,14 @@ void NeighborhoodHighlighter::updateGlNeighborhoodGraph() {
   glNeighborhoodGraphInputData->setElementTexture(originalInputData->getElementTexture());
   glNeighborhoodGraphInputData->setElementFont(originalInputData->getElementFont());
   glNeighborhoodGraphInputData->setElementFontSize(originalInputData->getElementFontSize());
-  glNeighborhoodGraphInputData->setElementSrcAnchorShape(originalInputData->getElementSrcAnchorShape());
-  glNeighborhoodGraphInputData->setElementSrcAnchorSize(originalInputData->getElementSrcAnchorSize());
-  glNeighborhoodGraphInputData->setElementTgtAnchorShape(originalInputData->getElementTgtAnchorShape());
-  glNeighborhoodGraphInputData->setElementTgtAnchorSize(originalInputData->getElementTgtAnchorSize());
+  glNeighborhoodGraphInputData->setElementSrcAnchorShape(
+      originalInputData->getElementSrcAnchorShape());
+  glNeighborhoodGraphInputData->setElementSrcAnchorSize(
+      originalInputData->getElementSrcAnchorSize());
+  glNeighborhoodGraphInputData->setElementTgtAnchorShape(
+      originalInputData->getElementTgtAnchorShape());
+  glNeighborhoodGraphInputData->setElementTgtAnchorSize(
+      originalInputData->getElementTgtAnchorSize());
 }
 
 void NeighborhoodHighlighter::updateNeighborhoodGraph() {
@@ -551,44 +509,48 @@ void NeighborhoodHighlighter::updateNeighborhoodGraph() {
 }
 
 void NeighborhoodHighlighter::computeNeighborhoodGraphBoundingBoxes() {
-  Coord centralNodeCoord = neighborhoodGraphOriginalLayout->getNodeValue(neighborhoodGraphCentralNode);
+  Coord centralNodeCoord =
+      neighborhoodGraphOriginalLayout->getNodeValue(neighborhoodGraphCentralNode);
   float originalLayoutRadius = computeNeighborhoodGraphRadius(neighborhoodGraphOriginalLayout);
   float circleLayoutRadius = computeNeighborhoodGraphRadius(neighborhoodGraphCircleLayout);
-  neighborhoodGraphOriginalLayoutBB[0] = centralNodeCoord - Coord(originalLayoutRadius, originalLayoutRadius);
-  neighborhoodGraphOriginalLayoutBB[1] = centralNodeCoord + Coord(originalLayoutRadius, originalLayoutRadius);
-  neighborhoodGraphCircleLayoutBB[0] = centralNodeCoord - Coord(circleLayoutRadius, circleLayoutRadius);
-  neighborhoodGraphCircleLayoutBB[1] = centralNodeCoord + Coord(circleLayoutRadius, circleLayoutRadius);
+  neighborhoodGraphOriginalLayoutBB[0] =
+      centralNodeCoord - Coord(originalLayoutRadius, originalLayoutRadius);
+  neighborhoodGraphOriginalLayoutBB[1] =
+      centralNodeCoord + Coord(originalLayoutRadius, originalLayoutRadius);
+  neighborhoodGraphCircleLayoutBB[0] =
+      centralNodeCoord - Coord(circleLayoutRadius, circleLayoutRadius);
+  neighborhoodGraphCircleLayoutBB[1] =
+      centralNodeCoord + Coord(circleLayoutRadius, circleLayoutRadius);
 }
 
-bool boundingBoxesIntersect(const BoundingBox &bb1, const BoundingBox &bb2)  {
-  return Rectangle<float>(bb1).intersect(Rectangle<float>(bb2));
-}
-
-
 void NeighborhoodHighlighter::computeNeighborhoodGraphCircleLayout() {
 
-  Size centralNodeSize = originalGlGraphComposite->getInputData()->getElementSize()->getNodeValue(neighborhoodGraphCentralNode);
+  Size centralNodeSize = originalGlGraphComposite->getInputData()->getElementSize()->getNodeValue(
+      neighborhoodGraphCentralNode);
   Coord centralNodeCoord = neighborhoodGraphLayout->getNodeValue(neighborhoodGraphCentralNode);
   neighborhoodGraphCircleLayout->setNodeValue(neighborhoodGraphCentralNode, centralNodeCoord);
 
   vector<node> neighborsNodes;
-  node n;
-  forEach(n, neighborhoodGraph->getNodes()) {
+  for (auto n : neighborhoodGraph->nodes()) {
     if (n != neighborhoodGraphCentralNode) {
       neighborsNodes.push_back(n);
     }
   }
 
-  sort(neighborsNodes.begin(), neighborsNodes.end(), NeighborNodesEdgeLengthOrdering(neighborhoodGraphCentralNode, neighborhoodGraphLayout));
+  sort(neighborsNodes.begin(), neighborsNodes.end(),
+       NeighborNodesEdgeLengthOrdering(neighborhoodGraphCentralNode, neighborhoodGraphLayout));
 
-  BoundingBox centralNodeBB(Coord(centralNodeCoord.getX() - centralNodeSize.getW() / 2, centralNodeCoord.getY() - centralNodeSize.getH() / 2, 0),
-                            Coord(centralNodeCoord.getX() + centralNodeSize.getW() / 2, centralNodeCoord.getY() + centralNodeSize.getH() / 2, 0));
+  BoundingBox centralNodeBB(Coord(centralNodeCoord.getX() - centralNodeSize.getW() / 2,
+                                  centralNodeCoord.getY() - centralNodeSize.getH() / 2, 0),
+                            Coord(centralNodeCoord.getX() + centralNodeSize.getW() / 2,
+                                  centralNodeCoord.getY() + centralNodeSize.getH() / 2, 0));
   vector<BoundingBox> neighborhoodNodesNewLayoutBB;
   neighborhoodNodesNewLayoutBB.resize(neighborsNodes.size());
 
-  for (size_t i = 0 ; i < neighborsNodes.size() ; ++i) {
+  for (size_t i = 0; i < neighborsNodes.size(); ++i) {
 
-    Size neighborNodeSize = originalGlGraphComposite->getInputData()->getElementSize()->getNodeValue(neighborsNodes[i]);
+    Size neighborNodeSize =
+        originalGlGraphComposite->getInputData()->getElementSize()->getNodeValue(neighborsNodes[i]);
     Coord neighborNodeCoord = neighborhoodGraphLayout->getNodeValue(neighborsNodes[i]);
     float edgeLength = centralNodeCoord.dist(neighborNodeCoord);
 
@@ -598,13 +560,18 @@ void NeighborhoodHighlighter::computeNeighborhoodGraphCircleLayout() {
     while (!nodePosOk) {
       float ratio = ((centralNodeSize.getW() / 2) + j++ * neighborNodeSize.getW()) / edgeLength;
       Coord newNodeCoord = centralNodeCoord + ratio * (neighborNodeCoord - centralNodeCoord);
-      neighborhoodNodesNewLayoutBB[i] = BoundingBox(Coord(newNodeCoord.getX() - neighborNodeSize.getW() / 2, newNodeCoord.getY() - neighborNodeSize.getH() / 2, 0),
-                                        Coord(newNodeCoord.getX() + neighborNodeSize.getW() / 2, newNodeCoord.getY() + neighborNodeSize.getH() / 2, 0));
+      neighborhoodNodesNewLayoutBB[i] =
+          BoundingBox(Coord(newNodeCoord.getX() - neighborNodeSize.getW() / 2,
+                            newNodeCoord.getY() - neighborNodeSize.getH() / 2, 0),
+                      Coord(newNodeCoord.getX() + neighborNodeSize.getW() / 2,
+                            newNodeCoord.getY() + neighborNodeSize.getH() / 2, 0));
       nodePosOk = true;
 
       if (i > 0) {
-        for (unsigned int k = 0 ; k < i ; ++k) {
-          nodePosOk = nodePosOk && !boundingBoxesIntersect(neighborhoodNodesNewLayoutBB[i],neighborhoodNodesNewLayoutBB[k]) && !boundingBoxesIntersect(neighborhoodNodesNewLayoutBB[i], centralNodeBB);
+        for (unsigned int k = 0; k < i; ++k) {
+          nodePosOk = nodePosOk &&
+                      !neighborhoodNodesNewLayoutBB[i].intersect(neighborhoodNodesNewLayoutBB[k]) &&
+                      !neighborhoodNodesNewLayoutBB[i].intersect(centralNodeBB);
         }
       }
 
@@ -614,9 +581,8 @@ void NeighborhoodHighlighter::computeNeighborhoodGraphCircleLayout() {
     }
   }
 
-  edge e;
-  forEach(e, neighborhoodGraph->getEdges()) {
-    const std::pair<node, node>& eEnds = neighborhoodGraph->ends(e);
+  for (auto e : neighborhoodGraph->edges()) {
+    const std::pair<node, node> &eEnds = neighborhoodGraph->ends(e);
     node srcNode = eEnds.first;
     node tgtNode = eEnds.second;
     Coord finalBendsCoord;
@@ -624,24 +590,20 @@ void NeighborhoodHighlighter::computeNeighborhoodGraphCircleLayout() {
     if (srcNode != neighborhoodGraphCentralNode) {
       Coord srcNodeCoord = neighborhoodGraphCircleLayout->getNodeValue(srcNode);
       finalBendsCoord = circleCenter + (srcNodeCoord - circleCenter) / 2.f;
-    }
-    else {
+    } else {
       Coord tgtNodeCoord = neighborhoodGraphCircleLayout->getNodeValue(tgtNode);
       finalBendsCoord = circleCenter + (tgtNodeCoord - circleCenter) / 2.f;
     }
 
-    vector<Coord> edgesBends = neighborhoodGraphLayout->getEdgeValue(e);
+    const vector<Coord> &edgesBends = neighborhoodGraphLayout->getEdgeValue(e);
 
-    for (size_t i = 0 ; i < edgesBends.size() ; ++i) {
-      edgesBends[i] = finalBendsCoord;
-    }
-
-    neighborhoodGraphCircleLayout->setEdgeValue(e, edgesBends);
+    neighborhoodGraphCircleLayout->setEdgeValue(e,
+                                                vector<Coord>(edgesBends.size(), finalBendsCoord));
   }
 }
 
-
-void NeighborhoodHighlighter::morphCircleAlpha(unsigned char startA, unsigned endA, int nbAnimationSteps) {
+void NeighborhoodHighlighter::morphCircleAlpha(unsigned char startA, unsigned endA,
+                                               int nbAnimationSteps) {
   startAlpha = startA;
   endAlpha = endA;
   nbAnimSteps = nbAnimationSteps;
@@ -656,17 +618,20 @@ void NeighborhoodHighlighter::morphCircleAlpha(unsigned char startA, unsigned en
 }
 
 void NeighborhoodHighlighter::morphCircleAlphaAnimStep(int animStep) {
-  circleAlphaValue = (unsigned char) (startAlpha + animStep/(float)nbAnimSteps * (endAlpha - startAlpha));
+  circleAlphaValue = uchar(startAlpha + animStep / float(nbAnimSteps) * (endAlpha - startAlpha));
   glWidget->redraw();
 }
 
-float NeighborhoodHighlighter::computeNeighborhoodGraphRadius(LayoutProperty *neighborhoodGraphLayoutProp) {
+float NeighborhoodHighlighter::computeNeighborhoodGraphRadius(
+    LayoutProperty *neighborhoodGraphLayoutProp) {
   float radius = 0;
   node n;
-  Coord centralNodeCoord = neighborhoodGraphLayoutProp->getNodeValue(neighborhoodGraphCentralNode);
-  forEach(n, neighborhoodGraph->getNodes()) {
-    Coord nodeCoord = neighborhoodGraphLayoutProp->getNodeValue(n);
-    Size nodeSize = originalGlGraphComposite->getInputData()->getElementSize()->getNodeValue(n);
+  const Coord &centralNodeCoord =
+      neighborhoodGraphLayoutProp->getNodeValue(neighborhoodGraphCentralNode);
+  for (auto n : neighborhoodGraph->nodes()) {
+    const Coord &nodeCoord = neighborhoodGraphLayoutProp->getNodeValue(n);
+    const Size &nodeSize =
+        originalGlGraphComposite->getInputData()->getElementSize()->getNodeValue(n);
     float dist = centralNodeCoord.dist(nodeCoord) + nodeSize.getW();
 
     if (dist > radius) {
@@ -676,20 +641,31 @@ float NeighborhoodHighlighter::computeNeighborhoodGraphRadius(LayoutProperty *ne
   return radius;
 }
 
+void NeighborhoodHighlighter::checkIfGraphHasChanged() {
+  if (glWidget->getScene()->getGlGraphComposite()->getGraph() != originalGraph) {
+    neighborhoodGraphCentralNode = node();
+    centralNodeLocked = false;
+    circleLayoutSet = false;
+    cleanupNeighborhoodGraph();
+    originalGraph = glWidget->getScene()->getGlGraphComposite()->getGraph();
+    originalGlGraphComposite = glWidget->getScene()->getGlGraphComposite();
+  }
+}
+
 bool NeighborhoodHighlighter::draw(GlMainWidget *glMainWidget) {
 
-  if (neighborhoodGraphCentralNode.isValid() && glNeighborhoodGraph != NULL) {
-    if(!glNeighborhoodCamera)
-      glNeighborhoodCamera=new Camera(glMainWidget->getScene()->getLayer("Main")->getCamera());
+  checkIfGraphHasChanged();
 
-    *glNeighborhoodCamera=glMainWidget->getScene()->getLayer("Main")->getCamera();
-    glNeighborhoodCamera->initGl();
+  if (neighborhoodGraphCentralNode.isValid() && glNeighborhoodGraph != nullptr) {
+
+    Camera &camera = glMainWidget->getScene()->getLayer("Main")->getCamera();
+    camera.initGl();
 
     glLineWidth(1.0);
     glPointSize(1.0);
     glEnable(GL_CULL_FACE);
     glEnable(GL_NORMALIZE);
-    glDepthFunc(GL_LEQUAL );
+    glDepthFunc(GL_LEQUAL);
     glPolygonMode(GL_FRONT, GL_FILL);
     glColorMask(1, 1, 1, 1);
     glEnable(GL_LINE_SMOOTH);
@@ -697,26 +673,25 @@ bool NeighborhoodHighlighter::draw(GlMainWidget *glMainWidget) {
     glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
     glIndexMask(UINT_MAX);
     glClearStencil(0xFFFF);
-    glStencilOp(GL_KEEP,GL_KEEP,GL_REPLACE);
+    glStencilOp(GL_KEEP, GL_KEEP, GL_REPLACE);
     glClear(GL_DEPTH_BUFFER_BIT | GL_STENCIL_BUFFER_BIT);
     glDisable(GL_TEXTURE_2D);
     glDisable(GL_LIGHTING);
 
-    GlCircle circle(circleCenter, computeNeighborhoodGraphRadius(neighborhoodGraphLayout), Color(0, 0 , 0, circleAlphaValue),
-                    Color (255, 255, 255, circleAlphaValue), true, true, 0.0, 60);
-    circle.draw(0,0);
+    GlCircle circle(circleCenter, computeNeighborhoodGraphRadius(neighborhoodGraphLayout),
+                    Color(0, 0, 0, circleAlphaValue), Color(255, 255, 255, circleAlphaValue), true,
+                    true, 0.0, 60);
+    circle.draw(0, nullptr);
 
-    GlGraphRenderingParameters renderingParameters = glWidget->getScene()->getGlGraphComposite()->getRenderingParameters();
+    GlGraphRenderingParameters renderingParameters =
+        glWidget->getScene()->getGlGraphComposite()->getRenderingParameters();
     renderingParameters.setNodesStencil(1);
     renderingParameters.setNodesLabelStencil(1);
     renderingParameters.setDisplayEdges(configWidget->isdisplayEdgesCBChecked());
     glNeighborhoodGraph->setRenderingParameters(renderingParameters);
-    glNeighborhoodGraph->draw(10,glNeighborhoodCamera);
-
+    glNeighborhoodGraph->draw(10, &camera);
   }
 
   return true;
 }
-
-
-}
+} // namespace tlp
