@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -26,13 +26,14 @@
 
 namespace tlp {
 
-class ZoomAndPanHighlighter: public PathHighlighter, public QObject {
+class ZoomAndPanHighlighter : public PathHighlighter, public QObject {
 public:
-  inline ZoomAndPanHighlighter(): PathHighlighter("Zoom and pan") {}
-  void highlight(const PathFinder *parent, tlp::GlMainWidget *glMainWidget, tlp::BooleanProperty *selection, tlp::node src, tlp::node tgt);
-  void draw(tlp::GlMainWidget *glMainWidget);
-  bool isConfigurable() const;
-  QWidget *getConfigurationWidget();
+  inline ZoomAndPanHighlighter() : PathHighlighter("Zoom and pan") {}
+  void highlight(const PathFinder *parent, tlp::GlMainWidget *glMainWidget,
+                 tlp::BooleanProperty *selection, tlp::node src, tlp::node tgt) override;
+  void draw(tlp::GlMainWidget *glMainWidget) override;
+  bool isConfigurable() const override;
+  QWidget *getConfigurationWidget() override;
 };
-}
+} // namespace tlp
 #endif /* ZOOMANDPANHIGHLIGHTER_H_ */
