@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,19 +19,17 @@
 #ifndef CONNECTEDCOMPONNENTPACKING_H
 #define CONNECTEDCOMPONNENTPACKING_H
 
-#include <tulip/TulipPluginHeaders.h>
+#include <tulip/LayoutProperty.h>
 
-class ConnectedComponentPacking: public tlp::LayoutAlgorithm {
+class ConnectedComponentPacking : public tlp::LayoutAlgorithm {
 public:
-  PLUGININFORMATION("Connected Component Packing", "David Auber", "26/05/05", "Implements a layout packing of the connected components of a graph. It builds a layout of the graph connected components so that they do not overlap and minimizes the lost space (packing).", "1.0", "Misc")
-  ConnectedComponentPacking(const tlp::PluginContext* context);
-  bool run();
-
-private:
-  tlp::Graph *workingGraph;
+  PLUGININFORMATION("Connected Component Packing", "David Auber", "26/05/05",
+                    "Implements a layout packing of the connected components of a graph. It builds "
+                    "a layout of the graph connected components so that they do not overlap and "
+                    "minimizes the lost space (packing).",
+                    "1.0", "Misc")
+  ConnectedComponentPacking(const tlp::PluginContext *context);
+  bool run() override;
 };
 
 #endif
-
-
-
