@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,22 +19,20 @@
 #ifndef DATASETTOOLS_H
 #define DATASETTOOLS_H
 
-#include <tulip/TulipPluginHeaders.h>
+#include <tulip/DataSet.h>
 #include <tulip/LayoutProperty.h>
 #include <tulip/SizeProperty.h>
 #include "Orientation.h"
 
-void addOrientationParameters(tlp::LayoutAlgorithm* pLayout);
+void addOrientationParameters(tlp::LayoutAlgorithm *pLayout);
 tlp::DataSet setOrientationParameters(int orientation);
-void addOrthogonalParameters(tlp::LayoutAlgorithm* pLayout);
-void addSpacingParameters(tlp::LayoutAlgorithm* pLayout);
-void getSpacingParameters(tlp::DataSet* dataSet, float& nodeSpacing, float& layerSpacing);
-void addNodeSizePropertyParameter(tlp::LayoutAlgorithm* pLayout,
-                                  bool inout = false);
-bool getNodeSizePropertyParameter(tlp::DataSet* dataSet, tlp::SizeProperty *&sizes);
-
-orientationType getMask(tlp::DataSet* dataSet);
-bool hasOrthogonalEdge(tlp::DataSet* dataSet);
+void addOrthogonalParameters(tlp::LayoutAlgorithm *pLayout);
+void addSpacingParameters(tlp::LayoutAlgorithm *pLayout);
+void getSpacingParameters(tlp::DataSet *dataSet, float &nodeSpacing, float &layerSpacing);
+void addNodeSizePropertyParameter(tlp::LayoutAlgorithm *pLayout, bool inout = false);
+bool getNodeSizePropertyParameter(tlp::DataSet *dataSet, tlp::SizeProperty *&sizes);
 
+orientationType getMask(tlp::DataSet *dataSet);
+bool hasOrthogonalEdge(tlp::DataSet *dataSet);
 
 #endif
