@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,7 +17,6 @@
  *
  */
 #include "Distances.h"
-#include <tulip/tuliphash.h>
 
 #include <tulip/MutableContainer.h>
 
@@ -26,35 +25,31 @@ using namespace std;
 
 unsigned int getDist(Graph *g, node n1, node n2) {
   vector<node> nextNodes;
-  TLP_HASH_MAP<node, unsigned int> nodeDepth;
+  std::unordered_map<node, unsigned int> nodeDepth;
   MutableContainer<bool> alreadyTreated;
   bool found = false;
   alreadyTreated.setAll(false);
   nextNodes.push_back(n1);
-  nodeDepth[n1]=0;
-  alreadyTreated.set(n1.id,true);
+  nodeDepth[n1] = 0;
+  alreadyTreated.set(n1.id, true);
 
-  for(unsigned int i = 0 ; !found && i < nextNodes.size(); ++i) {
+  for (unsigned int i = 0; !found && i < nextNodes.size(); ++i) {
     node current = nextNodes[i];
-    Iterator<node> * itn = g->getInOutNodes(current);
 
-    while(itn->hasNext()) {
-      node v = itn->next();
+    for (auto v : g->getInOutNodes(current)) {
 
-      if(alreadyTreated.get(v.id))
+      if (alreadyTreated.get(v.id))
         continue;
 
-      alreadyTreated.set(v.id,true);
+      alreadyTreated.set(v.id, true);
       nextNodes.push_back(v);
-      nodeDepth[v] = nodeDepth[current]+1;
+      nodeDepth[v] = nodeDepth[current] + 1;
 
-      if(v == n2) {
+      if (v == n2) {
         found = true;
         break;
       }
     }
-
-    delete itn;
   }
 
   return nodeDepth[n2];
