@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,13 +18,12 @@
  */
 #include "LinLogLayout.h"
 
-LinLogLayout::LinLogLayout (tlp::Graph* _graph,
-                            tlp::PluginProgress* _pluginProgress):
-  edgeWeight(NULL), layoutResult(NULL), linLogWeight(NULL), skipNodes(NULL),
-  graph(_graph), pluginProgress(_pluginProgress), _dim(2), _nbNodes(0) {
+LinLogLayout::LinLogLayout(tlp::Graph *_graph, tlp::PluginProgress *_pluginProgress)
+    : edgeWeight(nullptr), layoutResult(nullptr), linLogWeight(_graph), skipNodes(nullptr),
+      graph(_graph), pluginProgress(_pluginProgress), _dim(2), _nbNodes(0) {
 
-  if (_graph == NULL)
-    std::cerr<<"graph is Null\n";
+  if (_graph == nullptr)
+    std::cerr << "graph is Null\n";
 
   useOctTree = true;
 
@@ -40,47 +39,32 @@ LinLogLayout::LinLogLayout (tlp::Graph* _graph,
   max_iter = 100;
 }
 
-LinLogLayout::~LinLogLayout () {
-  if(layoutResult)
-    delete layoutResult;
-
-  if(linLogWeight)
-    delete linLogWeight;
-}
-
-bool LinLogLayout::initAlgo (tlp::LayoutProperty* _layout,
-                             tlp::NumericProperty* _weight,
-                             double _attrExponent,
-                             double _repuExponent,
-                             double _gravFactor,
-                             unsigned int _max_iter,
-                             bool _is3D,
-                             bool _useOctTree,
-                             tlp::BooleanProperty* _skipNodes) {
-  //initializes with the current layout,
-  //we might want to initialize it with a random layout too, not in this class
+bool LinLogLayout::initAlgo(tlp::LayoutProperty *_layout, tlp::NumericProperty *_weight,
+                            double _attrExponent, double _repuExponent, double _gravFactor,
+                            unsigned int _max_iter, bool _is3D, bool _useOctTree,
+                            tlp::BooleanProperty *_skipNodes) {
+  // initializes with the current layout,
+  // we might want to initialize it with a random layout too, not in this class
   layoutResult = _layout;
   skipNodes = _skipNodes;
 
-  //initializes the weight
+  // initializes the weight
   edgeWeight = _weight;
   initWeights();
 
-  //initializes the algorithm properties
+  // initializes the algorithm properties
   attrExponent = _attrExponent;
   repuExponent = _repuExponent;
   gravFactor = _gravFactor;
   useOctTree = _useOctTree;
 
-
-
   /* Handle parameters */
   _dim = (_is3D) ? 3 : 2;
 
   _nbNodes = graph->numberOfNodes();
 
-  if (layoutResult == NULL) {
-    std::cerr<<"layout result is null\n";
+  if (layoutResult == nullptr) {
+    std::cerr << "layout result is null\n";
     return false;
   }
 
@@ -92,9 +76,8 @@ bool LinLogLayout::initAlgo (tlp::LayoutProperty* _layout,
   return true;
 }
 
-bool LinLogLayout::startAlgo () {
-  return useOctTree ? minimizeEnergy (max_iter) :
-         minimizeEnergyNoTree(max_iter);
+bool LinLogLayout::startAlgo() {
+  return useOctTree ? minimizeEnergy(max_iter) : minimizeEnergyNoTree(max_iter);
 }
 
 /**
@@ -105,47 +88,38 @@ bool LinLogLayout::startAlgo () {
  * of the sum of the repuWeights, which is appropriate when each graph node
  * is visualized as a geometric object whose area is the node's repuWeight.
  */
-void LinLogLayout::initEnergyFactors () {
-  node u;
+void LinLogLayout::initEnergyFactors() {
   double repuSum = 0.0;
   double attrSum = 0.0;
 
-  forEach(u, graph->getNodes()) {
-    double u_weight = linLogWeight->getNodeValue(u);
+  for (auto u : graph->nodes()) {
+    double u_weight = linLogWeight.getNodeValue(u);
     repuSum += u_weight;
-    edge e;
-    forEach(e,  graph->getInOutEdges(u)) {
-      double edgeweight = linLogWeight->getEdgeValue(e);
+    for (auto e : graph->getInOutEdges(u)) {
+      double edgeweight = linLogWeight.getEdgeValue(e);
       attrSum += edgeweight;
     }
   }
 
   if (repuSum > 0.0 && attrSum > 0.0) {
     double density = attrSum / repuSum / repuSum;
-    repuFactor = density * pow(repuSum, 0.5*(attrExponent-repuExponent));
-    gravFactor = density * repuSum * pow(gravFactor, attrExponent-repuExponent);
-  }
-  else
+    repuFactor = density * pow(repuSum, 0.5 * (attrExponent - repuExponent));
+    gravFactor = density * repuSum * pow(gravFactor, attrExponent - repuExponent);
+  } else
     repuFactor = 1.0;
 }
 
-
 /**
  * Returns the total energy of a node.
  * @param node  u
  * @return total energy of the specified node
  */
-double LinLogLayout::getEnergy (node u) {
-  return getRepulsionEnergy (u)
-         + getAttractionEnergy (u)
-         + getGravitationEnergy (u);
+double LinLogLayout::getEnergy(node u) {
+  return getRepulsionEnergy(u) + getAttractionEnergy(u) + getGravitationEnergy(u);
 }
 
-
-double LinLogLayout::getEnergy (node u, OctTree* tree) {
-  return getRepulsionEnergy (u, tree)
-         + getAttractionEnergy (u)
-         + getGravitationEnergy (u);
+double LinLogLayout::getEnergy(node u, OctTree *tree) {
+  return getRepulsionEnergy(u, tree) + getAttractionEnergy(u) + getGravitationEnergy(u);
 }
 
 /**
@@ -153,16 +127,17 @@ double LinLogLayout::getEnergy (node u, OctTree* tree) {
  * @param node  repulsing node
  * @return repulsion energy of the specified node
  */
-double LinLogLayout::getRepulsionEnergy (node u) {
-  double u_weight = linLogWeight->getNodeValue(u);
+double LinLogLayout::getRepulsionEnergy(node u) {
+  double u_weight = linLogWeight.getNodeValue(u);
 
-  if (u_weight == 0.0) return 0.0;
+  if (u_weight == 0.0)
+    return 0.0;
 
-  const Coord& u_layout = layoutResult->getNodeValue(u);
+  const Coord &u_layout = layoutResult->getNodeValue(u);
   double energy = 0.0;
-  node v;
-  forEach(v, graph->getNodes()) {
-    double v_weight = linLogWeight->getNodeValue(v);
+
+  for (auto v : graph->nodes()) {
+    double v_weight = linLogWeight.getNodeValue(v);
 
     if (v == u || v_weight == 0.0)
       continue;
@@ -170,20 +145,17 @@ double LinLogLayout::getRepulsionEnergy (node u) {
     double dist = getDist(u_layout, layoutResult->getNodeValue(v));
 
     if (repuExponent == 0.0) {
-      energy -= repuFactor * u_weight * v_weight
-                * log(dist);
-    }
-    else {
-      energy -= repuFactor * u_weight * v_weight
-                * pow(dist, repuExponent) / repuExponent;
+      energy -= repuFactor * u_weight * v_weight * log(dist);
+    } else {
+      energy -= repuFactor * u_weight * v_weight * pow(dist, repuExponent) / repuExponent;
     }
   }
 
   return energy;
 }
 
-double LinLogLayout::getRepulsionEnergy (node u, OctTree* tree) {
-  if (tree == NULL)
+double LinLogLayout::getRepulsionEnergy(node u, OctTree *tree) {
+  if (tree == nullptr)
     return 0.0;
 
   node treeNode = tree->getNode();
@@ -191,9 +163,10 @@ double LinLogLayout::getRepulsionEnergy (node u, OctTree* tree) {
   if (treeNode == u)
     return 0.0;
 
-  double u_weight = linLogWeight->getNodeValue(u);
+  double u_weight = linLogWeight.getNodeValue(u);
 
-  if (u_weight == 0.0) return 0.0;
+  if (u_weight == 0.0)
+    return 0.0;
 
   double dist = getDist(layoutResult->getNodeValue(u), tree->position);
 
@@ -206,33 +179,28 @@ double LinLogLayout::getRepulsionEnergy (node u, OctTree* tree) {
     return energy;
   }
 
-  if (dist == 0.0) return 0.0;
+  if (dist == 0.0)
+    return 0.0;
 
   if (repuExponent == 0.0) {
-    return -repuFactor * u_weight * tree->weight
-           * log(dist);
-  }
-  else {
-    return -repuFactor * u_weight * tree->weight
-           * pow(dist, repuExponent) / repuExponent;
+    return -repuFactor * u_weight * tree->weight * log(dist);
+  } else {
+    return -repuFactor * u_weight * tree->weight * pow(dist, repuExponent) / repuExponent;
   }
 }
 
-
 /**
  * Returns the attraction energy of a node.
  * @param node  attracting node
  * @return attraction energy of the specified node
  */
-double LinLogLayout::getAttractionEnergy (node u) {
+double LinLogLayout::getAttractionEnergy(node u) {
   double energy = 0.0;
-  const Coord& u_layout = layoutResult->getNodeValue(u);
-  edge e;
-  forEach(e,  graph->getInOutEdges(u)) {
+  const Coord &u_layout = layoutResult->getNodeValue(u);
+  for (auto e : graph->getInOutEdges(u)) {
     node v = graph->opposite(e, u);
-    double dist = getDist(u_layout,
-                          layoutResult->getNodeValue(v));
-    double edgeweight = linLogWeight->getEdgeValue(e);
+    double dist = getDist(u_layout, layoutResult->getNodeValue(v));
+    double edgeweight = linLogWeight.getEdgeValue(e);
 
     if (attrExponent == 0.0)
       energy += edgeweight * log(dist);
@@ -243,14 +211,13 @@ double LinLogLayout::getAttractionEnergy (node u) {
   return energy;
 }
 
-
 /**
  * Returns the gravitation energy of a node.
  * @param node  gravitating node
  * @return gravitation energy of the specified node
  */
-double LinLogLayout::getGravitationEnergy (node u) {
-  double u_weight = linLogWeight->getNodeValue(u);
+double LinLogLayout::getGravitationEnergy(node u) {
+  double u_weight = linLogWeight.getNodeValue(u);
 
   double dist = getDist(layoutResult->getNodeValue(u), baryCenter);
 
@@ -264,7 +231,7 @@ double LinLogLayout::getGravitationEnergy (node u) {
  * Returns the Euclidean distance between the positions pos1 and pos2.
  * @return Euclidean distance between the positions pos1 and pos2
  */
-double LinLogLayout::getDist (const Coord& pos1, const Coord& pos2) {
+double LinLogLayout::getDist(const Coord &pos1, const Coord &pos2) {
   double dist = 0.0;
 
   for (unsigned int d = 0; d < _dim; ++d) {
@@ -275,9 +242,7 @@ double LinLogLayout::getDist (const Coord& pos1, const Coord& pos2) {
   return sqrt(dist);
 }
 
-
-double LinLogLayout::getDistForComparison (const Coord& pos1,
-    const Coord& pos2) {
+double LinLogLayout::getDistForComparison(const Coord &pos1, const Coord &pos2) {
   double dist = 0.0;
 
   for (unsigned int d = 0; d < _dim; ++d) {
@@ -288,7 +253,6 @@ double LinLogLayout::getDistForComparison (const Coord& pos1,
   return dist;
 }
 
-
 /**
  * Computes the direction of the repulsion force on a node.
  * @param  node  repulsing node
@@ -296,32 +260,32 @@ double LinLogLayout::getDistForComparison (const Coord& pos1,
  *         is added to this variable (output parameter)
  * @return approximate second derivation of the repulsion energy
  */
-double LinLogLayout::addRepulsionDir (node u, double* dir) {
-  double u_weight = linLogWeight->getNodeValue(u);
+double LinLogLayout::addRepulsionDir(node u, double *dir) {
+  double u_weight = linLogWeight.getNodeValue(u);
 
   if (u_weight == 0.0)
     return 0.0;
 
-  const Coord& position= layoutResult->getNodeValue(u);
+  const Coord &position = layoutResult->getNodeValue(u);
 
   double dir2 = 0.0;
-  node v;
-  forEach(v, graph->getNodes()) {
-    double v_weight = linLogWeight->getNodeValue(v);
 
-    if (v == u|| v_weight == 0.0)
+  for (auto v : graph->nodes()) {
+    double v_weight = linLogWeight.getNodeValue(v);
+
+    if (v == u || v_weight == 0.0)
       continue;
 
-    const Coord& position2 = layoutResult->getNodeValue(v);
+    const Coord &position2 = layoutResult->getNodeValue(v);
 
     double dist = getDist(position, position2);
 
-    if (dist == 0.0) continue;
+    if (dist == 0.0)
+      continue;
 
-    double tmp = repuFactor * u_weight * v_weight
-                 * pow(dist, repuExponent-2);
+    double tmp = repuFactor * u_weight * v_weight * pow(dist, repuExponent - 2);
 
-    dir2 += tmp * fabs(repuExponent-1);
+    dir2 += tmp * fabs(repuExponent - 1);
 
     for (unsigned int d = 0; d < _dim; ++d)
       dir[d] -= (position2[d] - position[d]) * tmp;
@@ -329,20 +293,21 @@ double LinLogLayout::addRepulsionDir (node u, double* dir) {
   return dir2;
 }
 
-double LinLogLayout::addRepulsionDir (node u, double* dir, OctTree* tree) {
-  if(tree==NULL || u == (tree->node))
+double LinLogLayout::addRepulsionDir(node u, double *dir, OctTree *tree) {
+  if (tree == nullptr || u == (tree->node))
     return 0.0;
 
-  double u_weight = linLogWeight->getNodeValue(u);
+  double u_weight = linLogWeight.getNodeValue(u);
 
   if (u_weight == 0.0)
     return 0.0;
 
-  const Coord& position = layoutResult->getNodeValue(u);
+  const Coord &position = layoutResult->getNodeValue(u);
 
   double dist = getDist(position, tree->position);
 
-  if (dist == 0.0) return 0.0;
+  if (dist == 0.0)
+    return 0.0;
 
   if (tree->childCount > 0 && dist < 2.0 * tree->width()) {
     double dir2 = 0.0;
@@ -354,13 +319,12 @@ double LinLogLayout::addRepulsionDir (node u, double* dir, OctTree* tree) {
     return dir2;
   }
 
-  double tmp = repuFactor * u_weight * tree->weight
-               * pow(dist, repuExponent-2);
+  double tmp = repuFactor * u_weight * tree->weight * pow(dist, repuExponent - 2);
 
   for (unsigned int d = 0; d < _dim; ++d)
     dir[d] -= (tree->position[d] - position[d]) * tmp;
 
-  return tmp * fabs(repuExponent-1);
+  return tmp * fabs(repuExponent - 1);
 }
 
 /**
@@ -370,28 +334,26 @@ double LinLogLayout::addRepulsionDir (node u, double* dir, OctTree* tree) {
  *         is added to this variable (output parameter)
  * @return approximate second derivation of the attraction energy
  */
-double LinLogLayout::addAttractionDir (node u, double* dir) {
+double LinLogLayout::addAttractionDir(node u, double *dir) {
   double dir2 = 0.0;
 
-  const Coord& position = layoutResult->getNodeValue(u);
+  const Coord &position = layoutResult->getNodeValue(u);
 
-  edge e;
-  forEach(e,  graph->getInOutEdges(u)) {
+  for (auto e : graph->getInOutEdges(u)) {
     node v = graph->opposite(e, u);
-    const Coord& position2 = layoutResult->getNodeValue(v);
+    const Coord &position2 = layoutResult->getNodeValue(v);
     double dist = getDist(position, position2);
 
     if (dist == 0.0)
       continue;
 
-    double edgeweight = linLogWeight->getEdgeValue(e);
-    double tmp = edgeweight * pow(dist, attrExponent-2);
+    double edgeweight = linLogWeight.getEdgeValue(e);
+    double tmp = edgeweight * pow(dist, attrExponent - 2);
 
-    dir2 += tmp * fabs(attrExponent-1);
+    dir2 += tmp * fabs(attrExponent - 1);
 
     for (unsigned int d = 0; d < _dim; ++d)
       dir[d] += (position2[d] - position[d]) * tmp;
-
   }
 
   return dir2;
@@ -404,75 +366,72 @@ double LinLogLayout::addAttractionDir (node u, double* dir) {
  *         is added to this variable (output parameter)
  * @return approximate second derivation of the gravitation energy
  */
-double LinLogLayout::addGravitationDir(node u, double* dir) {
-  const Coord& position = layoutResult->getNodeValue(u);
+double LinLogLayout::addGravitationDir(node u, double *dir) {
+  const Coord &position = layoutResult->getNodeValue(u);
 
   double dist = getDist(position, baryCenter);
 
-  double u_weight = linLogWeight->getNodeValue(u);
+  double u_weight = linLogWeight.getNodeValue(u);
 
-  double tmp = gravFactor * repuFactor * u_weight * pow(dist, attrExponent-2);
+  double tmp = gravFactor * repuFactor * u_weight * pow(dist, attrExponent - 2);
 
   for (unsigned int d = 0; d < _dim; ++d) {
     dir[d] += (baryCenter[d] - position[d]) * tmp;
   }
 
-  return tmp * fabs(attrExponent-1.0);
+  return tmp * fabs(attrExponent - 1.0);
 }
 
-
 /**
  * Computes the direction of the total force acting on a node.
  * @param  node  node
  * @param  dir   direction of the total force acting on the node
  *               (output parameter)
  */
-void LinLogLayout::getDirection (node u, double* dir) {
+void LinLogLayout::getDirection(node u, double *dir) {
 
-  for (unsigned int d=0; d<_dim; ++d)
+  for (unsigned int d = 0; d < _dim; ++d)
     dir[d] = 0.0;
 
   double dir2 = addRepulsionDir(u, dir);
   dir2 += addAttractionDir(u, dir);
   dir2 += addGravitationDir(u, dir);
 
-  const Coord& position = layoutResult->getNodeValue(u);
+  const Coord &position = layoutResult->getNodeValue(u);
 
   // compute average Euclidean distance to other nodes
   double avgDist = 0.0;
-  node v;
-  forEach(v, graph->getNodes()) {
-    const Coord& position2 = layoutResult->getNodeValue(v);
+  for (auto v : graph->nodes()) {
+    const Coord &position2 = layoutResult->getNodeValue(v);
 
     avgDist += getDist(position, position2);
   }
-  avgDist /= graph->numberOfNodes()-1;
+  avgDist /= graph->numberOfNodes() - 1;
 
   if (dir2 != 0.0) {
     // normalize force vector with second derivation of energy
-    for (unsigned int d=0; d<_dim; ++d)
+    for (unsigned int d = 0; d < _dim; ++d)
       dir[d] /= dir2;
 
     // ensure that the length of dir is not greater
     // than average Euclidean distance to other nodes
 
-    double length = 0;//calculate length of Dir //getDist(dir, new double[_dim]);
+    double length = 0; // calculate length of Dir //getDist(dir, new double[_dim]);
 
     if (avgDist > 0.0 && length > avgDist) {
       length /= avgDist;
 
-      for (unsigned int d=0; d<_dim; ++d)
+      for (unsigned int d = 0; d < _dim; ++d)
         dir[d] /= length;
     }
-  }
-  else {
-    for (unsigned int d=0; d<_dim; ++d)
+  } else {
+    for (unsigned int d = 0; d < _dim; ++d)
       dir[d] = 0.0;
   }
 }
 
-void LinLogLayout::getDirection (node u, double* dir, OctTree* tree) {
-  for (unsigned int d=0; d<_dim; ++d)
+void LinLogLayout::getDirection(node u, double *dir, OctTree *tree) {
+  for (unsigned int d = 0; d < _dim; ++d)
     dir[d] = 0.0;
 
   double dir2 = addRepulsionDir(u, dir, tree);
@@ -481,7 +440,7 @@ void LinLogLayout::getDirection (node u, double* dir, OctTree* tree) {
 
   if (dir2 != 0.0) {
     // normalize force vector with second derivation of energy
-    for (unsigned int d=0; d<_dim; ++d)
+    for (unsigned int d = 0; d < _dim; ++d)
       dir[d] /= dir2;
 
     // ensure that the length of dir is not greater
@@ -493,14 +452,13 @@ void LinLogLayout::getDirection (node u, double* dir, OctTree* tree) {
       double width = tree->maxPos[d] - tree->minPos[d];
 
       if (width > 0.0)
-        scale = std::min(scale, fabs(width/16/dir[d]));
+        scale = std::min(scale, fabs(width / 16 / dir[d]));
     }
 
-    for (unsigned int d=0; d<_dim; ++d)
+    for (unsigned int d = 0; d < _dim; ++d)
       dir[d] *= scale;
-  }
-  else {
-    for (unsigned int d=0; d<_dim; ++d)
+  } else {
+    for (unsigned int d = 0; d < _dim; ++d)
       dir[d] = 0.0;
   }
 }
@@ -509,17 +467,17 @@ void LinLogLayout::getDirection (node u, double* dir, OctTree* tree) {
  * Iteratively minimizes energy using the Barnes-Hut algorithm.
  * Starts from the positions in the parameter <code>positions</code>,
  * and stores the computed positions in <code>positions</code>.
-* @param positions  position in <code>nrDims</code>-dimensional space for each node.
-*   Is not copied and serves as input and output parameter.
-*   Each position must be a <code>double[nrDims]</code>.
-*   If the input is two-dimensional (i.e. the third array element
-*   is 0.0 for all nodes), the output is also two-dimensional.
-*   Different nodes with nonzero weights must have different positions.
-*   Random initial positions are appropriate.
-* @param nrIterations  number of iterations. Choose appropriate values
-*   by observing the convergence of energy.  A typical value is 100.
-*/
-bool LinLogLayout::minimizeEnergyNoTree (int nrIterations) {
+ * @param positions  position in <code>nrDims</code>-dimensional space for each node.
+ *   Is not copied and serves as input and output parameter.
+ *   Each position must be a <code>double[nrDims]</code>.
+ *   If the input is two-dimensional (i.e. the third array element
+ *   is 0.0 for all nodes), the output is also two-dimensional.
+ *   Different nodes with nonzero weights must have different positions.
+ *   Random initial positions are appropriate.
+ * @param nrIterations  number of iterations. Choose appropriate values
+ *   by observing the convergence of energy.  A typical value is 100.
+ */
+bool LinLogLayout::minimizeEnergyNoTree(int nrIterations) {
   if (graph->numberOfNodes() <= 1)
     return true;
 
@@ -533,13 +491,12 @@ bool LinLogLayout::minimizeEnergyNoTree (int nrIterations) {
 
   double energySum = 0.0;
 
-  node u;
-  forEach(u, graph->getNodes())
-  energySum += getEnergy(u);
+  for (auto u : graph->nodes())
+    energySum += getEnergy(u);
 
   // minimize energy
-  double oldPos[3] = {0,0,0};
-  double bestDir[3] = {0,0,0};
+  double oldPos[3] = {0, 0, 0};
+  double bestDir[3] = {0, 0, 0};
 
   for (int step = 1; step <= nrIterations; ++step) {
     computeBaryCenter();
@@ -548,26 +505,22 @@ bool LinLogLayout::minimizeEnergyNoTree (int nrIterations) {
       attrExponent = finalAttrExponent;
       repuExponent = finalRepuExponent;
 
-      if (step <= 0.6*nrIterations) {
+      if (step <= 0.6 * nrIterations) {
         // use energy model with few local minima
         attrExponent += 1.1 * (1.0 - finalRepuExponent);
         repuExponent += 0.9 * (1.0 - finalRepuExponent);
-      }
-      else if (step <= 0.9*nrIterations) {
+      } else if (step <= 0.9 * nrIterations) {
         // gradually move to final energy model
-        attrExponent += 1.1 * (1.0 - finalRepuExponent)
-                        * (0.9 - ((double)step)/nrIterations) / 0.3;
-        repuExponent += 0.9 * (1.0 - finalRepuExponent)
-                        * (0.9 - ((double)step)/nrIterations) / 0.3;
+        attrExponent +=
+            1.1 * (1.0 - finalRepuExponent) * (0.9 - (step / double(nrIterations))) / 0.3;
+        repuExponent +=
+            0.9 * (1.0 - finalRepuExponent) * (0.9 - (step / double(nrIterations))) / 0.3;
       }
     }
 
     // move each node
-    int count = 0;
     energySum = 0.0;
-    forEach(u, graph->getNodes()) {
-
-      count++;
+    for (auto u : graph->nodes()) {
 
       double oldEnergy = getEnergy(u);
       // compute direction of the move of the node
@@ -576,23 +529,22 @@ bool LinLogLayout::minimizeEnergyNoTree (int nrIterations) {
       // line search: compute length of the move
       Coord pos = layoutResult->getNodeValue(u);
 
-      for (unsigned int d=0; d<_dim; ++d)
+      for (unsigned int d = 0; d < _dim; ++d)
         oldPos[d] = pos[d];
 
       double bestEnergy = oldEnergy;
       int bestMultiple = 0;
 
-      for (unsigned int d=0; d<_dim; ++d)
+      for (unsigned int d = 0; d < _dim; ++d)
         bestDir[d] /= 32;
 
-      for (int multiple = 32;
-           multiple >= 1 && (bestMultiple==0 || bestMultiple/2==multiple);
+      for (int multiple = 32; multiple >= 1 && (bestMultiple == 0 || bestMultiple / 2 == multiple);
            multiple /= 2) {
-        for (unsigned int d=0; d<_dim; ++d)
+        for (unsigned int d = 0; d < _dim; ++d)
           pos[d] = oldPos[d] + bestDir[d] * multiple;
 
-        if(!skipNodes || !skipNodes->getNodeValue(u))
-          //if(!noackPillar->getNodeValue(u))
+        if (!skipNodes || !skipNodes->getNodeValue(u))
+          // if(!noackPillar->getNodeValue(u))
           layoutResult->setNodeValue(u, pos);
 
         double curEnergy = getEnergy(u);
@@ -603,14 +555,12 @@ bool LinLogLayout::minimizeEnergyNoTree (int nrIterations) {
         }
       }
 
-      for (int multiple = 64;
-           multiple <= 128 && bestMultiple == multiple/2;
-           multiple *= 2) {
-        for (unsigned int d=0; d<_dim; ++d)
+      for (int multiple = 64; multiple <= 128 && bestMultiple == multiple / 2; multiple *= 2) {
+        for (unsigned int d = 0; d < _dim; ++d)
           pos[d] = oldPos[d] + bestDir[d] * multiple;
 
-        if(!skipNodes || !skipNodes->getNodeValue(u))
-          //if(!noackPillar->getNodeValue(u))
+        if (!skipNodes || !skipNodes->getNodeValue(u))
+          // if(!noackPillar->getNodeValue(u))
           layoutResult->setNodeValue(u, pos);
 
         double curEnergy = getEnergy(u);
@@ -621,25 +571,25 @@ bool LinLogLayout::minimizeEnergyNoTree (int nrIterations) {
         }
       }
 
-      for (unsigned int d=0; d<_dim; ++d)
+      for (unsigned int d = 0; d < _dim; ++d)
         pos[d] = oldPos[d] + bestDir[d] * bestMultiple;
 
-      if(!skipNodes || !skipNodes->getNodeValue(u))
-        //if(!noackPillar->getNodeValue(u))
+      if (!skipNodes || !skipNodes->getNodeValue(u))
+        // if(!noackPillar->getNodeValue(u))
         layoutResult->setNodeValue(u, pos);
 
       energySum += bestEnergy;
-
     }
 
-    if ((step *100 / nrIterations) % 10 == 0 && pluginProgress->progress(step, nrIterations)!=TLP_CONTINUE)
-      return pluginProgress->state()!=TLP_CANCEL;
+    if ((step * 100 / nrIterations) % 10 == 0 &&
+        pluginProgress->progress(step, nrIterations) != TLP_CONTINUE)
+      return pluginProgress->state() != TLP_CANCEL;
   }
 
   return true;
 }
 
-bool LinLogLayout::minimizeEnergy (int nrIterations) {
+bool LinLogLayout::minimizeEnergy(int nrIterations) {
   if (graph->numberOfNodes() <= 1)
     return true;
 
@@ -650,17 +600,16 @@ bool LinLogLayout::minimizeEnergy (int nrIterations) {
 
   // compute initial energy
   computeBaryCenter();
-  OctTree* octTree = buildOctTree();
+  OctTree *octTree = buildOctTree();
 
   double energySum = 0.0;
 
-  node u;
-  forEach(u, graph->getNodes())
-  energySum += getEnergy(u, octTree);
+  for (auto u : graph->nodes())
+    energySum += getEnergy(u, octTree);
 
   // minimize energy
-  double oldPos[3] = {0,0,0};
-  double bestDir[3] = {0,0,0};
+  double oldPos[3] = {0, 0, 0};
+  double bestDir[3] = {0, 0, 0};
 
   for (int step = 1; step <= nrIterations; ++step) {
     computeBaryCenter();
@@ -670,25 +619,22 @@ bool LinLogLayout::minimizeEnergy (int nrIterations) {
       attrExponent = finalAttrExponent;
       repuExponent = finalRepuExponent;
 
-      if (step <= 0.6*nrIterations) {
+      if (step <= 0.6 * nrIterations) {
         // use energy model with few local minima
         attrExponent += 1.1 * (1.0 - finalRepuExponent);
         repuExponent += 0.9 * (1.0 - finalRepuExponent);
-      }
-      else if (step <= 0.9*nrIterations) {
+      } else if (step <= 0.9 * nrIterations) {
         // gradually move to final energy model
-        attrExponent += 1.1 * (1.0 - finalRepuExponent)
-                        * (0.9 - ((double)step)/nrIterations) / 0.3;
-        repuExponent += 0.9 * (1.0 - finalRepuExponent)
-                        * (0.9 - ((double)step)/nrIterations) / 0.3;
+        attrExponent +=
+            1.1 * (1.0 - finalRepuExponent) * (0.9 - (step / double(nrIterations))) / 0.3;
+        repuExponent +=
+            0.9 * (1.0 - finalRepuExponent) * (0.9 - (step / double(nrIterations))) / 0.3;
       }
     }
 
     // move each node
-    int count = 0;
     energySum = 0.0;
-    forEach(u, graph->getNodes()) {
-      ++count;
+    for (auto u : graph->nodes()) {
       double oldEnergy = getEnergy(u, octTree);
 
       // compute direction of the move of the node
@@ -697,27 +643,25 @@ bool LinLogLayout::minimizeEnergy (int nrIterations) {
       // line search: compute length of the move
       Coord pos = layoutResult->getNodeValue(u);
 
-      for (unsigned int d=0; d<_dim; ++d)
+      for (unsigned int d = 0; d < _dim; ++d)
         oldPos[d] = pos[d];
 
       double bestEnergy = oldEnergy;
       int bestMultiple = 0;
 
-      for (unsigned int d=0; d<_dim; ++d)
+      for (unsigned int d = 0; d < _dim; ++d)
         bestDir[d] /= 32;
 
-      for (int multiple = 32;
-           multiple >= 1 && (bestMultiple==0 || bestMultiple/2==multiple);
+      for (int multiple = 32; multiple >= 1 && (bestMultiple == 0 || bestMultiple / 2 == multiple);
            multiple /= 2) {
         octTree->removeNode(u, pos, 0);
 
-        for (unsigned int d=0; d<_dim; ++d)
+        for (unsigned int d = 0; d < _dim; ++d)
           pos[d] = oldPos[d] + bestDir[d] * multiple;
 
         octTree->addNode(u, pos, 0);
 
-
-        if(!skipNodes || !skipNodes->getNodeValue(u))
+        if (!skipNodes || !skipNodes->getNodeValue(u))
           layoutResult->setNodeValue(u, pos);
 
         double curEnergy = getEnergy(u);
@@ -728,17 +672,15 @@ bool LinLogLayout::minimizeEnergy (int nrIterations) {
         }
       }
 
-      for (int multiple = 64;
-           multiple <= 128 && bestMultiple == multiple/2;
-           multiple *= 2) {
+      for (int multiple = 64; multiple <= 128 && bestMultiple == multiple / 2; multiple *= 2) {
         octTree->removeNode(u, pos, 0);
 
-        for (unsigned int d=0; d<_dim; ++d)
+        for (unsigned int d = 0; d < _dim; ++d)
           pos[d] = oldPos[d] + bestDir[d] * multiple;
 
         octTree->addNode(u, pos, 0);
 
-        if(!skipNodes || !skipNodes->getNodeValue(u))
+        if (!skipNodes || !skipNodes->getNodeValue(u))
           layoutResult->setNodeValue(u, pos);
 
         double curEnergy = getEnergy(u);
@@ -749,133 +691,96 @@ bool LinLogLayout::minimizeEnergy (int nrIterations) {
         }
       }
 
-      for (unsigned int d=0; d<_dim; ++d)
+      for (unsigned int d = 0; d < _dim; ++d)
         pos[d] = oldPos[d] + bestDir[d] * bestMultiple;
 
-      if(!skipNodes || !skipNodes->getNodeValue(u))
+      if (!skipNodes || !skipNodes->getNodeValue(u))
         layoutResult->setNodeValue(u, pos);
 
       energySum += bestEnergy;
     }
 
-    if ((step *100 / nrIterations) % 10 == 0 &&
-        pluginProgress->progress(step, nrIterations)!=TLP_CONTINUE)
-      return pluginProgress->state()!=TLP_CANCEL;
+    if ((step * 100 / nrIterations) % 10 == 0 &&
+        pluginProgress->progress(step, nrIterations) != TLP_CONTINUE)
+      return pluginProgress->state() != TLP_CANCEL;
   }
 
   return true;
 }
 
-
-
 /**
-* Computes the position of the barycenter of all nodes
-* and stores it in the attribute <code>baryCenter</code>.
-*/
-void LinLogLayout::computeBaryCenter () {
-  for (unsigned int d=0; d<_dim; ++d)
+ * Computes the position of the barycenter of all nodes
+ * and stores it in the attribute <code>baryCenter</code>.
+ */
+void LinLogLayout::computeBaryCenter() {
+  for (unsigned int d = 0; d < _dim; ++d)
     baryCenter[d] = 0.0;
 
   double weightSum = 0.0;
-  node u;
-  forEach(u, graph->getNodes()) {
-    double u_weight = linLogWeight->getNodeValue(u);
+  for (auto u : graph->nodes()) {
+    double u_weight = linLogWeight.getNodeValue(u);
     weightSum += u_weight;
-    const Coord& position = layoutResult->getNodeValue(u);
+    const Coord &position = layoutResult->getNodeValue(u);
 
-    for (unsigned int d=0; d<_dim; ++d)
+    for (unsigned int d = 0; d < _dim; ++d)
       baryCenter[d] += u_weight * position[d];
   }
 
   if (weightSum > 0.0) {
-    for (unsigned int d=0; d<_dim; ++d)
+    for (unsigned int d = 0; d < _dim; ++d)
       baryCenter[d] /= weightSum;
   }
 }
 
-
-void LinLogLayout::initWeights2 () {
-  linLogWeight = new tlp::DoubleProperty(graph);
-  linLogWeight->setAllNodeValue(0.0);
-
-  double weight = 0.0;
-  node u;
-
-  if (edgeWeight == NULL)
-    forEach(u, graph->getNodes()) {
-    weight = 0.0;
-    edge e;
-    forEach(e,  graph->getInOutEdges(u)) {
-      ++weight;
-      linLogWeight->setEdgeValue(e,1.0);
-    }
-
-    linLogWeight->setNodeValue (u, weight);
-  }
-  else
-    forEach(u, graph->getNodes()) {
-    weight = 0.0;
-    edge e;
-    forEach(e,  graph->getInOutEdges(u)) {
-      double tmpweight = edgeWeight->getEdgeDoubleValue(e)*100.0+1.0;
-      weight+= tmpweight ;
-      linLogWeight->setEdgeValue(e,tmpweight);
-    }
-
-    linLogWeight->setNodeValue (u, weight);
-  }
-}
-
-void LinLogLayout::initWeights () {
-  linLogWeight = new tlp::DoubleProperty(graph);
-  linLogWeight->setAllNodeValue(0.0);
-  linLogWeight->setAllEdgeValue(0.0);
+void LinLogLayout::initWeights() {
+  linLogWeight.setAllNodeValue(0.0);
 
   node u;
 
-  if (edgeWeight == NULL) {
-    edge e;
-    forEach(e,  graph->getEdges()) {
-      const std::pair<node, node>& eEnds = graph->ends(e);
+  if (edgeWeight == nullptr) {
+    linLogWeight.setAllEdgeValue(1.0);
+    for (auto e : graph->edges()) {
+      auto eEnds = graph->ends(e);
       node u = eEnds.first;
       node v = eEnds.second;
-      double wu = linLogWeight->getNodeValue(u);
-      double wv = linLogWeight->getNodeValue(v);
+      double wu = linLogWeight.getNodeValue(u);
+      double wv = linLogWeight.getNodeValue(v);
 
-      linLogWeight->setEdgeValue(e,1.0);
-      linLogWeight->setNodeValue(u,wu+1.0);
-      linLogWeight->setNodeValue(v,wv+1.0);
+      linLogWeight.setNodeValue(u, wu + 1.0);
+      linLogWeight.setNodeValue(v, wv + 1.0);
     }
-  }
-  else
-    forEach(u, graph->getNodes()) {
-    double weight = 0.0;
-    edge e;
-    forEach(e,  graph->getInOutEdges(u)) {
-      double tmpweight = edgeWeight->getEdgeDoubleValue(e)*100.0+1.0;
-      weight+= tmpweight ;
-      linLogWeight->setEdgeValue(e,tmpweight);
+  } else {
+    for (auto e : graph->edges()) {
+      double tmpweight = edgeWeight->getEdgeDoubleValue(e) * 100.0 + 1.0;
+      linLogWeight.setEdgeValue(e, tmpweight);
     }
 
-    linLogWeight->setNodeValue (u, weight);
+    for (auto u : graph->nodes()) {
+      double weight = 0.0;
+      for (auto e : graph->getInOutEdges(u)) {
+        weight += linLogWeight.getEdgeValue(e);
+      }
+
+      linLogWeight.setNodeValue(u, weight);
+    }
   }
 }
 
-
-OctTree* LinLogLayout::buildOctTree() {
+OctTree *LinLogLayout::buildOctTree() {
   // compute mimima and maxima of positions in each dimension
-  Coord minPos (100000, 100000, 100000);
-  Coord maxPos (-100000,-100000,-100000);
-  Coord zero (0,0,0);
+  Coord minPos(100000, 100000, 100000);
+  Coord maxPos(-100000, -100000, -100000);
+  Coord zero(0, 0, 0);
 
-  node u;
-  forEach(u, linLogWeight->getNonDefaultValuatedNodes()) {
-    const Coord& position = layoutResult->getNodeValue(u);
+  node n;
+  for (auto u : linLogWeight.getNonDefaultValuatedNodes()) {
+    const Coord &position = layoutResult->getNodeValue(u);
 
     for (unsigned int d = 0; d < _dim; ++d) {
-      minPos[d] = std::min (position[d], minPos[d]);
-      maxPos[d] = std::max (position[d], maxPos[d]);
+      minPos[d] = std::min(position[d], minPos[d]);
+      maxPos[d] = std::max(position[d], maxPos[d]);
     }
+    n = u;
   }
 
   // provide additional space for moving nodes
@@ -885,24 +790,11 @@ OctTree* LinLogLayout::buildOctTree() {
     minPos[d] -= posDiff / 2;
   }
 
-  node n;
   // add nodes with non-zero weight to the octtree
-  OctTree* result = new OctTree(u, zero, minPos, maxPos, linLogWeight, true);
+  OctTree *result = new OctTree(n, zero, minPos, maxPos, &linLogWeight, true);
 
-  forEach (u, linLogWeight->getNonDefaultValuatedNodes()) {
-    result->addNode (u, layoutResult->getNodeValue(u), 0);
+  for (auto u : linLogWeight.getNonDefaultValuatedNodes()) {
+    result->addNode(u, layoutResult->getNodeValue(u), 0);
   }
   return result;
 }
-
-void LinLogLayout::setAttrExp (double d) {
-  attrExponent = d;
-}
-
-void LinLogLayout::setRepExp (double d) {
-  repuExponent = d;
-}
-
-void LinLogLayout::setGravFact (double d) {
-  gravFactor = d;
-}
