@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -22,33 +22,33 @@
 #include <tulip/Coord.h>
 class OrientableLayout;
 
-class OrientableCoord: public tlp::Coord {
+class OrientableCoord : public tlp::Coord {
 public:
-  OrientableCoord(OrientableLayout* fatherParam, const float x = 0,
-                  const float y = 0, const float z = 0);
-  OrientableCoord(OrientableLayout* fatherParam, const tlp::Coord& v);
+  OrientableCoord(OrientableLayout *fatherParam, const float x = 0, const float y = 0,
+                  const float z = 0);
+  OrientableCoord(OrientableLayout *fatherParam, const tlp::Coord &v);
 
-  void  set(const float x = 0, const float y = 0, const float z = 0);
-  void  set(const tlp::Coord& v);
+  void set(const float x = 0, const float y = 0, const float z = 0);
+  void set(const tlp::Coord &v);
 
-  void  setX(float x);
-  void  setY(float y);
-  void  setZ(float z);
+  void setX(float x);
+  void setY(float y);
+  void setZ(float z);
 
   float getX() const;
   float getY() const;
   float getZ() const;
 
-  void  setInvertedX(float x);
-  void  setInvertedY(float y);
-  void  setInvertedZ(float z);
+  void setInvertedX(float x);
+  void setInvertedY(float y);
+  void setInvertedZ(float z);
 
   float getInvertedX() const;
   float getInvertedY() const;
   float getInvertedZ() const;
 
 protected:
-  OrientableLayout* father;
+  OrientableLayout *father;
 };
 
 #endif
