@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -26,11 +26,10 @@ namespace tlp {
  * each face of the planar map contains only 3 edges.
  * The input graph must be planr in order to call this function.
  */
-void triangulate(SuperGraph *map, std::vector<edge>& addedEdges);
+void triangulate(SuperGraph *map, std::vector<edge> &addedEdges);
 /**
  * Build the canonical ordering of a planar triangulated graph. For information
  * about canonical ordering the user must reffer to the planar graph drawing book.
  */
 void canonicalOrdering(SuperGraph *graph, std::vector<node> &order);
-}
-
+} // namespace tlp
