@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,28 +18,23 @@
  */
 #include "Random.h"
 
-static const char * paramHelp[] = {
-  // 3D
-  HTML_HELP_OPEN() \
-  HTML_HELP_DEF( "type", "Boolean" ) \
-  HTML_HELP_BODY() \
-  "If true, the layout is computed in 3D, else it is computed in 2D" \
-  HTML_HELP_CLOSE()
-};
+static const char *paramHelp[] = {
+    // 3D layout
+    "If true, the layout is computed in 3D, else it is computed in 2D."};
 
 PLUGIN(Random)
 
 using namespace std;
 using namespace tlp;
 
-Random::Random(const tlp::PluginContext* context):LayoutAlgorithm(context) {
+Random::Random(const tlp::PluginContext *context) : LayoutAlgorithm(context) {
   addInParameter<bool>("3D layout", paramHelp[0], "false");
 }
 
 bool Random::run() {
-  bool is3D = false ;
+  bool is3D = false;
 
-  if ( dataSet!=NULL ) {
+  if (dataSet != nullptr) {
     dataSet->get("3D layout", is3D);
   }
 
@@ -47,17 +42,10 @@ bool Random::run() {
   // initialize a random sequence according the given seed
   tlp::initRandomSequence();
 
-  Iterator<node> *itN=graph->getNodes();
-
-  while (itN->hasNext()) {
-    node itn=itN->next();
-
-    if(is3D)
-      result->setNodeValue(itn,Coord(rand()%1024,rand()%1024,rand()%1024));
-    else
-      result->setNodeValue(itn,Coord(rand()%1024,rand()%1024,0));
+  for (auto n : graph->nodes()) {
+    result->setNodeValue(
+        n, Coord(randomInteger(1024), randomInteger(1024), is3D ? randomInteger(1024) : 0));
   }
 
-  delete itN;
   return true;
 }
