@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,13 +21,7 @@
 
 #include <tulip/TulipPluginHeaders.h>
 
-/// Random.h - An implementation of a random 3D layout.
-/** This plugin is an implementation of a random 3D layout
- *
- *  <b>HISTORY</b>
- *
- *  01/12/99 Verson 0.0.1: Initial release
- *
+/** This plugin is an implementation of a random 3D/2D layout
  *
  *  \note This algorithm works on general graphs. \n
  *  Let n be the number of nodes, the algorithm complexity is in O(n).
@@ -35,13 +29,13 @@
  *
  *  \author David Auber University Bordeaux I France, Email : auber@tulip-software.com
  */
-class Random:public tlp::LayoutAlgorithm {
+class Random : public tlp::LayoutAlgorithm {
 public:
-  PLUGININFORMATION("Random layout","David Auber","01/12/1999","The positions of the graph nodes are randomly selected.","1.1","Basic")
-  Random(const tlp::PluginContext* context);
+  PLUGININFORMATION("Random layout", "David Auber", "01/12/1999",
+                    "The positions of the graph nodes are randomly selected.", "1.1", "Basic")
+  Random(const tlp::PluginContext *context);
 
-  bool run();
+  bool run() override;
 };
 
 #endif
-
