@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -32,18 +32,19 @@
  *  "1963",
  *  pages 743-768.
  *
-*/
-class Tutte:public tlp::LayoutAlgorithm {
+ */
+class Tutte : public tlp::LayoutAlgorithm {
 public:
-  PLUGININFORMATION("3-Connected (Tutte)","David Auber","06/11/2002",
-                    "Implements the Tutte layout for 3-Connected graph algorithm first published as:<br/>"
-                    "<b>How to Draw a Graph</b>, W.T. Tutte, Proc. London Math. Soc. pages 743--768 (1963).",
-                    "1.0","Planar")
-  Tutte(const tlp::PluginContext* context);
-  ~Tutte();
+  PLUGININFORMATION(
+      "3-Connected (Tutte)", "David Auber", "06/11/2002",
+      "Implements the Tutte layout for 3-Connected graph algorithm first published as:<br/>"
+      "<b>How to Draw a Graph</b>, W.T. Tutte, Proc. London Math. Soc. pages 743--768 (1963).",
+      "1.0", "Planar")
+  Tutte(const tlp::PluginContext *context);
+  ~Tutte() override;
 
-  bool run();
-  bool check(std::string &);
+  bool run() override;
+  bool check(std::string &) override;
 };
 
 #endif
