@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -23,26 +23,24 @@ PLUGIN(DagLevelMetric)
 using namespace std;
 using namespace tlp;
 
-DagLevelMetric::DagLevelMetric(const tlp::PluginContext* context):DoubleAlgorithm(context) {}
+DagLevelMetric::DagLevelMetric(const tlp::PluginContext *context) : DoubleAlgorithm(context) {}
 
 DagLevelMetric::~DagLevelMetric() {}
 //======================================================
 bool DagLevelMetric::run() {
-  MutableContainer<unsigned int> level;
-  dagLevel(graph, level, pluginProgress);
-  node n;
-  forEach(n, graph->getNodes())
-  result->setNodeValue(n, level.get(n.id));
+  NodeStaticProperty<unsigned int> level(graph);
+  dagLevel(graph, level);
+  level.copyToProperty(result);
+
   return true;
 }
 //======================================================
 bool DagLevelMetric::check(std::string &erreurMsg) {
   if (AcyclicTest::isAcyclic(graph)) {
-    erreurMsg="";
+    erreurMsg = "";
     return true;
-  }
-  else {
-    erreurMsg="The graph must be a acylic.";
+  } else {
+    erreurMsg = "The graph must be a acylic.";
     return false;
   }
 }
