@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -27,13 +27,14 @@
  *  \note This algorithm works on general DAG, the complexity is in O(|E|+|V|);
  *
  */
-class DagLevelMetric:public tlp::DoubleAlgorithm {
+class DagLevelMetric : public tlp::DoubleAlgorithm {
 public:
-  PLUGININFORMATION("Dag Level","David Auber","10/03/2000","Implements a DAG layer decomposition.","1.0","Hierarchical")
-  DagLevelMetric(const tlp::PluginContext* context);
-  ~DagLevelMetric();
-  bool run();
-  bool check(std::string& erreurMsg);
+  PLUGININFORMATION("Dag Level", "David Auber", "10/03/2000",
+                    "Implements a DAG layer decomposition.", "1.0", "Hierarchical")
+  DagLevelMetric(const tlp::PluginContext *context);
+  ~DagLevelMetric() override;
+  bool run() override;
+  bool check(std::string &erreurMsg) override;
 };
 
 #endif
