@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,7 +19,7 @@
 #ifndef _DEGREEMETRIC_H
 #define _DEGREEMETRIC_H
 
-#include <tulip/TulipPluginHeaders.h>
+#include <tulip/DoubleProperty.h>
 
 /** \addtogroup metric */
 
@@ -31,12 +31,13 @@
  *  available in each graph.
  *
  */
-class DegreeMetric:public tlp::DoubleAlgorithm {
+class DegreeMetric : public tlp::DoubleAlgorithm {
 public:
-  PLUGININFORMATION("Degree","David Auber","04/10/2001","Assigns its degree to each node.","1.0","Graph")
-  DegreeMetric(const tlp::PluginContext* context);
-  bool run();
-  bool check(std::string& errorMsg);
+  PLUGININFORMATION("Degree", "David Auber", "04/10/2001", "Assigns its degree to each node.",
+                    "1.0", "Graph")
+  DegreeMetric(const tlp::PluginContext *context);
+  bool run() override;
+  bool check(std::string &errorMsg) override;
 };
 
 #endif
