@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,31 +19,26 @@
 #ifndef _LEAFMETRIC_H
 #define _LEAFMETRIC_H
 
-#include <tulip/TulipPluginHeaders.h>
+#include <tulip/DoubleProperty.h>
 
 /** \addtogroup metric */
 
 /** This plugin computes the number of leaves in the subtree induced by each node.
  *
- *  \note This algorithm assigns to each node a value defined as following : If two nodes are in the same
- *  connected component they have the same value else they have a
- *  different value.
  *
  */
-class LeafMetric:public tlp::DoubleAlgorithm {
+class LeafMetric : public tlp::DoubleAlgorithm {
 public:
-  PLUGININFORMATION("Leaf","David Auber","20/12/1999",
+  PLUGININFORMATION("Leaf", "David Auber", "20/12/1999",
                     "Computes the number of leaves in the subtree induced by each node.<br/>"
                     "<b>The graph must be acyclic</b>.",
-                    "1.0","Hierarchical")
-  LeafMetric(const tlp::PluginContext* context);
-  bool check(std::string &);
-  bool run();
+                    "1.0", "Hierarchical")
+  LeafMetric(const tlp::PluginContext *context);
+  bool check(std::string &) override;
+  bool run() override;
+
 private:
   double getNodeValue(const tlp::node n);
 };
 
 #endif
-
-
-
