@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,29 +21,28 @@
 
 #include <tulip/TulipPluginHeaders.h>
 
-
-
-
 /** \addtogroup metric */
 
 /** This plugin computes the number of nodes in the subtree induced by each node.
  *
- *  \note This algorithm assigns to each node a value defined as following : If two nodes are in the same
+ *  \note This algorithm assigns to each node a value defined as following : If two nodes are in the
+ * same
  *  connected component they have the same value else they have a
  *  different value.
  *
  */
-class NodeMetric:public tlp::DoubleAlgorithm {
+class NodeMetric : public tlp::DoubleAlgorithm {
 public:
-  PLUGININFORMATION("Node","David Auber","20/12/1999",
+  PLUGININFORMATION("Node", "David Auber", "20/12/1999",
                     "Computes the number of nodes in the subtree induced by each node.<br/>"
-                    "<b>The graph must be acyclic</b>.","1.0","Hierarchical")
-  NodeMetric(const tlp::PluginContext* context);
-  bool run();
-  bool check(std::string &);
+                    "<b>The graph must be acyclic</b>.",
+                    "1.0", "Hierarchical")
+  NodeMetric(const tlp::PluginContext *context);
+  bool run() override;
+  bool check(std::string &) override;
+
 private:
   double getNodeValue(const tlp::node n);
 };
 
 #endif
-
