@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -16,32 +16,22 @@
  * See the GNU General Public License for more details.
  *
  */
-#ifndef _RANDOMMETRIC_H
-#define _RANDOMMETRIC_H
+#ifndef RANDOMMETRIC_H
+#define RANDOMMETRIC_H
 
-#include <tulip/TulipPluginHeaders.h>
+#include <tulip/DoubleProperty.h>
 
 /** \addtogroup metric */
 
-/** This plugins assigns random values to nodes and edges. the values are between 0 and 1.
- *
+/** This plugin assigns random values to nodes or edges or both.
+ * The values are between 0 and 1.
  */
-class RandomMetric:public tlp::DoubleAlgorithm {
+class RandomMetric : public tlp::DoubleAlgorithm {
+
 public:
-  PLUGININFORMATION("Random metric","David Auber","04/10/2001","Assigns random values to nodes and edges.","1.0","Misc")
-  RandomMetric(const tlp::PluginContext* context);
-  bool run();
+  PLUGININFORMATION("Random metric", "David Auber", "04/10/2001",
+                    "Assigns random values to nodes and edges.", "1.1", "Misc")
+  RandomMetric(const tlp::PluginContext *context);
+  bool run() override;
 };
-
-#endif
-
-
-
-
-
-
-
-
-
-
-
+#endif // RANDOMMETRIC_H
