@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -28,12 +28,12 @@ class ExpandableGroupBox : public QGroupBox {
   Q_PROPERTY(bool expanded READ expanded WRITE setExpanded)
   bool _expanded;
 
-  Q_PROPERTY(QWidget * widget READ widget WRITE setWidget)
+  Q_PROPERTY(QWidget *widget READ widget WRITE setWidget)
   QWidget *_widget;
 
 public:
-  explicit ExpandableGroupBox(QWidget *parent = NULL, const QString &title=QString());
-  virtual ~ExpandableGroupBox();
+  explicit ExpandableGroupBox(QWidget *parent = nullptr, const QString &title = QString());
+  ~ExpandableGroupBox() override;
   bool expanded() const {
     return _expanded;
   }
