@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -31,26 +31,27 @@ namespace tlp {
 class GraphHierarchiesModel;
 }
 
-class ExportWizard: public QWizard {
+class ExportWizard : public QWizard {
   Q_OBJECT
 
-  Ui::ExportWizard* _ui;
-  tlp::Graph* _graph;
+  Ui::ExportWizard *_ui;
+  tlp::Graph *_graph;
+
 public:
-  explicit ExportWizard(tlp::Graph* g, const QString& exportFile,
-                        QWidget *parent = NULL);
-  virtual ~ExportWizard();
+  explicit ExportWizard(tlp::Graph *g, const QString &exportFile, QWidget *parent = nullptr);
+  ~ExportWizard() override;
 
   QString algorithm() const;
   tlp::DataSet parameters() const;
   QString outputFile() const;
 
 protected slots:
-  void algorithmSelected (const QModelIndex& index);
+  void algorithmSelected(const QModelIndex &index);
   void updateFinishButton();
 
   void pathChanged(QString s);
   void browseButtonClicked();
+  bool validateCurrentPage() override;
 };
 
 #endif // EXPORTWIZARD_H
