@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -31,19 +31,20 @@ namespace tlp {
 class GraphHierarchiesModel;
 }
 
-class ImportWizard: public QWizard {
+class ImportWizard : public QWizard {
   Q_OBJECT
 
-  Ui::ImportWizard* _ui;
+  Ui::ImportWizard *_ui;
+
 public:
-  explicit ImportWizard(QWidget *parent = NULL);
-  virtual ~ImportWizard();
+  explicit ImportWizard(QWidget *parent = nullptr);
+  ~ImportWizard() override;
 
   QString algorithm() const;
   tlp::DataSet parameters() const;
 
 protected slots:
-  void algorithmSelected (const QModelIndex& index);
+  void algorithmSelected(const QModelIndex &index);
   void updateFinishButton();
 };
 
