@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -29,16 +29,22 @@ class PreferencesDialog;
 class PreferencesDialog : public QDialog {
   Q_OBJECT
 
-  Ui::PreferencesDialog* _ui;
+  Ui::PreferencesDialog *_ui;
+
 public:
-  explicit PreferencesDialog(QWidget *parent = 0);
-  ~PreferencesDialog();
+  explicit PreferencesDialog(QWidget *parent = nullptr);
+  ~PreferencesDialog() override;
 
 public slots:
   void writeSettings();
   void readSettings();
   void cellChanged(int row, int column);
   void randomSeedCheckChanged(int);
+  void showGraphDefaultsContextMenu(const QPoint &);
+
+private slots:
+  void usetlpbformat(int state);
+  void resetToTulipDefaults(int row = -1, int updateMode = 0);
 };
 
 #endif // PREFERENCESDIALOG_H
