@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,29 +19,26 @@
 #ifndef Tulip_LoopSelection_H
 #define Tulip_LoopSelection_H
 
-#include <tulip/TulipPluginHeaders.h>
+#include <tulip/BooleanProperty.h>
+#include "../utils/PluginNames.h"
 
 /** \addtogroup selection */
 
-
 /**
  * This selection plugins enables to find loops in a graph
  * A loop is an edge that has the same source and target.
  *
  *  \author David Auber, LaBRI University Bordeaux I France:
- *   auber@tulip-software.org
+ *   auber@labri.fr
  */
-class LoopSelection:public tlp::BooleanAlgorithm {
+class LoopSelection : public tlp::BooleanAlgorithm {
 public:
-  PLUGININFORMATION("Loop Selection","David Auber","20/01/2003",
-                    "Selects loops in a graph.<br/>A loop is an edge that has the same source and target.",
-                    "1.0", "Selection")
-  LoopSelection(const tlp::PluginContext* context);
-  bool run();
+  PLUGININFORMATION(
+      tlp::SelectionAlgorithm::LoopSelection, "David Auber", "20/01/2003",
+      "Selects loops in a graph.<br/>A loop is an edge that has the same source and target.", "1.0",
+      "Selection")
+  LoopSelection(const tlp::PluginContext *context);
+  bool run() override;
 };
 
 #endif
-
-
-
-
