@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,7 +17,7 @@
  *
  */
 #include "MultipleEdgeSelection.h"
-#include <tulip/BooleanProperty.h>
+
 #include <tulip/SimpleTest.h>
 
 PLUGIN(MultipleEdgeSelection)
@@ -25,17 +25,30 @@ PLUGIN(MultipleEdgeSelection)
 using namespace std;
 using namespace tlp;
 
-MultipleEdgeSelection::MultipleEdgeSelection(const tlp::PluginContext* context):BooleanAlgorithm(context) {}
+MultipleEdgeSelection::MultipleEdgeSelection(const tlp::PluginContext *context)
+    : BooleanAlgorithm(context) {
+  addInParameter<bool>("directed",
+                       "Indicates if the graph should be considered as directed or not.", "false");
+  addOutParameter<unsigned int>("#edges selected", "The number of multiple edges selected");
+}
 
 bool MultipleEdgeSelection::run() {
+  bool directed = false;
+  if (dataSet)
+    dataSet->get("directed", directed);
+
   vector<edge> multipleEdges;
-  SimpleTest::simpleTest(graph, &multipleEdges);
+  SimpleTest::simpleTest(graph, &multipleEdges, nullptr, directed);
   result->setAllNodeValue(false);
   result->setAllEdgeValue(false);
-  vector<edge>::const_iterator it;
 
-  for (it = multipleEdges.begin(); it != multipleEdges.end(); ++it)
-    result->setEdgeValue(*it, true);
+  for (auto e : multipleEdges) {
+    result->setEdgeValue(e, true);
+  }
+
+  // output some useful information
+  if (dataSet != nullptr)
+    dataSet->set("#edges selected", uint(multipleEdges.size()));
 
   return true;
 }
