@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -16,8 +16,9 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <tulip/BooleanProperty.h>
+
 #include <tulip/AcyclicTest.h>
+#include <tulip/StaticProperty.h>
 
 #include "SpanningDagSelection.h"
 
@@ -27,16 +28,30 @@ using namespace std;
 using namespace tlp;
 
 //=================================================================
-SpanningDagSelection::SpanningDagSelection(const tlp::PluginContext* context):BooleanAlgorithm(context) {}
+SpanningDagSelection::SpanningDagSelection(const tlp::PluginContext *context)
+    : BooleanAlgorithm(context) {
+  addOutParameter<unsigned int>("#edges selected", "The number of 'dag' selected edges");
+}
 //=================================================================
 bool SpanningDagSelection::run() {
-  result->setAllNodeValue(true);
-  result->setAllEdgeValue(true);
+  for (auto n : graph->nodes())
+    result->setNodeValue(n, true);
+
+  EdgeStaticProperty<bool> edgeprop(graph);
+  edgeprop.setAll(true);
+
   vector<edge> obstructions;
   AcyclicTest::acyclicTest(graph, &obstructions);
 
-  for (vector<edge>::const_iterator it = obstructions.begin(); it != obstructions.end(); ++it) {
-    result->setEdgeValue(*it, false);
+  for (auto e : obstructions) {
+    edgeprop[e] = false;
+  }
+
+  edgeprop.copyToProperty(result);
+
+  // output some useful information
+  if (dataSet != nullptr) {
+    dataSet->set("#edges selected", uint(graph->numberOfEdges() - obstructions.size()));
   }
 
   return true;
