@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,27 +19,24 @@
 #ifndef Tulip_SpanningDagSelection_H
 #define Tulip_SpanningDagSelection_H
 
-#include <tulip/TulipPluginHeaders.h>
-
-template<typename T>
-class MutableConatainer;
+#include <tulip/BooleanProperty.h>
+#include "../utils/PluginNames.h"
 
 /** \addtogroup selection */
 
-
 /**
- * This selection plugins enables to find a subgraph of G that is acyclic.
+ * This selection plugin enables to find a subgraph of G that is acyclic.
  *
- *  \author David Auber, LaBRI University Bordeaux I France:
- *   auber@tulip-software.org
+ *  \author David Auber, LaBRI University of Bordeaux, France:
+ *   auber@labri.fr
  */
-class SpanningDagSelection:public tlp::BooleanAlgorithm {
+class SpanningDagSelection : public tlp::BooleanAlgorithm {
 
 public:
-  PLUGININFORMATION("Spanning Dag","David Auber","01/12/1999",
-                    "Selects an acyclic subgraph of a graph.","1.0", "Selection")
-  SpanningDagSelection(const tlp::PluginContext* context);
-  bool run();
+  PLUGININFORMATION(tlp::SelectionAlgorithm::SpanningDagSelection, "David Auber", "01/12/1999",
+                    "Selects an acyclic subgraph of a graph.", "1.0", "Selection")
+  SpanningDagSelection(const tlp::PluginContext *context);
+  bool run() override;
 };
 
 #endif
