@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,24 +19,23 @@
 #ifndef Tulip_SPANNINGTREESELECTION_H
 #define Tulip_SPANNINGTREESELECTION_H
 
-#include <tulip/TulipPluginHeaders.h>
+#include <tulip/BooleanProperty.h>
 
 /** \addtogroup selection */
 
-
 /**
  * This selection plugins enables to find a subgraph of G that is a forest (a set of trees).
  *
  *  \author David Auber, LaBRI University Bordeaux I France:
- *   auber@tulip-software.org
+ *   auber@labri.fr
  */
-class SpanningTreeSelection:public tlp::BooleanAlgorithm {
+class SpanningTreeSelection : public tlp::BooleanAlgorithm {
 public:
-  PLUGININFORMATION("Spanning Forest","David Auber","01/12/1999",
-                    "Selects a subgraph of a graph that is a forest (a set of trees).","1.0", "Selection")
-  SpanningTreeSelection(const tlp::PluginContext* context);
-  ~SpanningTreeSelection();
-  bool run();
+  PLUGININFORMATION("Spanning Forest", "David Auber", "01/12/1999",
+                    "Selects a subgraph of a graph that is a forest (a set of trees).", "1.0",
+                    "Selection")
+  SpanningTreeSelection(const tlp::PluginContext *context);
+  bool run() override;
 };
 
 #endif
