@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,13 +17,14 @@
  *
  */
 
-#ifndef ADDRESSSELECTIONDIALOG_H_
-#define ADDRESSSELECTIONDIALOG_H_
+#ifndef ADDRESS_SELECTION_DIALOG_H
+#define ADDRESS_SELECTION_DIALOG_H
 
 #include <QDialog>
 
 class QWidget;
 class QString;
+class QShowEvent;
 
 namespace Ui {
 class AddressSelectionDialogData;
@@ -32,12 +33,11 @@ class AddressSelectionDialogData;
 namespace tlp {
 class AddressSelectionDialog : public QDialog {
 
-  Ui::AddressSelectionDialogData* _ui;
+  Ui::AddressSelectionDialogData *_ui;
 
-public :
-
-  AddressSelectionDialog(QWidget *parent = 0);
-  ~AddressSelectionDialog();
+public:
+  AddressSelectionDialog(QWidget *parent = nullptr);
+  ~AddressSelectionDialog() override;
 
   void setBaseAddress(const QString &address);
 
@@ -49,6 +49,8 @@ public :
 
   bool rememberAddressChoice() const;
 
+  void showEvent(QShowEvent *showEvt) override;
 };
-}
-#endif /* ADDRESSSELECTIONDIALOG_H_ */
+} // namespace tlp
+
+#endif // ADDRESS_SELECTION_DIALOG_H
