@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -32,27 +32,25 @@ class QWidget;
 
 namespace tlp {
 
-class GlyphScaleConfigDialog : public QDialog  {
+class GlyphScaleConfigDialog : public QDialog {
 
   Q_OBJECT
 
-public :
-
-  GlyphScaleConfigDialog(QWidget *parent = 0);
-  ~GlyphScaleConfigDialog();
+public:
+  GlyphScaleConfigDialog(QWidget *parent = nullptr);
+  ~GlyphScaleConfigDialog() override;
 
   std::vector<int> getSelectedGlyphsId() const;
 
-  void showEvent(QShowEvent *event);
+  void showEvent(QShowEvent *event) override;
 
-private slots :
+private slots:
 
   void nbGlyphsSpinBoxValueChanged(int value);
 
-private :
-
+private:
   QStringList glyphsNameList;
-  Ui::GlyphScaleConfigDialogData* _ui;
+  Ui::GlyphScaleConfigDialogData *_ui;
 };
-}
+} // namespace tlp
 #endif /* GLYPHSCALECONFIGDIALOG_H_ */
