@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,7 +21,6 @@
 #include <tulip/IntegerProperty.h>
 #include <tulip/GlPolyQuad.h>
 #include <tulip/Gl2DRect.h>
-#include <tulip/ForEach.h>
 #include <tulip/GlOffscreenRenderer.h>
 #include <tulip/GlTextureManager.h>
 #include <tulip/TlpTools.h>
@@ -31,14 +30,11 @@
 
 using namespace std;
 
-const string BIN_RECT_TEXTURE = tlp::TulipBitmapDir + "histo_texture.png";
-
 const float DEFAULT_AXIS_LENGTH = 1000.;
 
 const std::string XAXIS_ID = "x axis";
 const std::string YAXIS_ID = "y axis";
 
-
 template <typename T>
 std::string getStringFromNumber(T number, unsigned int precision = 5) {
   std::ostringstream oss;
@@ -49,11 +45,11 @@ std::string getStringFromNumber(T number, unsigned int precision = 5) {
 
 namespace tlp {
 
-static void setGraphView (GlGraphComposite *glGraph, bool displayEdges) {
+static void setGraphView(GlGraphComposite *glGraph, bool displayEdges) {
   GlGraphRenderingParameters param = glGraph->getRenderingParameters();
-  param.setAntialiasing (true);
-  param.setViewNodeLabel (true);
-  param.setFontsType (2);
+  param.setAntialiasing(true);
+  param.setViewNodeLabel(true);
+  param.setFontsType(2);
   param.setSelectedNodesStencil(1);
   param.setNodesStencil(1);
   param.setNodesLabelStencil(1);
@@ -62,28 +58,34 @@ static void setGraphView (GlGraphComposite *glGraph, bool displayEdges) {
   param.setSelectedEdgesStencil(1);
   param.setDisplayNodes(true);
   param.setDisplayMetaNodes(true);
-  glGraph->setRenderingParameters (param);
+  glGraph->setRenderingParameters(param);
 }
 
 int Histogram::overviewCpt(0);
 
-Histogram::Histogram(Graph *graph, Graph* edgeGraph,
-                     std::map<edge, node>& edgeMap,
-                     const std::string& propertyName, const ElementType &dataLocation, const Coord &blCorner, unsigned int size,
-                     const Color &backgroundColor, const Color &textColor) :
-  graph(graph), propertyName(propertyName), blCorner(blCorner), size(size), nbHistogramBins(100), xAxis(NULL), yAxis(NULL),
-  xAxisLogScale(false), yAxisLogScale(false), nbXGraduations(15), yAxisIncrementStep(0), histogramLayout(new LayoutProperty(graph)), histogramEdgeLayout(new LayoutProperty(graph)), histogramSize(new SizeProperty(graph)), histoBinsComposite(new GlComposite()), uniformQuantification(false),
-  cumulativeFreqHisto(false), lastCumulHisto(false), edgeAsNodeGraph(edgeGraph), edgeToNode(edgeMap), backgroundColor(backgroundColor), textColor(textColor), integerScale(false),
-  dataLocation(dataLocation), displayEdges(false), layoutUpdateNeeded(true),sizesUpdateNeeded(true), textureUpdateNeeded(true), xAxisScaleDefined(false), yAxisScaleDefined(false),
-  xAxisScale(make_pair(0,0)), yAxisScale(make_pair(0,0)), initXAxisScale(make_pair(0,0)), initYAxisScale(make_pair(0,0)) {
+Histogram::Histogram(Graph *graph, Graph *edgeGraph, std::unordered_map<edge, node> &edgeMap,
+                     const std::string &propertyName, const ElementType &dataLocation,
+                     const Coord &blCorner, unsigned int size, const Color &backgroundColor,
+                     const Color &textColor)
+    : graph(graph), propertyName(propertyName), blCorner(blCorner), size(size),
+      nbHistogramBins(100), xAxis(nullptr), yAxis(nullptr), xAxisLogScale(false),
+      yAxisLogScale(false), nbXGraduations(15), yAxisIncrementStep(0),
+      histogramLayout(new LayoutProperty(graph)), histogramEdgeLayout(new LayoutProperty(graph)),
+      histogramSize(new SizeProperty(graph)), histoBinsComposite(new GlComposite()),
+      uniformQuantification(false), cumulativeFreqHisto(false), lastCumulHisto(false),
+      edgeAsNodeGraph(edgeGraph), edgeToNode(edgeMap), backgroundColor(backgroundColor),
+      textColor(textColor), integerScale(false), dataLocation(dataLocation), displayEdges(false),
+      layoutUpdateNeeded(true), sizesUpdateNeeded(true), updateNeeded(true),
+      xAxisScaleDefined(false), yAxisScaleDefined(false), xAxisScale(make_pair(0, 0)),
+      yAxisScale(make_pair(0, 0)), initXAxisScale(make_pair(0, 0)),
+      initYAxisScale(make_pair(0, 0)) {
 
   if (dataLocation == NODE) {
     graphComposite = new GlGraphComposite(graph);
     GlGraphInputData *glGraphInputData = graphComposite->getInputData();
     glGraphInputData->setElementLayout(histogramLayout);
     glGraphInputData->setElementSize(histogramSize);
-  }
-  else {
+  } else {
     graphComposite = new GlGraphComposite(edgeAsNodeGraph);
     GlGraphInputData *glGraphInputData = graphComposite->getInputData();
     glGraphInputData->setElementLayout(histogramEdgeLayout);
@@ -96,12 +98,14 @@ Histogram::Histogram(Graph *graph, Graph* edgeGraph,
 }
 
 Histogram::~Histogram() {
-  GlTextureManager::getInst().deleteTexture(textureName);
+  GlTextureManager::deleteTexture(textureName);
   delete histogramLayout;
   delete histogramEdgeLayout;
   delete histogramSize;
   delete histoBinsComposite;
   delete graphComposite;
+  delete xAxis;
+  delete yAxis;
 }
 
 void Histogram::setDataLocation(const ElementType &dataLocation) {
@@ -115,8 +119,7 @@ void Histogram::setDataLocation(const ElementType &dataLocation) {
       GlGraphInputData *glGraphInputData = graphComposite->getInputData();
       glGraphInputData->setElementLayout(histogramLayout);
       glGraphInputData->setElementSize(histogramSize);
-    }
-    else {
+    } else {
       graphComposite = new GlGraphComposite(edgeAsNodeGraph);
       GlGraphInputData *glGraphInputData = graphComposite->getInputData();
       glGraphInputData->setElementLayout(histogramEdgeLayout);
@@ -141,20 +144,17 @@ void Histogram::computeHistogram() {
     if (dataLocation == NODE) {
       min = graph->getProperty<DoubleProperty>(propertyName)->getNodeMin(graph);
       max = graph->getProperty<DoubleProperty>(propertyName)->getNodeMax(graph);
-    }
-    else {
+    } else {
       min = graph->getProperty<DoubleProperty>(propertyName)->getEdgeMin(graph);
       max = graph->getProperty<DoubleProperty>(propertyName)->getEdgeMax(graph);
     }
-  }
-  else {
+  } else {
     if (dataLocation == NODE) {
-      min = (double) graph->getProperty<IntegerProperty>(propertyName)->getNodeMin(graph);
-      max = (double) graph->getProperty<IntegerProperty>(propertyName)->getNodeMax(graph);
-    }
-    else {
-      min = (double) graph->getProperty<IntegerProperty>(propertyName)->getEdgeMin(graph);
-      max = (double) graph->getProperty<IntegerProperty>(propertyName)->getEdgeMax(graph);
+      min = graph->getProperty<IntegerProperty>(propertyName)->getNodeMin(graph);
+      max = graph->getProperty<IntegerProperty>(propertyName)->getNodeMax(graph);
+    } else {
+      min = graph->getProperty<IntegerProperty>(propertyName)->getEdgeMin(graph);
+      max = graph->getProperty<IntegerProperty>(propertyName)->getEdgeMax(graph);
     }
   }
 
@@ -181,47 +181,35 @@ void Histogram::computeHistogram() {
   integerScale = true;
 
   if (uniformQuantification) {
-    DoubleProperty *propertyCopy = new DoubleProperty(graph);
+    DoubleProperty propertyCopy(graph);
 
     if (graph->getProperty(propertyName)->getTypename() == "double") {
-      *propertyCopy = *(graph->getProperty<DoubleProperty>(propertyName));
-    }
-    else {
-      if (dataLocation ==  NODE) {
-        Iterator<node> *nodesIt = graph->getNodes();
-
-        while (nodesIt->hasNext()) {
-          node n = nodesIt->next();
-          propertyCopy->setNodeValue(n, graph->getProperty<IntegerProperty>(propertyName)->getNodeValue(n));
+      propertyCopy = *(graph->getProperty<DoubleProperty>(propertyName));
+    } else {
+      if (dataLocation == NODE) {
+        for (auto n : graph->nodes()) {
+          propertyCopy.setNodeValue(
+              n, graph->getProperty<IntegerProperty>(propertyName)->getNodeValue(n));
         }
-
-        delete nodesIt;
-      }
-      else {
-        Iterator<edge> *edgesIt = graph->getEdges();
-
-        while (edgesIt->hasNext()) {
-          edge e = edgesIt->next();
-          propertyCopy->setEdgeValue(e, graph->getProperty<IntegerProperty>(propertyName)->getEdgeValue(e));
+      } else {
+        for (auto e : graph->edges()) {
+          propertyCopy.setEdgeValue(
+              e, graph->getProperty<IntegerProperty>(propertyName)->getEdgeValue(e));
         }
-
-        delete edgesIt;
       }
     }
 
-    propertyCopy->uniformQuantification(nbHistogramBins);
+    propertyCopy.uniformQuantification(nbHistogramBins);
 
-    for (unsigned int i = 0 ; i < nbHistogramBins ; ++i) {
+    for (unsigned int i = 0; i < nbHistogramBins; ++i) {
       binMinMaxMap[i].first = DBL_MAX;
       binMinMaxMap[i].second = 0;
     }
 
     if (dataLocation == NODE) {
-      Iterator<node> *nodesIt = graph->getNodes();
 
-      while (nodesIt->hasNext()) {
-        node n = nodesIt->next();
-        unsigned int binId = (unsigned int) propertyCopy->getNodeValue(n);
+      for (auto n : graph->nodes()) {
+        unsigned int binId = uint(propertyCopy.getNodeValue(n));
         histogramBins[binId].push_back(n.id);
 
         if (histogramBins[binId].size() > maxBinSize) {
@@ -232,8 +220,7 @@ void Histogram::computeHistogram() {
 
         if (graph->getProperty(propertyName)->getTypename() == "double") {
           val = graph->getProperty<DoubleProperty>(propertyName)->getNodeValue(n);
-        }
-        else {
+        } else {
           val = graph->getProperty<IntegerProperty>(propertyName)->getNodeValue(n);
         }
 
@@ -246,15 +233,10 @@ void Histogram::computeHistogram() {
         }
       }
 
-      delete nodesIt;
+    } else {
 
-    }
-    else {
-      Iterator<edge> *edgesIt = graph->getEdges();
-
-      while (edgesIt->hasNext()) {
-        edge e = edgesIt->next();
-        unsigned int binId = (unsigned int) propertyCopy->getEdgeValue(e);
+      for (auto e : graph->edges()) {
+        unsigned int binId = uint(propertyCopy.getEdgeValue(e));
         histogramBins[binId].push_back(e.id);
 
         if (histogramBins[binId].size() > maxBinSize) {
@@ -265,8 +247,7 @@ void Histogram::computeHistogram() {
 
         if (graph->getProperty(propertyName)->getTypename() == "double") {
           val = graph->getProperty<DoubleProperty>(propertyName)->getEdgeValue(e);
-        }
-        else {
+        } else {
           val = graph->getProperty<IntegerProperty>(propertyName)->getEdgeValue(e);
         }
 
@@ -278,36 +259,29 @@ void Histogram::computeHistogram() {
           binMinMaxMap[binId].second = val;
         }
       }
-
-      delete edgesIt;
     }
 
     uniformQuantificationAxisLabels.clear();
 
-    for (unsigned int i = 0 ; i < nbHistogramBins ; ++i) {
+    for (unsigned int i = 0; i < nbHistogramBins; ++i) {
       if (histogramBins[i].size() > 0) {
         uniformQuantificationAxisLabels.push_back(getStringFromNumber(binMinMaxMap[i].first));
-      }
-      else {
-        if (histogramBins[i-1].size() > 0) {
-          uniformQuantificationAxisLabels.push_back(getStringFromNumber(binMinMaxMap[i-1].second));
-        }
-        else {
+      } else {
+        if (histogramBins[i - 1].size() > 0) {
+          uniformQuantificationAxisLabels.push_back(
+              getStringFromNumber(binMinMaxMap[i - 1].second));
+        } else {
           uniformQuantificationAxisLabels.push_back(" ");
         }
       }
     }
 
-    uniformQuantificationAxisLabels.push_back(getStringFromNumber(binMinMaxMap[nbHistogramBins - 1].second));
-    delete propertyCopy;
-
-  }
-  else {
+    uniformQuantificationAxisLabels.push_back(
+        getStringFromNumber(binMinMaxMap[nbHistogramBins - 1].second));
+  } else {
     if (dataLocation == NODE) {
-      Iterator<node> *nodesIt = graph->getNodes();
 
-      while (nodesIt->hasNext()) {
-        node n = nodesIt->next();
+      for (auto n : graph->nodes()) {
         double value;
 
         if (graph->getProperty(propertyName)->getTypename() == "double") {
@@ -315,36 +289,30 @@ void Histogram::computeHistogram() {
           double intpart, fracpart;
           fracpart = modf(value, &intpart);
           integerScale = integerScale && (fracpart == 0);
-        }
-        else {
-          value = (double) graph->getProperty<IntegerProperty>(propertyName)->getNodeValue(n);
+        } else {
+          value = graph->getProperty<IntegerProperty>(propertyName)->getNodeValue(n);
         }
 
         if (value != max) {
-          unsigned int nodeHistoBin = clamp(static_cast<unsigned int>(floor((value - min) / binWidth)), 0, nbHistogramBins - 1);
+          unsigned int nodeHistoBin =
+              clamp(uint(floor((value - min) / binWidth)), 0, nbHistogramBins - 1);
           histogramBins[nodeHistoBin].push_back(n.id);
 
           if (histogramBins[nodeHistoBin].size() > maxBinSize) {
             maxBinSize = histogramBins[nodeHistoBin].size();
           }
-        }
-        else {
+        } else {
           histogramBins[nbHistogramBins - 1].push_back(n.id);
 
           if (histogramBins[nbHistogramBins - 1].size() > maxBinSize) {
             maxBinSize = histogramBins[nbHistogramBins - 1].size();
           }
         }
-
       }
 
-      delete nodesIt;
-    }
-    else {
-      Iterator<edge> *edgesIt = graph->getEdges();
+    } else {
 
-      while (edgesIt->hasNext()) {
-        edge e = edgesIt->next();
+      for (auto e : graph->edges()) {
         double value;
 
         if (graph->getProperty(propertyName)->getTypename() == "double") {
@@ -352,20 +320,18 @@ void Histogram::computeHistogram() {
           double intpart, fracpart;
           fracpart = modf(value, &intpart);
           integerScale = integerScale && (fracpart == 0);
-        }
-        else {
-          value = (double) graph->getProperty<IntegerProperty>(propertyName)->getEdgeValue(e);
+        } else {
+          value = graph->getProperty<IntegerProperty>(propertyName)->getEdgeValue(e);
         }
 
         if (value != max) {
-          unsigned int nodeHistoBin = (unsigned int) floor((value - min) / binWidth);
+          unsigned int nodeHistoBin = uint(floor((value - min) / binWidth));
           histogramBins[nodeHistoBin].push_back(e.id);
 
           if (histogramBins[nodeHistoBin].size() > maxBinSize) {
             maxBinSize = histogramBins[nodeHistoBin].size();
           }
-        }
-        else {
+        } else {
           histogramBins[nbHistogramBins - 1].push_back(e.id);
 
           if (histogramBins[nbHistogramBins - 1].size() > maxBinSize) {
@@ -373,21 +339,17 @@ void Histogram::computeHistogram() {
           }
         }
       }
-
-      delete edgesIt;
     }
   }
 }
 
-
-
 void Histogram::createAxis() {
 
-  if (xAxis != NULL && yAxis != NULL) {
+  if (xAxis != nullptr && yAxis != nullptr) {
     delete xAxis;
     delete yAxis;
-    xAxis = NULL;
-    yAxis = NULL;
+    xAxis = nullptr;
+    yAxis = nullptr;
   }
 
   const float axisLength = DEFAULT_AXIS_LENGTH;
@@ -397,62 +359,62 @@ void Histogram::createAxis() {
   if (cumulativeFreqHisto) {
     if (dataLocation == NODE) {
       maxAxisValue = graph->numberOfNodes();
-    }
-    else {
+    } else {
       maxAxisValue = graph->numberOfEdges();
     }
-  }
-  else {
+  } else {
     maxAxisValue = maxBinSize;
   }
 
   initYAxisScale = make_pair(minAxisValue, maxAxisValue);
 
   if (yAxisScaleDefined) {
-    if (yAxisScale.first < (double)minAxisValue)
-      minAxisValue = (unsigned int)yAxisScale.first;
+    if (yAxisScale.first < double(minAxisValue))
+      minAxisValue = uint(yAxisScale.first);
 
-    if (yAxisScale.second > (double)maxAxisValue)
-      maxAxisValue = (unsigned int)yAxisScale.second;
+    if (yAxisScale.second > double(maxAxisValue))
+      maxAxisValue = uint(yAxisScale.second);
   }
 
-  yAxisScale.first = (double)minAxisValue;
-  yAxisScale.second = (double)maxAxisValue;
+  yAxisScale.first = minAxisValue;
+  yAxisScale.second = maxAxisValue;
 
   yAxisIncrementStep = maxAxisValue / 10;
 
-  if (yAxisIncrementStep < 1) yAxisIncrementStep = 1;
+  if (yAxisIncrementStep < 1)
+    yAxisIncrementStep = 1;
 
   if (lastCumulHisto != cumulativeFreqHisto) {
     unsigned int n;
 
     if (!lastCumulHisto) {
       n = maxBinSize;
-    }
-    else {
+    } else {
       if (dataLocation == NODE) {
         n = graph->numberOfNodes();
-      }
-      else {
+      } else {
         n = graph->numberOfEdges();
       }
     }
 
     yAxisIncrementStep = (yAxisIncrementStep * maxAxisValue) / n;
 
-    if (lastCumulHisto) ++yAxisIncrementStep;
+    if (lastCumulHisto)
+      ++yAxisIncrementStep;
   }
 
-  yAxis = new GlQuantitativeAxis((dataLocation == NODE ? "number of nodes" : "number of edges"), Coord(0,0,0), axisLength, GlAxis::VERTICAL_AXIS, textColor);
-  yAxis->setAxisParameters((int) minAxisValue ,(int) maxAxisValue, yAxisIncrementStep, GlAxis::LEFT_OR_BELOW, true);
+  yAxis = new GlQuantitativeAxis((dataLocation == NODE ? "number of nodes" : "number of edges"),
+                                 Coord(0, 0, 0), axisLength, GlAxis::VERTICAL_AXIS, textColor);
+  yAxis->setAxisParameters(int(minAxisValue), int(maxAxisValue), yAxisIncrementStep,
+                           GlAxis::LEFT_OR_BELOW, true);
   yAxis->setLogScale(yAxisLogScale);
   float yAxisGradsWidth = axisLength / 20;
   yAxis->setAxisGradsWidth(yAxisGradsWidth);
   yAxis->updateAxis();
   yAxis->addCaption(GlAxis::BELOW, axisLength / 10, false, (axisLength / 2.), 0, " ");
 
-
-  xAxis = new GlQuantitativeAxis(propertyName, Coord(0,0,0), axisLength, GlAxis::HORIZONTAL_AXIS, textColor, true);
+  xAxis = new GlQuantitativeAxis(propertyName, Coord(0, 0, 0), axisLength, GlAxis::HORIZONTAL_AXIS,
+                                 textColor, true);
   float xAxisGradWidth = axisLength / 20;
 
   if (uniformQuantification) {
@@ -463,26 +425,24 @@ void Histogram::createAxis() {
 
   if (uniformQuantification) {
     xAxis->setAxisGraduations(uniformQuantificationAxisLabels, GlAxis::LEFT_OR_BELOW);
-  }
-  else {
+  } else {
     if (integerScale) {
-      long long axisMin = (long long) min;
-      long long axisMax = (long long) max;
+      long long axisMin = static_cast<long long>(min);
+      long long axisMax = static_cast<long long>(max);
 
       // check the [min, max] double values range
       // fit in a long long range
       if (axisMax != LLONG_MIN) {
-        long long incrementStep = (long long) ((max - min) / nbXGraduations);
+        long long incrementStep = static_cast<long long>((max - min) / nbXGraduations);
 
-        if (incrementStep <1) incrementStep = 1;
+        if (incrementStep < 1)
+          incrementStep = 1;
 
         xAxis->setAxisParameters(axisMin, axisMax, incrementStep, GlAxis::LEFT_OR_BELOW, true);
-      }
-      else
-        xAxis->setAxisParameters(min ,max, nbXGraduations, GlAxis::LEFT_OR_BELOW, true);
-    }
-    else {
-      xAxis->setAxisParameters(min ,max, nbXGraduations, GlAxis::LEFT_OR_BELOW, true);
+      } else
+        xAxis->setAxisParameters(min, max, nbXGraduations, GlAxis::LEFT_OR_BELOW, true);
+    } else {
+      xAxis->setAxisParameters(min, max, nbXGraduations, GlAxis::LEFT_OR_BELOW, true);
     }
   }
 
@@ -495,19 +455,20 @@ void Histogram::createAxis() {
 
   if (cumulativeFreqHisto) {
     if (dataLocation == NODE) {
-      refSizeY = yAxis->getAxisPointCoordForValue(graph->numberOfNodes()).getY() / graph->numberOfNodes();
+      refSizeY =
+          yAxis->getAxisPointCoordForValue(graph->numberOfNodes()).getY() / graph->numberOfNodes();
+    } else {
+      refSizeY =
+          yAxis->getAxisPointCoordForValue(graph->numberOfEdges()).getY() / graph->numberOfEdges();
     }
-    else {
-      refSizeY = yAxis->getAxisPointCoordForValue(graph->numberOfEdges()).getY() / graph->numberOfEdges();
-    }
-  }
-  else {
+  } else {
     refSizeY = yAxis->getAxisPointCoordForValue(maxBinSize).getY() / maxBinSize;
   }
 
   refSize = std::min(refSizeX, refSizeY);
 
-  edgeAsNodeGraph->getProperty<SizeProperty>("viewSize")->setAllNodeValue(Size(refSize, refSize, 0));
+  edgeAsNodeGraph->getProperty<SizeProperty>("viewSize")
+      ->setAllNodeValue(Size(refSize, refSize, 0));
 }
 
 void Histogram::updateLayout() {
@@ -516,39 +477,40 @@ void Histogram::updateLayout() {
 
   unsigned int cumulativeSize = 0;
 
-  for (unsigned int i = 0 ; i < nbHistogramBins ; ++i) {
+  for (unsigned int i = 0; i < nbHistogramBins; ++i) {
     unsigned int binSize = histogramBins[i].size();
     cumulativeSize += binSize;
     float binXCoord, binXCoordEnd;
 
     if (!uniformQuantification) {
       binXCoord = xAxis->getAxisPointCoordForValue(min + i * binWidth).getX();
-      binXCoordEnd = xAxis->getAxisPointCoordForValue(min + (i+1) * binWidth).getX();
-    }
-    else {
+      binXCoordEnd = xAxis->getAxisPointCoordForValue(min + (i + 1) * binWidth).getX();
+    } else {
       binXCoord = i * refSizeX;
-      binXCoordEnd = (i+1) * refSizeX;
+      binXCoordEnd = (i + 1) * refSizeX;
     }
 
     float nodeXCoord = (binXCoord + binXCoordEnd) / 2.f;
 
-    for (unsigned int j = 0 ; j < binSize ; ++j) {
+    for (unsigned int j = 0; j < binSize; ++j) {
       float nodeYCoord;
 
       if (!cumulativeFreqHisto) {
-        nodeYCoord = (yAxis->getAxisPointCoordForValue(j).getY() + yAxis->getAxisPointCoordForValue(j+1).getY()) / 2.f;
+        nodeYCoord = (yAxis->getAxisPointCoordForValue(j).getY() +
+                      yAxis->getAxisPointCoordForValue(j + 1).getY()) /
+                     2.f;
 
-      }
-      else {
-        nodeYCoord = (yAxis->getAxisPointCoordForValue(cumulativeSize - j - 1).getY() + yAxis->getAxisPointCoordForValue(cumulativeSize - j).getY()) / 2.;
+      } else {
+        nodeYCoord = (yAxis->getAxisPointCoordForValue(cumulativeSize - j - 1).getY() +
+                      yAxis->getAxisPointCoordForValue(cumulativeSize - j).getY()) /
+                     2.;
       }
 
       Coord nodeCoord(nodeXCoord, nodeYCoord, 0);
 
       if (dataLocation == NODE) {
         histogramLayout->setNodeValue(node(histogramBins[i][j]), nodeCoord);
-      }
-      else {
+      } else {
         node n = edgeToNode[edge(histogramBins[i][j])];
         histogramEdgeLayout->setNodeValue(n, nodeCoord);
 
@@ -571,11 +533,10 @@ void Histogram::updateSizes() {
   float minSize = (refSize / 10.);
   Size deltaSize(eltMaxSize - eltMinSize);
 
-  for (unsigned int i = 0 ; i < 2 ; ++i) {
+  for (unsigned int i = 0; i < 2; ++i) {
     if (deltaSize[i] != 0) {
-      resizeFactor[i] = (refSize - minSize)/ deltaSize[i];
-    }
-    else {
+      resizeFactor[i] = (refSize - minSize) / deltaSize[i];
+    } else {
       resizeFactor[i] = 0;
     }
   }
@@ -586,7 +547,7 @@ void Histogram::updateSizes() {
     resize = false;
   }
 
-  for (unsigned int i = 0 ; i < nbHistogramBins ; ++i) {
+  for (unsigned int i = 0; i < nbHistogramBins; ++i) {
 
     unsigned int binSize = histogramBins[i].size();
 
@@ -594,14 +555,13 @@ void Histogram::updateSizes() {
 
     if (!uniformQuantification) {
       binXCoord = xAxis->getAxisPointCoordForValue(min + i * binWidth).getX();
-      binXCoordEnd = xAxis->getAxisPointCoordForValue(min + (i+1) * binWidth).getX();
-    }
-    else {
+      binXCoordEnd = xAxis->getAxisPointCoordForValue(min + (i + 1) * binWidth).getX();
+    } else {
       binXCoord = i * refSizeX;
-      binXCoordEnd = (i+1) * refSizeX;
+      binXCoordEnd = (i + 1) * refSizeX;
     }
 
-    for (unsigned int j = 0 ; j < binSize ; ++j) {
+    for (unsigned int j = 0; j < binSize; ++j) {
       if (dataLocation == NODE) {
         const Size &currentNodeSize = viewSize->getNodeValue(node(histogramBins[i][j]));
         Size newNodeSize;
@@ -609,8 +569,7 @@ void Histogram::updateSizes() {
         if (resize) {
           newNodeSize[0] = minSize + resizeFactor[0] * (currentNodeSize[0] - eltMinSize[0]);
           newNodeSize[1] = minSize + resizeFactor[1] * (currentNodeSize[1] - eltMinSize[1]);
-        }
-        else {
+        } else {
           newNodeSize[0] = refSize;
           newNodeSize[1] = refSize;
         }
@@ -630,7 +589,7 @@ void Histogram::updateSizes() {
 
 void Histogram::update() {
 
-  if (!textureUpdateNeeded)
+  if (!updateNeeded)
     return;
 
   if (layoutUpdateNeeded)
@@ -640,26 +599,28 @@ void Histogram::update() {
     updateSizes();
 
   ostringstream oss;
-  edgeAsNodeGraph->getProperty<SizeProperty>("viewSize")->setAllNodeValue(Size(refSize,refSize,refSize));
+  edgeAsNodeGraph->getProperty<SizeProperty>("viewSize")
+      ->setAllNodeValue(Size(refSize, refSize, refSize));
   ColorProperty *viewColor = graph->getProperty<ColorProperty>("viewColor");
 
+  reset(true);
   histoBinsComposite->reset(true);
 
   unsigned int cumulativeSize = 0;
   unsigned int rectCpt = 0;
   GlPolyQuad *cumulativeHistogram = new GlPolyQuad();
 
-  for (unsigned int i = 0 ; i < nbHistogramBins ; ++i) {
+  for (unsigned int i = 0; i < nbHistogramBins; ++i) {
     Vector<int, 4> quadColorCumul;
     quadColorCumul.fill(0);
     Color quadColor;
     unsigned int binSize = histogramBins[i].size();
     cumulativeSize += binSize;
 
-    for (unsigned int j = 0 ; j < binSize ; ++j) {
+    for (unsigned int j = 0; j < binSize; ++j) {
       if (dataLocation == NODE) {
-        for (unsigned int k = 0 ; k < 4 ; ++k ) {
-          quadColorCumul[k] += (unsigned int) viewColor->getNodeValue(node(histogramBins[i][j]))[k];
+        for (unsigned int k = 0; k < 4; ++k) {
+          quadColorCumul[k] += uint(viewColor->getNodeValue(node(histogramBins[i][j]))[k]);
         }
       }
     }
@@ -668,11 +629,10 @@ void Histogram::update() {
 
     if (!uniformQuantification) {
       binXCoord = xAxis->getAxisPointCoordForValue(min + i * binWidth).getX();
-      binXCoordEnd = xAxis->getAxisPointCoordForValue(min + (i+1) * binWidth).getX();
-    }
-    else {
+      binXCoordEnd = xAxis->getAxisPointCoordForValue(min + (i + 1) * binWidth).getX();
+    } else {
       binXCoord = i * refSizeX;
-      binXCoordEnd = (i+1) * refSizeX;
+      binXCoordEnd = (i + 1) * refSizeX;
     }
 
     if (binSize > 0) {
@@ -681,8 +641,7 @@ void Histogram::update() {
       if (!cumulativeFreqHisto) {
         binYTop = yAxis->getAxisPointCoordForValue(binSize).getY();
         binYBottom = yAxis->getAxisPointCoordForValue(0).getY();
-      }
-      else {
+      } else {
         binYTop = yAxis->getAxisPointCoordForValue(cumulativeSize).getY();
         binYBottom = yAxis->getAxisPointCoordForValue(cumulativeSize - binSize).getY();
       }
@@ -699,13 +658,14 @@ void Histogram::update() {
 
       if (dataLocation == NODE) {
         quadColorCumul /= binSize;
-        quadColor = Color(quadColorCumul[0], quadColorCumul[1], quadColorCumul[2], quadColorCumul[3]);
-      }
-      else {
-        quadColor = Color(255,0,0);
+        quadColor =
+            Color(quadColorCumul[0], quadColorCumul[1], quadColorCumul[2], quadColorCumul[3]);
+      } else {
+        quadColor = Color(255, 0, 0);
       }
 
-      GlPolyQuad *binRect = new GlPolyQuad(polyQuadCoords, quadColor, BIN_RECT_TEXTURE, true, 1, quadColor);
+      GlPolyQuad *binRect =
+          new GlPolyQuad(polyQuadCoords, quadColor, BIN_RECT_TEXTURE, true, 1, quadColor);
       binRect->setStencil(1);
       oss.str("");
       oss << "bin rect " << ++rectCpt;
@@ -716,10 +676,12 @@ void Histogram::update() {
       float quadEdgeYTopCoord = yAxis->getAxisPointCoordForValue(cumulativeSize).getY();
 
       if ((i == 0 || i == (nbHistogramBins - 1)) || binSize > 0) {
-        cumulativeHistogram->addQuadEdge(Coord(binXCoord, xAxis->getAxisBaseCoord().getY()), Coord(binXCoord, quadEdgeYTopCoord, 0), quadColor);
+        cumulativeHistogram->addQuadEdge(Coord(binXCoord, xAxis->getAxisBaseCoord().getY()),
+                                         Coord(binXCoord, quadEdgeYTopCoord, 0), quadColor);
 
         if (i == (nbHistogramBins - 1)) {
-          cumulativeHistogram->addQuadEdge(Coord(binXCoordEnd, xAxis->getAxisBaseCoord().getY()), Coord(binXCoordEnd, quadEdgeYTopCoord, 0),quadColor);
+          cumulativeHistogram->addQuadEdge(Coord(binXCoordEnd, xAxis->getAxisBaseCoord().getY()),
+                                           Coord(binXCoordEnd, quadEdgeYTopCoord, 0), quadColor);
         }
       }
     }
@@ -727,8 +689,7 @@ void Histogram::update() {
 
   if (cumulativeFreqHisto) {
     histoBinsComposite->addGlEntity(cumulativeHistogram, "cumulative histogram");
-  }
-  else {
+  } else {
     delete cumulativeHistogram;
   }
 
@@ -744,19 +705,19 @@ void Histogram::update() {
   glOffscreenRenderer->addGraphCompositeToScene(graphComposite);
   glOffscreenRenderer->renderScene(true);
   GLuint textureId = glOffscreenRenderer->getGLTexture(true);
-  GlTextureManager::getInst().deleteTexture(textureName);
-  GlTextureManager::getInst().registerExternalTexture(textureName, textureId);
+  GlTextureManager::deleteTexture(textureName);
+  GlTextureManager::registerExternalTexture(textureName, textureId);
   glOffscreenRenderer->clearScene();
 
-
-  Gl2DRect *rectTextured = new Gl2DRect(blCorner.getY()+size, blCorner.getY(), blCorner.getX(), blCorner.getX() + size, textureName);
-  rectTextured->setFillColor(Color(255,255,255));
+  Gl2DRect *rectTextured = new Gl2DRect(blCorner.getY() + size, blCorner.getY(), blCorner.getX(),
+                                        blCorner.getX() + size, textureName);
+  rectTextured->setFillColor(Color(255, 255, 255));
   addGlEntity(rectTextured, textureName + " overview");
   computeBoundingBox();
 
   lastCumulHisto = cumulativeFreqHisto;
 
-  textureUpdateNeeded = false;
+  updateNeeded = false;
 }
 
 void Histogram::setBLCorner(const Coord &blCorner) {
@@ -766,11 +727,11 @@ void Histogram::setBLCorner(const Coord &blCorner) {
 }
 
 void Histogram::setTextColor(const Color &color) {
-  if (xAxis != NULL) {
+  if (xAxis != nullptr) {
     xAxis->setAxisColor(color);
   }
 
-  if (yAxis != NULL) {
+  if (yAxis != nullptr) {
     yAxis->setAxisColor(color);
   }
 
@@ -779,16 +740,15 @@ void Histogram::setTextColor(const Color &color) {
 
 void Histogram::setLayoutUpdateNeeded() {
   layoutUpdateNeeded = true;
-  textureUpdateNeeded = true;
+  updateNeeded = true;
 }
 
 void Histogram::setSizesUpdateNeeded() {
   sizesUpdateNeeded = true;
-  textureUpdateNeeded = true;
-}
-
-void Histogram::setTextureUpdateNeeded() {
-  textureUpdateNeeded = true;
+  updateNeeded = true;
 }
 
+void Histogram::setUpdateNeeded() {
+  updateNeeded = true;
 }
+} // namespace tlp
