@@ -1,24 +1,23 @@
 /**
-*
-* This file is part of Tulip (www.tulip-software.org)
-*
-* Authors: David Auber and the Tulip development Team
-* from LaBRI, University of Bordeaux
-*
-* Tulip is free software; you can redistribute it and/or modify
-* it under the terms of the GNU Lesser General Public License
-* as published by the Free Software Foundation, either version 3
-* of the License, or (at your option) any later version.
-*
-* Tulip is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-* See the GNU General Public License for more details.
-*
-*/
+ *
+ * This file is part of Tulip (http://tulip.labri.fr)
+ *
+ * Authors: David Auber and the Tulip development Team
+ * from LaBRI, University of Bordeaux
+ *
+ * Tulip is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License
+ * as published by the Free Software Foundation, either version 3
+ * of the License, or (at your option) any later version.
+ *
+ * Tulip is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
+ *
+ */
 
 #include <tulip/OpenGlConfigManager.h>
-#include <tulip/ForEach.h>
 #include <tulip/GlLines.h>
 #include <tulip/GlMainWidget.h>
 #include <tulip/Camera.h>
@@ -28,52 +27,40 @@
 #include "HistoStatsConfigWidget.h"
 #include "HistogramView.h"
 
-#if defined(_MSC_VER) || (defined(__clang_major__) && __clang_major__ >= 4)
-
 #include <functional>
 
-// when compose2 is missing, use implementation from boost
+// use compose2 implementation from boost
 
 /* class for the compose_f_gx_hx adapter
  */
 template <class OP1, class OP2, class OP3>
 class compose_f_gx_hx_t
-  : public std::unary_function<typename OP2::argument_type,
-      typename OP1::result_type> {
+    : public std::unary_function<typename OP2::argument_type, typename OP1::result_type> {
 private:
-  OP1 op1;    // process: op1(op2(x),op3(x))
+  OP1 op1; // process: op1(op2(x),op3(x))
   OP2 op2;
   OP3 op3;
+
 public:
   // constructor
-  compose_f_gx_hx_t (const OP1& o1, const OP2& o2, const OP3& o3)
-    : op1(o1), op2(o2), op3(o3) {
-  }
+  compose_f_gx_hx_t(const OP1 &o1, const OP2 &o2, const OP3 &o3) : op1(o1), op2(o2), op3(o3) {}
 
   // function call
-  typename OP1::result_type
-  operator()(const typename OP2::argument_type& x) const {
-    return op1(op2(x),op3(x));
+  typename OP1::result_type operator()(const typename OP2::argument_type &x) const {
+    return op1(op2(x), op3(x));
   }
 };
 
 /* convenience functions for the compose_f_gx_hx adapter
  */
 template <class OP1, class OP2, class OP3>
-inline compose_f_gx_hx_t<OP1,OP2,OP3>
-compose_f_gx_hx (const OP1& o1, const OP2& o2, const OP3& o3) {
-  return compose_f_gx_hx_t<OP1,OP2,OP3>(o1,o2,o3);
+inline compose_f_gx_hx_t<OP1, OP2, OP3> compose_f_gx_hx(const OP1 &o1, const OP2 &o2,
+                                                        const OP3 &o3) {
+  return compose_f_gx_hx_t<OP1, OP2, OP3>(o1, o2, o3);
 }
 
 #define compose_fn compose_f_gx_hx
 
-#else
-
-#include <ext/functional>
-#define compose_fn stdext::compose2
-
-#endif
-
 #include "HistogramStatistics.h"
 
 using namespace std;
@@ -82,11 +69,11 @@ template <class K, class V>
 class map_value_greater_equal : public unary_function<pair<K, V>, bool> {
 private:
   V value;
+
 public:
+  map_value_greater_equal(const V &v) : value(v) {}
 
-  map_value_greater_equal(const V& v) : value(v) {}
-
-  bool operator() (const pair<K, V> &elem) const {
+  bool operator()(const pair<K, V> &elem) const {
     return elem.second >= value;
   }
 };
@@ -95,36 +82,34 @@ template <class K, class V>
 class map_value_less_equal : public unary_function<pair<K, V>, bool> {
 private:
   V value;
+
 public:
+  map_value_less_equal(const V &v) : value(v) {}
 
-  map_value_less_equal(const V& v) : value(v) {}
-
-  bool operator() (const pair<K, V> &elem) const {
+  bool operator()(const pair<K, V> &elem) const {
     return elem.second <= value;
   }
 };
 
 namespace {
 inline double square(double x) {
-  return x*x;
+  return x * x;
 }
 
 /*inline double cube(double x) {
 return x*x*x;
 }*/
-}
+} // namespace
 static void drawComposite(tlp::GlComposite *composite, float lod, tlp::Camera *camera) {
-  map<string, tlp::GlSimpleEntity*> glEntities = composite->getGlEntities();
-  map<string, tlp::GlSimpleEntity*>::iterator it2;
+  map<string, tlp::GlSimpleEntity *> glEntities = composite->getGlEntities();
 
-  for (it2 = glEntities.begin(); it2 != glEntities.end() ; ++it2) {
+  for (auto it2 = glEntities.begin(); it2 != glEntities.end(); ++it2) {
     tlp::GlSimpleEntity *entity = it2->second;
     tlp::GlComposite *compositeEntity = dynamic_cast<tlp::GlComposite *>(entity);
 
-    if (compositeEntity != NULL) {
+    if (compositeEntity != nullptr) {
       drawComposite(compositeEntity, lod, camera);
-    }
-    else {
+    } else {
       entity->draw(lod, camera);
     }
   }
@@ -134,13 +119,11 @@ namespace tlp {
 
 class UniformKernel : public KernelFunction {
 
-public :
-
-  double operator()(double val) {
+public:
+  double operator()(double val) override {
     if (fabs(val) < 1) {
-      return 1./2.;
-    }
-    else {
+      return 1. / 2.;
+    } else {
       return 0.;
     }
   }
@@ -148,25 +131,21 @@ public :
 
 class GaussianKernel : public KernelFunction {
 
-public :
-
-  double operator()(double val) {
-    return (1./M_PI)*exp(-square(val)/2.);
+public:
+  double operator()(double val) override {
+    return (1. / M_PI) * exp(-square(val) / 2.);
   }
-
 };
 
 class TriangleKernel : public KernelFunction {
 
-public :
-
-  double operator()(double val) {
+public:
+  double operator()(double val) override {
     double valAbs = fabs(val);
 
     if (valAbs < 1) {
       return 1 - valAbs;
-    }
-    else {
+    } else {
       return 0.;
     }
   }
@@ -174,32 +153,27 @@ public :
 
 class EpanechnikovKernel : public KernelFunction {
 
-public :
-
-  double operator()(double val) {
+public:
+  double operator()(double val) override {
     double valAbs = fabs(val);
 
     if (valAbs < 1) {
-      return (3./4.)*(1-square(val));
-    }
-    else {
+      return (3. / 4.) * (1 - square(val));
+    } else {
       return 0.;
     }
   }
-
 };
 
 class QuarticKernel : public KernelFunction {
 
-public :
-
-  double operator()(double val) {
+public:
+  double operator()(double val) override {
     double valAbs = fabs(val);
 
     if (valAbs < 1) {
-      return (15./16.)*square(1-square(val));
-    }
-    else {
+      return (15. / 16.) * square(1 - square(val));
+    } else {
       return 0.;
     }
   }
@@ -207,16 +181,14 @@ public :
 
 class CubicKernel : public KernelFunction {
 
-public :
-
-  double operator()(double val) {
+public:
+  double operator()(double val) override {
     double valAbs = fabs(val);
 
     if (valAbs < 1.) {
-      double d = (35./32.) * pow((1. - square(val)), 3);
+      double d = (35. / 32.) * pow((1. - square(val)), 3);
       return d;
-    }
-    else {
+    } else {
       return 0.;
     }
   }
@@ -224,50 +196,50 @@ public :
 
 class CosineKernel : public KernelFunction {
 
-public :
-
-  double operator()(double val) {
+public:
+  double operator()(double val) override {
     double valAbs = fabs(val);
 
     if (valAbs < 1) {
-      return (M_PI/4.)*cos((M_PI/2.)*val);
-    }
-    else {
+      return (M_PI / 4.) * cos((M_PI / 2.) * val);
+    } else {
       return 0.;
     }
   }
 };
 
-
 HistogramStatistics::HistogramStatistics(HistoStatsConfigWidget *ConfigWidget)
-  : histoView(NULL) , histoStatsConfigWidget(ConfigWidget),
-    propertyMean(0), propertyStandardDeviation(0),
-    densityAxis(NULL), meanAxis(NULL), standardDeviationPosAxis(NULL),
-    standardDeviationNegAxis(NULL), standardDeviation2PosAxis(NULL), standardDeviation2NegAxis(NULL),
-    standardDeviation3PosAxis(NULL), standardDeviation3NegAxis(NULL) {
+    : histoView(nullptr), histoStatsConfigWidget(ConfigWidget), propertyMean(0),
+      propertyStandardDeviation(0), densityAxis(nullptr), meanAxis(nullptr),
+      standardDeviationPosAxis(nullptr), standardDeviationNegAxis(nullptr),
+      standardDeviation2PosAxis(nullptr), standardDeviation2NegAxis(nullptr),
+      standardDeviation3PosAxis(nullptr), standardDeviation3NegAxis(nullptr) {
   initKernelFunctionsMap();
 }
 
 HistogramStatistics::HistogramStatistics(const HistogramStatistics &histoStats)
-  : histoView(histoStats.histoView), histoStatsConfigWidget(histoStats.histoStatsConfigWidget), propertyMean(0), propertyStandardDeviation(0),
-    densityAxis(NULL), meanAxis(NULL), standardDeviationPosAxis(NULL),
-    standardDeviationNegAxis(NULL), standardDeviation2PosAxis(NULL), standardDeviation2NegAxis(NULL),
-    standardDeviation3PosAxis(NULL), standardDeviation3NegAxis(NULL) {
+    : histoView(histoStats.histoView), histoStatsConfigWidget(histoStats.histoStatsConfigWidget),
+      propertyMean(0), propertyStandardDeviation(0), densityAxis(nullptr), meanAxis(nullptr),
+      standardDeviationPosAxis(nullptr), standardDeviationNegAxis(nullptr),
+      standardDeviation2PosAxis(nullptr), standardDeviation2NegAxis(nullptr),
+      standardDeviation3PosAxis(nullptr), standardDeviation3NegAxis(nullptr) {
   initKernelFunctionsMap();
 }
 
 HistogramStatistics::~HistogramStatistics() {
   cleanupAxis();
 
-  for (map<QString, KernelFunction *>::iterator it = kernelFunctionsMap.begin() ; it != kernelFunctionsMap.end() ; ++it) {
+  for (map<QString, KernelFunction *>::iterator it = kernelFunctionsMap.begin();
+       it != kernelFunctionsMap.end(); ++it) {
     delete it->second;
   }
 }
 
 void HistogramStatistics::viewChanged(View *view) {
   histoView = static_cast<HistogramView *>(view);
-  connect(histoStatsConfigWidget, SIGNAL(computeAndDrawInteractor()), this, SLOT(computeAndDrawInteractor()));
-  //computeAndDrawInteractor();
+  connect(histoStatsConfigWidget, SIGNAL(computeAndDrawInteractor()), this,
+          SLOT(computeAndDrawInteractor()));
+  // computeAndDrawInteractor();
 }
 
 void HistogramStatistics::initKernelFunctionsMap() {
@@ -291,35 +263,35 @@ bool HistogramStatistics::eventFilter(QObject *, QEvent *e) {
 }
 
 void HistogramStatistics::cleanupAxis() {
-  if (densityAxis != NULL) {
+  if (densityAxis != nullptr) {
     delete densityAxis;
-    densityAxis = NULL;
+    densityAxis = nullptr;
   }
 
-  if (meanAxis != NULL) {
+  if (meanAxis != nullptr) {
     delete meanAxis;
-    meanAxis = NULL;
+    meanAxis = nullptr;
   }
 
-  if (standardDeviationNegAxis != NULL) {
+  if (standardDeviationNegAxis != nullptr) {
     delete standardDeviationNegAxis;
-    standardDeviationNegAxis = NULL;
+    standardDeviationNegAxis = nullptr;
     delete standardDeviationPosAxis;
-    standardDeviationPosAxis = NULL;
+    standardDeviationPosAxis = nullptr;
   }
 
-  if (standardDeviation2PosAxis != NULL) {
+  if (standardDeviation2PosAxis != nullptr) {
     delete standardDeviation2PosAxis;
-    standardDeviation2PosAxis = NULL;
+    standardDeviation2PosAxis = nullptr;
     delete standardDeviation2NegAxis;
-    standardDeviation2NegAxis = NULL;
+    standardDeviation2NegAxis = nullptr;
   }
 
-  if (standardDeviation3PosAxis != NULL) {
+  if (standardDeviation3PosAxis != nullptr) {
     delete standardDeviation3PosAxis;
-    standardDeviation3PosAxis = NULL;
+    standardDeviation3PosAxis = nullptr;
     delete standardDeviation3NegAxis;
-    standardDeviation3NegAxis = NULL;
+    standardDeviation3NegAxis = nullptr;
   }
 }
 
@@ -327,7 +299,7 @@ void HistogramStatistics::computeInteractor() {
   GlQuantitativeAxis *histoXAxis = histoView->getDetailedHistogram()->getXAxis();
   GlQuantitativeAxis *histoYAxis = histoView->getDetailedHistogram()->getYAxis();
 
-  if (histoYAxis == NULL) {
+  if (histoYAxis == nullptr) {
     return;
   }
 
@@ -344,26 +316,23 @@ void HistogramStatistics::computeInteractor() {
   cleanupAxis();
 
   string propertyType(graph->getProperty(selectedProperty)->getTypename());
-  double min ,max;
+  double min, max;
 
   if (propertyType == "double") {
     if (histoView->getDataLocation() == NODE) {
       min = graph->getProperty<DoubleProperty>(selectedProperty)->getNodeMin();
       max = graph->getProperty<DoubleProperty>(selectedProperty)->getNodeMax();
-    }
-    else {
+    } else {
       min = graph->getProperty<DoubleProperty>(selectedProperty)->getEdgeMin();
       max = graph->getProperty<DoubleProperty>(selectedProperty)->getEdgeMax();
     }
-  }
-  else {
+  } else {
     if (histoView->getDataLocation() == NODE) {
-      min = (double) graph->getProperty<IntegerProperty>(selectedProperty)->getNodeMin();
-      max = (double) graph->getProperty<IntegerProperty>(selectedProperty)->getNodeMax();
-    }
-    else {
-      min = (double) graph->getProperty<IntegerProperty>(selectedProperty)->getEdgeMin();
-      max = (double) graph->getProperty<IntegerProperty>(selectedProperty)->getEdgeMax();
+      min = graph->getProperty<IntegerProperty>(selectedProperty)->getNodeMin();
+      max = graph->getProperty<IntegerProperty>(selectedProperty)->getNodeMax();
+    } else {
+      min = graph->getProperty<IntegerProperty>(selectedProperty)->getEdgeMin();
+      max = graph->getProperty<IntegerProperty>(selectedProperty)->getEdgeMax();
     }
   }
 
@@ -371,46 +340,38 @@ void HistogramStatistics::computeInteractor() {
 
   if (histoView->getDataLocation() == NODE) {
     nbElements = graph->numberOfNodes();
-    node n;
-    forEach(n, graph->getNodes()) {
+    for (auto n : graph->nodes()) {
       double nodeVal;
 
       if (propertyType == "double") {
         nodeVal = graph->getProperty<DoubleProperty>(selectedProperty)->getNodeValue(n);
-      }
-      else {
-        nodeVal = (double) graph->getProperty<IntegerProperty>(selectedProperty)->getNodeValue(n);
+      } else {
+        nodeVal = graph->getProperty<IntegerProperty>(selectedProperty)->getNodeValue(n);
       }
 
       graphPropertyValueSet[n.id] = nodeVal;
       propertyMean += nodeVal;
-
     }
 
-  }
-  else {
+  } else {
     nbElements = graph->numberOfEdges();
-    edge e;
-    forEach(e, graph->getEdges()) {
+    for (auto e : graph->edges()) {
       double edgeVal;
 
       if (propertyType == "double") {
         edgeVal = graph->getProperty<DoubleProperty>(selectedProperty)->getEdgeValue(e);
-      }
-      else {
-        edgeVal = (double) graph->getProperty<IntegerProperty>(selectedProperty)->getEdgeValue(e);
+      } else {
+        edgeVal = graph->getProperty<IntegerProperty>(selectedProperty)->getEdgeValue(e);
       }
 
       graphPropertyValueSet[e.id] = edgeVal;
       propertyMean += edgeVal;
-
     }
   }
 
-
   propertyMean /= (nbElements);
 
-  for (map<unsigned int, double>::iterator it = graphPropertyValueSet.begin() ; it != graphPropertyValueSet.end() ; ++it) {
+  for (auto it = graphPropertyValueSet.begin(); it != graphPropertyValueSet.end(); ++it) {
     propertyStandardDeviation += square(it->second - propertyMean);
   }
 
@@ -426,14 +387,14 @@ void HistogramStatistics::computeInteractor() {
 
     KernelFunction *kf = kernelFunctionsMap[histoStatsConfigWidget->getKernelFunctionName()];
 
-    for (double val = min ; val <= max ; val += sampleStep) {
+    for (double val = min; val <= max; val += sampleStep) {
       float fx = 0;
 
-      for (map<unsigned, double>::iterator it = graphPropertyValueSet.begin() ; it != graphPropertyValueSet.end() ; ++it) {
-        fx +=  (*kf)((val - (it->second)) / (bandwidth / 2.));
+      for (auto it = graphPropertyValueSet.begin(); it != graphPropertyValueSet.end(); ++it) {
+        fx += float((*kf)((val - (it->second)) / (bandwidth / 2.)));
       }
 
-      fx *= (1. / (float) (graphPropertyValueSet.size() * (bandwidth / 2.)));
+      fx *= (1.f / float(graphPropertyValueSet.size() * (bandwidth / 2.)));
       estimatedDensity.push_back(fx);
 
       if (fx > maxDensityValue) {
@@ -444,15 +405,21 @@ void HistogramStatistics::computeInteractor() {
     double val;
     unsigned int i;
 
-    for (val = min , i = 0 ; val <= max ; val += sampleStep , ++i) {
+    for (val = min, i = 0; val <= max; val += sampleStep, ++i) {
       float x = histoXAxis->getAxisPointCoordForValue(val).getX();
-      float y = histoYAxis->getAxisPointCoordForValue((estimatedDensity[i] * (histoView->getDetailedHistogram()->getMaxBinSize())) / maxDensityValue).getY();
+      float y =
+          histoYAxis
+              ->getAxisPointCoordForValue(
+                  (estimatedDensity[i] * (histoView->getDetailedHistogram()->getMaxBinSize())) /
+                  maxDensityValue)
+              .getY();
       densityEstimationCurvePoints.push_back(Coord(x, y, 0));
     }
 
-    densityAxis = new GlQuantitativeAxis("density", Coord(histoXAxis->getAxisBaseCoord().getX() + histoXAxis->getAxisLength(), 0, 0),
-                                         histoYAxis->getAxisLength(), GlAxis::VERTICAL_AXIS, Color(255,0,0), true);
-    densityAxis->setAxisParameters((double) 0 ,(double) maxDensityValue, 15, GlAxis::RIGHT_OR_ABOVE, true);
+    densityAxis = new GlQuantitativeAxis(
+        "density", Coord(histoXAxis->getAxisBaseCoord().getX() + histoXAxis->getAxisLength(), 0, 0),
+        histoYAxis->getAxisLength(), GlAxis::VERTICAL_AXIS, Color(255, 0, 0), true);
+    densityAxis->setAxisParameters(0.0, double(maxDensityValue), 15, GlAxis::RIGHT_OR_ABOVE, true);
     densityAxis->updateAxis();
     densityAxis->addCaption(GlAxis::LEFT, densityAxis->getSpaceBetweenAxisGrads(), false);
   }
@@ -463,39 +430,47 @@ void HistogramStatistics::computeInteractor() {
     float axisLength = histoYAxis->getAxisLength() + axisExtension;
     float captionHeight = histoXAxis->getAxisGradsWidth();
     float x = histoXAxis->getAxisPointCoordForValue(propertyMean).getX();
-    meanAxis = new GlAxis("m", Coord(x, y, 0), axisLength, GlAxis::VERTICAL_AXIS, Color(255,0,0));
+    meanAxis = new GlAxis("m", Coord(x, y, 0), axisLength, GlAxis::VERTICAL_AXIS, Color(255, 0, 0));
     meanAxis->addCaption(GlAxis::LEFT, captionHeight, false);
     x = histoXAxis->getAxisPointCoordForValue(propertyMean + propertyStandardDeviation).getX();
-    standardDeviationPosAxis = new GlAxis("+sd", Coord(x, y, 0), axisLength, GlAxis::VERTICAL_AXIS, Color(255,0,0));
+    standardDeviationPosAxis =
+        new GlAxis("+sd", Coord(x, y, 0), axisLength, GlAxis::VERTICAL_AXIS, Color(255, 0, 0));
     standardDeviationPosAxis->addCaption(GlAxis::LEFT, captionHeight, false);
     x = histoXAxis->getAxisPointCoordForValue(propertyMean - propertyStandardDeviation).getX();
-    standardDeviationNegAxis = new GlAxis("-sd", Coord(x, y, 0), axisLength, GlAxis::VERTICAL_AXIS, Color(255,0,0));
+    standardDeviationNegAxis =
+        new GlAxis("-sd", Coord(x, y, 0), axisLength, GlAxis::VERTICAL_AXIS, Color(255, 0, 0));
     standardDeviationNegAxis->addCaption(GlAxis::LEFT, captionHeight, false);
 
     if (propertyMean - 2 * propertyStandardDeviation > min) {
-      x = histoXAxis->getAxisPointCoordForValue(propertyMean + 2 * propertyStandardDeviation).getX();
-      standardDeviation2PosAxis = new GlAxis("+2sd", Coord(x, y, 0), axisLength, GlAxis::VERTICAL_AXIS, Color(255,0,0));
+      x = histoXAxis->getAxisPointCoordForValue(propertyMean + 2 * propertyStandardDeviation)
+              .getX();
+      standardDeviation2PosAxis =
+          new GlAxis("+2sd", Coord(x, y, 0), axisLength, GlAxis::VERTICAL_AXIS, Color(255, 0, 0));
       standardDeviation2PosAxis->addCaption(GlAxis::LEFT, captionHeight, false);
-      x = histoXAxis->getAxisPointCoordForValue(propertyMean - 2 * propertyStandardDeviation).getX();
-      standardDeviation2NegAxis = new GlAxis("-2sd", Coord(x, y, 0), axisLength, GlAxis::VERTICAL_AXIS, Color(255,0,0));
+      x = histoXAxis->getAxisPointCoordForValue(propertyMean - 2 * propertyStandardDeviation)
+              .getX();
+      standardDeviation2NegAxis =
+          new GlAxis("-2sd", Coord(x, y, 0), axisLength, GlAxis::VERTICAL_AXIS, Color(255, 0, 0));
       standardDeviation2NegAxis->addCaption(GlAxis::LEFT, captionHeight, false);
-    }
-    else {
-      standardDeviation2NegAxis = NULL;
-      standardDeviation2PosAxis = NULL;
+    } else {
+      standardDeviation2NegAxis = nullptr;
+      standardDeviation2PosAxis = nullptr;
     }
 
     if (propertyMean - 3 * propertyStandardDeviation > min) {
-      x = histoXAxis->getAxisPointCoordForValue(propertyMean + 3 * propertyStandardDeviation).getX();
-      standardDeviation3PosAxis = new GlAxis("+3sd", Coord(x, y, 0), axisLength, GlAxis::VERTICAL_AXIS, Color(255,0,0));
+      x = histoXAxis->getAxisPointCoordForValue(propertyMean + 3 * propertyStandardDeviation)
+              .getX();
+      standardDeviation3PosAxis =
+          new GlAxis("+3sd", Coord(x, y, 0), axisLength, GlAxis::VERTICAL_AXIS, Color(255, 0, 0));
       standardDeviation3PosAxis->addCaption(GlAxis::LEFT, captionHeight, false);
-      x = histoXAxis->getAxisPointCoordForValue(propertyMean - 3 * propertyStandardDeviation).getX();
-      standardDeviation3NegAxis = new GlAxis("-3sd", Coord(x, y, 0), axisLength, GlAxis::VERTICAL_AXIS, Color(255,0,0));
+      x = histoXAxis->getAxisPointCoordForValue(propertyMean - 3 * propertyStandardDeviation)
+              .getX();
+      standardDeviation3NegAxis =
+          new GlAxis("-3sd", Coord(x, y, 0), axisLength, GlAxis::VERTICAL_AXIS, Color(255, 0, 0));
       standardDeviation3NegAxis->addCaption(GlAxis::LEFT, captionHeight, false);
-    }
-    else {
-      standardDeviation3NegAxis = NULL;
-      standardDeviation3PosAxis = NULL;
+    } else {
+      standardDeviation3NegAxis = nullptr;
+      standardDeviation3PosAxis = nullptr;
     }
 
     if (histoStatsConfigWidget->nodesSelection()) {
@@ -505,20 +480,21 @@ void HistogramStatistics::computeInteractor() {
       viewSelection->setAllEdgeValue(false);
       double lowerBound = histoStatsConfigWidget->getSelectionLowerBound();
       double upperBound = histoStatsConfigWidget->getSelectionUpperBound();
-      map<unsigned int, double>::iterator pos = find_if(graphPropertyValueSet.begin(), graphPropertyValueSet.end(),
+      map<unsigned int, double>::iterator pos = find_if(
+          graphPropertyValueSet.begin(), graphPropertyValueSet.end(),
           compose_fn(logical_and<bool>(), map_value_greater_equal<unsigned int, double>(lowerBound),
                      map_value_less_equal<unsigned int, double>(upperBound)));
 
       while (pos != graphPropertyValueSet.end()) {
         if (histoView->getDataLocation() == EDGE) {
           viewSelection->setNodeValue(node(pos->first), true);
-        }
-        else {
+        } else {
           viewSelection->setEdgeValue(edge(pos->first), true);
         }
 
         pos = find_if(++pos, graphPropertyValueSet.end(),
-                      compose_fn(logical_and<bool>(), map_value_greater_equal<unsigned int, double>(lowerBound),
+                      compose_fn(logical_and<bool>(),
+                                 map_value_greater_equal<unsigned int, double>(lowerBound),
                                  map_value_less_equal<unsigned int, double>(upperBound)));
       }
 
@@ -537,36 +513,37 @@ bool HistogramStatistics::draw(GlMainWidget *glMainWidget) {
   Camera &camera = glMainWidget->getScene()->getLayer("Main")->getCamera();
   camera.initGl();
   glEnable(GL_BLEND);
-  glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+  glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
   glDisable(GL_LIGHTING);
   glDisable(GL_DEPTH_TEST);
 
   if (!densityEstimationCurvePoints.empty()) {
-    Color curveColor(255,0,0);
+    Color curveColor(255, 0, 0);
     Coord startPoint(densityEstimationCurvePoints[0]);
     Coord endPoint(densityEstimationCurvePoints[densityEstimationCurvePoints.size() - 1]);
     vector<Coord> densityEstimationCurvePointsCp(densityEstimationCurvePoints);
     densityEstimationCurvePointsCp.erase(densityEstimationCurvePointsCp.begin());
     densityEstimationCurvePointsCp.pop_back();
-    GlLines::glDrawCurve(startPoint, densityEstimationCurvePointsCp, endPoint, 2., GlLines::TLP_PLAIN, curveColor, curveColor);
+    GlLines::glDrawCurve(startPoint, densityEstimationCurvePointsCp, endPoint, 2.,
+                         GlLines::TLP_PLAIN, curveColor, curveColor);
     drawComposite(densityAxis, 0, &camera);
   }
 
-  if (meanAxis != NULL) {
+  if (meanAxis != nullptr) {
     drawComposite(meanAxis, 0, &camera);
   }
 
-  if (standardDeviationPosAxis != NULL) {
+  if (standardDeviationPosAxis != nullptr) {
     drawComposite(standardDeviationPosAxis, 0, &camera);
     drawComposite(standardDeviationNegAxis, 0, &camera);
   }
 
-  if (standardDeviation2PosAxis != NULL) {
+  if (standardDeviation2PosAxis != nullptr) {
     drawComposite(standardDeviation2PosAxis, 0, &camera);
     drawComposite(standardDeviation2NegAxis, 0, &camera);
   }
 
-  if (standardDeviation3PosAxis != NULL) {
+  if (standardDeviation3PosAxis != nullptr) {
     drawComposite(standardDeviation3PosAxis, 0, &camera);
     drawComposite(standardDeviation3NegAxis, 0, &camera);
   }
@@ -575,5 +552,4 @@ bool HistogramStatistics::draw(GlMainWidget *glMainWidget) {
   glEnable(GL_LIGHTING);
   return true;
 }
-
-}
+} // namespace tlp
