@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -29,29 +29,25 @@ class HistogramView;
 
 class HistogramViewNavigator : public GLInteractorComponent {
 
-public :
-
+public:
   HistogramViewNavigator();
-  ~HistogramViewNavigator();
+  ~HistogramViewNavigator() override;
 
-  bool eventFilter(QObject *, QEvent *);
-  bool draw(GlMainWidget *) {
+  bool eventFilter(QObject *, QEvent *) override;
+  bool draw(GlMainWidget *) override {
     return false;
   }
-  bool compute(GlMainWidget *) {
+  bool compute(GlMainWidget *) override {
     return false;
   }
-  void viewChanged(View *view);
-
-
-private :
+  void viewChanged(View *view) override;
 
+private:
   Histogram *getOverviewUnderPointer(const Coord &sceneCoord) const;
 
   HistogramView *histoView;
   Histogram *selectedHistoOverview;
 };
-
-}
+} // namespace tlp
 
 #endif /* HISTOGRAMVIEWNAVIGATOR_H_ */
