@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -33,12 +33,11 @@ class SizeScaleConfigDialog : public QDialog {
 
   Q_OBJECT
 
-  Ui::SizeScaleConfigDialogData* _ui;
+  Ui::SizeScaleConfigDialogData *_ui;
 
-public :
-
-  SizeScaleConfigDialog(QWidget *d = 0);
-  ~SizeScaleConfigDialog();
+public:
+  SizeScaleConfigDialog(QWidget *d = nullptr);
+  ~SizeScaleConfigDialog() override;
 
   bool doMappingOnViewSize() const;
 
@@ -49,12 +48,11 @@ public :
   bool applySizeMappingOnY() const;
   bool applySizeMappingOnZ() const;
 
-private slots :
+private slots:
 
   void minSizeValueChanged(double newValue);
   void maxSizeValueChanged(double newValue);
   void viewSizeRadioButtonToggled(bool checked);
-
 };
-}
+} // namespace tlp
 #endif /* SIZESCALECONFIGDIALOG_H_ */
