@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,20 +21,20 @@
 #define GLMATRIXBACKGROUNDGRID_H
 
 #include <tulip/GlSimpleEntity.h>
-
+namespace tlp {
 class MatrixView;
 
-class GlMatrixBackgroundGrid: public tlp::GlSimpleEntity {
+class GlMatrixBackgroundGrid : public tlp::GlSimpleEntity {
 public:
   GlMatrixBackgroundGrid(MatrixView *view);
-  virtual tlp::BoundingBox getBoundingBox();
-  virtual void draw(float lod,tlp::Camera* camera);
+  tlp::BoundingBox getBoundingBox() override;
+  void draw(float lod, tlp::Camera *camera) override;
 
-  void getXML(std::string &) {}
-  void setWithXML(const std::string &, unsigned int &) {}
+  void getXML(std::string &) override {}
+  void setWithXML(const std::string &, unsigned int &) override {}
 
 private:
   MatrixView *_view;
 };
-
+} // namespace tlp
 #endif // GLMATRIXBACKGROUNDGRID_H
