@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -23,11 +23,11 @@
 #include "MatrixView.h"
 #include "PropertyValuesDispatcher.h"
 #include "GlMatrixBackgroundGrid.h"
+#include "MatrixViewQuickAccessBar.h"
 
 #include <tulip/Graph.h>
 #include <tulip/IntegerProperty.h>
 #include <tulip/GlMainWidget.h>
-#include <tulip/ForEach.h>
 #include <tulip/TlpQtTools.h>
 #include <tulip/GlLabel.h>
 #include <tulip/GlGraphComposite.h>
@@ -35,19 +35,27 @@
 #include <tulip/ParametricCurves.h>
 #include <tulip/TulipViewSettings.h>
 
-using namespace tlp;
 using namespace std;
 
-MatrixView::MatrixView(const PluginContext *):
-  NodeLinkDiagramComponent(),
-  _matrixGraph(NULL), _graphEntitiesToDisplayedNodes(NULL), _displayedNodesToGraphEntities(NULL), _displayedEdgesToGraphEdges(NULL), _displayedNodesAreNodes(NULL), _dispatcher(NULL),
-  _configurationWidget(NULL), _mustUpdateSizes(false), _mustUpdateLayout(false), _isOriented(false), _orderingMetricName("") {
-}
+namespace tlp {
+
+MatrixView::MatrixView(const PluginContext *)
+    : NodeLinkDiagramComponent(), _bar(nullptr), _matrixGraph(nullptr),
+      _graphEntitiesToDisplayedNodes(nullptr), _displayedNodesToGraphEntities(nullptr),
+      _displayedEdgesToGraphEdges(nullptr), _displayedNodesAreNodes(nullptr), _dispatcher(nullptr),
+      _configurationWidget(nullptr), _mustUpdateSizes(false), _mustUpdateLayout(false),
+      _isOriented(false), _orderingMetricName("") {}
 
 MatrixView::~MatrixView() {
   deleteDisplayedGraph();
 }
 
+QuickAccessBar *MatrixView::getQuickAccessBarImpl() {
+  _bar = new MatrixViewQuickAccessBar(_configurationWidget);
+  connect(_bar, SIGNAL(settingsChanged()), this, SLOT(applySettings()));
+  return _bar;
+}
+
 void MatrixView::setState(const DataSet &ds) {
 
   clearRedrawTriggers();
@@ -55,18 +63,17 @@ void MatrixView::setState(const DataSet &ds) {
   setOverviewVisible(true);
 
   if (!_configurationWidget) {
-    _configurationWidget = new MatrixViewConfigurationWidget(getGlMainWidget()->parentWidget());
-    connect(_configurationWidget, SIGNAL(changeBackgroundColor(QColor)), this, SLOT(setBackgroundColor(QColor)));
-    connect(_configurationWidget, SIGNAL(metricSelected(std::string)), this, SLOT(setOrderingMetric(std::string)));
+    _configurationWidget = new MatrixViewConfigurationWidget();
+    connect(_configurationWidget, SIGNAL(changeBackgroundColor(QColor)), this,
+            SLOT(setBackgroundColor(QColor)));
+    connect(_configurationWidget, SIGNAL(metricSelected(std::string)), this,
+            SLOT(setOrderingMetric(std::string)));
     connect(_configurationWidget, SIGNAL(setGridDisplayMode()), this, SLOT(setGridDisplayMode()));
     connect(_configurationWidget, SIGNAL(showEdges(bool)), this, SLOT(showEdges(bool)));
-    connect(_configurationWidget, SIGNAL(enableEdgeColorInterpolation(bool)), this, SLOT(enableEdgeColorInterpolation(bool)));
+    connect(_configurationWidget, SIGNAL(nodeLabels(bool)), this, SLOT(showNodeLabels(bool)));
+    connect(_configurationWidget, SIGNAL(enableEdgeColorInterpolation(bool)), this,
+            SLOT(enableEdgeColorInterpolation(bool)));
     connect(_configurationWidget, SIGNAL(updateOriented(bool)), this, SLOT(setOriented(bool)));
-
-    QAction* centerAction = new QAction(trUtf8("Center"),this);
-    centerAction->setShortcut(trUtf8("Ctrl+Shift+C"));
-    connect(centerAction,SIGNAL(triggered()),getGlMainWidget(),SLOT(centerScene()));
-    graphicsView()->addAction(centerAction);
   }
 
   _configurationWidget->setGraph(graph());
@@ -74,23 +81,27 @@ void MatrixView::setState(const DataSet &ds) {
   initDisplayedGraph();
   registerTriggers();
 
-  bool status=true;
+  bool status = true;
   ds.get("show Edges", status);
   showEdges(status);
   _configurationWidget->setDisplayEdges(status);
 
+  ds.get("show Node Labels", status);
+  showNodeLabels(status);
+  _configurationWidget->setDisplayNodeLabels(status);
+
   ds.get("ascending order", status);
   _configurationWidget->setAscendingOrder(status);
 
-  Color c=getGlMainWidget()->getScene()->getBackgroundColor();
+  Color c = getGlMainWidget()->getScene()->getBackgroundColor();
   ds.get("Background Color", c);
   _configurationWidget->setBackgroundColor(tlp::colorToQColor(c));
 
-  unsigned grid=0;
+  unsigned grid = 0;
   ds.get("Grid mode", grid);
   _configurationWidget->setgridmode(grid);
 
-  int orderingindex=0;
+  int orderingindex = 0;
   ds.get("ordering", orderingindex);
   _configurationWidget->setOrderingProperty(orderingindex);
 
@@ -103,15 +114,40 @@ void MatrixView::setState(const DataSet &ds) {
   ds.get("edge color interpolation", status);
   enableEdgeColorInterpolation(status);
   _configurationWidget->setEdgeColorInterpolation(status);
+
+  bool quickAccessBarVisible = false;
+
+  if (ds.get<bool>("quickAccessBarVisible", quickAccessBarVisible)) {
+    needQuickAccessBar = true;
+    setQuickAccessBarVisible(quickAccessBarVisible);
+  } else // display quickaccessbar
+    setQuickAccessBarVisible(true);
 }
 
 void MatrixView::showEdges(bool show) {
-  getGlMainWidget()->getScene()->getGlGraphComposite()->getRenderingParametersPointer()->setDisplayEdges(show);
+  getGlMainWidget()
+      ->getScene()
+      ->getGlGraphComposite()
+      ->getRenderingParametersPointer()
+      ->setDisplayEdges(show);
+  emit drawNeeded();
+}
+
+void MatrixView::showNodeLabels(bool show) {
+  getGlMainWidget()
+      ->getScene()
+      ->getGlGraphComposite()
+      ->getRenderingParametersPointer()
+      ->setViewNodeLabel(show);
   emit drawNeeded();
 }
 
 void MatrixView::enableEdgeColorInterpolation(bool flag) {
-  getGlMainWidget()->getScene()->getGlGraphComposite()->getRenderingParametersPointer()->setEdgeColorInterpolate(flag);
+  getGlMainWidget()
+      ->getScene()
+      ->getGlGraphComposite()
+      ->getRenderingParametersPointer()
+      ->setEdgeColorInterpolate(flag);
   emit drawNeeded();
 }
 
@@ -121,29 +157,23 @@ void MatrixView::setOriented(bool flag) {
     Observable::holdObservers();
 
     if (_isOriented) {
-      edge e;
-      forEach(e, graph()->getEdges()) {
+      for (auto e : graph()->edges()) {
         // delete the second node mapping the current edge
-        vector<int> edgeNodes = _graphEntitiesToDisplayedNodes->getEdgeValue(e);
+        const vector<int> &edgeNodes = _graphEntitiesToDisplayedNodes->getEdgeValue(e);
         _matrixGraph->delNode(node(edgeNodes[1]));
-        edgeNodes.resize(1);
-        _graphEntitiesToDisplayedNodes->setEdgeValue(e, edgeNodes);
+        _graphEntitiesToDisplayedNodes->popBackEdgeEltValue(e);
       }
-    }
-    else {
-      edge e;
-      forEach(e, graph()->getEdges()) {
-        // must add the symetric node
-        vector<int> edgeNodes = _graphEntitiesToDisplayedNodes->getEdgeValue(e);
-        edgeNodes.push_back(_matrixGraph->addNode().id);
-        _graphEntitiesToDisplayedNodes->setEdgeValue(e, edgeNodes);
-
-        // layout and shape will be updated in updataLayout method
+    } else {
+      for (auto e : graph()->edges()) {
+        // must add the symmetric node
+        node sym = _matrixGraph->addNode();
+        _graphEntitiesToDisplayedNodes->pushBackEdgeEltValue(e, sym.id);
+        const vector<int> &edgeNodes = _graphEntitiesToDisplayedNodes->getEdgeValue(e);
+        // layout and shape will be updated in updateLayout method
         // but other view properties must be set now
-        for (set<string>::iterator it = _sourceToTargetProperties.begin(); it != _sourceToTargetProperties.end(); ++it) {
-          PropertyInterface *prop = _matrixGraph->getProperty(*it);
-          prop->setNodeStringValue(node(edgeNodes[1]),
-                                   prop->getNodeStringValue(node(edgeNodes[0])));
+        for (const string &strProp : _sourceToTargetProperties) {
+          PropertyInterface *prop = _matrixGraph->getProperty(strProp);
+          prop->setNodeStringValue(sym, prop->getNodeStringValue(node(edgeNodes[0])));
         }
       }
     }
@@ -159,47 +189,67 @@ void MatrixView::graphChanged(Graph *) {
 
 DataSet MatrixView::state() const {
   DataSet ds;
-  ds.set("show Edges", getGlMainWidget()->getScene()->getGlGraphComposite()->getRenderingParametersPointer()->isDisplayEdges());
-  ds.set("edge color interpolation", getGlMainWidget()->getScene()->getGlGraphComposite()->getRenderingParametersPointer()->isEdgeColorInterpolate());
+  ds.set("show Edges", getGlMainWidget()
+                           ->getScene()
+                           ->getGlGraphComposite()
+                           ->getRenderingParametersPointer()
+                           ->isDisplayEdges());
+  ds.set("show Node Labels", getGlMainWidget()
+                                 ->getScene()
+                                 ->getGlGraphComposite()
+                                 ->getRenderingParametersPointer()
+                                 ->isViewNodeLabel());
+  ds.set("edge color interpolation", getGlMainWidget()
+                                         ->getScene()
+                                         ->getGlGraphComposite()
+                                         ->getRenderingParametersPointer()
+                                         ->isEdgeColorInterpolate());
   ds.set("ascending order", _configurationWidget->ascendingOrder());
   ds.set("Grid mode", _configurationWidget->gridDisplayMode());
   ds.set("Background Color", getGlMainWidget()->getScene()->getBackgroundColor());
   ds.set("ordering", _configurationWidget->orderingProperty());
   ds.set("oriented", _isOriented);
+
+  if (needQuickAccessBar)
+    ds.set("quickAccessBarVisible", quickAccessBarVisible());
+
   return ds;
 }
 
 QList<QWidget *> MatrixView::configurationWidgets() const {
-  return QList<QWidget *>() << _configurationWidget ;
+  return QList<QWidget *>() << _configurationWidget;
 }
 
 void MatrixView::fillContextMenu(QMenu *menu, const QPointF &point) {
-  GlMainView::fillContextMenu(menu,point);
-  //Check if a node/edge is under the mouse pointer
+  GlMainView::fillContextMenu(menu, point);
+  // Check if a node/edge is under the mouse pointer
   SelectedEntity entity;
 
   if (getGlMainWidget()->pickNodesEdges(point.x(), point.y(), entity)) {
     menu->addSeparator();
     isNode = entity.getEntityType() == SelectedEntity::NODE_SELECTED;
     itemId = entity.getComplexEntityId();
+    QString sId = QString::number(itemId);
 
     if (isNode) {
       if (!_displayedNodesAreNodes->getNodeValue(node(itemId)))
         isNode = false;
 
       itemId = _displayedNodesToGraphEntities->getNodeValue(node(itemId));
-    }
-    else
+    } else
       itemId = _displayedEdgesToGraphEdges->getEdgeValue(edge(itemId));
 
-    menu->addAction((isNode ? trUtf8("Node #") : trUtf8("Edge #"))
-                    + QString::number(itemId))->setEnabled(false);
+    menu->addAction((isNode ? "Node #" : "Edge #") + sId)->setEnabled(false);
 
     menu->addSeparator();
 
-    menu->addAction(tr("Toggle selection"),this,SLOT(addRemoveItemToSelection()));
-    menu->addAction(tr("Select"),this,SLOT(selectItem()));
-    menu->addAction(tr("Delete"),this,SLOT(deleteItem()));
+    QAction *action = menu->addAction("Toggle selection", this, SLOT(addRemoveItemToSelection()));
+    action->setToolTip(QString("Invert the selection of the ") + (isNode ? "node #" : "edge #") +
+                       sId);
+    action = menu->addAction("Select", this, SLOT(selectItem()));
+    action->setToolTip(QString("Select the ") + (isNode ? "node #" : "edge #") + sId);
+    action = menu->addAction("Delete", this, SLOT(deleteItem()));
+    action->setToolTip(QString("Delete the ") + (isNode ? "node #" : "edge #") + sId);
   }
 }
 
@@ -222,21 +272,22 @@ void MatrixView::refresh() {
 }
 
 void MatrixView::deleteDisplayedGraph() {
-  foreach (tlp::Observable* obs, triggers()) {
+  for (auto obs : triggers()) {
     removeRedrawTrigger(obs);
   }
+
   delete _matrixGraph;
-  _matrixGraph=NULL;
+  _matrixGraph = nullptr;
   delete _graphEntitiesToDisplayedNodes;
-  _graphEntitiesToDisplayedNodes=NULL;
+  _graphEntitiesToDisplayedNodes = nullptr;
   delete _displayedNodesToGraphEntities;
-  _displayedNodesToGraphEntities=NULL;
+  _displayedNodesToGraphEntities = nullptr;
   delete _displayedEdgesToGraphEdges;
-  _displayedEdgesToGraphEdges=NULL;
+  _displayedEdgesToGraphEdges = nullptr;
   delete _displayedNodesAreNodes;
-  _displayedNodesAreNodes=NULL;
+  _displayedNodesAreNodes = nullptr;
   delete _dispatcher;
-  _dispatcher=NULL;
+  _dispatcher = nullptr;
 }
 
 void MatrixView::initDisplayedGraph() {
@@ -245,7 +296,7 @@ void MatrixView::initDisplayedGraph() {
 
   deleteDisplayedGraph();
 
-  if(!graph()) {
+  if (graph() == nullptr) {
     return;
   }
 
@@ -257,19 +308,18 @@ void MatrixView::initDisplayedGraph() {
   _displayedNodesAreNodes = new BooleanProperty(_matrixGraph);
   _displayedNodesToGraphEntities = new IntegerProperty(_matrixGraph);
   _displayedEdgesToGraphEdges = new IntegerProperty(_matrixGraph);
-  createScene(_matrixGraph,DataSet());
+  createScene(_matrixGraph, DataSet());
 
   Observable::holdObservers();
-  node n;
-  forEach(n, graph()->getNodes())
-  addNode(graph(), n);
+  for (auto n : graph()->nodes())
+    addNode(graph(), n);
 
-  edge e;
-  forEach(e, graph()->getEdges())
-  addEdge(graph(), e);
+  for (auto e : graph()->edges())
+    addEdge(graph(), e);
   Observable::unholdObservers();
 
-  GlGraphInputData *inputData = getGlMainWidget()->getScene()->getGlGraphComposite()->getInputData();
+  GlGraphInputData *inputData =
+      getGlMainWidget()->getScene()->getGlGraphComposite()->getInputData();
   _sourceToTargetProperties.clear();
   _sourceToTargetProperties.insert(inputData->getElementColor()->getName());
   _sourceToTargetProperties.insert(inputData->getElementShape()->getName());
@@ -283,13 +333,18 @@ void MatrixView::initDisplayedGraph() {
   _sourceToTargetProperties.insert(inputData->getElementTexture()->getName());
   set<string> targetToSourceProperties;
   targetToSourceProperties.insert(inputData->getElementSelected()->getName());
-  _dispatcher = new PropertyValuesDispatcher(graph(), _matrixGraph, _sourceToTargetProperties, targetToSourceProperties, _graphEntitiesToDisplayedNodes, _displayedNodesAreNodes, _displayedNodesToGraphEntities, _displayedEdgesToGraphEdges, _edgesMap);
+  _dispatcher = new PropertyValuesDispatcher(
+      graph(), _matrixGraph, _sourceToTargetProperties, targetToSourceProperties,
+      _graphEntitiesToDisplayedNodes, _displayedNodesAreNodes, _displayedNodesToGraphEntities,
+      _displayedEdgesToGraphEdges, _edgesMap);
 
-  GlGraphRenderingParameters *renderingParameters = getGlMainWidget()->getScene()->getGlGraphComposite()->getRenderingParametersPointer();
+  GlGraphRenderingParameters *renderingParameters =
+      getGlMainWidget()->getScene()->getGlGraphComposite()->getRenderingParametersPointer();
   renderingParameters->setLabelScaled(true);
   renderingParameters->setLabelsDensity(100);
 
-  _configurationWidget->setBackgroundColor(colorToQColor(getGlMainWidget()->getScene()->getBackgroundColor()));
+  _configurationWidget->setBackgroundColor(
+      colorToQColor(getGlMainWidget()->getScene()->getBackgroundColor()));
   addGridBackground();
 
   if (_mustUpdateSizes) {
@@ -306,36 +361,40 @@ void MatrixView::initDisplayedGraph() {
 }
 
 void MatrixView::normalizeSizes(double maxVal) {
-  float maxWidth=FLT_MIN, maxHeight=FLT_MIN;
-  SizeProperty *originalSizes = getGlMainWidget()->getScene()->getGlGraphComposite()->getInputData()->getElementSize();
-  SizeProperty *matrixSizes = getGlMainWidget()->getScene()->getGlGraphComposite()->getInputData()->getElementSize();
+  if (graph() == nullptr)
+    return;
 
-  node n;
-  forEach(n, graph()->getNodes()) {
+  float maxWidth = FLT_MIN, maxHeight = FLT_MIN;
+  SizeProperty *originalSizes =
+      getGlMainWidget()->getScene()->getGlGraphComposite()->getInputData()->getElementSize();
+  SizeProperty *matrixSizes =
+      getGlMainWidget()->getScene()->getGlGraphComposite()->getInputData()->getElementSize();
+
+  for (auto n : graph()->nodes()) {
     Size s(originalSizes->getNodeValue(n));
-    maxWidth = max<float>(maxWidth,s[0]);
-    maxHeight = max<float>(maxHeight,s[1]);
+    maxWidth = max<float>(maxWidth, s[0]);
+    maxHeight = max<float>(maxHeight, s[1]);
   }
 
   Observable::holdObservers();
-  forEach(n, _matrixGraph->getNodes()) {
+  for (auto n : _matrixGraph->nodes()) {
     if (!_displayedNodesAreNodes->getNodeValue(n))
       continue;
 
     Size s(originalSizes->getNodeValue(node(_displayedNodesToGraphEntities->getNodeValue(n))));
-    matrixSizes->setNodeValue(n, Size(s[0]*maxVal/maxWidth, s[1]*maxVal/maxHeight, 1));
+    matrixSizes->setNodeValue(n, Size(s[0] * maxVal / maxWidth, s[1] * maxVal / maxHeight, 1));
   }
   Observable::unholdObservers();
 }
 
 void MatrixView::addNode(tlp::Graph *, const tlp::node n) {
   _mustUpdateLayout = true;
-  _mustUpdateSizes=true;
+  _mustUpdateSizes = true;
 
   vector<int> nodeToDisplayedNodes;
   nodeToDisplayedNodes.reserve(2);
 
-  for (int i=0; i < 2; ++i) {
+  for (int i = 0; i < 2; ++i) {
     node dispNode = _matrixGraph->addNode();
     nodeToDisplayedNodes.push_back(dispNode);
     _displayedNodesToGraphEntities->setNodeValue(dispNode, n.id);
@@ -347,7 +406,7 @@ void MatrixView::addNode(tlp::Graph *, const tlp::node n) {
 
 void MatrixView::addEdge(tlp::Graph *g, const tlp::edge e) {
   _mustUpdateLayout = true;
-  _mustUpdateSizes=true;
+  _mustUpdateSizes = true;
 
   vector<int> edgeToDisplayedNodes;
   edgeToDisplayedNodes.reserve(2);
@@ -361,63 +420,77 @@ void MatrixView::addEdge(tlp::Graph *g, const tlp::edge e) {
 
   _graphEntitiesToDisplayedNodes->setEdgeValue(e, edgeToDisplayedNodes);
 
-  const std::pair<node, node>& eEnds = g->ends(e);
+  const std::pair<node, node> &eEnds = g->ends(e);
 
   node dispSrc = node(_graphEntitiesToDisplayedNodes->getNodeValue(eEnds.first)[0]);
 
   node dispTgt = node(_graphEntitiesToDisplayedNodes->getNodeValue(eEnds.second)[0]);
 
-  edge dispEdge = _matrixGraph->addEdge(dispSrc,dispTgt);
+  edge dispEdge = _matrixGraph->addEdge(dispSrc, dispTgt);
 
   _edgesMap[e] = dispEdge;
 
   _displayedEdgesToGraphEdges->setEdgeValue(dispEdge, e.id);
 
-  ColorProperty* originalColors = graph()->getProperty<ColorProperty>("viewColor");
-  ColorProperty* colors = getGlMainWidget()->getScene()->getGlGraphComposite()->getInputData()->getElementColor();
+  ColorProperty *originalColors = graph()->getProperty<ColorProperty>("viewColor");
+  ColorProperty *colors =
+      getGlMainWidget()->getScene()->getGlGraphComposite()->getInputData()->getElementColor();
 
-  colors->setEdgeValue(dispEdge,originalColors->getEdgeValue(e));
+  colors->setEdgeValue(dispEdge, originalColors->getEdgeValue(e));
 }
 
-void MatrixView::delNode(tlp::Graph *,const tlp::node n) {
-  _mustUpdateLayout = true;
-  _mustUpdateSizes=true;
+void MatrixView::treatEvent(const Event &message) {
+  const GraphEvent *graphEvent = dynamic_cast<const GraphEvent *>(&message);
 
-  vector<int> vect = _graphEntitiesToDisplayedNodes->getNodeValue(n);
+  if (graphEvent) {
+    if (graphEvent->getType() == GraphEvent::TLP_ADD_EDGE)
+      addEdge(graphEvent->getGraph(), graphEvent->getEdge());
 
-  for (vector<int>::iterator it = vect.begin(); it != vect.end(); ++it)
-    _matrixGraph->delNode(node(*it));
+    if (graphEvent->getType() == GraphEvent::TLP_DEL_NODE)
+      delNode(graphEvent->getGraph(), graphEvent->getNode());
+
+    if (graphEvent->getType() == GraphEvent::TLP_DEL_EDGE)
+      delEdge(graphEvent->getGraph(), graphEvent->getEdge());
+  }
 }
 
-void MatrixView::delEdge(tlp::Graph *,const tlp::edge e) {
+void MatrixView::delNode(tlp::Graph *, const tlp::node n) {
   _mustUpdateLayout = true;
-  _mustUpdateSizes=true;
+  _mustUpdateSizes = true;
 
-  vector<int> vect = _graphEntitiesToDisplayedNodes->getEdgeValue(e);
+  const vector<int> &vect = _graphEntitiesToDisplayedNodes->getNodeValue(n);
 
-  for (vector<int>::iterator it = vect.begin(); it != vect.end(); ++it)
-    _matrixGraph->delNode(node(*it));
+  for (auto id : vect)
+    _matrixGraph->delNode(node(id));
+}
+
+void MatrixView::delEdge(tlp::Graph *, const tlp::edge e) {
+  _mustUpdateLayout = true;
+  _mustUpdateSizes = true;
+
+  const vector<int> &vect = _graphEntitiesToDisplayedNodes->getEdgeValue(e);
+
+  for (auto id : vect)
+    _matrixGraph->delNode(node(id));
 
   _matrixGraph->delEdge(_edgesMap[e]);
   _edgesMap.remove(e);
 }
 
-template<typename PROPTYPE>
+template <typename PROPTYPE>
 struct AscendingPropertySorter {
   PROPTYPE *prop;
-  AscendingPropertySorter(PropertyInterface *_prop) :
-    prop(static_cast<PROPTYPE*>(_prop)) {}
-  bool operator()(node a,node b) {
+  AscendingPropertySorter(PropertyInterface *_prop) : prop(static_cast<PROPTYPE *>(_prop)) {}
+  bool operator()(node a, node b) {
     return prop->getNodeValue(a) < prop->getNodeValue(b);
   }
 };
 
-template<typename PROPTYPE>
+template <typename PROPTYPE>
 struct DescendingPropertySorter {
   PROPTYPE *prop;
-  DescendingPropertySorter(PropertyInterface *_prop) :
-    prop(static_cast<PROPTYPE*>(_prop)) {}
-  bool operator()(node a,node b) {
+  DescendingPropertySorter(PropertyInterface *_prop) : prop(static_cast<PROPTYPE *>(_prop)) {}
+  bool operator()(node a, node b) {
     return prop->getNodeValue(a) > prop->getNodeValue(b);
   }
 };
@@ -431,10 +504,9 @@ struct DescendingIdSorter {
 void MatrixView::updateNodesOrder() {
   _orderedNodes.clear();
   _orderedNodes.resize(graph()->numberOfNodes());
-  int i=0;
-  node n;
-  forEach(n, graph()->getNodes())
-  _orderedNodes[i++] = n;
+  int i = 0;
+  for (auto n : graph()->nodes())
+    _orderedNodes[i++] = n;
 
   if (graph()->existProperty(_orderingMetricName)) {
     PropertyInterface *pi = graph()->getProperty(_orderingMetricName);
@@ -447,16 +519,14 @@ void MatrixView::updateNodesOrder() {
         sort(_orderedNodes.begin(), _orderedNodes.end(),
              DescendingPropertySorter<DoubleProperty>(pi));
 
-    }
-    else if (pi->getTypename() == "int") {
+    } else if (pi->getTypename() == "int") {
       if (_configurationWidget->ascendingOrder())
         sort(_orderedNodes.begin(), _orderedNodes.end(),
              AscendingPropertySorter<IntegerProperty>(pi));
       else
         sort(_orderedNodes.begin(), _orderedNodes.end(),
              DescendingPropertySorter<IntegerProperty>(pi));
-    }
-    else if (pi->getTypename() == "string") {
+    } else if (pi->getTypename() == "string") {
       if (_configurationWidget->ascendingOrder())
         sort(_orderedNodes.begin(), _orderedNodes.end(),
              AscendingPropertySorter<StringProperty>(pi));
@@ -464,73 +534,78 @@ void MatrixView::updateNodesOrder() {
         sort(_orderedNodes.begin(), _orderedNodes.end(),
              DescendingPropertySorter<StringProperty>(pi));
     }
-  }
-  else if (!_configurationWidget->ascendingOrder())
-    sort(_orderedNodes.begin(), _orderedNodes.end(),
-         DescendingIdSorter());
+  } else if (!_configurationWidget->ascendingOrder())
+    sort(_orderedNodes.begin(), _orderedNodes.end(), DescendingIdSorter());
 }
 
 void MatrixView::updateLayout() {
+  if (graph() == nullptr)
+    return;
+
   holdObservers();
   updateNodesOrder();
 
-  LayoutProperty *layout = getGlMainWidget()->getScene()->getGlGraphComposite()->getInputData()->getElementLayout();
-  Coord horiz(1,0,0), vert(0,-1,0);
-  IntegerProperty* position = getGlMainWidget()->getScene()->getGlGraphComposite()->getInputData()->getElementLabelPosition();
+  LayoutProperty *layout =
+      getGlMainWidget()->getScene()->getGlGraphComposite()->getInputData()->getElementLayout();
+  Coord horiz(1, 0, 0), vert(0, -1, 0);
+  IntegerProperty *position = getGlMainWidget()
+                                  ->getScene()
+                                  ->getGlGraphComposite()
+                                  ->getInputData()
+                                  ->getElementLabelPosition();
 
-  for (vector<node>::iterator it = _orderedNodes.begin(); it != _orderedNodes.end(); ++it) {
-    vector<int> dispNodes = _graphEntitiesToDisplayedNodes->getNodeValue(node(*it));
+  for (auto _on : _orderedNodes) {
+    const vector<int> &dispNodes = _graphEntitiesToDisplayedNodes->getNodeValue(node(_on));
     layout->setNodeValue(node(dispNodes[0]), horiz);
     position->setNodeValue(node(dispNodes[0]), LabelPosition::Top);
     layout->setNodeValue(node(dispNodes[1]), vert);
     position->setNodeValue(node(dispNodes[1]), LabelPosition::Left);
-    horiz[0]+=1;
-    vert[1]-=1;
+    horiz[0] += 1;
+    vert[1] -= 1;
   }
 
-  IntegerProperty* shapes = getGlMainWidget()->getScene()->getGlGraphComposite()->getInputData()->getElementShape();
-  int shape = GlyphManager::getInst().glyphId("2D - Square");
-  edge e;
-  forEach (e, graph()->getEdges()) {
-    const std::pair<node, node> eEnds = graph()->ends(e);
-    vector<int> srcNodes = _graphEntitiesToDisplayedNodes->getNodeValue(eEnds.first),
-                tgtNodes = _graphEntitiesToDisplayedNodes->getNodeValue(eEnds.second),
-                edgeNodes = _graphEntitiesToDisplayedNodes->getEdgeValue(e);
+  IntegerProperty *shapes =
+      getGlMainWidget()->getScene()->getGlGraphComposite()->getInputData()->getElementShape();
+  int shape = GlyphManager::glyphId("2D - Square");
+  for (auto e : graph()->edges()) {
+    auto eEnds = graph()->ends(e);
+    const vector<int> &srcNodes = _graphEntitiesToDisplayedNodes->getNodeValue(eEnds.first),
+                      &tgtNodes = _graphEntitiesToDisplayedNodes->getNodeValue(eEnds.second),
+                      &edgeNodes = _graphEntitiesToDisplayedNodes->getEdgeValue(e);
 
     // 0 => horizontal line, 1 => vertical line
-    Coord src0 = layout->getNodeValue(node(srcNodes[0])), tgt0 = layout->getNodeValue(node(tgtNodes[0])),
-          src1 = layout->getNodeValue(node(srcNodes[1])), tgt1 = layout->getNodeValue(node(tgtNodes[1]));
+    const Coord &src0 = layout->getNodeValue(node(srcNodes[0])),
+                &tgt0 = layout->getNodeValue(node(tgtNodes[0])),
+                &src1 = layout->getNodeValue(node(srcNodes[1])),
+                &tgt1 = layout->getNodeValue(node(tgtNodes[1]));
 
     layout->setNodeValue(node(edgeNodes[0]), Coord(tgt0[0], src1[1], 0));
-    shapes->setNodeValue(node(edgeNodes[0]),shape);
+    shapes->setNodeValue(node(edgeNodes[0]), shape);
 
     if (_isOriented == false) {
       layout->setNodeValue(node(edgeNodes[1]), Coord(src0[0], tgt1[1], 0));
-      shapes->setNodeValue(node(edgeNodes[1]),shape);
+      shapes->setNodeValue(node(edgeNodes[1]), shape);
     }
   }
 
-  forEach(e, _matrixGraph->getEdges()) {
-    const std::pair<node, node> eEnds = _matrixGraph->ends(e);
-    node src = eEnds.first;
-    node tgt = eEnds.second;
+  for (auto e : _matrixGraph->edges()) {
+    auto eEnds = _matrixGraph->ends(e);
 
-    Coord srcPos = layout->getNodeValue(src);
-    Coord tgtPos = layout->getNodeValue(tgt);
-    float xMax = max(srcPos[0],tgtPos[0]);
-    float xMin = min(srcPos[0],tgtPos[0]);
+    auto &srcPos = layout->getNodeValue(eEnds.first);
+    auto &tgtPos = layout->getNodeValue(eEnds.second);
+    float xMax = max(srcPos[0], tgtPos[0]);
+    float xMin = min(srcPos[0], tgtPos[0]);
     float dist = (xMax - xMin);
-    Coord b(xMin+dist,srcPos[1]+dist/2.,0);
     std::vector<Coord> bends(4);
     bends[0] = srcPos;
     bends[1] = srcPos;
-    bends[1][1] += dist/3. + 1.;
+    bends[1][1] += dist / 3. + 1.;
     bends[2] = tgtPos;
-    bends[2][1] += dist/3. + 1.;
+    bends[2][1] += dist / 3. + 1.;
     bends[3] = tgtPos;
     vector<Coord> curvePoints;
-    computeBezierPoints(bends,curvePoints,20);
-    layout->setEdgeValue(e,curvePoints);
+    computeBezierPoints(bends, curvePoints, 20);
+    layout->setEdgeValue(e, curvePoints);
   }
 
   unholdObservers();
@@ -541,8 +616,8 @@ void MatrixView::setBackgroundColor(QColor c) {
   emit drawNeeded();
 }
 
-void MatrixView::setOrderingMetric(const std::string& name) {
-  if (name != "" && !graph()->existProperty(name))
+void MatrixView::setOrderingMetric(const std::string &name) {
+  if (!name.empty() && !graph()->existProperty(name))
     return;
 
   if (graph()->existProperty(_orderingMetricName))
@@ -562,17 +637,15 @@ void MatrixView::setGridDisplayMode() {
 }
 
 void MatrixView::registerTriggers() {
-  foreach (tlp::Observable* obs, triggers()) {
+  for (auto obs : triggers()) {
     removeRedrawTrigger(obs);
   }
 
-  if(_matrixGraph) {
-    addRedrawTrigger(_matrixGraph);
-    Iterator<string> *it = _matrixGraph->getProperties();
+  if (graph()) {
+    addRedrawTrigger(graph());
 
-    while(it->hasNext()) {
-      PropertyInterface *property=_matrixGraph->getProperty(it->next());
-      addRedrawTrigger(property);
+    for (PropertyInterface *prop : _matrixGraph->getObjectProperties()) {
+      addRedrawTrigger(prop);
     }
   }
 }
@@ -587,11 +660,12 @@ void MatrixView::removeGridBackground() {
   GlLayer *backgroundLayer = getGlMainWidget()->getScene()->getLayer("MatrixView_Background");
 
   if (!backgroundLayer) {
-    backgroundLayer = new GlLayer("MatrixView_Background", &(getGlMainWidget()->getScene()->getLayer("Main")->getCamera()), true);
+    backgroundLayer =
+        new GlLayer("MatrixView_Background",
+                    &(getGlMainWidget()->getScene()->getLayer("Main")->getCamera()), true);
     backgroundLayer->clear();
     getGlMainWidget()->getScene()->addExistingLayerBefore(backgroundLayer, "Main");
-  }
-  else {
+  } else {
     GlEntity *entity = backgroundLayer->findGlEntity("MatrixView_backgroundGrid");
     delete entity;
   }
@@ -603,3 +677,4 @@ void MatrixView::applySettings() {
 }
 
 PLUGIN(MatrixView)
+} // namespace tlp
