@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -26,7 +26,7 @@ namespace pocore {
 class ColorFunction {
 public:
   virtual ~ColorFunction() {}
-  virtual RGBA getColor(const double& value, const unsigned int itemId) const = 0;
+  virtual RGBA getColor(const double &value, const unsigned int itemId) const = 0;
 };
-}
-#endif //COLORFUNCTION_H
+} // namespace pocore
+#endif // COLORFUNCTION_H
