@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -27,12 +27,12 @@ namespace pocore {
 class FishEyesScreenFurnas : public ScreenFunction {
 
 public:
-  FishEyesScreenFurnas ();
-  Vec2f project (const Vec2f& ) const;
-  Vec2f unproject (const Vec2f& ) const;
-  void  setCenter (double x, double y);
-  void  setRadius (double r);
-  void  setHeight (double h);
+  FishEyesScreenFurnas();
+  Vec2f project(const Vec2f &) const override;
+  Vec2f unproject(const Vec2f &) const override;
+  void setCenter(double x, double y);
+  void setRadius(double r);
+  void setHeight(double h);
 
 private:
   double R;
@@ -40,6 +40,5 @@ private:
   double l;
   Vec2f fisheyesCenter;
 };
-}
-#endif //FISHEYESSCREENFURNAS_H
-
+} // namespace pocore
+#endif // FISHEYESSCREENFURNAS_H
