@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -23,8 +23,7 @@ namespace pocore {
 
 HSIColorMapping::HSIColorMapping(const HSI &from, const HSI &to) : hsiColorScale(from, to) {}
 
-RGBA HSIColorMapping::getColor(const double& value, const unsigned int) const {
+RGBA HSIColorMapping::getColor(const double &value, const unsigned int) const {
   return hsiColorScale[value].getRGBA();
 }
-
-}
+} // namespace pocore
