@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -28,19 +28,14 @@ namespace pocore {
 
 class HSIColorMapping : public ColorFunction {
 
-public :
-
-  HSIColorMapping(const HSI& from = HSI(1.5, 1.0, 0.4), const HSI& to = HSI(1.0, 1.0, 1.0));
+public:
+  HSIColorMapping(const HSI &from = HSI(1.5, 1.0, 0.4), const HSI &to = HSI(1.0, 1.0, 1.0));
 
   // value must be normalized
-  RGBA getColor(const double& value, const unsigned int) const;
-
-private :
+  RGBA getColor(const double &value, const unsigned int) const override;
 
+private:
   HSIColorScale hsiColorScale;
-
 };
-
-}
+} // namespace pocore
 #endif /* HSICOLORMAPPING_H_ */
-
