@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,11 +17,10 @@
  *
  */
 
-
-// This implementation of HSI Color Space is from the following paper : "Issues in Visualizing Large Databases"
+// This implementation of HSI Color Space is from the following paper : "Issues in Visualizing Large
+// Databases"
 // D. A. Keim, H.-P. Kriegel
 
-
 #ifndef HSI_H_
 #define HSI_H_
 
@@ -31,30 +30,24 @@ namespace pocore {
 
 class HSI {
 
-public :
-
+public:
   HSI(double hue, double saturation, double intensity);
   HSI(const RGBA &c);
   double value(double hue_phase) const;
   RGBA getRGBA() const;
 
   double hue, saturation, intensity;
-
 };
 
 class HSIColorScale {
 
-public :
-
-  HSIColorScale(const HSI& from, const HSI& to);
+public:
+  HSIColorScale(const HSI &from, const HSI &to);
   HSI operator[](double f) const;
 
-private :
-
+private:
   HSI foot;
   double hue_range, sat_range, int_range;
-
 };
-
-}
+} // namespace pocore
 #endif /* HSI_H_ */
