@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -28,11 +28,12 @@ namespace pocore {
 class HilbertLayout : public LayoutFunction {
 public:
   HilbertLayout(unsigned char order);
-  Vec2i  project (const unsigned int id) const;
-  unsigned int unproject (const Vec2i& ) const;
+  Vec2i project(const unsigned int id) const override;
+  unsigned int unproject(const Vec2i &) const override;
+
 private:
   unsigned char order;
   int shift;
 };
-}
-#endif //HILBERTLAYOUT_H
+} // namespace pocore
+#endif // HILBERTLAYOUT_H
