@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -25,9 +25,8 @@ namespace pocore {
 class LayoutFunction {
 public:
   virtual ~LayoutFunction() {}
-  virtual Vec2i project (const unsigned int id) const = 0;
-  virtual unsigned int  unproject (const Vec2i& ) const = 0;
+  virtual Vec2i project(const unsigned int id) const = 0;
+  virtual unsigned int unproject(const Vec2i &) const = 0;
 };
-}
-#endif //LAYOUTFUNCTION_H
-
+} // namespace pocore
+#endif // LAYOUTFUNCTION_H
