@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -26,14 +26,14 @@
 namespace pocore {
 class LinearMappingColor : public ColorFunction {
 public:
-  LinearMappingColor(const double& min, const double& max);
-  RGBA getColor(const double& value, const unsigned int) const;
+  LinearMappingColor(const double &min, const double &max);
+  RGBA getColor(const double &value, const unsigned int) const override;
+
 private:
   double _min;
   double _max;
   RGBA startColor;
   RGBA endColor;
 };
-}
-#endif //LINEARMAPPINGCOLOR_H
-
+} // namespace pocore
+#endif // LINEARMAPPINGCOLOR_H
