@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,10 +20,9 @@
 #include "LogarithmicMappingColor.h"
 
 namespace pocore {
-LogarithmicMappingColor::LogarithmicMappingColor(const double &min, const double &max) :
-  LinearMappingColor(log(1.+min), log(1.+ max)) {
-}
+LogarithmicMappingColor::LogarithmicMappingColor(const double &min, const double &max)
+    : LinearMappingColor(log1p(min), log1p(max)) {}
 RGBA LogarithmicMappingColor::getColor(const double &value, const unsigned int idColor) const {
-  return LinearMappingColor::getColor(log(1. + value), idColor);
-}
+  return LinearMappingColor::getColor(log1p(value), idColor);
 }
+} // namespace pocore
