@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -26,8 +26,8 @@
 namespace pocore {
 class LogarithmicMappingColor : public LinearMappingColor {
 public:
-  LogarithmicMappingColor(const double& min, const double& max);
-  RGBA getColor(const double& value, const unsigned int) const;
+  LogarithmicMappingColor(const double &min, const double &max);
+  RGBA getColor(const double &value, const unsigned int) const override;
 };
-}
-#endif //LOGARITHMICMAPPINGCOLOR_H
+} // namespace pocore
+#endif // LOGARITHMICMAPPINGCOLOR_H
