@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -27,9 +27,8 @@ class ScreenFunction {
 
 public:
   virtual ~ScreenFunction() {}
-  virtual Vec2f project(const Vec2f& ) const = 0;
-  virtual Vec2f unproject(const Vec2f& ) const = 0;
+  virtual Vec2f project(const Vec2f &) const = 0;
+  virtual Vec2f unproject(const Vec2f &) const = 0;
 };
-}
-#endif //SCREENFUNCTION_H
-
+} // namespace pocore
+#endif // SCREENFUNCTION_H
