@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -23,13 +23,11 @@
 #include <string>
 #include "LayoutFunction.h"
 
-
 namespace pocore {
 class SpiralLayout : public LayoutFunction {
 public:
-  Vec2i  project (const unsigned int id) const;
-  unsigned int unproject (const Vec2i& ) const;
-
+  Vec2i project(const unsigned int id) const override;
+  unsigned int unproject(const Vec2i &) const override;
 };
-}
-#endif //SPIRALLAYOUT_H
+} // namespace pocore
+#endif // SPIRALLAYOUT_H
