@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -25,11 +25,12 @@
 namespace pocore {
 class SquareLayout : public LayoutFunction {
 public:
-  SquareLayout(unsigned int widht);
-  Vec2i  project (const unsigned int id) const;
-  unsigned int unproject (const Vec2i& ) const;
+  SquareLayout(unsigned int width);
+  Vec2i project(const unsigned int id) const override;
+  unsigned int unproject(const Vec2i &) const override;
+
 private:
   unsigned int _width;
 };
-}
-#endif //SQUARELAYOUT_H
+} // namespace pocore
+#endif // SQUARELAYOUT_H
