@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -26,22 +26,18 @@
 #include "ColorFunction.h"
 #include "potypes.h"
 
-
 namespace pocore {
 
 class TulipNodeColorMapping : public ColorFunction {
 
-public :
-
+public:
   TulipNodeColorMapping(tlp::Graph *graph);
 
-  RGBA getColor(const double&, const unsigned int itemId) const;
-
-private :
+  RGBA getColor(const double &, const unsigned int itemId) const override;
 
+private:
   tlp::Graph *graph;
 };
-
-}
+} // namespace pocore
 
 #endif /* TULIPNODECOLORMAPPING_H_ */
