@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -26,8 +26,7 @@ namespace pocore {
 
 typedef tlp::Vector<unsigned char, 4> RGBA;
 typedef tlp::Vector<float, 2> Vec2f;
-typedef tlp::Vector<int, 2>   Vec2i;
-
-}
+typedef tlp::Vector<int, 2> Vec2i;
+} // namespace pocore
 
 #endif
