@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,31 +21,29 @@
 #define PIXELORIENTEDVIEWINTERACTORS_H_
 
 #include <tulip/NodeLinkDiagramComponentInteractor.h>
+#include "../../utils/PluginNames.h"
 
 namespace tlp {
 
 class PixelOrientedInteractor : public NodeLinkDiagramComponentInteractor {
 
-public :
-
-  PixelOrientedInteractor(const QString &iconPath, const QString &text);
-
-  bool isCompatible(const std::string &viewName) const;
+public:
+  PixelOrientedInteractor(const QString &iconPath, const QString &text,
+                          const unsigned int priority = 0);
 
+  bool isCompatible(const std::string &viewName) const override;
 };
 
 class PixelOrientedInteractorNavigation : public PixelOrientedInteractor {
 
-public :
-
-  PLUGININFORMATION("PixelOrientedInteractorNavigation", "Tulip Team", "02/04/2009", "Pixel Oriented Navigation Interactor", "1.0", "Navigation")
+public:
+  PLUGININFORMATION(InteractorName::PixelOrientedInteractorNavigation, "Tulip Team", "02/04/2009",
+                    "Pixel Oriented Navigation Interactor", "1.0", "Navigation")
 
   PixelOrientedInteractorNavigation(const tlp::PluginContext *);
 
-  void construct();
-
+  void construct() override;
 };
-
-}
+} // namespace tlp
 
 #endif /* PIXELORIENTEDVIEWINTERACTORS_H_ */
