@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -34,30 +34,24 @@ class PixelOrientedOptionsWidget : public QWidget {
 
   Q_OBJECT
 
-  Ui::PixelOrientedOptionsWidgetData* _ui;
-public :
+  Ui::PixelOrientedOptionsWidgetData *_ui;
 
-  PixelOrientedOptionsWidget(QWidget *parent = 0);
-  ~PixelOrientedOptionsWidget();
+public:
+  PixelOrientedOptionsWidget(QWidget *parent = nullptr);
+  ~PixelOrientedOptionsWidget() override;
 
   Color getBackgroundColor() const;
   void setBackgroundColor(const Color &color);
 
   std::string getLayoutType() const;
-  void setLayoutType(const std::string& layoutType);
+  void setLayoutType(const std::string &layoutType);
 
   bool configurationChanged();
 
-private slots :
-
-  void pressBackgroundColorButton();
-
-private :
-
+private:
   bool oldValuesInitialized;
   Color oldBackgroundColor;
   std::string oldLayoutType;
-
 };
-}
+} // namespace tlp
 #endif /* PIXELORIENTEDOPTIONSWIDGET_H_ */
