@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,13 +20,14 @@
 #include <fstream>
 #include <cmath>
 
+#include <QTimer>
+
 #include <tulip/TlpTools.h>
 #include <tulip/Graph.h>
 #include <tulip/GlMainWidget.h>
 #include <tulip/GlRect.h>
 #include <tulip/GlGraphComposite.h>
 #include <tulip/GlLayer.h>
-#include <tulip/GlProgressBar.h>
 #include <tulip/GlLabel.h>
 #include <tulip/LayoutProperty.h>
 #include <tulip/StringProperty.h>
@@ -34,34 +35,37 @@
 #include <tulip/IntegerProperty.h>
 #include <tulip/ColorProperty.h>
 #include <tulip/SizeProperty.h>
-#include <tulip/ForEach.h>
 #include <tulip/tulipconf.h>
+#include <tulip/TlpQtTools.h>
+#include <tulip/Perspective.h>
 
 #include "PixelOrientedInteractors.h"
 #include "PixelOrientedView.h"
+#include "PixelOrientedViewQuickAccessBar.h"
 
 #include "../utils/ViewGraphPropertiesSelectionWidget.h"
 
 #include <QApplication>
-#include <QMenu>
 #include <QGraphicsView>
+#include <QMainWindow>
+#include <QProgressDialog>
+#include <QTimer>
 
 using namespace std;
 using namespace pocore;
-using namespace tlp;
 
-static void setGraphView (tlp::GlGraphComposite *glGraph, bool displayNodes) {
-  tlp::GlGraphRenderingParameters param = glGraph->getRenderingParameters ();
-  param.setAntialiasing (true);
-  param.setViewNodeLabel (true);
-  param.setFontsType (2);
+static void setGraphView(tlp::GlGraphComposite *glGraph, bool displayNodes) {
+  tlp::GlGraphRenderingParameters param = glGraph->getRenderingParameters();
+  param.setAntialiasing(true);
+  param.setViewNodeLabel(true);
+  param.setFontsType(2);
   param.setSelectedNodesStencil(1);
   param.setNodesStencil(0xFFFF);
   param.setNodesLabelStencil(0xFFFF);
   param.setDisplayEdges(false);
   param.setDisplayNodes(displayNodes);
   param.setDisplayMetaNodes(displayNodes);
-  glGraph->setRenderingParameters (param);
+  glGraph->setRenderingParameters(param);
 }
 
 const string propertiesTypes[] = {"double", "int"};
@@ -72,63 +76,56 @@ namespace tlp {
 
 PLUGIN(PixelOrientedView)
 
-PixelOrientedView::PixelOrientedView(const PluginContext *) :
-  pixelOrientedGraph(NULL), graphComposite(NULL), mainLayer(NULL),
-  overviewsComposite(NULL), optionsWidget(NULL), propertiesSelectionWidget(NULL),
-  pixelOrientedMediator(NULL),
-  lastNbNodes(0), overviewWidth(0), overviewHeight(0), minWidth(0), refSize(0), hilbertLayout(NULL), squareLayout(NULL), spiralLayout(new SpiralLayout()),
-  zorderLayout(NULL), tulipNodeColorMapping(NULL), smallMultiplesView(true), sceneRadiusBak(0.0), zoomFactorBak(0.0), detailViewLabel(NULL), detailOverview(NULL),
-  newGraphSet(false), smallMultiplesNeedUpdate(false), lastViewWindowWidth(0), lastViewWindowHeight(0), center(false), interactorsActivated(false),isConstruct(false)  {
-}
+PixelOrientedView::PixelOrientedView(const PluginContext *)
+    : GlMainView(true), pixelOrientedGraph(nullptr), graphComposite(nullptr), mainLayer(nullptr),
+      overviewsComposite(nullptr), optionsWidget(nullptr), propertiesSelectionWidget(nullptr),
+      pixelOrientedMediator(nullptr), lastNbNodes(0), overviewWidth(0), overviewHeight(0),
+      minWidth(0), refSize(0), hilbertLayout(nullptr), squareLayout(nullptr),
+      spiralLayout(new SpiralLayout()), zorderLayout(nullptr), tulipNodeColorMapping(nullptr),
+      smallMultiplesView(true), sceneRadiusBak(0.0), zoomFactorBak(0.0), detailViewLabel(nullptr),
+      detailOverview(nullptr), newGraphSet(false), smallMultiplesNeedUpdate(false),
+      lastViewWindowWidth(0), lastViewWindowHeight(0), center(false), isConstruct(false) {}
 
 PixelOrientedView::~PixelOrientedView() {
-  if(isConstruct) {
+  if (isConstruct) {
     destroyData();
-
-    if (mainLayer->findGlEntity("graph")) {
-      GlGraphComposite *lastGraphComposite = (GlGraphComposite *)mainLayer->findGlEntity("graph");
-      Graph *theGraph = lastGraphComposite->getInputData()->getGraph();
-      theGraph->removeListener(lastGraphComposite);
-    }
-
-    delete spiralLayout;
-
-    if (hilbertLayout != NULL) {
-      delete hilbertLayout;
-      delete squareLayout;
-      delete zorderLayout;
-    }
-
-    delete tulipNodeColorMapping;
-    delete pixelOrientedMediator;
-    delete propertiesSelectionWidget;
-    delete optionsWidget;
   }
+
+  delete spiralLayout;
+  delete hilbertLayout;
+  delete squareLayout;
+  delete zorderLayout;
+  delete tulipNodeColorMapping;
+  delete pixelOrientedMediator;
+  delete propertiesSelectionWidget;
+  delete optionsWidget;
+  delete graphComposite;
 }
 
 QList<QWidget *> PixelOrientedView::configurationWidgets() const {
-  return QList<QWidget *>() << propertiesSelectionWidget << optionsWidget ;
+  return QList<QWidget *>() << propertiesSelectionWidget << optionsWidget;
 }
 
 void PixelOrientedView::initGlWidget() {
   mainLayer = getGlMainWidget()->getScene()->getLayer("Main");
 
-  if (mainLayer == NULL) {
+  if (mainLayer == nullptr) {
     mainLayer = new GlLayer("Main");
     getGlMainWidget()->getScene()->addExistingLayer(mainLayer);
   }
 
   if (mainLayer->findGlEntity("graph")) {
-    GlGraphComposite *lastGraphComposite = (GlGraphComposite *)mainLayer->findGlEntity("graph");
+    GlGraphComposite *lastGraphComposite =
+        static_cast<GlGraphComposite *>(mainLayer->findGlEntity("graph"));
     Graph *theGraph = lastGraphComposite->getInputData()->getGraph();
 
-    if(theGraph)
+    if (theGraph)
       theGraph->removeListener(lastGraphComposite);
   }
 
-  if (overviewsComposite != NULL) {
+  if (overviewsComposite != nullptr) {
     overviewsComposite->reset(true);
-    detailOverview = NULL;
+    detailOverview = nullptr;
   }
 
   mainLayer->getComposite()->reset(true);
@@ -136,7 +133,7 @@ void PixelOrientedView::initGlWidget() {
   overviewsComposite = new GlComposite();
   mainLayer->addGlEntity(overviewsComposite, "overview composite");
 
-  detailViewLabel = NULL;
+  detailViewLabel = nullptr;
 
   graphComposite = new GlGraphComposite(pixelOrientedGraph);
   mainLayer->addGlEntity(graphComposite, "graph");
@@ -153,36 +150,38 @@ void PixelOrientedView::setLayoutFunction(pocore::LayoutFunction *layoutFunction
 
 void PixelOrientedView::setState(const DataSet &dataSet) {
 
-  if(!isConstruct) {
-    isConstruct=true;
+  if (!isConstruct) {
+    isConstruct = true;
     propertiesSelectionWidget = new ViewGraphPropertiesSelectionWidget();
     propertiesSelectionWidget->enableEdgesButton(false);
-    pixelOrientedMediator = new PixelOrientedMediator(spiralLayout, NULL);
+    pixelOrientedMediator = new PixelOrientedMediator(spiralLayout, nullptr);
     optionsWidget = new PixelOrientedOptionsWidget();
     layoutFunctionsMap["Spiral"] = spiralLayout;
     setOverviewVisible(true);
   }
 
+  GlMainView::setState(dataSet);
+
   Graph *lastGraph = this->pixelOrientedGraph;
 
-  if (graph() == NULL) {
+  if (graph() == nullptr) {
     this->pixelOrientedGraph = graph();
     destroyData();
     initGlWidget();
     lastNbNodes = 0;
 
-    if (lastGraph != NULL && lastGraph != pixelOrientedGraph) {
+    if (lastGraph != nullptr && lastGraph != pixelOrientedGraph) {
       overviewsComposite->reset(true);
       overviewsMap.clear();
-      detailOverview = NULL;
+      detailOverview = nullptr;
       newGraphSet = true;
     }
 
-    foreach (tlp::Observable* obs, triggers()) {
+    for (auto obs : triggers()) {
       removeRedrawTrigger(obs);
     }
 
-    propertiesSelectionWidget->setWidgetParameters(NULL, propertiesTypesFilter);
+    propertiesSelectionWidget->setWidgetParameters(nullptr, propertiesTypesFilter);
 
     center = true;
     draw();
@@ -191,32 +190,32 @@ void PixelOrientedView::setState(const DataSet &dataSet) {
     return;
   }
 
-  if (tulipNodeColorMapping != NULL && this->pixelOrientedGraph != graph()) {
+  if (tulipNodeColorMapping != nullptr && this->pixelOrientedGraph != graph()) {
     delete tulipNodeColorMapping;
-    tulipNodeColorMapping = NULL;
+    tulipNodeColorMapping = nullptr;
   }
 
-  if (tulipNodeColorMapping == NULL) {
+  if (tulipNodeColorMapping == nullptr) {
     tulipNodeColorMapping = new TulipNodeColorMapping(pixelOrientedGraph);
     pixelOrientedMediator->setColorFunction(tulipNodeColorMapping);
   }
 
-  if (lastGraph == NULL || lastGraph != graph()) {
+  if (lastGraph == nullptr || lastGraph != graph()) {
     this->pixelOrientedGraph = graph();
     initGlWidget();
     destroyData();
     lastNbNodes = pixelOrientedGraph->numberOfNodes();
     initLayoutFunctions();
 
-    if (lastGraph != NULL && lastGraph != pixelOrientedGraph) {
+    if (lastGraph != nullptr && lastGraph != pixelOrientedGraph) {
       overviewsComposite->reset(true);
       overviewsMap.clear();
-      detailOverview = NULL;
+      detailOverview = nullptr;
       newGraphSet = true;
     }
   }
 
-  if (lastGraph != NULL && lastGraph->getRoot() != pixelOrientedGraph->getRoot()) {
+  if (lastGraph != nullptr && lastGraph->getRoot() != pixelOrientedGraph->getRoot()) {
     overviewGenMap.clear();
     detailOverviewPropertyName = "";
   }
@@ -226,21 +225,21 @@ void PixelOrientedView::setState(const DataSet &dataSet) {
 
   propertiesSelectionWidget->setWidgetParameters(pixelOrientedGraph, propertiesTypesFilter);
 
-  Color backgroundColor(255,255,255);
+  Color backgroundColor(255, 255, 255);
   dataSet.get("background color", backgroundColor);
   optionsWidget->setBackgroundColor(backgroundColor);
 
-  bool haveSelectedGraphProperties=false;
+  bool haveSelectedGraphProperties = false;
 
   DataSet selectedGraphPropertiesDataSet;
 
   if (dataSet.get("selected graph properties", selectedGraphPropertiesDataSet)) {
-    haveSelectedGraphProperties=true;
+    haveSelectedGraphProperties = true;
     int i = 0;
     ostringstream oss;
     oss << i;
 
-    while (selectedGraphPropertiesDataSet.exist(oss.str())) {
+    while (selectedGraphPropertiesDataSet.exists(oss.str())) {
       string propertyName;
       selectedGraphPropertiesDataSet.get(oss.str(), propertyName);
       selectedGraphProperties.push_back(propertyName);
@@ -250,16 +249,16 @@ void PixelOrientedView::setState(const DataSet &dataSet) {
 
     propertiesSelectionWidget->setSelectedProperties(selectedGraphProperties);
 
-    for (size_t i = 0 ; i < selectedGraphProperties.size() ; ++i) {
+    for (size_t i = 0; i < selectedGraphProperties.size(); ++i) {
       bool overviewGenerated = false;
       dataSet.get(selectedGraphProperties[i], overviewGenerated);
       overviewGenMap[selectedGraphProperties[i]] = overviewGenerated;
     }
 
-    string layoutName = "";
+    string layoutName("");
     dataSet.get("layout", layoutName);
 
-    if (layoutName != "") {
+    if (!layoutName.empty()) {
       optionsWidget->setLayoutType(layoutName);
     }
   }
@@ -269,15 +268,23 @@ void PixelOrientedView::setState(const DataSet &dataSet) {
 
   center = true;
 
-  if(haveSelectedGraphProperties) {
+  if (haveSelectedGraphProperties) {
     updateOverviews(true);
     getGlMainWidget()->centerScene();
   }
 
+  bool quickAccessBarVisible = false;
+
+  if (dataSet.get<bool>("quickAccessBarVisible", quickAccessBarVisible)) {
+    needQuickAccessBar = true;
+    setQuickAccessBarVisible(quickAccessBarVisible);
+  } else // display quickaccessbar
+    setQuickAccessBarVisible(true);
+
   draw();
   center = false;
 
-  if (detailOverviewName != "") {
+  if (!detailOverviewName.empty()) {
     switchFromSmallMultiplesToDetailView(overviewsMap[detailOverviewName]);
   }
 
@@ -286,28 +293,27 @@ void PixelOrientedView::setState(const DataSet &dataSet) {
 }
 
 DataSet PixelOrientedView::state() const {
-  DataSet dataSet;
+  DataSet dataSet = GlMainView::state();
   DataSet selectedGraphPropertiesDataSet;
 
-  for (size_t i = 0 ; i < selectedGraphProperties.size() ; ++i) {
+  unsigned int i = 0;
+  for (auto &prop : selectedGraphProperties) {
     ostringstream oss;
-    oss << i;
-    selectedGraphPropertiesDataSet.set(oss.str(), selectedGraphProperties[i]);
+    oss << i++;
+    selectedGraphPropertiesDataSet.set(oss.str(), prop);
+    dataSet.set(prop, overviewGenMap.find(prop)->second);
   }
 
   dataSet.set("selected graph properties", selectedGraphPropertiesDataSet);
   dataSet.set("layout", optionsWidget->getLayoutType());
-
-  map<string, bool> tmpOverviewGenMap=overviewGenMap;
-
-  for (size_t i = 0 ; i < selectedGraphProperties.size() ; ++i) {
-    dataSet.set(selectedGraphProperties[i], tmpOverviewGenMap[selectedGraphProperties[i]]);
-  }
-
-  dataSet.set("lastViewWindowWidth",  getGlMainWidget()->width());
-  dataSet.set("lastViewWindowHeight",  getGlMainWidget()->height());
+  dataSet.set("lastViewWindowWidth", getGlMainWidget()->width());
+  dataSet.set("lastViewWindowHeight", getGlMainWidget()->height());
   dataSet.set("detail overview  name", detailOverviewPropertyName);
   dataSet.set("background color", optionsWidget->getBackgroundColor());
+
+  if (needQuickAccessBar)
+    dataSet.set("quickAccessBarVisible", quickAccessBarVisible());
+
   return dataSet;
 }
 
@@ -316,15 +322,13 @@ void PixelOrientedView::graphChanged(Graph *) {
 }
 
 void PixelOrientedView::initLayoutFunctions() {
-  if (hilbertLayout != NULL) {
-    delete hilbertLayout;
-    delete squareLayout;
-    delete zorderLayout;
-  }
+  delete hilbertLayout;
+  delete squareLayout;
+  delete zorderLayout;
 
-  hilbertLayout = new HilbertLayout((int) ceil(log(pixelOrientedGraph->numberOfNodes())/ log(4)));
-  squareLayout = new SquareLayout((int) ceil(sqrt(pixelOrientedGraph->numberOfNodes())));
-  zorderLayout = new ZorderLayout((int) ceil(log(pixelOrientedGraph->numberOfNodes())/ log(4)));
+  hilbertLayout = new HilbertLayout(int(ceil(log(pixelOrientedGraph->numberOfNodes()) / log(4))));
+  squareLayout = new SquareLayout(int(ceil(sqrt(pixelOrientedGraph->numberOfNodes()))));
+  zorderLayout = new ZorderLayout(int(ceil(log(pixelOrientedGraph->numberOfNodes()) / log(4))));
   layoutFunctionsMap["Zorder"] = zorderLayout;
   layoutFunctionsMap["Peano"] = hilbertLayout;
   layoutFunctionsMap["Square"] = squareLayout;
@@ -344,7 +348,7 @@ void PixelOrientedView::initPixelView() {
   overviewWidth = MIN_IMAGE_WIDTH;
   overviewHeight = MIN_IMAGE_HEIGHT;
 
-  minWidth = ((unsigned int) floor(sqrt((double)pixelOrientedGraph->numberOfNodes()))) + 1;
+  minWidth = uint(floor(sqrt(double(pixelOrientedGraph->numberOfNodes())))) + 1;
 
   while (minWidth > overviewWidth) {
     overviewWidth *= 2;
@@ -361,46 +365,54 @@ void PixelOrientedView::initPixelView() {
 
   selectedGraphProperties = propertiesSelectionWidget->getSelectedGraphProperties();
 
-  if (selectedGraphProperties.size()  == 0) return;
+  if (selectedGraphProperties.empty())
+    return;
 
-  float squareRoot = sqrt(double(selectedGraphProperties.size()));
-  const unsigned int N =  (unsigned int) squareRoot + (fmod((float) selectedGraphProperties.size(), squareRoot) == 0. ? 0 : 1);
+  float squareRoot = sqrt(float(selectedGraphProperties.size()));
+  const unsigned int N =
+      uint(squareRoot) + (fmod(float(selectedGraphProperties.size()), squareRoot) == 0.f ? 0u : 1u);
 
-  for (size_t i = 0 ; i < selectedGraphProperties.size() ; ++i) {
+  for (size_t i = 0; i < selectedGraphProperties.size(); ++i) {
+    const string &prop = selectedGraphProperties[i];
 
-    if (dataMap.find(selectedGraphProperties[i]) == dataMap.end()) {
-      dataMap[selectedGraphProperties[i]] = new TulipGraphDimension(pixelOrientedGraph, selectedGraphProperties[i]);
-    }
-    else {
-      dataMap[selectedGraphProperties[i]]->updateNodesRank();
-    }
+    auto itd = dataMap.find(prop);
+    if (itd == dataMap.end())
+      dataMap.emplace(prop, new TulipGraphDimension(pixelOrientedGraph, prop));
+    else
+      itd->second->updateNodesRank();
 
     unsigned int row = i / N;
     unsigned int col = i % N;
 
-    Coord overviewBLCorner = Coord(col * (overviewWidth + spaceBetweenOverviews), -(labelHeight + row * (labelHeight + overviewHeight + spaceBetweenOverviews)), 0);
+    Coord overviewBLCorner(
+        col * (overviewWidth + spaceBetweenOverviews),
+        -(labelHeight + row * (labelHeight + overviewHeight + spaceBetweenOverviews)), 0);
     ostringstream oss;
-    oss << "pixel oriented overview for dimension " << selectedGraphProperties[i];
+    oss << "pixel oriented overview for dimension " << prop;
 
-    if (overviewsMap.find(selectedGraphProperties[i]) == overviewsMap.end()) {
-      PixelOrientedOverview *pixelOrientedOverview = new PixelOrientedOverview(dataMap[selectedGraphProperties[i]], pixelOrientedMediator, overviewBLCorner, selectedGraphProperties[i], backgroundColor, textColor);
+    PixelOrientedOverview *pixelOrientedOverview;
+    auto ito = overviewsMap.find(prop);
+    if (ito == overviewsMap.end()) {
+      pixelOrientedOverview = new PixelOrientedOverview(
+          dataMap[prop], pixelOrientedMediator, overviewBLCorner, prop, backgroundColor, textColor);
       pixelOrientedOverview->computePixelView();
-      overviewsMap[selectedGraphProperties[i]] = pixelOrientedOverview;
+      overviewsMap.emplace(prop, pixelOrientedOverview);
 
-      if (overviewGenMap.find(selectedGraphProperties[i]) == overviewGenMap.end()) {
-        overviewGenMap[selectedGraphProperties[i]] = false;
+      auto itog = overviewGenMap.find(prop);
+      if (itog == overviewGenMap.end()) {
+        overviewGenMap.emplace(prop, false);
       }
-    }
-    else {
-      overviewsMap[selectedGraphProperties[i]]->setBLCorner(overviewBLCorner);
-      overviewsMap[selectedGraphProperties[i]]->setBackgroundColor(backgroundColor);
-      overviewsMap[selectedGraphProperties[i]]->setTextColor(textColor);
+    } else {
+      pixelOrientedOverview = ito->second;
+      pixelOrientedOverview->setBLCorner(overviewBLCorner);
+      pixelOrientedOverview->setBackgroundColor(backgroundColor);
+      pixelOrientedOverview->setTextColor(textColor);
     }
 
-    overviewsComposite->addGlEntity(overviewsMap[selectedGraphProperties[i]], oss.str());
+    overviewsComposite->addGlEntity(pixelOrientedOverview, oss.str());
   }
 
-  if (detailOverviewPropertyName != "") {
+  if (!detailOverviewPropertyName.empty()) {
     detailOverview = overviewsMap[detailOverviewPropertyName];
   }
 
@@ -410,45 +422,53 @@ void PixelOrientedView::initPixelView() {
 void PixelOrientedView::destroyOverviewsIfNeeded() {
   vector<string> propertiesToRemove;
 
-  for (size_t i = 0 ; i < selectedGraphProperties.size() ; ++i) {
-    if (!pixelOrientedGraph->existProperty(selectedGraphProperties[i])) {
-      if (overviewsMap[selectedGraphProperties[i]] == detailOverview) {
-        detailOverview = NULL;
+  for (auto &prop : selectedGraphProperties) {
+    if (!pixelOrientedGraph->existProperty(prop)) {
+      if (overviewsMap[prop] == detailOverview) {
+        detailOverview = nullptr;
         detailOverviewPropertyName = "";
       }
 
-      delete overviewsMap[selectedGraphProperties[i]];
-      overviewsMap.erase(selectedGraphProperties[i]);
-      delete dataMap[selectedGraphProperties[i]];
-      dataMap.erase(selectedGraphProperties[i]);
-      propertiesToRemove.push_back(selectedGraphProperties[i]);
+      delete overviewsMap[prop];
+      overviewsMap.erase(prop);
+      delete dataMap[prop];
+      dataMap.erase(prop);
+      propertiesToRemove.push_back(prop);
     }
   }
 
-  for (size_t i = 0 ; i < propertiesToRemove.size() ; ++i) {
-    selectedGraphProperties.erase(remove(selectedGraphProperties.begin(), selectedGraphProperties.end(), propertiesToRemove[i]), selectedGraphProperties.end());
+  for (auto &prop : propertiesToRemove) {
+    selectedGraphProperties.erase(
+        remove(selectedGraphProperties.begin(), selectedGraphProperties.end(), prop),
+        selectedGraphProperties.end());
   }
 }
 
 void PixelOrientedView::destroyData() {
-  for (map<string, TulipGraphDimension *>::iterator it = dataMap.begin() ; it != dataMap.end(); ++it) {
-    delete it->second;
+  for (auto &it : dataMap) {
+    delete it.second;
   }
 
   dataMap.clear();
 }
 
 void PixelOrientedView::addEmptyViewLabel() {
+  Color backgroundColor(optionsWidget->getBackgroundColor());
+  getGlMainWidget()->getScene()->setBackgroundColor(backgroundColor);
+
   Color textColor = getTextColor();
-  GlLabel *noDimsLabel = new GlLabel(Coord(0,0,0), Size(200,200), textColor);
+
+  GlLabel *noDimsLabel = new GlLabel(Coord(0.0f, 0.0f, 0.0f), Size(200.0f, 200.0f), textColor);
   noDimsLabel->setText(ViewName::PixelOrientedViewName);
   mainLayer->addGlEntity(noDimsLabel, "no dimensions label");
-  GlLabel *noDimsLabel1 = new GlLabel(Coord(0,-50, 0), Size(400,200), textColor);
+  GlLabel *noDimsLabel1 = new GlLabel(Coord(0.0f, -50.0f, 0.0f), Size(400.0f, 200.0f), textColor);
   noDimsLabel1->setText("No graph properties selected.");
   mainLayer->addGlEntity(noDimsLabel1, "no dimensions label 1");
-  GlLabel *noDimsLabel2 = new GlLabel(Coord(0,-100,0), Size(700,200), textColor);
+  GlLabel *noDimsLabel2 = new GlLabel(Coord(0.0f, -100.0f, 0.0f), Size(700.0f, 200.0f), textColor);
   noDimsLabel2->setText("Go to the \"Properties\" tab in top right corner.");
   mainLayer->addGlEntity(noDimsLabel2, "no dimensions label 2");
+
+  mainLayer->deleteGlEntity(graphComposite);
 }
 
 void PixelOrientedView::removeEmptyViewLabel() {
@@ -456,65 +476,70 @@ void PixelOrientedView::removeEmptyViewLabel() {
   GlSimpleEntity *noDimsLabel1 = mainLayer->findGlEntity("no dimensions label 1");
   GlSimpleEntity *noDimsLabel2 = mainLayer->findGlEntity("no dimensions label 2");
 
-  if (noDimsLabel != NULL) {
+  if (noDimsLabel != nullptr) {
     mainLayer->deleteGlEntity(noDimsLabel);
     delete noDimsLabel;
     mainLayer->deleteGlEntity(noDimsLabel1);
     delete noDimsLabel1;
     mainLayer->deleteGlEntity(noDimsLabel2);
     delete noDimsLabel2;
+
+    mainLayer->addGlEntity(graphComposite, "graph");
   }
 }
 
-void PixelOrientedView::generatePixelOverview(PixelOrientedOverview *pixelOverview, GlMainWidget *glWidget) {
-  pixelOverview->computePixelView(glWidget);
+void PixelOrientedView::generatePixelOverview(PixelOrientedOverview *pixelOverview) {
+  pixelOverview->computePixelView();
   overviewGenMap[pixelOverview->getDimensionName()] = true;
 }
 
 void PixelOrientedView::draw() {
-  if (pixelOrientedGraph != NULL) {
-
-    getGlMainWidget()->getScene()->setBackgroundColor(optionsWidget->getBackgroundColor());
+  GlMainWidget *glw = getGlMainWidget();
+  GlScene *scene = glw->getScene();
 
+  if (pixelOrientedGraph != nullptr) {
+    scene->setBackgroundColor(optionsWidget->getBackgroundColor());
     unsigned int lastNbDimensionsSelected = selectedGraphProperties.size();
-
     destroyOverviewsIfNeeded();
 
-    if (pixelOrientedGraph->numberOfNodes() >= 2) // We stop the creation of pixel overviews if we have less than 2 nodes as we need at least two to compute sizes for overview
+    if (pixelOrientedGraph->numberOfNodes() >= 2) // We stop the creation of pixel overviews if we
+                                                  // have less than 2 nodes as we need at least two
+                                                  // to compute sizes for overview
       initPixelView();
     else
       selectedGraphProperties.clear();
 
-
-    if (selectedGraphProperties.size() == 0) {
+    if (selectedGraphProperties.empty()) {
       if (!smallMultiplesView) {
         switchFromDetailViewToSmallMultiples();
       }
 
       removeEmptyViewLabel();
       addEmptyViewLabel();
-      getGlMainWidget()->getScene()->centerScene();
-      getGlMainWidget()->draw();
+      if (quickAccessBarVisible())
+        _quickAccessBar->setEnabled(false);
+      scene->centerScene();
+      glw->draw();
       return;
-    }
-    else {
+    } else {
       removeEmptyViewLabel();
+      if (quickAccessBarVisible())
+        _quickAccessBar->setEnabled(true);
     }
 
     if (lastNbDimensionsSelected != selectedGraphProperties.size()) {
       center = true;
     }
 
-    if (!smallMultiplesView && lastNbDimensionsSelected == 1 && selectedGraphProperties.size() > 1) {
+    if (!smallMultiplesView && lastNbDimensionsSelected == 1 &&
+        selectedGraphProperties.size() > 1) {
       switchFromDetailViewToSmallMultiples();
-    }
-    else if (selectedGraphProperties.size() == 1) {
-      getGlMainWidget()->makeCurrent();
+    } else if (selectedGraphProperties.size() == 1) {
+      glw->makeCurrent();
       overviewsMap[selectedGraphProperties[0]]->computePixelView();
       overviewGenMap[selectedGraphProperties[0]] = true;
       switchFromSmallMultiplesToDetailView(overviewsMap[selectedGraphProperties[0]]);
-    }
-    else if (!smallMultiplesView && detailOverview != NULL) {
+    } else if (!smallMultiplesView && detailOverview != nullptr) {
       detailOverview->computePixelView();
       smallMultiplesNeedUpdate = true;
 
@@ -522,29 +547,25 @@ void PixelOrientedView::draw() {
         switchFromSmallMultiplesToDetailView(detailOverview);
         newGraphSet = false;
       }
-    }
-    else if (!smallMultiplesView && detailOverview == NULL) {
+    } else if (!smallMultiplesView && detailOverview == nullptr) {
       switchFromDetailViewToSmallMultiples();
-    }
-    else {
-      getGlMainWidget()->makeCurrent();
+    } else {
+      glw->makeCurrent();
       updateOverviews(true);
     }
 
-    if (!smallMultiplesView && detailViewLabel != NULL) {
+    if (!smallMultiplesView && detailViewLabel != nullptr) {
       detailViewLabel->setColor(getTextColor());
     }
 
     if (center) {
       centerView();
       center = false;
+    } else {
+      glw->draw();
     }
-    else {
-      getGlMainWidget()->draw();
-    }
-  }
-  else {
-    getGlMainWidget()->draw();
+  } else {
+    glw->draw();
   }
 }
 
@@ -563,10 +584,9 @@ Color PixelOrientedView::getTextColor() const {
   int bgV = backgroundColor.getV();
 
   if (bgV < 128) {
-    textColor = Color(255,255,255);
-  }
-  else {
-    textColor = Color(0,0,0);
+    textColor = Color(255, 255, 255);
+  } else {
+    textColor = Color(0, 0, 0);
   }
 
   return textColor;
@@ -575,20 +595,19 @@ Color PixelOrientedView::getTextColor() const {
 void PixelOrientedView::centerView(bool) {
   if (!getGlMainWidget()->isVisible()) {
     if (lastViewWindowWidth != 0 && lastViewWindowHeight != 0) {
-      getGlMainWidget()->getScene()->ajustSceneToSize(lastViewWindowWidth, lastViewWindowHeight);
-    }
-    else {
+      getGlMainWidget()->getScene()->adjustSceneToSize(lastViewWindowWidth, lastViewWindowHeight);
+    } else {
       getGlMainWidget()->getScene()->centerScene();
     }
-  }
-  else {
-    getGlMainWidget()->getScene()->ajustSceneToSize(getGlMainWidget()->width(), getGlMainWidget()->height());
+  } else {
+    getGlMainWidget()->getScene()->adjustSceneToSize(getGlMainWidget()->width(),
+                                                     getGlMainWidget()->height());
   }
 
-  // we apply a zoom factor to preserve a 50 px margin width
+  // we apply a zoom factor to preserve a 50 px margin height
   // to ensure the scene will not be drawn under the configuration tabs title
-  float glWidth = (float) graphicsView()->width();
-  getGlMainWidget()->getScene()->zoomFactor((glWidth - 50)/ glWidth);
+  float glHeight = graphicsView()->width();
+  getGlMainWidget()->getScene()->zoomFactor((glHeight - 50) / glHeight);
   getGlMainWidget()->draw();
 }
 
@@ -596,63 +615,54 @@ void PixelOrientedView::updateOverviews(const bool updateAll) {
 
   if (smallMultiplesView) {
     mainLayer->deleteGlEntity(overviewsComposite);
-  }
-  else {
+  } else {
     setGraphView(graphComposite, false);
     mainLayer->deleteGlEntity(detailViewLabel);
   }
 
   unsigned int nbOverviews = selectedGraphProperties.size();
   unsigned currentStep = 0;
+  Camera &cam = getGlMainWidget()->getScene()->getGraphCamera();
+  double sceneRadiusBak = cam.getSceneRadius();
+  double zoomFactorBak = cam.getZoomFactor();
+  Coord eyesBak = cam.getEyes();
+  Coord centerBak = cam.getCenter();
+  Coord upBak = cam.getUp();
 
-  double sceneRadiusBak = getGlMainWidget()->getScene()->getGraphCamera().getSceneRadius();
-  double zoomFactorBak = getGlMainWidget()->getScene()->getGraphCamera().getZoomFactor();
-  Coord eyesBak = getGlMainWidget()->getScene()->getGraphCamera().getEyes();
-  Coord centerBak = getGlMainWidget()->getScene()->getGraphCamera().getCenter();
-  Coord upBak = getGlMainWidget()->getScene()->getGraphCamera().getUp();
+  if (nbOverviews) {
+    QProgressDialog progress(Perspective::instance()->mainWindow());
+    progress.setCancelButton(nullptr);
+    progress.setWindowTitle("Computing pixel oriented view for: ");
+    progress.setRange(0, nbOverviews);
+    progress.setMinimumWidth(400);
+    progress.setWindowModality(Qt::WindowModal);
+    progress.setValue(0);
 
-  GlProgressBar *progressBar =
-    new GlProgressBar(Coord(0, 0, 0), 600, 100,
-                      // use same green color as the highlighting one
-                      // in workspace panel
-                      Color(0xCB, 0xDE, 0x5D));
-  progressBar->setComment("Updating pixel oriented view...");
-  progressBar->progress(currentStep, nbOverviews);
-  mainLayer->addGlEntity(progressBar, "progress bar");
-  getGlMainWidget()->draw();
-  // needed to display progressBar
-  QApplication::processEvents();
-
-  for (map<string, PixelOrientedOverview *>::iterator it = overviewsMap.begin() ; it != overviewsMap.end() ; ++it) {
-    if (std::find(selectedGraphProperties.begin(), selectedGraphProperties.end(), it->first) != selectedGraphProperties.end()) {
-      if (updateAll || overviewGenMap[it->first]) {
-        (it->second)->computePixelView();
-        overviewGenMap[it->first] = true;
+    for (auto &it : overviewsMap) {
+      if (std::find(selectedGraphProperties.begin(), selectedGraphProperties.end(), it.first) !=
+          selectedGraphProperties.end()) {
+        if (updateAll || overviewGenMap[it.first]) {
+          (it.second)->computePixelView();
+          overviewGenMap[it.first] = true;
+        }
+        progress.setLabelText((it.second)->getDimensionName().c_str());
+        progress.setValue(++currentStep);
       }
-
-      progressBar->progress(++currentStep, nbOverviews);
-      getGlMainWidget()->draw();
-      // needed to display progressBar
-      QApplication::processEvents();
     }
   }
 
-  mainLayer->deleteGlEntity(progressBar);
-  delete progressBar;
-
   if (smallMultiplesView) {
     mainLayer->addGlEntity(overviewsComposite, "overviews composite");
-  }
-  else {
+  } else {
     setGraphView(graphComposite, true);
     mainLayer->addGlEntity(detailViewLabel, "dimension label");
   }
 
-  getGlMainWidget()->getScene()->getGraphCamera().setSceneRadius(sceneRadiusBak);
-  getGlMainWidget()->getScene()->getGraphCamera().setZoomFactor(zoomFactorBak);
-  getGlMainWidget()->getScene()->getGraphCamera().setEyes(eyesBak);
-  getGlMainWidget()->getScene()->getGraphCamera().setCenter(centerBak);
-  getGlMainWidget()->getScene()->getGraphCamera().setUp(upBak);
+  cam.setSceneRadius(sceneRadiusBak);
+  cam.setZoomFactor(zoomFactorBak);
+  cam.setEyes(eyesBak);
+  cam.setCenter(centerBak);
+  cam.setUp(upBak);
 
   getGlMainWidget()->draw();
 }
@@ -660,15 +670,23 @@ void PixelOrientedView::updateOverviews(const bool updateAll) {
 vector<PixelOrientedOverview *> PixelOrientedView::getOverviews() {
   vector<PixelOrientedOverview *> ret;
 
-  for (map<string, PixelOrientedOverview *>::iterator it = overviewsMap.begin() ; it != overviewsMap.end() ; ++it) {
-    if (std::find(selectedGraphProperties.begin(), selectedGraphProperties.end(), it->first) != selectedGraphProperties.end()) {
-      ret.push_back(it->second);
+  for (auto &it : overviewsMap) {
+    if (std::find(selectedGraphProperties.begin(), selectedGraphProperties.end(), it.first) !=
+        selectedGraphProperties.end()) {
+      ret.push_back(it.second);
     }
   }
 
   return ret;
 }
 
+QuickAccessBar *PixelOrientedView::getQuickAccessBarImpl() {
+  auto _bar = new PixelOrientedViewQuickAccessBar(optionsWidget);
+
+  connect(_bar, SIGNAL(settingsChanged()), this, SLOT(applySettings()));
+  return _bar;
+}
+
 void PixelOrientedView::switchFromSmallMultiplesToDetailView(PixelOrientedOverview *pixelOverview) {
 
   if (smallMultiplesView) {
@@ -690,14 +708,13 @@ void PixelOrientedView::switchFromSmallMultiplesToDetailView(PixelOrientedOvervi
   graphComposite->acceptVisitor(&glBBSV);
   BoundingBox graphBoundingBox = glBBSV.getBoundingBox();
 
-
-  if (detailViewLabel != NULL) {
-    delete detailViewLabel;
-  }
-
-  detailViewLabel = new GlLabel(Coord((graphBoundingBox[0][0] + graphBoundingBox[1][0])/ 2.f, graphBoundingBox[0][1] - (graphBoundingBox[1][1] - graphBoundingBox[0][1]) / 8.f),
-                                Size((graphBoundingBox[1][0] - graphBoundingBox[0][0]), (graphBoundingBox[1][1] - graphBoundingBox[0][1]) / 4.f),
-                                getTextColor());
+  delete detailViewLabel;
+  detailViewLabel = new GlLabel(
+      Coord((graphBoundingBox[0][0] + graphBoundingBox[1][0]) / 2.f,
+            graphBoundingBox[0][1] - (graphBoundingBox[1][1] - graphBoundingBox[0][1]) / 8.f),
+      Size((graphBoundingBox[1][0] - graphBoundingBox[0][0]),
+           (graphBoundingBox[1][1] - graphBoundingBox[0][1]) / 4.f),
+      getTextColor());
   detailViewLabel->setText(pixelOverview->getData()->getDimensionName());
   mainLayer->addGlEntity(detailViewLabel, "dimension label");
   smallMultiplesView = false;
@@ -709,7 +726,11 @@ void PixelOrientedView::switchFromSmallMultiplesToDetailView(PixelOrientedOvervi
     propertiesSelectionWidget->setEnabled(false);
   }
 
-  centerView();
+  if (tlp::inGuiTestingMode())
+    // sometimes we must wait a bit to ensure an effective centerView
+    QTimer::singleShot(200, this, SLOT(centerView()));
+  else
+    centerView();
 }
 
 void PixelOrientedView::switchFromDetailViewToSmallMultiples() {
@@ -728,61 +749,62 @@ void PixelOrientedView::switchFromDetailViewToSmallMultiples() {
   getGlMainWidget()->getScene()->getGraphCamera().setUp(upBak);
   smallMultiplesView = true;
   toggleInteractors(false);
-  detailOverview = NULL;
+  detailOverview = nullptr;
   detailOverviewPropertyName = "";
   propertiesSelectionWidget->setEnabled(true);
   getGlMainWidget()->draw();
 }
 
 BoundingBox PixelOrientedView::getSmallMultiplesViewBoundingBox() {
-  GlBoundingBoxSceneVisitor glBBSV(NULL);
+  GlBoundingBoxSceneVisitor glBBSV(nullptr);
   overviewsComposite->acceptVisitor(&glBBSV);
   return glBBSV.getBoundingBox();
 }
 
-void PixelOrientedView::interactorsInstalled(const QList<tlp::Interactor*>&) {
-  toggleInteractors(false);
+void PixelOrientedView::interactorsInstalled(const QList<tlp::Interactor *> &) {
+  toggleInteractors(detailOverview != nullptr);
 }
 
 void PixelOrientedView::toggleInteractors(const bool activate) {
-  QList<Interactor *> interactorsList = interactors();
-
-  for (QList<Interactor *>::iterator it = interactorsList.begin() ; it != interactorsList.end() ; ++it) {
-    if (!(dynamic_cast<PixelOrientedInteractorNavigation *>(*it))) {
-      (*it)->action()->setEnabled(activate);
-
-      if (!activate) {
-        (*it)->action()->setChecked(false);
-      }
-    }
-    else if (!activate) {
-      (*it)->action()->setChecked(true);
-    }
-
-    interactorsActivated = activate;
-  }
+  View::toggleInteractors(activate, {InteractorName::PixelOrientedInteractorNavigation});
 }
 
 void PixelOrientedView::registerTriggers() {
-  foreach (tlp::Observable* obs, triggers()) {
+  for (auto obs : triggers()) {
     removeRedrawTrigger(obs);
   }
+
   addRedrawTrigger(graph());
-  Iterator<string> *it = graph()->getProperties();
 
-  while(it->hasNext()) {
-    PropertyInterface *property=graph()->getProperty(it->next());
-    addRedrawTrigger(property);
+  for (auto prop : graph()->getObjectProperties()) {
+    addRedrawTrigger(prop);
   }
-
-  delete it;
 }
 
 void PixelOrientedView::applySettings() {
-  if(propertiesSelectionWidget->configurationChanged() || optionsWidget->configurationChanged()) {
+  if (propertiesSelectionWidget->configurationChanged() || optionsWidget->configurationChanged()) {
     updateOverviews(true);
     draw();
+
+    if (!smallMultiplesView) {
+      mainLayer->deleteGlEntity(detailViewLabel);
+      GlGraphInputData *inputData = graphComposite->getInputData();
+      inputData->setElementLayout(detailOverview->getPixelViewLayout());
+      inputData->setElementSize(detailOverview->getPixelViewSize());
+      GlBoundingBoxSceneVisitor glBBSV(inputData);
+      graphComposite->acceptVisitor(&glBBSV);
+      BoundingBox graphBoundingBox = glBBSV.getBoundingBox();
+
+      detailViewLabel->setPosition(
+          Coord((graphBoundingBox[0][0] + graphBoundingBox[1][0]) / 2.f,
+                graphBoundingBox[0][1] - (graphBoundingBox[1][1] - graphBoundingBox[0][1]) / 8.f));
+
+      detailViewLabel->setSize(Size((graphBoundingBox[1][0] - graphBoundingBox[0][0]),
+                                    (graphBoundingBox[1][1] - graphBoundingBox[0][1]) / 4.f));
+
+      mainLayer->addGlEntity(detailViewLabel, "dimension label");
+      centerView();
+    }
   }
 }
-
-}
+} // namespace tlp
