@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -35,13 +35,13 @@ class Graph;
 /**
  * @brief Class configuring properties selected and number of iteration for computing SOM.
  */
-class ComputeSOMWidget: public QWidget {
+class ComputeSOMWidget : public QWidget {
   Q_OBJECT
-  Ui::SOMComputeWidget* _ui;
+  Ui::SOMComputeWidget *_ui;
 
 public:
-  ComputeSOMWidget(QWidget* parent = NULL);
-  ~ComputeSOMWidget();
+  ComputeSOMWidget(QWidget *parent = nullptr);
+  ~ComputeSOMWidget() override;
   unsigned number() const;
   void setNumber(unsigned uintValue);
   void clearLists();
@@ -49,5 +49,5 @@ public:
   void setWidgetParameters(tlp::Graph *g, std::vector<std::string> &propertyFilterType);
   void setOutputPropertiesList(std::vector<std::string> &properties);
 };
-}
+} // namespace tlp
 #endif /* COMPUTESOMWIDGET_H_ */
