@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -37,18 +37,17 @@ public:
   GradientManager();
   virtual ~GradientManager();
 
-  void init(const std::vector<std::string>& properties);
+  void init(const std::vector<std::string> &properties);
 
-  tlp::ColorScale* getColorScale(const std::string& propertyName);
+  tlp::ColorScale *getColorScale(const std::string &propertyName);
 
 protected:
-
   void cleanAllGradients();
 
-  std::map<std::string, tlp::ColorScale*> colorScaleMap;
+  std::map<std::string, tlp::ColorScale *> colorScaleMap;
   int beginColorRange;
   int endColorRange;
   int minSVal;
 };
-}
+} // namespace tlp
 #endif /* GRADIENTMANAGER_H_ */
