@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,26 +19,21 @@
 
 #include "DiffusionRateFunction.h"
 
-DiffusionRateFunction::DiffusionRateFunction(
-  TimeDecreasingFunction* decreasingFunction) :
-  timeFunction(decreasingFunction) {
-
-}
+DiffusionRateFunction::DiffusionRateFunction(TimeDecreasingFunction *decreasingFunction)
+    : timeFunction(decreasingFunction) {}
 
 DiffusionRateFunction::~DiffusionRateFunction() {
   delete timeFunction;
 }
 
-TimeDecreasingFunction* DiffusionRateFunction::getTimeDecreasingFunction() {
+TimeDecreasingFunction *DiffusionRateFunction::getTimeDecreasingFunction() {
   return timeFunction;
 }
 
-void DiffusionRateFunction::setTimeDecreasingFunction(
-  TimeDecreasingFunction* timeFunction) {
+void DiffusionRateFunction::setTimeDecreasingFunction(TimeDecreasingFunction *timeFunction) {
   if (this->timeFunction) {
     delete this->timeFunction;
   }
 
   this->timeFunction = timeFunction;
 }
-
