@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -24,10 +24,10 @@
 
 class DiffusionRateFunctionSimple : public DiffusionRateFunction {
 public:
-  DiffusionRateFunctionSimple(TimeDecreasingFunction* timeFunction, unsigned int neighborhood);
-  virtual ~DiffusionRateFunctionSimple();
-  double computeSpaceRate(unsigned int distance, unsigned int currentIteration,unsigned int maxIteration,unsigned int inputSampleSize);
-
+  DiffusionRateFunctionSimple(TimeDecreasingFunction *timeFunction, unsigned int neighborhood);
+  ~DiffusionRateFunctionSimple() override;
+  double computeSpaceRate(unsigned int distance, unsigned int currentIteration,
+                          unsigned int maxIteration, unsigned int inputSampleSize) override;
 
 protected:
   unsigned int neighborhoodMax;
