@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -22,18 +22,18 @@
 #include <tulip/tulipconf.h>
 
 DifusionRateFunctionGaussian::DifusionRateFunctionGaussian(
-  TimeDecreasingFunction* decreasingFunction) : DiffusionRateFunction(decreasingFunction) {
-}
+    TimeDecreasingFunction *decreasingFunction)
+    : DiffusionRateFunction(decreasingFunction) {}
 
-DifusionRateFunctionGaussian::~DifusionRateFunctionGaussian() {
-}
+DifusionRateFunctionGaussian::~DifusionRateFunctionGaussian() {}
 
 double DifusionRateFunctionGaussian::computeSpaceRate(unsigned int distance,
-    unsigned int currentIteration, unsigned int maxIteration,
-    unsigned int inputSampleSize) {
+                                                      unsigned int currentIteration,
+                                                      unsigned int maxIteration,
+                                                      unsigned int inputSampleSize) {
 
-  double timeVal = timeFunction->computeCurrentTimeRate(currentIteration,
-                   maxIteration, inputSampleSize);
+  double timeVal =
+      timeFunction->computeCurrentTimeRate(currentIteration, maxIteration, inputSampleSize);
   double value = (sqrt((distance * distance))) / (2 * (timeVal * timeVal));
 
   return exp(-value);
