@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -22,14 +22,14 @@
 
 #include "DiffusionRateFunction.h"
 
-class DifusionRateFunctionGaussian: public DiffusionRateFunction {
+class DifusionRateFunctionGaussian : public DiffusionRateFunction {
 public:
-  DifusionRateFunctionGaussian(TimeDecreasingFunction* decreasingFunction );
-  virtual ~DifusionRateFunctionGaussian();
+  DifusionRateFunctionGaussian(TimeDecreasingFunction *decreasingFunction);
+  ~DifusionRateFunctionGaussian() override;
   double computeSpaceRate(unsigned int distance, unsigned int currentIteration,
-                          unsigned int maxIteration, unsigned int inputSampleSize);
-protected:
+                          unsigned int maxIteration, unsigned int inputSampleSize) override;
 
+protected:
 };
 
 #endif /* DIFUSIONRATEFUNCTIONGAUSSIAN_H_ */
