@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,18 +19,15 @@
 
 #include "TimeDecreasingFunctionSimple.h"
 
-TimeDecreasingFunctionSimple::TimeDecreasingFunctionSimple(double initialCoef) :
-  initialCoef(initialCoef) {
-}
+TimeDecreasingFunctionSimple::TimeDecreasingFunctionSimple(double initialCoef)
+    : initialCoef(initialCoef) {}
 
-TimeDecreasingFunctionSimple::~TimeDecreasingFunctionSimple() {
-}
+TimeDecreasingFunctionSimple::~TimeDecreasingFunctionSimple() {}
 
-double TimeDecreasingFunctionSimple::computeCurrentTimeRate(
-  unsigned int currentIteration, unsigned int,
-  unsigned int inputSampleSize) {
+double TimeDecreasingFunctionSimple::computeCurrentTimeRate(unsigned int currentIteration,
+                                                            unsigned int,
+                                                            unsigned int inputSampleSize) {
 
-  //Learning rate
+  // Learning rate
   return initialCoef / (1 + (currentIteration / inputSampleSize));
 }
-
