@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -22,11 +22,12 @@
 
 #include "TimeDecreasingFunction.h"
 
-class TimeDecreasingFunctionSimple :public TimeDecreasingFunction {
+class TimeDecreasingFunctionSimple : public TimeDecreasingFunction {
 public:
   TimeDecreasingFunctionSimple(double initialCoef);
-  virtual ~TimeDecreasingFunctionSimple();
-  double computeCurrentTimeRate(unsigned int currentIteration,unsigned int maxIteration,unsigned int inputSampleSize);
+  ~TimeDecreasingFunctionSimple() override;
+  double computeCurrentTimeRate(unsigned int currentIteration, unsigned int maxIteration,
+                                unsigned int inputSampleSize) override;
 
   double getInitialCoefficient() {
     return initialCoef;
