@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -27,15 +27,15 @@ class SOMWidget;
 }
 
 namespace tlp {
-class SOMWidget:public QWidget {
+class SOMWidget : public QWidget {
   Q_OBJECT
 
-  Ui::SOMWidget* _ui;
+  Ui::SOMWidget *_ui;
 
 public:
-  SOMWidget(QWidget *parent = NULL);
-  ~SOMWidget();
+  SOMWidget(QWidget *parent = nullptr);
+  ~SOMWidget() override;
 };
-}
+} // namespace tlp
 
 #endif /* SOMWIDGET_H_ */
