@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -24,8 +24,6 @@
 
 #include <tulip/GlLabel.h>
 #include <tulip/GlBoundingBoxSceneVisitor.h>
-#include <tulip/ForEach.h>
-#include <tulip/QGlPixelBufferManager.h>
 #include <tulip/GlTextureManager.h>
 #include <tulip/ColorScale.h>
 #include <tulip/GlQuad.h>
@@ -36,38 +34,30 @@
 
 #include <QToolTip>
 #include <QMouseEvent>
-#include <QGLPixelBuffer>
 #include <QPicture>
 
-#include <stdint.h>
+#include <cstdint>
 
 using namespace tlp;
 using namespace std;
 
-static Coord basePos[4] = { Coord(0, 0, 0), Coord(0, 0, 0), Coord(0, 0, 0), Coord(0, 0, 0) };
 void drawComposite(GlComposite *composite, float lod, Camera *camera) {
-
-  map<string, GlSimpleEntity*> glEntities = composite->getGlEntities();
-
-  map<string, GlSimpleEntity*>::iterator it2;
-
-  for (it2 = glEntities.begin(); it2 != glEntities.end(); ++it2) {
-    it2->second->draw(lod, camera);
+  for (auto &it2 : composite->getGlEntities()) {
+    it2.second->draw(lod, camera);
   }
 }
 
 ColorScaleSlider::ColorScaleSlider(SliderWay way, Size size, GlLabelledColorScale *colorScale,
-                                   const string& textureName) :
-  way(way), size(size), linkedSlider(NULL), linkedScale(colorScale), currentShift(0) {
+                                   const string &textureName)
+    : way(way), size(size), linkedSlider(nullptr), linkedScale(colorScale), currentShift(0) {
 
   buildComposite(textureName);
   linkedScale->getGlColorScale()->getColorScale()->addObserver(this);
-
 }
 
 double ColorScaleSlider::getValue() {
-  return linkedScale->getMinValue() + currentShift
-         * (linkedScale->getMaxValue() - linkedScale->getMinValue());
+  return linkedScale->getMinValue() +
+         currentShift * (linkedScale->getMaxValue() - linkedScale->getMinValue());
 }
 
 ColorScaleSlider::~ColorScaleSlider() {
@@ -75,9 +65,9 @@ ColorScaleSlider::~ColorScaleSlider() {
   reset(true);
 }
 
-void ColorScaleSlider::buildComposite(const std::string& textureName) {
+void ColorScaleSlider::buildComposite(const std::string &textureName) {
   ostringstream oss;
-  Coord colorScaleCoord = linkedScale->getGlColorScale()->getBaseCoord();
+  const Coord &colorScaleCoord = linkedScale->getGlColorScale()->getBaseCoord();
   float Ypos = colorScaleCoord.getY() - linkedScale->getGlColorScale()->getThickness() * .5;
 
   if (way == ToLeft) {
@@ -85,8 +75,7 @@ void ColorScaleSlider::buildComposite(const std::string& textureName) {
     position.set(colorScaleCoord.getX() + linkedScale->getGlColorScale()->getLength(), Ypos,
                  colorScaleCoord.getZ());
     currentShift = 1;
-  }
-  else {
+  } else {
     oss << linkedScale->getMinValue();
     position.set(colorScaleCoord.getX(), Ypos, colorScaleCoord.getZ());
     currentShift = 0;
@@ -96,20 +85,18 @@ void ColorScaleSlider::buildComposite(const std::string& textureName) {
 
   Size labelSize(size.getW(), size.getH());
   vector<Color> fillColors;
-  fillColors.insert(fillColors.begin(), 3,
-                    linkedScale->getGlColorScale()->getColorAtPos(position));
+  fillColors.insert(fillColors.begin(), 3, linkedScale->getGlColorScale()->getColorAtPos(position));
 
   vector<Coord> points;
   points.push_back(position);
   points.push_back(Coord(position.getX() - (size.getW() * 0.5), position.getY() - arrowLen));
   points.push_back(Coord(position.getX() + (size.getW() * 0.5), position.getY() - arrowLen));
 
-  Coord p1 = Coord(points[2].getX(), position.getY() - size.getH(), 0);
-  Coord p2 = Coord(points[1].getX(), position.getY() - size.getH(), 0);
+  Coord p1(points[2].getX(), position.getY() - size.getH(), 0);
+  Coord p2(points[1].getX(), position.getY() - size.getH(), 0);
 
   rect = new GlQuad(p1, p2, points[1], points[2], Color(255, 255, 255));
-  Coord labelPosition(position.getX(), p1.getY() + (points[1].getY()
-                      - p1.getY()) * 0.5);
+  Coord labelPosition(position.getX(), p1.getY() + (points[1].getY() - p1.getY()) * 0.5);
   rect->setTextureName(textureName);
   arrow = new GlPolygon(points, fillColors, fillColors, true, false);
   addGlEntity(arrow, "arrow");
@@ -119,27 +106,25 @@ void ColorScaleSlider::buildComposite(const std::string& textureName) {
   label->setText(oss.str());
 
   computeBoundingBox();
-
 }
 
-void ColorScaleSlider::setLinkedSlider(ColorScaleSlider* linkedSlider) {
+void ColorScaleSlider::setLinkedSlider(ColorScaleSlider *linkedSlider) {
   if (!linkedSlider)
-    this->linkedSlider = NULL;
+    this->linkedSlider = nullptr;
   else {
     if (way == ToLeft) {
       if (linkedSlider->getBasePosition().getX() <= position.getX())
         this->linkedSlider = linkedSlider;
       else {
-        this->linkedSlider = NULL;
+        this->linkedSlider = nullptr;
         std::cerr << __PRETTY_FUNCTION__ << ":" << __LINE__ << " "
                   << "Invalid linked slider bad coordinates" << std::endl;
       }
-    }
-    else {
+    } else {
       if (linkedSlider->getBasePosition().getX() >= position.getX())
         this->linkedSlider = linkedSlider;
       else {
-        this->linkedSlider = NULL;
+        this->linkedSlider = nullptr;
         std::cerr << __PRETTY_FUNCTION__ << ":" << __LINE__ << " "
                   << "Invalid linked slider bad coordinates" << std::endl;
       }
@@ -148,7 +133,7 @@ void ColorScaleSlider::setLinkedSlider(ColorScaleSlider* linkedSlider) {
 }
 
 void ColorScaleSlider::computeBoundingBox() {
-  tlp::GlBoundingBoxSceneVisitor visitor(NULL);
+  tlp::GlBoundingBoxSceneVisitor visitor(nullptr);
   acceptVisitor(&visitor);
   boundingBox = visitor.getBoundingBox();
 }
@@ -158,13 +143,13 @@ void ColorScaleSlider::setColor(Color c) {
 }
 
 float ColorScaleSlider::getLeftBound() {
-  if (way == ToRight || linkedSlider == NULL)
+  if (way == ToRight || linkedSlider == nullptr)
     return 0;
   else
     return linkedSlider->getCurrentShift();
 }
 float ColorScaleSlider::getRightBound() {
-  if (way == ToLeft || linkedSlider == NULL)
+  if (way == ToLeft || linkedSlider == nullptr)
     return 1;
   else
     return linkedSlider->getCurrentShift();
@@ -172,8 +157,8 @@ float ColorScaleSlider::getRightBound() {
 
 void ColorScaleSlider::setValue(double value) {
   if (value >= linkedScale->getMinValue() && value <= linkedScale->getMaxValue()) {
-    currentShift = (value - linkedScale->getMinValue()) / (linkedScale->getMaxValue()
-                   - linkedScale->getMinValue());
+    currentShift = (value - linkedScale->getMinValue()) /
+                   (linkedScale->getMaxValue() - linkedScale->getMinValue());
     updatePosition();
   }
 }
@@ -200,7 +185,7 @@ void ColorScaleSlider::updatePosition() {
     arrow->translate(mouvement);
     label->translate(mouvement);
     rect->translate(mouvement);
-    setColor(linkedScale->getGlColorScale()->getColorAtPos(Coord(xPos,0,0)));
+    setColor(linkedScale->getGlColorScale()->getColorAtPos(Coord(xPos, 0, 0)));
     ostringstream oss;
     oss << getValue();
     label->setText(oss.str());
@@ -208,35 +193,30 @@ void ColorScaleSlider::updatePosition() {
   }
 }
 
-void ColorScaleSlider::beginShift() {
-}
+void ColorScaleSlider::beginShift() {}
 
-void ColorScaleSlider::endShift() {
-}
+void ColorScaleSlider::endShift() {}
 void ColorScaleSlider::draw(float lod, Camera *camera) {
   arrow->draw(lod, camera);
   rect->draw(lod, camera);
   label->draw(lod, camera);
 }
 
-void ColorScaleSlider::update(std::set<Observable *>::iterator,
-                              std::set<Observable *>::iterator) {
+void ColorScaleSlider::update(std::set<Observable *>::iterator, std::set<Observable *>::iterator) {
   float xPos = linkedScale->getPosition().getX() + currentShift * linkedScale->getSize().getW();
-  setColor(linkedScale->getGlColorScale()->getColorAtPos(Coord(xPos,0,0)));
-}
-void ColorScaleSlider::observableDestroyed(Observable *) {
+  setColor(linkedScale->getGlColorScale()->getColorAtPos(Coord(xPos, 0, 0)));
 }
+void ColorScaleSlider::observableDestroyed(Observable *) {}
 
-SliderBar::SliderBar(ColorScaleSlider* left, ColorScaleSlider* right, const string& textureName) :
-  GlSimpleEntity(), left(left), right(right), texture(textureName),isVisible(false) {
-}
+SliderBar::SliderBar(ColorScaleSlider *left, ColorScaleSlider *right, const string &textureName)
+    : GlSimpleEntity(), left(left), right(right), texture(textureName), isVisible(false) {}
 
-SliderBar::~SliderBar() {
-}
+SliderBar::~SliderBar() {}
 
 float SliderBar::getLeftBound() {
   return left->getLeftBound();
 }
+
 float SliderBar::getRightBound() {
   return right->getRightBound();
 }
@@ -246,6 +226,7 @@ void SliderBar::beginShift() {
   right->beginShift();
   left->beginShift();
 }
+
 void SliderBar::shift(float shift) {
   float combinedShift = shift;
 
@@ -258,54 +239,50 @@ void SliderBar::shift(float shift) {
   right->shift(combinedShift);
   left->shift(combinedShift);
 }
+
 void SliderBar::endShift() {
   right->endShift();
   left->endShift();
   isVisible = false;
 }
+
 void SliderBar::draw(float lod, tlp::Camera *camera) {
   glEnable(GL_BLEND);
   glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 
-  Coord lPos = left->getBasePosition();
-  Size lSize = left->getSize();
-  Coord rPos = right->getBasePosition();
-  Size rSize = right->getSize();
+  const Coord &lPos = left->getBasePosition();
+  const Size &lSize = left->getSize();
+  const Coord &rPos = right->getBasePosition();
+  const Size &rSize = right->getSize();
 
   Coord topLeft(lPos.getX() + lSize.getW() * 0.5, lPos.getY() - lSize.getH(), lPos.getZ());
-  Coord bottomRight(rPos.getX() - rSize.getW() * .5, rPos.getY() - rSize.getH() * .25,rPos.getZ());
+  Coord bottomRight(rPos.getX() - rSize.getW() * .5, rPos.getY() - rSize.getH() * .25, rPos.getZ());
 
-  //Sliders are overlapping don't draw the slider bar
-  if(bottomRight.getX() - topLeft.getX() > 0) {
-    GlRect rect(topLeft,bottomRight,Color(255,255,255),Color(255,255,255));
+  // Sliders are overlapping don't draw the slider bar
+  if (bottomRight.getX() - topLeft.getX() > 0) {
+    GlRect rect(topLeft, bottomRight, Color(255, 255, 255), Color(255, 255, 255));
 
-    if(isVisible) {
+    if (isVisible) {
       rect.setTextureName(texture);
-    }
-    else {
-      rect.setTopLeftColor(Color(255,255,255,0));
-      rect.setBottomRightColor(Color(255,255,255,0));
+    } else {
+      rect.setTopLeftColor(Color(255, 255, 255, 0));
+      rect.setBottomRightColor(Color(255, 255, 255, 0));
     }
 
-    rect.draw(lod,camera);
+    rect.draw(lod, camera);
   }
 
-  boundingBox = BoundingBox();
-  boundingBox.expand(topLeft);
-  boundingBox.expand(bottomRight);
+  boundingBox.init(topLeft);
+  boundingBox.expand(bottomRight, true);
 
   glDisable(GL_BLEND);
 }
-ThresholdInteractor::ThresholdInteractor() :
-  layer(new GlLayer("Threshold")), mouvingSlider(NULL),rSlider(NULL),lSlider(NULL), startDrag(false), textureName("") {
-}
+
+ThresholdInteractor::ThresholdInteractor()
+    : layer(new GlLayer("Threshold")), mouvingSlider(nullptr), rSlider(nullptr), lSlider(nullptr),
+      bar(nullptr), startDrag(false), XPosCursor(0), textureName(":/sliderTexture.png") {}
 
 ThresholdInteractor::~ThresholdInteractor() {
-  if (!textureName.empty()) {
-    static_cast<SOMView*>(view())->getMapWidget()->deleteTexture(textureId);
-    GlTextureManager::getInst().deleteTexture(textureName);
-  }
-
   layer->getComposite()->reset(true);
   delete layer;
 }
@@ -314,7 +291,7 @@ void ThresholdInteractor::setView(View *view) {
   EditColorScaleInteractor::setView(view);
 
   if (currentProperty)
-    buildSliders(static_cast<SOMView*>(view));
+    buildSliders(static_cast<SOMView *>(view));
 
   view->refresh();
 }
@@ -332,52 +309,50 @@ bool ThresholdInteractor::draw(GlMainWidget *glMainWidget) {
 
   return true;
 }
-bool ThresholdInteractor::eventFilter(QObject * widget, QEvent * event) {
 
-  GlMainWidget *glMainWidget = dynamic_cast<GlMainWidget*>(widget);
-  SOMView *somView = dynamic_cast<SOMView*>(view());
+bool ThresholdInteractor::eventFilter(QObject *widget, QEvent *event) {
 
-  if (event->type() == QEvent::MouseButtonPress && ((QMouseEvent*) event)->button()
-      == Qt::LeftButton) {
+  GlMainWidget *glMainWidget = static_cast<GlMainWidget *>(widget);
+  SOMView *somView = static_cast<SOMView *>(view());
+
+  QMouseEvent *me = static_cast<QMouseEvent *>(event);
+
+  if (event->type() == QEvent::MouseButtonPress && me->button() == Qt::LeftButton) {
 
-    QMouseEvent *e = static_cast<QMouseEvent*>(event);
     vector<SelectedEntity> selectedEntities;
-    //set<Slider*> finalSelectedEntities;
+    // set<Slider*> finalSelectedEntities;
 
-    //Update Camera for selection
+    // Update Camera for selection
     layer->set2DMode();
     glMainWidget->getScene()->addExistingLayer(layer);
-    glMainWidget->getScene()->selectEntities(RenderingSimpleEntities, e->x(), e->y(), 0, 0, layer,
-        selectedEntities);
-    glMainWidget->getScene()->removeLayer(layer,false);
+    glMainWidget->getScene()->selectEntities(RenderingSimpleEntities, me->x(), me->y(), 0, 0, layer,
+                                             selectedEntities);
+    glMainWidget->getScene()->removeLayer(layer, false);
 
     if (!selectedEntities.empty()) {
 
-      map<string, GlSimpleEntity*> displays = layer->getGlEntities();
+      map<string, GlSimpleEntity *> displays = layer->getGlEntities();
 
-      for (vector<SelectedEntity>::iterator itPE = selectedEntities.begin(); itPE
-           != selectedEntities.end(); ++itPE) {
-        for (map<string, GlSimpleEntity*>::iterator itDisplay = displays.begin(); itDisplay
-             != displays.end(); ++itDisplay) {
-          GlComposite *composite = dynamic_cast<GlComposite*> (itDisplay->second);
+      for (auto &itPE : selectedEntities) {
+        for (auto &itDisplay : displays) {
+          GlComposite *composite = dynamic_cast<GlComposite *>(itDisplay.second);
 
-          if (composite && !composite->findKey(itPE->getSimpleEntity()).empty()) {
+          if (composite && !composite->findKey(itPE.getSimpleEntity()).empty()) {
 
-            Slider *slider = dynamic_cast<Slider*> (composite);
+            Slider *slider = dynamic_cast<Slider *>(composite);
 
             if (slider) {
-              //finalSelectedEntities.insert(slider);
+              // finalSelectedEntities.insert(slider);
               mouvingSlider = slider;
             }
 
             break;
-          }
-          else {
-            if (itDisplay->second == (itPE->getSimpleEntity())) {
-              Slider *slider = dynamic_cast<Slider*> (itDisplay->second);
+          } else {
+            if (itDisplay.second == (itPE.getSimpleEntity())) {
+              Slider *slider = dynamic_cast<Slider *>(itDisplay.second);
 
               if (slider) {
-                //finalSelectedEntities.insert(slider);
+                // finalSelectedEntities.insert(slider);
                 mouvingSlider = slider;
               }
             }
@@ -385,15 +360,15 @@ bool ThresholdInteractor::eventFilter(QObject * widget, QEvent * event) {
         }
       }
 
-      //assert(!finalSelectedEntities.empty());
+      // assert(!finalSelectedEntities.empty());
 
       if (!startDrag) {
         glMainWidget->setMouseTracking(true);
         startDrag = true;
-        //mouvingSlider = *finalSelectedEntities.begin();
+        // mouvingSlider = *finalSelectedEntities.begin();
         assert(mouvingSlider);
         mouvingSlider->beginShift();
-        XPosCursor = e->x();
+        XPosCursor = me->x();
         glMainWidget->getScene()->getGraphCamera().initGl();
 
         layer->setVisible(false);
@@ -410,9 +385,8 @@ bool ThresholdInteractor::eventFilter(QObject * widget, QEvent * event) {
 
   if (event->type() == QEvent::MouseMove) {
     if (startDrag) {
-      QMouseEvent *e = (QMouseEvent*) event;
-      float xShift = e->x() - XPosCursor;
-      XPosCursor = e->x();
+      float xShift = me->x() - XPosCursor;
+      XPosCursor = me->x();
 
       if (xShift == 0) {
         return true;
@@ -426,13 +400,12 @@ bool ThresholdInteractor::eventFilter(QObject * widget, QEvent * event) {
   }
 
   if (event->type() == QEvent::MouseButtonRelease && startDrag) {
-    QMouseEvent *me = (QMouseEvent*) event;
     SOMMap *som = somView->getSOM();
-    assert(mouvingSlider != NULL);
+    assert(mouvingSlider != nullptr);
     glMainWidget->setMouseTracking(false);
     startDrag = false;
     mouvingSlider->endShift();
-    mouvingSlider = NULL;
+    mouvingSlider = nullptr;
     Qt::KeyboardModifiers systMod;
 #if defined(__APPLE__)
     systMod = Qt::AltModifier;
@@ -445,8 +418,7 @@ bool ThresholdInteractor::eventFilter(QObject * widget, QEvent * event) {
         performSelection(somView, somView->getMask()->getNodesEqualTo(true, som));
       else
         performSelection(somView, som->getNodes());
-    }
-    else
+    } else
       performSelection(somView, som->getNodes());
 
     return true;
@@ -457,26 +429,31 @@ bool ThresholdInteractor::eventFilter(QObject * widget, QEvent * event) {
 }
 
 void ThresholdInteractor::performSelection(SOMView *view, tlp::Iterator<node> *it) {
-  BooleanProperty* selection = view->graph()->getProperty<BooleanProperty> ("viewSelection");
+  BooleanProperty *selection = view->graph()->getProperty<BooleanProperty>("viewSelection");
   set<node> mask;
-  map<node, set<node> > &mappingTab = view->getMappingTab();
+  unordered_map<node, set<node>> &mappingTab = view->getMappingTab();
   Observable::holdObservers();
   selection->setAllNodeValue(false);
 
-  //If we are using normalized values we display unnormalized values, to compare them we need to renormalize them
+  // If we are using normalized values we display unnormalized values, to compare them we need to
+  // renormalize them
   InputSample &inputSample = view->getInputSample();
   unsigned int propertyIndex = inputSample.findIndexForProperty(view->getSelectedProperty());
-  double rightSliderRealValue = inputSample.isUsingNormalizedValues()?inputSample.normalize(rSlider->getValue(),propertyIndex):rSlider->getValue();
-  double leftSliderRealValue = inputSample.isUsingNormalizedValues()?inputSample.normalize(lSlider->getValue(),propertyIndex):lSlider->getValue();
+  double rightSliderRealValue = inputSample.isUsingNormalizedValues()
+                                    ? inputSample.normalize(rSlider->getValue(), propertyIndex)
+                                    : rSlider->getValue();
+  double leftSliderRealValue = inputSample.isUsingNormalizedValues()
+                                   ? inputSample.normalize(lSlider->getValue(), propertyIndex)
+                                   : lSlider->getValue();
 
-  node n;
-  forEach(n,it) {
+  for (auto n : it) {
     double nodeValue = currentProperty->getNodeDoubleValue(n);
 
-    if (nodeValue <=  rightSliderRealValue && nodeValue >= leftSliderRealValue) {
-      if (mappingTab.find(n) != mappingTab.end()) {
-        for (set<node>::iterator it = mappingTab[n].begin(); it != mappingTab[n].end(); ++it) {
-          selection->setNodeValue(*it, true);
+    if (nodeValue <= rightSliderRealValue && nodeValue >= leftSliderRealValue) {
+      auto it = mappingTab.find(n);
+      if (it != mappingTab.end()) {
+        for (auto n2 : it->second) {
+          selection->setNodeValue(n2, true);
         }
       }
 
@@ -487,42 +464,46 @@ void ThresholdInteractor::performSelection(SOMView *view, tlp::Iterator<node> *i
   Observable::unholdObservers();
 }
 
-void ThresholdInteractor::screenSizeChanged(SOMView* somView) {
-  EditColorScaleInteractor::screenSizeChanged(somView);
-  clearSliders();
+bool ThresholdInteractor::screenSizeChanged(SOMView *somView) {
+  if (EditColorScaleInteractor::screenSizeChanged(somView)) {
+    clearSliders();
 
-  if (currentProperty)
-    buildSliders(somView);
+    if (currentProperty)
+      buildSliders(somView);
+
+    return true;
+  }
+
+  return false;
 }
 
-void ThresholdInteractor::propertyChanged(SOMView* somView,const string& propertyName, NumericProperty *newProperty) {
-  EditColorScaleInteractor::propertyChanged(somView,propertyName, newProperty);
+void ThresholdInteractor::propertyChanged(SOMView *somView, const string &propertyName,
+                                          NumericProperty *newProperty) {
+  EditColorScaleInteractor::propertyChanged(somView, propertyName, newProperty);
 
   if (newProperty) {
     clearSliders();
     buildSliders(somView);
     layer->setVisible(true);
-  }
-  else
+  } else
     layer->setVisible(false);
-
 }
-void ThresholdInteractor::buildSliders(SOMView* somView) {
+
+void ThresholdInteractor::buildSliders(SOMView *somView) {
   BooleanProperty *mask = somView->getMask();
   SOMMap *som = somView->getSOM();
   assert(som);
   Size sliderSize(colorScale->getSize().getH(), colorScale->getSize().getH());
 
   double minValue, maxValue, intervalMinValue, intervalMaxValue;
-  //Get the minimum and the maximum values.
+  // Get the minimum and the maximum values.
   minValue = currentProperty->getNodeDoubleMin(somView->getSOM());
   maxValue = currentProperty->getNodeDoubleMax(somView->getSOM());
 
   if (mask) {
     intervalMinValue = maxValue;
     intervalMaxValue = minValue;
-    node n;
-    forEach (n,mask->getNodesEqualTo(true,som)) {
+    for (auto n : mask->getNodesEqualTo(true, som)) {
       double nodeValue = currentProperty->getNodeDoubleValue(n);
 
       if (nodeValue < intervalMinValue)
@@ -531,23 +512,24 @@ void ThresholdInteractor::buildSliders(SOMView* somView) {
       if (nodeValue > intervalMaxValue)
         intervalMaxValue = nodeValue;
     }
-  }
-  else {
+  } else {
     intervalMinValue = minValue;
     intervalMaxValue = maxValue;
   }
 
-  InputSample& inputSample = somView->getInputSample();
+  InputSample &inputSample = somView->getInputSample();
   unsigned int propertyIndex = inputSample.findIndexForProperty(somView->getSelectedProperty());
 
   if (textureName.empty())
-    generateSliderTexture(somView->getMapWidget());
+    generateSliderTexture();
 
   lSlider = new ColorScaleSlider(ColorScaleSlider::ToRight, sliderSize, colorScale, textureName);
 
   if (intervalMinValue != minValue) {
-    //If we use normalized values we need to translate them to unnormalized for user comprehension
-    double intervalMinDisplayValue = inputSample.isUsingNormalizedValues()?inputSample.unnormalize(intervalMinValue,propertyIndex):intervalMinValue;
+    // If we use normalized values we need to translate them to unnormalized for user comprehension
+    double intervalMinDisplayValue = inputSample.isUsingNormalizedValues()
+                                         ? inputSample.unnormalize(intervalMinValue, propertyIndex)
+                                         : intervalMinValue;
     lSlider->setValue(intervalMinDisplayValue);
   }
 
@@ -556,8 +538,10 @@ void ThresholdInteractor::buildSliders(SOMView* somView) {
   rSlider = new ColorScaleSlider(ColorScaleSlider::ToLeft, sliderSize, colorScale, textureName);
 
   if (intervalMaxValue != maxValue) {
-    //If we use normalized values we need to translate them to unnormalized for user comprehension
-    double intervalMaxDisplayValue = inputSample.isUsingNormalizedValues()?inputSample.unnormalize(intervalMaxValue,propertyIndex):intervalMaxValue;
+    // If we use normalized values we need to translate them to unnormalized for user comprehension
+    double intervalMaxDisplayValue = inputSample.isUsingNormalizedValues()
+                                         ? inputSample.unnormalize(intervalMaxValue, propertyIndex)
+                                         : intervalMaxValue;
     rSlider->setValue(intervalMaxDisplayValue);
   }
 
@@ -573,17 +557,11 @@ void ThresholdInteractor::clearSliders() {
   if (layer)
     layer->getComposite()->reset(true);
 
-  rSlider = NULL;
-  lSlider = NULL;
-  bar = NULL;
+  rSlider = nullptr;
+  lSlider = nullptr;
+  bar = nullptr;
 }
 
-void ThresholdInteractor::generateSliderTexture(GlMainWidget* widget) {
-  uintptr_t id = reinterpret_cast<uintptr_t>(this);
-  ostringstream oss;
-  oss << "ThresholdInteractorSliderTexture" << id;
-  widget->makeCurrent();
-  textureId = widget->bindTexture(QPixmap(":/sliderTexture.png"));
-  textureName = oss.str();
-  GlTextureManager::getInst().registerExternalTexture(textureName, textureId);
+void ThresholdInteractor::generateSliderTexture() {
+  GlTextureManager::loadTexture(textureName);
 }
