@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -26,7 +26,9 @@ namespace tlp {
 class GlMainWidget;
 struct BoundingBox;
 
-void zoomOnScreenRegion(GlMainWidget *glWidget, const BoundingBox &boundingBox, const bool optimalPath = true, const double velocity = 1.1, const double p = std::sqrt(1.6));
+void zoomOnScreenRegion(GlMainWidget *glWidget, const BoundingBox &boundingBox,
+                        const bool optimalPath = true, const double velocity = 1.1,
+                        const double p = std::sqrt(1.6));
 void zoomOnScreenRegionWithoutAnimation(GlMainWidget *glWidget, const BoundingBox &boundingBox);
-}
+} // namespace tlp
 #endif /* ZOOMUTILS_H_ */
