@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -30,32 +30,27 @@ class ScatterPlot2D;
 
 class ScatterPlot2DViewNavigator : public GLInteractorComponent {
 
-public :
-
+public:
   ScatterPlot2DViewNavigator();
-  ~ScatterPlot2DViewNavigator();
+  ~ScatterPlot2DViewNavigator() override;
 
-  bool eventFilter(QObject *, QEvent *);
-  bool draw(GlMainWidget*) {
+  bool eventFilter(QObject *, QEvent *) override;
+  bool draw(GlMainWidget *) override {
     return false;
   }
-  bool compute(GlMainWidget*) {
+  bool compute(GlMainWidget *) override {
     return false;
   }
-  void viewChanged(View *view);
-
-private :
+  void viewChanged(View *view) override;
 
+private:
   ScatterPlot2D *getOverviewUnderPointer(const Coord &sceneCoord);
 
   ScatterPlot2DView *scatterPlot2dView;
   ScatterPlot2D *selectedScatterPlotOverview;
 
   GlMainWidget *glWidget;
-
 };
-
-}
-
+} // namespace tlp
 
 #endif /* SCATTERPLOTPREVIEWGENERATOR_H_ */
