@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -28,23 +28,19 @@ class ScatterPlot2DView;
 
 class ScatterPlotTrendLine : public GLInteractorComponent {
 
-public :
-
+public:
   ScatterPlotTrendLine();
-  ~ScatterPlotTrendLine();
+  ~ScatterPlotTrendLine() override;
 
-  bool eventFilter(QObject *, QEvent *);
-  bool draw(GlMainWidget *glMainWidget);
-  bool compute(GlMainWidget *glMainWidget);
-  void viewChanged(View *view);
-
-private :
+  bool eventFilter(QObject *, QEvent *) override;
+  bool draw(GlMainWidget *glMainWidget) override;
+  bool compute(GlMainWidget *glMainWidget) override;
+  void viewChanged(View *view) override;
 
+private:
   ScatterPlot2DView *scatterView;
   float a, b;
-
 };
-
-}
+} // namespace tlp
 
 #endif /* SCATTERPLOTTRENDLINE_H_ */
