@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -27,20 +27,16 @@ class NavigableTableView : public QTableView {
   Q_OBJECT
 
 public:
-
-  explicit NavigableTableView(QWidget *parent = 0);
-  void keyPressEvent(QKeyEvent *event);
+  explicit NavigableTableView(QWidget *parent = nullptr);
+  void keyPressEvent(QKeyEvent *event) override;
 
 protected:
-
-  int sizeHintForRow(int row) const;
-  int sizeHintForColumn(int col) const;
-  void paintEvent(QPaintEvent * event);
+  int sizeHintForRow(int row) const override;
+  int sizeHintForColumn(int col) const override;
+  void paintEvent(QPaintEvent *event) override;
 
 private:
-
   void resizeTableRows();
-
 };
 
 #endif // NAVIGABLETABLEVIEW_H
