@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -30,14 +30,16 @@ class PerspectiveSelectionDialog;
 class PerspectiveSelectionDialog : public QDialog {
   Q_OBJECT
 
-  Ui::PerspectiveSelectionDialog* _ui;
+  Ui::PerspectiveSelectionDialog *_ui;
   QString _perspective;
+
 public:
-  explicit PerspectiveSelectionDialog(QWidget *parent = 0);
+  explicit PerspectiveSelectionDialog(QWidget *parent = nullptr);
+  ~PerspectiveSelectionDialog() override;
   QString perspectiveName() const;
 
 protected slots:
-  void selectionChanged(const QModelIndex& a, const QModelIndex& b);
+  void selectionChanged(const QModelIndex &a, const QModelIndex &b);
 };
 
 #endif // PERSPECTIVESELECTIONDIALOG_H
