@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,30 +20,24 @@
 #ifndef PLUGINERRORREPORT_H
 #define PLUGINERRORREPORT_H
 
-#include <QWidget>
-
-namespace Ui {
-class PluginErrorReportData;
-}
+#include <QLabel>
 
 /**
-  @brief This widget provides with maintenance actions related to a plugin load errror.
+  @brief This widget provides with maintenance actions related to a plugin load error.
   When a plugin crash at load time, the user shall have the following choices:
   @list
   @li Uninstall the plugin (removes the file permanantly)
   @li Reinstall it from a distant repository
   @list
   */
-class PluginErrorReport: public QWidget {
+class PluginErrorReport : public QLabel {
   Q_OBJECT
 public:
-  explicit PluginErrorReport(const QString &fileName, const QString &errorMsg, QWidget *parent=NULL);
+  explicit PluginErrorReport(const QString &fileName, const QString &errorMsg,
+                             QWidget *parent = nullptr);
 
 protected:
-  virtual void focusInEvent(QFocusEvent *);
-  virtual void focusOutEvent(QFocusEvent *);
-
-private:
-  Ui::PluginErrorReportData *_ui;
+  void focusInEvent(QFocusEvent *) override;
+  void focusOutEvent(QFocusEvent *) override;
 };
 #endif // PLUGINERRORREPORT_H
