@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -32,13 +32,14 @@ class QNetworkReply;
 
 /**
   @brief The widget containing the Welcome screen in tulip_app.
-  This widget will allow a user to select an installed perspective, read latest news from the Tulip website, and display startup tips.
+  This widget will allow a user to select an installed perspective, read latest news from the Tulip
+  website, and display startup tips.
   */
-class TulipWelcomePage: public QWidget {
+class TulipWelcomePage : public QWidget {
   Q_OBJECT
 public:
-  explicit TulipWelcomePage(QWidget *parent=NULL);
-  virtual ~TulipWelcomePage();
+  explicit TulipWelcomePage(QWidget *parent = nullptr);
+  ~TulipWelcomePage() override;
 
 signals:
   void openPerspective(QString);
@@ -48,7 +49,7 @@ signals:
 protected slots:
   void rssReply(QNetworkReply *);
   void openLink(const QString &link);
-  void recentFileLinkActivated(const QString&);
+  void recentFileLinkActivated(const QString &);
 
 private:
   Ui::TulipWelcomePageData *_ui;
