@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (http://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,25 +20,20 @@
 #include "PluginErrorReport.h"
 
 #include <QFileInfo>
-#include <QDebug>
 
-#include "ui_PluginErrorReport.h"
-
-PluginErrorReport::PluginErrorReport(const QString &fileName, const QString &errorMsg, QWidget *parent): QWidget(parent), _ui(new Ui::PluginErrorReportData()) {
+PluginErrorReport::PluginErrorReport(const QString &fileName, const QString &errorMsg,
+                                     QWidget *parent)
+    : QLabel(parent) {
   setStyleSheet("#PluginErrorReportData { background-color: white; }");
-  _ui->setupUi(this);
 
   QFileInfo fileInfo(fileName);
-  _ui->fileName->setText("<html><head/><body><b>" + fileInfo.fileName() + "</b></body></head>");
-
-  _ui->errorMsg->setText("<p><span style=\"font-size:small;\">" +
-                         errorMsg +
-                         "</span></p>");
-
+  setText("<html><head/><body><p><b>" + fileInfo.fileName() +
+          "</b></p><p><span style=\"font-size:small;\">" + errorMsg + "</span></p></body></head>");
 }
 
 void PluginErrorReport::focusInEvent(QFocusEvent *) {
-  setStyleSheet("#PluginErrorReportData { background-color: rgb(232, 238, 244); border: 1px solid #C9C9C9; }");
+  setStyleSheet("#PluginErrorReportData { background-color: rgb(232, 238, 244); border: 1px solid "
+                "#C9C9C9; }");
   repaint();
 }
 
